# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""With Geostatistical Analyst, you can easily create a continuous
surface or map from measurements stored in a point feature layer or
raster layer or by using polygon centroids. The sample points may be
measurements such as elevation, depth to the water table, or levels of
pollution. Geostatistical Analyst provides a comprehensive set of
tools for creating surfaces that can be used to visualize, analyze,
and understand spatial phenomena."""
__all__ = ['ArealInterpolationLayerToPolygons', 'CreateSpatiallyBalancedPoints',
           'CrossValidation', 'DensifySamplingNetwork',
           'DiffusionInterpolationWithBarriers', 'EBKRegressionPrediction',
           'EmpiricalBayesianKriging', 'EmpiricalBayesianKriging3D',
           'ExtractValuesToTable', 'GACalculateZValue',
           'GACreateGeostatisticalLayer', 'GAGetModelParameter',
           'GALayerToContour', 'GALayerToGrid', 'GALayerToPoints',
           'GALayerToRasters', 'GAMovingWindowKriging',
           'GANeighborhoodSelection', 'GASemivariogramSensitivity',
           'GASetModelParameter', 'GaussianGeostatisticalSimulations',
           'GenerateSubsetPolygons', 'GlobalPolynomialInterpolation', 'IDW',
           'KernelInterpolationWithBarriers', 'LocalPolynomialInterpolation',
           'RadialBasisFunctions', 'SubsetFeatures']
__alias__ = 'ga'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
from arcpy import _ga
from arcpy._ga import *
__all__ += _ga.__all__

# Interpolation toolset
@gptooldoc('DiffusionInterpolationWithBarriers_ga', None)
def DiffusionInterpolationWithBarriers(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, in_barrier_features=None, bandwidth=None, number_iterations=None, weight_field=None, in_additive_barrier_raster=None, in_cumulative_barrier_raster=None, in_flow_barrier_raster=None):
    """DiffusionInterpolationWithBarriers_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {in_barrier_features}, {bandwidth}, {number_iterations}, {weight_field}, {in_additive_barrier_raster}, {in_cumulative_barrier_raster}, {in_flow_barrier_raster})

        Interpolates a surface using a kernel that is based upon the heat
        equation and allows one to use raster and feature barriers to redefine
        distances between input points.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      in_barrier_features {Feature Layer}:
          Absolute barrier features using non-Euclidean distances rather than
          line-of-sight distances.
      bandwidth {Double}:
          Used to specify the maximum distance at which data points are used
          for prediction. With increasing bandwidth, prediction bias increases
          and prediction variance decreases.
      number_iterations {Long}:
          The iteration count controls the accuracy of the numerical solution
          because the model solves the diffusion equation numerically. The
          larger this number, the more accurate the predictions, yet the longer
          the processing time. The more complex the barrier's geometry and the
          larger the bandwidth, the more iterations are required for accurate
          predictions.
      weight_field {Field}:
          Used to emphasize an observation. The larger the weight, the more
          impact it has on the prediction. For coincident observations, assign
          the largest weight to the most reliable measurement.
      in_additive_barrier_raster {Raster Layer}:
          The travel distance from one raster cell to the next based on this
          formula:(average cost value in the neighboring cells) x (distance
          between cell
          centers)
      in_cumulative_barrier_raster {Raster Layer}:
          The travel distance from one raster cell to the next based on this
          formula:(difference between cost values in the neighboring cells) +
          (distance
          between cell centers)
      in_flow_barrier_raster {Raster Layer}:
          A flow barrier is used when interpolating data with preferential
          direction of data variation, based on this formula:Indicator (cost
          values in the to neighboring cell > cost values in the
          from neighboring cell) * (cost values in the to neighboring cell -
          cost values in the from neighboring cell) + (distance between cell
          centers),where indicator(true) = 1 and indicator(false) = 0.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DiffusionInterpolationWithBarriers_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, in_barrier_features, bandwidth, number_iterations, weight_field, in_additive_barrier_raster, in_cumulative_barrier_raster, in_flow_barrier_raster), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EBKRegressionPrediction_ga', None)
def EBKRegressionPrediction(in_features=None, dependent_field=None, in_explanatory_rasters=None, out_ga_layer=None, out_raster=None, out_diagnostic_feature_class=None, measurement_error_field=None, min_cumulative_variance=None, in_subset_features=None, transformation_type=None, semivariogram_model_type=None, max_local_points=None, overlap_factor=None, number_simulations=None, search_neighborhood=None):
    """EBKRegressionPrediction_ga(in_features, dependent_field, in_explanatory_rasters;in_explanatory_rasters..., out_ga_layer, {out_raster}, {out_diagnostic_feature_class}, {measurement_error_field}, {min_cumulative_variance}, {in_subset_features}, {transformation_type}, {semivariogram_model_type}, {max_local_points}, {overlap_factor}, {number_simulations}, {search_neighborhood})

        EBK Regression Prediction is a geostatistical interpolation method
        that uses Empirical Bayesian Kriging with explanatory variable rasters
        that are known to affect the value of the data that you are
        interpolating. This approach combines kriging with regression analysis
        to make predictions that are more accurate than either regression or
        kriging can achieve on their own.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the field that will be
          interpolated.
      dependent_field (Field):
          The field of the Input dependent variable features containing the
          values of the dependent variable. This is the field that will be
          interpolated.
      in_explanatory_rasters (Raster Layer / Mosaic Layer):
          Input rasters representing the explanatory variables that will be used
          to build the regression model. These rasters should represent
          variables that are known to influence the values of the dependent
          variable. For example, when interpolating temperature data, an
          elevation raster should be used as an explanatory variable because
          temperature is influenced by elevation. You can use up to 62
          explanatory rasters.
      measurement_error_field {Field}:
          A field that specifies the measurement error for each point in the
          dependent variable features. For each point, the value of this field
          should correspond to one standard deviation of the measured value of
          the point. Use this field if the measurement error values are not the
          same at each point.A common source of nonconstant measurement error is
          when the data is
          measured with different devices. One device might be more precise than
          another, which means that it will have a smaller measurement error.
          For example, one thermometer rounds to the nearest degree and another
          thermometer rounds to the nearest tenth of a degree. The variability
          of measurements is often provided by the manufacturer of the measuring
          device, or it may be known from empirical practice.Leave this
          parameter empty if there are no measurement error values or
          the measurement error values are unknown.
      min_cumulative_variance {Double}:
          Defines the minimum cumulative percent of variance from the principal
          components of the explanatory variable rasters. Before building the
          regression model, the principal components of the explanatory
          variables are calculated, and these principal components are used as
          explanatory variables in the regression. Each principal component
          captures a certain percent of the variance of the explanatory
          variables, and this parameter controls the minimum percent of variance
          that must be captured by the principal components of each local model.
          For example, if a value of 75 is provided, the software will use the
          minimum number of principal components that are necessary to capture
          at least 75 percent of the variance of the explanatory
          variables.Principal components are all mutually uncorrelated with each
          other, so
          using principal components solves the problem of multicollinearity
          (explanatory variables that are correlated with each other). Most of
          the information contained in all explanatory variables can frequently
          be captured in just a few principal components. By discarding the
          least useful principal components, the model calculation becomes more
          stable and efficient without significant loss of accuracy.To calculate
          principal components, there must be variability in the
          explanatory variables, so if any of your Input explanatory variable
          rasters contain constant values within a subset, these constant
          rasters will not be used to compute principal components for that
          subset. If all explanatory variable rasters in a subset contain
          constant values, the Output diagnostic feature class will report that
          zero principal components were used and that they captured zero
          percent of the variability.
      in_subset_features {Feature Layer}:
          Polygon features defining where the local models will be calculated.
          The points inside each polygon will be used for the local models. This
          parameter is useful when you know that the values of the dependent
          variable changes according to known regions. For example, these
          polygons may represent administrative health districts where health
          policy changes in different districts.You can also use the Generate
          Subset Polygons tool to create subset
          polygons. The polygons created by this tool will be non-overlapping
          and compact.
      transformation_type {String}:
          Type of transformation to be applied to the input data.

          * NONE-Do not apply any transformation. This is the default.

          * EMPIRICAL-Multiplicative Skewing transformation with Empirical base
          function.

          * LOGEMPIRICAL-Multiplicative Skewing transformation with Log
          Empirical base function. All data values must be positive. If this
          option is chosen, all predictions will be positive.
      semivariogram_model_type {String}:
          The semivariogram model that will be used for the interpolation.

          * EXPONENTIAL-Exponential semivariogram

          * NUGGET-Nugget semivariogram

          * WHITTLE-Whittle semivariogram

          * K_BESSEL-K-Bessel semivariogram
      max_local_points {Long}:
          The input data will automatically be divided into subsets that do not
          have more than this number of points. If Subset polygon features are
          supplied, the value of this parameter will be ignored.
      overlap_factor {Double}:
          A factor representing the degree of overlap between local models (also
          called subsets). Each input point can fall into several subsets, and
          the overlap factor specifies the average number of subsets that each
          point will fall into. A high value of the overlap factor makes the
          output surface smoother, but it also increases processing time. Values
          must be between 1 and 5. If Subset polygon features are supplied, the
          value of this parameter will be ignored.
      number_simulations {Long}:
          The number of simulated semivariograms of each local model. Using more
          simulations will make the model calculations more stable, but the
          model will take longer to calculate.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Defines which surrounding points will be used to control the output.
          Standard is the default.The following are Search Neighborhood classes:
          SearchNeighborhoodStandardCircular and
          SearchNeighborhoodSmoothCircular.Standard Circular

          * radius-The length of the radius of the search circle.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth Circular

          * radius-The length of the radius of the search circle.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.

     OUTPUTS:
      out_ga_layer (Geostatistical Layer):
          The output geostatistical layer displaying the result of the
          interpolation.
      out_raster {Raster Dataset}:
          The output raster displaying the result of the interpolation. The
          default cell size will be the maximum of the cell sizes of the Input
          explanatory variable rasters. To use a different cell size, use the
          cell size environmental setting.
      out_diagnostic_feature_class {Feature Class}:
          Output polygon feature class that shows the regions of each local
          model and contains fields with diagnostic information for the local
          models. For each subset, a polygon will be created that surrounds the
          points in the subset so you can easily identify which points were used
          in each subset. For example, if there are 10 local models, there will
          be ten polygons in this output. The feature class will contain the
          following fields:

          * Number of Principal Components (PrincComps)-The number of principal
          components that were used as explanatory variables. The value will
          always be less than or equal to the number of explanatory variable
          rasters.

          * Percent of Variance (PercVar)-The percent of variance captured by
          the principal components. This value will be greater than or equal to
          the value specified in the Minimum cumulative percent of variance
          parameter below.

          * Root Mean Square Error (RMSE)-The square root of the average squared
          cross-validation errors. The smaller this value, the better the model
          fits.

          * Percent 90 Interval (Perc90)-The percent of data points that fall
          within a 90 percent cross-validation confidence interval. Ideally,
          this number should be close to 90. A value significantly smaller than
          90 indicates that standard errors are being underestimated. A value
          significantly larger than 90 indicates that standard errors are being
          overestimated.

          * Percent 95 Interval (Perc95)-The percent of data points that fall
          within a 95 percent cross-validation confidence interval. Ideally,
          this number should be close to 95. A value significantly smaller than
          95 indicates that standard errors are being underestimated. A value
          significantly larger than 95 indicates that standard errors are being
          overestimated.

          * Mean Absolute Error (MeanAbsErr)-The average of the absolute values
          of the cross-validation errors. This value should be as small as
          possible. It is similar to Root Mean Square Error, but it is less
          influenced by extreme values.

          * Mean Error (MeanError)-The average of the cross-validation errors.
          This value should be close to zero. A value significantly different
          than zero indicates that the predictions are biased.

          * Continuous Ranked Probability Score (CRPS)-The continuous ranked
          probability score is a diagnostic that measures the deviation from the
          predictive cumulative distribution function to each observed data
          value. This value should be as small as possible. This diagnostic has
          advantages over cross-validation diagnostics because it compares the
          data to a full distribution rather than to single-point predictions."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EBKRegressionPrediction_ga(*gp_fixargs((in_features, dependent_field, in_explanatory_rasters, out_ga_layer, out_raster, out_diagnostic_feature_class, measurement_error_field, min_cumulative_variance, in_subset_features, transformation_type, semivariogram_model_type, max_local_points, overlap_factor, number_simulations, search_neighborhood), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EmpiricalBayesianKriging_ga', None)
def EmpiricalBayesianKriging(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, transformation_type=None, max_local_points=None, overlap_factor=None, number_semivariograms=None, search_neighborhood=None, output_type=None, quantile_value=None, threshold_type=None, probability_threshold=None, semivariogram_model_type=None):
    """EmpiricalBayesianKriging_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {transformation_type}, {max_local_points}, {overlap_factor}, {number_semivariograms}, {search_neighborhood}, {output_type}, {quantile_value}, {threshold_type}, {probability_threshold}, {semivariogram_model_type})

        Empirical Bayesian kriging is an interpolation method that accounts
        for the error in estimating the underlying semivariogram through
        repeated simulations.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      transformation_type {String}:
          Type of transformation to be applied to the input data.

          * NONE-Do not apply any transformation. This is the default.

          * EMPIRICAL-Multiplicative Skewing transformation with Empirical base
          function.

          * LOGEMPIRICAL-Multiplicative Skewing transformation with Log
          Empirical base function. All data values must be positive. If this
          option is chosen, all predictions will be positive.
      max_local_points {Long}:
          The input data will automatically be divided into groups that do not
          have more than this number of points.
      overlap_factor {Double}:
          A factor representing the degree of overlap between local models (also
          called subsets). Each input point can fall into several subsets, and
          the overlap factor specifies the average number of subsets that each
          point will fall into. A high value of the overlap factor makes the
          output surface smoother, but it also increases processing time.
          Typical values vary between 0.01 and 5.
      number_semivariograms {Long}:
          The number of simulated semivariograms of each local model.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Defines which surrounding points will be used to control the output.
          Standard Circular is the default.The following are Search Neighborhood
          classes:
          SearchNeighborhoodStandardCircular and
          SearchNeighborhoodSmoothCircular.Standard Circular

          * radius-The length of the radius of the search circle.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth Circular

          * radius-The length of the radius of the search circle.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.
      output_type {String}:
          Surface type to store the interpolation results.For more information
          about the output surface types, see What output
          surface types can the interpolation models generate?

          * PREDICTION-Prediction surfaces are produced from the interpolated
          values.

          * PREDICTION_STANDARD_ERROR-Standard Error surfaces are produced from
          the standard errors of the interpolated values.

          * PROBABILITY-Probability surface of values exceeding or not exceeding
          a certain threshold.

          * QUANTILE-Quantile surface predicting the specified quantile of the
          prediction distribution.
      quantile_value {Double}:
          The quantile value for which the output raster will be generated.
      threshold_type {String}:
          Specifies whether to calculate the probability of exceeding or not
          exceeding the specified threshold.

          * EXCEED-Probability values exceed the threshold. This is the default.

          * NOT_EXCEED-Probability values will not exceed the threshold.
      probability_threshold {Double}:
          The probability threshold value. If left empty, the median (50th
          quantile) of the input data will be used.
      semivariogram_model_type {String}:
          The semivariogram model that will be used for the interpolation.

          * POWER-Power semivariogram

          * LINEAR-Linear semivariogram

          * THIN_PLATE_SPLINE-Thin Plate Spline semivariogram

          * EXPONENTIAL-Exponential semivariogram

          * EXPONENTIAL_DETRENDED-Exponential semivariogram with first order
          trend removal

          * WHITTLE-Whittle semivariogram

          * WHITTLE_DETRENDED-Whittle semivariogram with first order trend
          removal

          * K_BESSEL-K-Bessel semivariogram

          * K_BESSEL_DETRENDED-K-Bessel semivariogram with first order trend
          removal
          The available choices depend on the value of the transformation_type
          parameter. If the transformation type is set to , only the first three
          semivariograms are available. If the type is EMPIRICAL or
          LOGEMPIRICAL, the last six semivariograms are available.For more
          information about choosing an appropriate semivariogram for
          your data, see the topic What is Empirical Bayesian Kriging.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EmpiricalBayesianKriging_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, transformation_type, max_local_points, overlap_factor, number_semivariograms, search_neighborhood, output_type, quantile_value, threshold_type, probability_threshold, semivariogram_model_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EmpiricalBayesianKriging3D_ga', None)
def EmpiricalBayesianKriging3D(in_features=None, elevation_field=None, value_field=None, out_ga_layer=None, elevation_units=None, measurement_error_field=None, semivariogram_model_type=None, transformation_type=None, subset_size=None, overlap_factor=None, number_simulations=None, trend_removal=None, elev_inflation_factor=None, search_neighborhood=None, output_elevation=None, output_type=None, quantile_value=None, threshold_type=None, probability_threshold=None):
    """EmpiricalBayesianKriging3D_ga(in_features, elevation_field, value_field, out_ga_layer, {elevation_units}, {measurement_error_field}, {semivariogram_model_type}, {transformation_type}, {subset_size}, {overlap_factor}, {number_simulations}, {trend_removal}, {elev_inflation_factor}, {search_neighborhood}, {output_elevation}, {output_type}, {quantile_value}, {threshold_type}, {probability_threshold})

        Empirical Bayesian kriging 3D is a geostatistical interpolation method
        that uses Empirical Bayesian Kriging to interpolate 3D point data. All
        points must have x-, y-, and z-coordinates and a measured value to be
        interpolated. The output is a 3D geostatistical layer that calculates
        and renders itself as a 2D transect at a given elevation. The
        elevation of the layer can be changed with the range slider, and the
        layer will update to show the interpolated predictions for the new
        elevation.3D interpolation has the following potential applications:

        * Oceanographers can create maps of dissolved oxygen and salinity at
        various depths in the ocean.

        * Atmospheric scientists can create models for pollution and
        greenhouse gasses throughout the atmosphere.

        * Geologists can predict subsurface geologic properties such as
        mineral concentrations and porosity.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the field that will be
          interpolated.
      elevation_field (Field):
          The in_features field containing the elevation value of each input
          point.If the elevation values are stored as geometry attributes in
          Shape.Z,
          it is recommended that you use that field. If the elevation values are
          stored in an attribute field, the elevation values must indicate
          distance from sea level. Positive values indicate distance above sea
          level, and negative values indicate distance below sea level.
      value_field (Field):
          The in_features field containing the measured values that will be
          interpolated.
      elevation_units {String}:
          The units of the elevation_field.If Shape.Z is provided as the
          elevation field, the units will
          automatically match the z-units of the vertical coordinate system.

          * INCH-Elevations are in inches.

          * FOOT-Elevations are in feet.

          * YARD-Elevations are in yards.

          * MILE_US-Elevations are in US miles.

          * NAUTICAL_MILE-Elevations are in nautical miles.

          * MILLIMETER-Elevations are in millimeters.

          * CENTIMETER-Elevations are in centimeters.

          * DECIMETER-Elevations are in decimeters.

          * METER-Elevations are in meters.

          * KILOMETER-Elevations are in kilometers.
      measurement_error_field {Field}:
          Specifies the measurement error for each point in the input features.
          For each point, the value of this field should correspond to one
          standard deviation of the measured value of the point. Use this field
          if the measurement error values are not the same at each point.A
          common source of nonconstant measurement error is when the data is
          measured with different devices. One device may be more precise than
          another, which means that it will have a smaller measurement error.
          For example, a thermometer rounds to the nearest degree and another
          thermometer rounds to the nearest tenth of a degree. The variability
          of measurements is often provided by the manufacturer of the measuring
          device, or it may be known from empirical practice.Leave this
          parameter empty if there are no measurement error values or
          the measurement error values are unknown.
      semivariogram_model_type {String}:
          The semivariogram model that will be used for the interpolation.

          * POWER-Power semivariogram

          * LINEAR-Linear semivariogram

          * THIN_PLATE_SPLINE-Thin plate spline semivariogram

          * EXPONENTIAL-Exponential semivariogram

          * WHITTLE-Whittle semivariogram

          * K_BESSEL-K-Bessel semivariogram
      transformation_type {String}:
          The type of transformation to be applied to the input features.

          * NONE-Do not apply any transformation. This is the default.

          * EMPIRICAL-Multiplicative Skewing transformation with Empirical base
          function is applied.

          * LOGEMPIRICAL-Multiplicative Skewing transformation with Log
          Empirical base function is applied. All data values must be positive.
          If this option is chosen, all predictions will be positive.
      subset_size {Long}:
          The size of the subset. The input data will automatically be divided
          into subsets before processing. This parameter controls the number of
          points that will be in each subset.
      overlap_factor {Double}:
          A factor representing the degree of overlap between local models (also
          called subsets).Each input point can fall into several subsets, and
          the overlap factor
          specifies the average number of subsets into which each point will
          fall. A high value of the overlap factor produces a smoother output
          surface, but it also increases processing time. Values must be between
          1 and 5. The actual overlap that will be used will usually be larger
          than this value, so each subset will contain the same number of
          points.
      number_simulations {Long}:
          The number of simulated semivariograms of each local model.Using more
          simulations will make the model calculations more stable,
          but the model will take longer to calculate.
      trend_removal {String}:
          The order of trend removal in the vertical direction.For most data in
          three dimensions, the values of the points change
          faster vertically than they do horizontally. Removing trend in the
          vertical direction will help alleviate this and stabilize
          calculations.

          * NONE-Do not remove trend. This is the default.

          * FIRST-Remove first order vertical trend.
      elev_inflation_factor {Double}:
          A constant value that is multiplied by the Elevation field value prior
          to subsetting and model estimation. For most data in three dimensions,
          the values of the points change faster vertically than they do
          horizontally, and this factor stretches the locations of the points
          such that one unit of distance vertically is statistically equivalent
          to one unit of distance horizontally. The locations of the points will
          be moved back to their original locations before returning the result
          of the interpolation. This correction is needed to accurately estimate
          the semivariogram model and for the Search neighborhood to use the
          correct neighbors. The elevation inflation factor is unitless and will
          provide the same results regardless of the units of the x-, y-, or
          z-coordinate of the input points.If no value is provided for this
          parameter, one will be calculated at
          run time using maximum likelihood estimation. The value will be
          printed as a geoprocessing message. The value calculated at run time
          will be between 1 and 1000. However, you can type values between 0.01
          and 1,000,000. If the calculated value is equal to 1 or 1000, you can
          provide values outside that range and choose a value based on cross
          validation.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Specifies the number and orientation of neighbors using the
          SearchNeighborhoodStandard3D class.Standard3D

          * radius-The length of the radius of the search neighborhood.

          * nbrMax-The maximum number of neighbors per sector that will be used
          to estimate the value at the unknown location.

          * nbrMin-The minimum number of neighbors per sector that will be used
          to estimate the value at the unknown location.

          * sectorType-The geometry of the 3D neighborhood. Sectors are used to
          ensure that neighbors are used in different directions around the
          prediction location. All sector types are formed from the Platonic
          solids.

          * ONE_SECTOR-The closest neighbors from any direction will be used.

          * FOUR_SECTORS-Divides space into four regions, and neighbors will be
          used in each of the four regions.

          * SIX_SECTORS-Divides space into six regions, and neighbors will be
          used in each of the six regions.

          * EIGHT_SECTORS-Divides space into eight regions, and neighbors will
          be used in each of the eight regions.

          * TWELVE_SECTORS-Divides space into twelve regions, and neighbors will
          be used in each of the twelve regions.

          * TWENTY_SECTORS-Divides space into twenty regions, and neighbors will
          be used in each of the twenty regions.
      output_elevation {Double}:
          The default elevation of the out_ga_layer.The geostatistical layer
          will always draw as a horizontal surface at a
          given elevation, and this parameter specifies this elevation. After
          it's created, the elevation of the geostatistical layer can be changed
          using the range slider.
      output_type {String}:
          Surface type to store the interpolation results.For more information
          about output surface types, see What output
          surface types can the interpolation models generate?

          * PREDICTION-Prediction surfaces are produced from the interpolated
          values.

          * PREDICTION_STANDARD_ERROR-Standard Error surfaces are produced from
          the standard errors of the interpolated values.

          * PROBABILITY-Probability surface of values exceeding or not exceeding
          a certain threshold.

          * QUANTILE-Quantile surface predicting the specified quantile of the
          prediction distribution.
      quantile_value {Double}:
          The quantile value for which the output layer will be generated.
      threshold_type {String}:
          Specifies whether to calculate the probability of exceeding or not
          exceeding the specified threshold.

          * EXCEED-Probability values exceed the threshold. This is the default.

          * NOT_EXCEED-Probability values will not exceed the threshold.
      probability_threshold {Double}:
          The probability threshold value. If left empty, the median (50th
          quantile) of the input data will be used.

     OUTPUTS:
      out_ga_layer (Geostatistical Layer):
          The output geostatistical layer that will display the interpolation
          result."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EmpiricalBayesianKriging3D_ga(*gp_fixargs((in_features, elevation_field, value_field, out_ga_layer, elevation_units, measurement_error_field, semivariogram_model_type, transformation_type, subset_size, overlap_factor, number_simulations, trend_removal, elev_inflation_factor, search_neighborhood, output_elevation, output_type, quantile_value, threshold_type, probability_threshold), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GAMovingWindowKriging_ga', None)
def GAMovingWindowKriging(in_ga_model_source=None, in_datasets=None, in_locations=None, neighbors_max=None, out_featureclass=None, cell_size=None, out_surface_grid=None):
    """GAMovingWindowKriging_ga(in_ga_model_source, in_datasets;in_datasets..., in_locations, neighbors_max, out_featureclass, {cell_size}, {out_surface_grid})

        Recalculates the Range, Nugget, and Partial Sill semivariogram
        parameters based on a smaller neighborhood, moving through all
        location points.

     INPUTS:
      in_ga_model_source (Geostatistical Layer / File):
          The geostatistical model source to be analyzed.
      in_datasets (Geostatistical Value Table):
          A GeostatisticalDatasets object.Alternatively, it can be a semicolon-
          delimited string of elements.
          Each element is comprised of the following components:

          * The catalog path and name to a dataset or the name of a layer in the
          current table of contents, followed by a space.

          * A sequence of field names, each field name separated by a space. In
          the case of a raster, the cell values will be used.
      in_locations (Feature Layer):
          Point locations where predictions will be performed.
      neighbors_max (Long):
          Number of neighbors to use in the moving window.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.

     OUTPUTS:
      out_featureclass (Feature Class):
          Feature class storing the results.
      out_surface_grid {Raster Dataset}:
          The prediction values in the output feature class are interpolated
          onto a raster using the Local polynomial interpolation method."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GAMovingWindowKriging_ga(*gp_fixargs((in_ga_model_source, in_datasets, in_locations, neighbors_max, out_featureclass, cell_size, out_surface_grid), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GlobalPolynomialInterpolation_ga', None)
def GlobalPolynomialInterpolation(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, power=None, weight_field=None):
    """GlobalPolynomialInterpolation_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {power}, {weight_field})

        Fits a smooth surface that is defined by a mathematical function (a
        polynomial) to the input sample points.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      power {Long}:
          The order of the polynomial.
      weight_field {Field}:
          Used to emphasize an observation. The larger the weight, the more
          impact it has on the prediction. For coincident observations, assign
          the largest weight to the most reliable measurement.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GlobalPolynomialInterpolation_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, power, weight_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('IDW_ga', None)
def IDW(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, power=None, search_neighborhood=None, weight_field=None):
    """IDW_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {power}, {search_neighborhood}, {weight_field})

        Uses the measured values surrounding the prediction location to
        predict a value for any unsampled location, based on the assumption
        that things that are close to one another are more alike than those
        that are farther apart.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      power {Double}:
          The exponent of distance that controls the significance of surrounding
          points on the interpolated value. A higher power results in less
          influence from distant points.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Defines which surrounding points will be used to control the output.
          Standard is the default.The following are Search Neighborhood classes:
          SearchNeighborhoodStandard, SearchNeighborhoodSmooth,
          SearchNeighborhoodStandardCircular, and
          SearchNeighborhoodSmoothCircular.Standard

          * majorSemiaxis-The major semiaxis value of the searching
          neighborhood.

          * minorSemiaxis-The minor semiaxis value of the searching
          neighborhood.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth

          * majorSemiaxis-The major semiaxis value of the searching
          neighborhood.

          * minorSemiaxis-The minor semiaxis value of the searching
          neighborhood.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.
          Standard Circular

          * radius-The length of the radius of the search circle.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth Circular

          * radius-The length of the radius of the search circle.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.
      weight_field {Field}:
          Used to emphasize an observation. The larger the weight, the more
          impact it has on the prediction. For coincident observations, assign
          the largest weight to the most reliable measurement.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.IDW_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, power, search_neighborhood, weight_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('KernelInterpolationWithBarriers_ga', None)
def KernelInterpolationWithBarriers(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, in_barrier_features=None, kernel_function=None, bandwidth=None, power=None, ridge=None, output_type=None):
    """KernelInterpolationWithBarriers_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {in_barrier_features}, {kernel_function}, {bandwidth}, {power}, {ridge}, {output_type})

        A moving window predictor that uses the shortest distance between
        points so that points on either side of the line barriers are
        connected.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      in_barrier_features {Feature Layer}:
          Absolute barrier features using non-Euclidean distances rather than
          line-of-sight distances.
      kernel_function {String}:
          The kernel function used in the simulation.

          * EXPONENTIAL-The function grows or decays proportionally.

          * GAUSSIAN-Bell-shaped function that falls off quickly toward
          plus/minus infinity.

          * QUARTIC-Fourth-order polynomial function.

          * EPANECHNIKOV-A discontinuous parabolic function.

          * POLYNOMIAL5-Fifth-order polynomial function.

          * CONSTANT-An indicator function.
      bandwidth {Double}:
          Used to specify the maximum distance at which data points are used
          for prediction. With increasing bandwidth, prediction bias increases
          and prediction variance decreases.
      power {Long}:
          Sets the order of the polynomial.
      ridge {Double}:
          Used for the numerical stabilization of the solution of the system of
          linear equations. It does not influence predictions in the case of
          regularly distributed data without barriers. Predictions for areas in
          which the data is located near the feature barrier or isolated by the
          barriers can be unstable and tend to require relatively large ridge
          parameter values.
      output_type {String}:
          Surface type to store the interpolation results.For more information
          about the output surface types, see What output
          surface types can the interpolation models generate?

          * PREDICTION-Prediction surfaces are produced from the interpolated
          values.

          * PREDICTION_STANDARD_ERROR-Standard Error surfaces are produced from
          the standard errors of the interpolated values.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.KernelInterpolationWithBarriers_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, in_barrier_features, kernel_function, bandwidth, power, ridge, output_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('LocalPolynomialInterpolation_ga', None)
def LocalPolynomialInterpolation(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, power=None, search_neighborhood=None, kernel_function=None, bandwidth=None, use_condition_number=None, condition_number=None, weight_field=None, output_type=None):
    """LocalPolynomialInterpolation_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {power}, {search_neighborhood}, {kernel_function}, {bandwidth}, {use_condition_number}, {condition_number}, {weight_field}, {output_type})

        Fits the specified order (zero, first, second, third, and so on)
        polynomial, each within specified overlapping neighborhoods, to
        produce an output surface.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      power {Long}:
          The order of the polynomial.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Defines which surrounding points will be used to control the output.
          Standard is the default.The following are Search Neighborhood classes:
          SearchNeighborhoodStandard, SearchNeighborhoodSmooth,
          SearchNeighborhoodStandardCircular, and
          SearchNeighborhoodSmoothCircular.Standard

          * majorSemiaxis-The major semiaxis value of the searching
          neighborhood.

          * minorSemiaxis-The minor semiaxis value of the searching
          neighborhood.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth

          * majorSemiaxis-The major semiaxis value of the searching
          neighborhood.

          * minorSemiaxis-The minor semiaxis value of the searching
          neighborhood.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.
          Standard Circular

          * radius-The length of the radius of the search circle.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Smooth Circular

          * radius-The length of the radius of the search circle.

          * smoothFactor-The Smooth Interpolation option creates an outer
          ellipse and an inner ellipse at a distance equal to the Major Semiaxis
          multiplied by the Smoothing factor. The points that fall outside the
          smallest ellipse but inside the largest ellipse are weighted using a
          sigmoidal function with a value between zero and one.
      kernel_function {String}:
          The kernel function used in the simulation.

          * EXPONENTIAL-The function grows or decays proportionally.

          * GAUSSIAN-Bell-shaped function that falls off quickly toward plus or
          minus infinity.

          * QUARTIC-Fourth-order polynomial function.

          * EPANECHNIKOV-A discontinuous parabolic function.

          * POLYNOMIAL5-Fifth-order polynomial function.

          * CONSTANT-An indicator function.
      bandwidth {Double}:
          Used to specify the maximum distance at which data points are used
          for prediction. With increasing bandwidth, prediction bias increases
          and prediction variance decreases.
      use_condition_number {Boolean}:
          Option to control the creation of prediction and prediction standard
          errors where the predictions are unstable. This option is only
          available for polynomials of order 1, 2, and 3.

          * NO_USE_CONDITION_NUMBER-Predictions will be created everywhere,
          including areas where the predictions are unstable. This is the
          default.

          * USE_CONDITION_NUMBER-Prediction and prediction standard errors will
          not be created where the predictions are unstable.
      condition_number {Double}:
          Every invertible square matrix has a condition number that indicates
          how inaccurate the solution to the linear equations can be with a
          small change in the matrix coefficients (it can be due to imprecise
          data). If the condition number is large, a small change in the matrix
          coefficients results in a large change in the solution vector.
      weight_field {Field}:
          Used to emphasize an observation. The larger the weight, the more
          impact it has on the prediction. For coincident observations, assign
          the largest weight to the most reliable measurement.
      output_type {String}:
          Surface type to store the interpolation results.For more information
          about the output surface types, see What output
          surface types can the interpolation models generate?

          * PREDICTION-Prediction surfaces are produced from the interpolated
          values.

          * PREDICTION_STANDARD_ERROR-Standard Error surfaces are produced from
          the standard errors of the interpolated values.

          * CONDITION_NUMBER-The Spatial condition number surface indicates the
          stability of calculations at a particular location. The larger the
          condition number, the more unstable the prediction, so locations with
          large condition numbers may be prone to artifacts and erratic
          predicted values.

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.LocalPolynomialInterpolation_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, power, search_neighborhood, kernel_function, bandwidth, use_condition_number, condition_number, weight_field, output_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RadialBasisFunctions_ga', None)
def RadialBasisFunctions(in_features=None, z_field=None, out_ga_layer=None, out_raster=None, cell_size=None, search_neighborhood=None, radial_basis_functions=None, small_scale_parameter=None):
    """RadialBasisFunctions_ga(in_features, z_field, {out_ga_layer}, {out_raster}, {cell_size}, {search_neighborhood}, {radial_basis_functions}, {small_scale_parameter})

        Uses one of five basis functions to interpolate a surfaces that passes
        through the input points exactly.

     INPUTS:
      in_features (Feature Layer):
          The input point features containing the z-values to be interpolated.
      z_field (Field):
          Field that holds a height or magnitude value for each point. This can
          be a numeric field or the Shape field if the input features contain
          z-values or m-values.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      search_neighborhood {Geostatistical Search Neighborhood}:
          Defines which surrounding points will be used to control the output.
          Standard is the default.The following are Search Neighborhood classes:
          SearchNeighborhoodStandard and
          SearchNeighborhoodStandardCircular.Standard

          * majorSemiaxis-The major semiaxis value of the searching
          neighborhood.

          * minorSemiaxis-The minor semiaxis value of the searching
          neighborhood.

          * angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.

          Standard Circular

          * radius-The length of the radius of the search circle.

          * Angle-The angle of rotation for the axis (circle) or semimajor axis
          (ellipse) of the moving window.

          * nbrMax-The maximum number of neighbors that will be used to estimate
          the value at the unknown location.

          * nbrMin-The minimum number of neighbors that will be used to estimate
          the value at the unknown location.

          * sectorType-The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse.

          * FOUR_SECTORS-Ellipse divided into four sectors.

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees.

          * EIGHT_SECTORS-Ellipse divided into eight sectors.
      radial_basis_functions {String}:
          There are five radial basis functions available.

          * THIN_PLATE_SPLINE-Thin-plate spline function

          * SPLINE_WITH_TENSION-Spline with tension function

          * COMPLETELY_REGULARIZED_SPLINE-Completely regularized spline
          function

          * MULTIQUADRIC_FUNCTION-Multiquadric spline function

          * INVERSE_MULTIQUADRIC_FUNCTION-Inverse multiquadric spline function
      small_scale_parameter {Double}:
          Used to calculate the weights assigned to the points located in the
          moving window. Each of the radial basis functions has a parameter that
          controls the degree of small-scale variation of the surface. The
          (optimal) parameter is determined by finding the value that minimizes
          the root mean square prediction error (RMSPE).

     OUTPUTS:
      out_ga_layer {Geostatistical Layer}:
          The geostatistical layer produced. This layer is required output only
          if no output raster is requested.
      out_raster {Raster Dataset}:
          The output raster. This raster is required output only if no output
          geostatistical layer is requested."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RadialBasisFunctions_ga(*gp_fixargs((in_features, z_field, out_ga_layer, out_raster, cell_size, search_neighborhood, radial_basis_functions, small_scale_parameter), True)))
        return retval
    except Exception as e:
        raise e


# Sampling Network Design toolset
@gptooldoc('CreateSpatiallyBalancedPoints_ga', None)
def CreateSpatiallyBalancedPoints(in_probability_raster=None, number_output_points=None, out_feature_class=None):
    """CreateSpatiallyBalancedPoints_ga(in_probability_raster, number_output_points, out_feature_class)

        Generates a set of sample points based on inclusion probabilities,
        resulting in a spatially balanced sample design. This tool is
        generally used for designing a monitoring network by suggesting
        locations to take samples, and a preference for particular locations
        can be defined using an inclusion probability raster.

     INPUTS:
      in_probability_raster (Raster Layer / Mosaic Layer):
          This raster defines the inclusion probabilities for each location in
          the area of interest. The location values range from 0 (low inclusion
          probability) to 1 (high inclusion probability).
      number_output_points (Long):
          Specify how many sample locations to generate.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class contains the selected sample locations and
          their inclusion probabilities."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateSpatiallyBalancedPoints_ga(*gp_fixargs((in_probability_raster, number_output_points, out_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DensifySamplingNetwork_ga', None)
def DensifySamplingNetwork(in_geostat_layer=None, number_output_points=None, out_feature_class=None, selection_criteria=None, threshold=None, in_weight_raster=None, in_candidate_point_features=None, inhibition_distance=None):
    """DensifySamplingNetwork_ga(in_geostat_layer, number_output_points, out_feature_class, {selection_criteria}, {threshold}, {in_weight_raster}, {in_candidate_point_features}, {inhibition_distance})

        Uses a predefined geostatistical kriging layer to determine where new
        monitoring stations should be built. It can also be used to determine
        which monitoring stations should be removed from an existing network.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          Input a geostatistical layer resulting from a Kriging model.
      number_output_points (Long):
          Specify how many sample locations to generate.
      selection_criteria {String}:
          Methods to densify a sampling network.

          * STDERR-Standard error of prediction criteria

          * STDERR_THRESHOLD-Standard error threshold criteria

          * QUARTILE_THRESHOLD-Lower quartile threshold criteria

          * QUARTILE_THRESHOLD_UPPER-Upper quartile threshold criteria
          The STERR option will give extra weight to locations where the
          standard error of prediction is large. The STDERR_THRESHOLD,
          QUARTILE_THRESHOLD, and QUARTILE_THRESHOLD_UPPER options are useful
          when there is a critical threshold value for the variable under study
          (such as the highest admissible ozone level). The STDERR_THRESHOLD
          option will give extra weight to locations whose values are close to
          the threshold. The QUARTILE_THRESHOLD option will give extra weight to
          locations that are least likely to exceed the critical threshold. The
          QUARTILE_THRESHOLD_UPPER option will give extra weight to locations
          that are most likely to exceed the critical threshold.The equations
          for each option are:Standard error of prediction =
          stderr  Standard error threshold =
          stderr(s)(1 - 2 · abs(prob[Z(s) > threshold] - 0.5))  Lower quartile
          threshold = (Z0.75(s) - Z0.25(s)) · (prob[Z(s) < threshold])  Upper
          quartile threshold = (Z0.75(s) - Z0.25(s)) · (prob[Z(s) > threshold])
      threshold {Double}:
          The threshold value used to densify the sampling network.This
          parameter is only applicable when Standard error threshold, Lower
          quartile threshold, or Upper quartile threshold selection criteria is
          used.
      in_weight_raster {Raster Layer}:
          A raster used to determine which locations to weight for preference.
      in_candidate_point_features {Feature Layer}:
          Sample locations to pick from.
      inhibition_distance {Linear Unit}:
          Used to prevent any samples being placed within this distance from
          each other.

     OUTPUTS:
      out_feature_class (Feature Class):
          The name of the output feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DensifySamplingNetwork_ga(*gp_fixargs((in_geostat_layer, number_output_points, out_feature_class, selection_criteria, threshold, in_weight_raster, in_candidate_point_features, inhibition_distance), True)))
        return retval
    except Exception as e:
        raise e


# Simulation toolset
@gptooldoc('ExtractValuesToTable_ga', None)
def ExtractValuesToTable(in_features=None, in_rasters=None, out_table=None, out_raster_names_table=None, add_warning_field=None):
    """ExtractValuesToTable_ga(in_features, in_rasters;in_rasters..., out_table, {out_raster_names_table}, {add_warning_field})

        Extracts cell values from a set of rasters to a table, based on a
        point or polygon feature class.

     INPUTS:
      in_features (Feature Layer):
          The points or polygon features to be created.
      in_rasters (Raster Layer / Mosaic Layer):
          The rasters must all have the same extent, coordinate system, and cell
          size.
      add_warning_field {Boolean}:
          Records if input features are partially or completely covered by the
          Input rasters.

          * ADD_WARNING_FIELD-Warning field is added to the output table and
          populated with a P when a feature is partially covered by raster
          values.

          * DO_NOT_ADD_WARNING_FIELD-Warning field is not added to the output
          table.

     OUTPUTS:
      out_table (Table):
          The output table contains a record for each point and each raster that
          has data. If polygon features are input, they are converted to points
          that coincide with the raster cell centers.
      out_raster_names_table {Table}:
          Saves the names of the Input rasters to disc."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtractValuesToTable_ga(*gp_fixargs((in_features, in_rasters, out_table, out_raster_names_table, add_warning_field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GaussianGeostatisticalSimulations_ga', None)
def GaussianGeostatisticalSimulations(in_geostat_layer=None, number_of_realizations=None, output_workspace=None, output_simulation_prefix=None, in_conditioning_features=None, conditioning_field=None, cell_size=None, in_bounding_dataset=None, save_simulated_rasters=None, quantile=None, threshold=None, in_stats_polygons=None, raster_stat_type=None, conditioning_measurement_error_field=None):
    """GaussianGeostatisticalSimulations_ga(in_geostat_layer, number_of_realizations, output_workspace, output_simulation_prefix, {in_conditioning_features}, {conditioning_field}, {cell_size}, {in_bounding_dataset}, {save_simulated_rasters}, {quantile}, {threshold}, {in_stats_polygons}, {raster_stat_type;raster_stat_type...}, {conditioning_measurement_error_field})

        Performs a conditional or unconditional geostatistical simulation
        based on a Simple Kriging model. The simulated rasters can be
        considered equally probable realizations of the kriging model.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          Input a geostatistical layer resulting from a Simple Kriging model.
      number_of_realizations (Long):
          The number of simulations to perform.
      output_workspace (Workspace):
          Stores all the simulation results. The workspace can be either a
          folder or a geodatabase.
      output_simulation_prefix (String):
          A one- to three-character alphanumeric prefix that is automatically
          added to the output dataset names.
      in_conditioning_features {Feature Layer}:
          The features used to condition the realizations. If left blank,
          unconditional realizations are produced.
      conditioning_field {Field}:
          The field used to condition the realizations. If left blank,
          unconditional realizations are produced.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      in_bounding_dataset {Feature Layer}:
          Limits the analysis to these features' bounding polygon. If point
          features are entered, then a convex hull polygon is automatically
          created. Realizations are then performed within that polygon. If
          bounding features are supplied, any features or rasters supplied in
          the Mask environment will be ignored.
      save_simulated_rasters {Boolean}:
          Specifies whether or not the simulated rasters are saved to disk.

          * SAVE_SIMULATIONS-Indicates that the simulated rasters will be saved
          to disk.

          * DO_NOT_SAVE_SIMULATIONS-Indicates that the simulated rasters will
          not be saved to disk.
      quantile {Double}:
          The quantile value for which the output raster will be generated.
      threshold {Double}:
          The threshold value for which the output raster will be generated, as
          the percentage of the number of times the set threshold was exceeded,
          on a cell-by-cell basis.
      in_stats_polygons {Feature Layer}:
          These polygons represent areas of interest for which summary
          statistics are calculated.If in_stats_polygons are provided, the
          output polygon feature class
          will be saved in the location defined by output_workspace, and it will
          have the same name as the input polygons, preceded by the
          output_simulation_prefix. For example, if the input statistical
          polygons were named myPolys and you entered aaa as the output prefix,
          then the output polygons will be named aaamyPolys and will be saved in
          the specified output workspace.
      raster_stat_type {String}:
          The simulated rasters are postprocessed on a cell-by-cell basis, and
          each selected statistics type is calculated and reported in an output
          raster.

          * MIN-Calculates the minimum (smallest value).

          * MAX-Calculates the maximum (largest value).

          * MEAN-Calculates the mean (average).

          * STDDEV-Calculates the standard deviation.

          * QUARTILE1-Calculates the 25th quantile.

          * MEDIAN-Calculates the median.

          * QUARTILE3-Calculates the 75th quantile.

          * QUANTILE-Calculates a user-specified quantile (0 < Q < 1).

          * P_THRSHLD-Calculates the percentage of the simulations where the
          cell value exceeds a user-specified threshold value.
      conditioning_measurement_error_field {Field}:
          A field that specifies the measurement error for each input point in
          the conditioning features. For each conditioning feature, the value of
          this field should correspond to one standard deviation of the measured
          value of the feature. Use this field if the measurement error values
          are not the same at each sampling location.A common source of
          nonconstant measurement error is when the data is
          measured with different devices. One device might be more precise than
          another, which means that it will have a smaller measurement error.
          For example, one thermometer rounds to the nearest degree and another
          thermometer rounds to the nearest tenth of a degree. The variability
          of measurements is often provided by the manufacturer of the measuring
          device, or it may be known from empirical practice.Leave this
          parameter blank if there are no measurement error values or
          the measurement error values are unknown."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GaussianGeostatisticalSimulations_ga(*gp_fixargs((in_geostat_layer, number_of_realizations, output_workspace, output_simulation_prefix, in_conditioning_features, conditioning_field, cell_size, in_bounding_dataset, save_simulated_rasters, quantile, threshold, in_stats_polygons, raster_stat_type, conditioning_measurement_error_field), True)))
        return retval
    except Exception as e:
        raise e


# Utilities toolset
@gptooldoc('CrossValidation_ga', None)
def CrossValidation(in_geostat_layer=None, out_point_feature_class=None):
    """CrossValidation_ga(in_geostat_layer, {out_point_feature_class})

        Removes one data location and predicts the associated data using the
        data at the rest of the locations. The primary use for this tool is to
        compare the predicted value to the observed value in order to obtain
        useful information about some of your model parameters.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.

     OUTPUTS:
      out_point_feature_class {Feature Class}:
          Stores the cross-validation statistics at each location in the
          geostatistical layer."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CrossValidation_ga(*gp_fixargs((in_geostat_layer, out_point_feature_class), True)))
        from arcpy._ga import CrossValidationResult
        retval.__class__ = CrossValidationResult
        return retval
    except Exception as e:
        raise e

@gptooldoc('GANeighborhoodSelection_ga', None)
def GANeighborhoodSelection(in_dataset=None, out_layer=None, point_coord=None, neighbors_max=None, neighbors_min=None, minor_semiaxis=None, major_semiaxis=None, angle=None, shape_type=None):
    """GANeighborhoodSelection_ga(in_dataset, out_layer, point_coord, neighbors_max, neighbors_min, minor_semiaxis, major_semiaxis, angle, {shape_type})

        Creates a layer of points based on a user-defined neighborhood. For
        example, you might wish to create a selection of points in a
        circular neighborhood around a location defined by the Input point.
        The illustration above demonstrates that the output will be the 10
        points, colored blue, that fall within the circle.

     INPUTS:
      in_dataset (Feature Layer):
          Points used to create a neighborhood selection.
      point_coord (Point):
          The neighborhood center's x,y coordinate.
      neighbors_max (Long):
          The number of points to use in each sector. If a sector has the
          required number of points, all points in that sector are used.
      neighbors_min (Long):
          The minimum number of points to use in each sector. If the minimum
          number of required points are not available in any given sector, the
          nearest available point outside the sector will be selected.
      minor_semiaxis (Double):
          Size of the minor semiaxis of the search neighborhood.
      major_semiaxis (Double):
          Size of the major semiaxis of the search neighborhood.
      angle (Double):
          The angle of rotation of the neighborhood axis.
      shape_type {String}:
          The geometry of the neighborhood.

          * ONE_SECTOR-Single ellipse

          * FOUR_SECTORS-Ellipse divided into four sectors

          * FOUR_SECTORS_SHIFTED-Ellipse divided into four sectors and shifted
          45 degrees

          * EIGHT_SECTORS-Ellipse divided into eight sectors

     OUTPUTS:
      out_layer (Feature Layer):
          Layer to store the neighborhood selection."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GANeighborhoodSelection_ga(*gp_fixargs((in_dataset, out_layer, point_coord, neighbors_max, neighbors_min, minor_semiaxis, major_semiaxis, angle, shape_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GASemivariogramSensitivity_ga', None)
def GASemivariogramSensitivity(in_ga_model_source=None, in_datasets=None, in_locations=None, nugget_span_percents=None, nugget_calc_times=None, partialsill_span_percents=None, partialsill_calc_times=None, range_span_percents=None, range_calc_times=None, minrange_span_percents=None, minrange_calc_times=None, out_table=None):
    """GASemivariogramSensitivity_ga(in_ga_model_source, in_datasets;in_datasets..., in_locations, {nugget_span_percents}, {nugget_calc_times}, {partialsill_span_percents}, {partialsill_calc_times}, {range_span_percents}, {range_calc_times}, {minrange_span_percents}, {minrange_calc_times}, out_table)

        This tool performs a sensitivity analysis on the predicted values and
        associated standard errors by changing the model's semivariogram
        parameters (the nugget, partial sill, and major/minor ranges) within a
        percentage of the original values. The tool takes a geostatistical
        model source in order to populate these initial values of the nugget,
        partial sill, and major/minor ranges. The tool's output is a table
        indicating which parameter values were used and what the resulting
        predicted and standard error values were. If there are large
        fluctuations in the output with small changes in the model's parameter
        values, then you cannot have much confidence in the output. On the
        other hand, if changes in the output are small, then you can be
        confident in the model's predictions and make decisions based on its
        output.

     INPUTS:
      in_ga_model_source (Geostatistical Layer / File):
          The geostatistical model source to be analyzed.
      in_datasets (Geostatistical Value Table):
          A GeostatisticalDatasets object.Alternatively, it can be a semicolon-
          delimited string of elements.
          Each element is comprised of the following components:

          * The catalog path and name to a dataset or the name of a layer in the
          current table of contents, followed by a space.

          * A sequence of field names, each field name separated by a space. In
          the case of a raster, the cell values will be used.
      in_locations (Feature Layer):
          Point locations where the sensitivity analysis is performed.
      nugget_span_percents {Double}:
          The percentage subtracted and added to the Nugget parameter to create
          a range for a subsequent random Nugget parameter selection.
      nugget_calc_times {Long}:
          Number of random Nugget values randomly sampled from the Nugget span.
      partialsill_span_percents {Double}:
          Percentage subtracted from and added to the Partial Sill parameter to
          create a range for a random Partial Sill selection.
      partialsill_calc_times {Long}:
          Number of Partial Sill values randomly sampled from the Partial Sill
          span.
      range_span_percents {Double}:
          Percentage subtracted and added to the Major Range parameter to create
          a range for a random Major Range selection.
      range_calc_times {Long}:
          Number of Major Range values randomly sampled from the Major Range
          span.
      minrange_span_percents {Double}:
          Percentage subtracted and added to the Minor Range parameter to create
          a range for a random Minor Range selection.
      minrange_calc_times {Long}:
          Number of Minor Range values randomly sampled from the Minor Range
          span.If Anisotropy has been set in the input geostatistical model
          source, a
          value is required.

     OUTPUTS:
      out_table (Table):
          Table storing the sensitivity results."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GASemivariogramSensitivity_ga(*gp_fixargs((in_ga_model_source, in_datasets, in_locations, nugget_span_percents, nugget_calc_times, partialsill_span_percents, partialsill_calc_times, range_span_percents, range_calc_times, minrange_span_percents, minrange_calc_times, out_table), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateSubsetPolygons_ga', None)
def GenerateSubsetPolygons(in_point_features=None, out_feature_class=None, min_points_per_subset=None, max_points_per_subset=None, coincident_points=None):
    """GenerateSubsetPolygons_ga(in_point_features, out_feature_class, {min_points_per_subset}, {max_points_per_subset}, {coincident_points})

        Generates nonoverlapping subset polygon features from a set of input
        points. The goal is to divide the points into compact, nonoverlapping
        subsets, and create polygon regions around each subset of points. The
        minimum and maximum number of points in each subset can be
        controlled.The process of generating subset polygon features begins by
        connecting
        all points with a linear curve and cutting this curve into segments.
        These segments are chosen in order to minimize the total squared
        distance from the center of the segment to each point in the segment
        given the minimum and maximum number of points that are allowed to be
        in each subset. Any overlaps between the segments are then removed,
        and new segments are created. After several iterations of segmentation
        and overlap removal, no overlaps will remain, and all points within
        each segment will be declared part of the same subset. Thiessen
        polygons are then generated for the input points, and all Thiessen
        polygons belonging to the same subset are dissolved into a single
        polygon feature.

     INPUTS:
      in_point_features (Feature Layer):
          The points that will be grouped into subsets.
      min_points_per_subset {Long}:
          The minimum number of points that can be grouped into a subset. All
          subset polygons will contain at least this many points.
      max_points_per_subset {Long}:
          The maximum number of points that can be grouped into a subset.Each
          subset will always contain fewer than two times the
          min_points_per_subset regardless of the maximum number provided. This
          is because if a subset contains at least twice the minimum number of
          points, it will always be subdivided into two or more new subsets.
      coincident_points {Boolean}:
          Specifies whether coincident points (points that are at the same
          location) are treated like a single point or as multiple individual
          points.If you intend to use the subset polygons as Subset polygon
          features in
          EBK Regression Prediction, you should maintain consistency between
          this parameter and your choice for the Coincident points environment
          in EBK Regression Prediction.If COINCIDENT_ALL is chosen, your
          Out_feature_class polygons may
          overlap.

          * COINCIDENT_SINGLE-Coincident points will be treated as a single
          point in the subsetting. This is the default.

          * COINCIDENT_ALL-Coincident points will be treated as multiple
          individual points in the subsetting.

     OUTPUTS:
      out_feature_class (Feature Class):
          The polygons defining the region of each subset. All points within a
          single polygon feature are considered part of the same subset. The
          polygon feature class will contain a field named PointCount that will
          store the number of points contained in each polygon subset."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateSubsetPolygons_ga(*gp_fixargs((in_point_features, out_feature_class, min_points_per_subset, max_points_per_subset, coincident_points), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SubsetFeatures_ga', None)
def SubsetFeatures(in_features=None, out_training_feature_class=None, out_test_feature_class=None, size_of_training_dataset=None, subset_size_units=None):
    """SubsetFeatures_ga(in_features, out_training_feature_class, {out_test_feature_class}, {size_of_training_dataset}, {subset_size_units})

        Divides the original dataset into two parts: one part to be used to
        model the spatial structure and produce a surface, the other to be
        used to compare and validate the output surface.

     INPUTS:
      in_features (Table View):
          Points, lines, polygon features, or table from which to create a
          subset.
      size_of_training_dataset {Double}:
          The size of the output training feature class, entered either as a
          percentage of the input features or as an absolute number of features.
      subset_size_units {Boolean}:
          Type of subset size.

          * PERCENTAGE_OF_INPUT-The percentage of the input features that will
          be in the training dataset.

          * ABSOLUTE_VALUE-The number of features that will be in the training
          dataset.

     OUTPUTS:
      out_training_feature_class (Feature Class / Table):
          The subset of training features to be created.
      out_test_feature_class {Feature Class / Table}:
          The subset of test features to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SubsetFeatures_ga(*gp_fixargs((in_features, out_training_feature_class, out_test_feature_class, size_of_training_dataset, subset_size_units), True)))
        return retval
    except Exception as e:
        raise e


# Working with Geostatistical Layers toolset
@gptooldoc('ArealInterpolationLayerToPolygons_ga', None)
def ArealInterpolationLayerToPolygons(in_areal_interpolation_layer=None, in_polygon_features=None, out_feature_class=None, append_all_fields=None):
    """ArealInterpolationLayerToPolygons_ga(in_areal_interpolation_layer, in_polygon_features, out_feature_class, {append_all_fields})

        Reaggregates the predictions of an Areal Interpolation layer to a new
        set of polygons.

     INPUTS:
      in_areal_interpolation_layer (Geostatistical Layer):
          Input geostatistical layer resulting from an Areal Interpolation
          model.
      in_polygon_features (Feature Layer):
          The polygons where predictions and standard errors will be aggregated.
      append_all_fields {Boolean}:
          Determines whether all fields will be copied from the input features
          to the output feature class.

          * ALL-All fields from the input features will be copied to the output
          feature class. This is the default.

          * FID_ONLY-Only the feature ID will be copied, and it will be named
          Source_ID on the output feature class.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class containing the aggregated predictions and
          standard errors for the new polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ArealInterpolationLayerToPolygons_ga(*gp_fixargs((in_areal_interpolation_layer, in_polygon_features, out_feature_class, append_all_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GACalculateZValue_ga', None)
def GACalculateZValue(in_geostat_layer=None, point_coord=None):
    """GACalculateZValue_ga(in_geostat_layer, point_coord)

        Uses the interpolation model in a geostatistical layer to predict a
        value at a single location.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.
      point_coord (Point):
          The x,y coordinate of the point for which the Z-value will be
          calculated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GACalculateZValue_ga(*gp_fixargs((in_geostat_layer, point_coord), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GACreateGeostatisticalLayer_ga', None)
def GACreateGeostatisticalLayer(in_ga_model_source=None, in_datasets=None, out_layer=None):
    """GACreateGeostatisticalLayer_ga(in_ga_model_source, in_datasets;in_datasets..., out_layer)

        Creates a new geostatistical layer. An existing geostatistical layer
        is required to populate the initial values for the new layer.

     INPUTS:
      in_ga_model_source (Geostatistical Layer / File):
          The geostatistical model source to be analyzed.
      in_datasets (Geostatistical Value Table):
          A GeostatisticalDatasets object.Alternatively, it can be a semicolon-
          delimited string of elements.
          Each element is comprised of the following components:

          * The catalog path and name to a dataset or the name of a layer in the
          current table of contents, followed by a space.

          * A sequence of field names, each field name separated by a space. In
          the case of a raster, the cell values will be used.

     OUTPUTS:
      out_layer (Geostatistical Layer):
          The geostatistical layer produced by the tool."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GACreateGeostatisticalLayer_ga(*gp_fixargs((in_ga_model_source, in_datasets, out_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GAGetModelParameter_ga', None)
def GAGetModelParameter(in_ga_model_source=None, model_param_xpath=None):
    """GAGetModelParameter_ga(in_ga_model_source, model_param_xpath)

        Gets model parameter value from an existing geostatistical model
        source.

     INPUTS:
      in_ga_model_source (Geostatistical Layer / File):
          The geostatistical model source to be analyzed.
      model_param_xpath (String):
          XML path to the required model parameter."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GAGetModelParameter_ga(*gp_fixargs((in_ga_model_source, model_param_xpath), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GALayerToContour_ga', None)
def GALayerToContour(in_geostat_layer=None, contour_type=None, out_feature_class=None, contour_quality=None, classification_type=None, classes_count=None, classes_breaks=None, out_elevation=None):
    """GALayerToContour_ga(in_geostat_layer, contour_type, out_feature_class, {contour_quality}, {classification_type}, {classes_count}, {classes_breaks;classes_breaks...}, {out_elevation})

        Creates a feature class of contours from a geostatistical layer. The
        output feature class can be either a line feature class of contour
        lines or a polygon feature class of filled contours.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.
      contour_type (String):
          Type of contour to represent the geostatistical layer.

          * CONTOUR-The contour or isoline representation of the geostatistical
          layer. Displays the lines in either draft or presentation quality.

          * FILLED_CONTOUR-The polygon representation of the geostatistical
          layer. It assumes for the graphical display that the values between
          contour lines are the same for all locations within the polygon.
          Displays the lines in either draft or presentation quality.

          * SAME_AS_LAYER-Use the current renderer of the input geostatistical
          layer.
      contour_quality {String}:
          Determines the smoothness of contour line representation.

          * DRAFT-The default Draft quality presents a generalized version of
          isolines for faster display.

          * PRESENTATION-The Presentation option ensures more detailed isolines
          for the output feature class.
      classification_type {String}:
          Specifies how the contour breaks will be calculated.

          * GEOMETRIC_INTERVAL-Contour breaks are calculated based on geometric
          intervals.

          * EQUAL_INTERVAL-Contour breaks are calculated based on equal
          intervals.

          * QUANTILE-Contour breaks are calculated from quantiles of the input
          data.

          * MANUAL-Specify your own break values.
      classes_count {Long}:
          Specify the number of classes in the output feature class.If
          contour_type is set to output filled contour polygons, the number
          of polygons created will equal the value specified in this parameter.
          If it is set to output contour polylines, the number of polylines will
          be one less than the value specified in this parameter (because N
          class intervals define N-1 contour break values).This parameter does
          not apply if the classification_type is set to
          Manual.
      classes_breaks {Double}:
          The list of break values if the classification_type is set to Manual.
          The values should be passed as a list, and the values can be in any
          order.

          * For contour output, these are the values of the contour lines.

          * For filled contour, these are the upper limits of each class
          interval. Note that if the largest break value is less than the
          maximum of the geostatistical layer, the output feature class will not
          fill up the entire rectangular extent; all locations with predicted
          values above the largest break will not receive filled contours.
      out_elevation {Linear Unit}:
          For 3D interpolation models, you can export contours at any elevation.
          Use this parameter to specify the elevation that you want to export.
          If left empty, the elevation will be inherited from the input layer.
          The units will default to the same units of the input layer.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class will either be a polyline or a polygon,
          depending on the selected contour type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToContour_ga(*gp_fixargs((in_geostat_layer, contour_type, out_feature_class, contour_quality, classification_type, classes_count, classes_breaks, out_elevation), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GALayerToGrid_ga', None)
def GALayerToGrid(in_geostat_layer=None, out_surface_grid=None, cell_size=None, points_per_block_horz=None, points_per_block_vert=None):
    """GALayerToGrid_ga(in_geostat_layer, out_surface_grid, {cell_size}, {points_per_block_horz}, {points_per_block_vert})

        Exports a Geostatistical layer to a raster.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.
      cell_size {Analysis Cell Size}:
          The cell size at which the output raster will be created.This value
          can be explicitly set in the Environments by the Cell Size
          parameter.If not set, it is the shorter of the width or the height of
          the extent
          of the input point features, in the input spatial reference, divided
          by 250.
      points_per_block_horz {Long}:
          The number of predictions for each cell in the horizontal direction
          for block interpolation.
      points_per_block_vert {Long}:
          The number of predictions for each cell in the vertical direction for
          block interpolation.

     OUTPUTS:
      out_surface_grid (Raster Dataset):
          The raster to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToGrid_ga(*gp_fixargs((in_geostat_layer, out_surface_grid, cell_size, points_per_block_horz, points_per_block_vert), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GALayerToPoints_ga', None)
def GALayerToPoints(in_geostat_layer=None, in_locations=None, z_field=None, out_feature_class=None, append_all_fields=None, elevation_field=None, elevation_units=None):
    """GALayerToPoints_ga(in_geostat_layer, in_locations, {z_field}, out_feature_class, {append_all_fields}, {elevation_field}, {elevation_units})

        Exports a geostatistical layer to points. The tool can also be used to
        predict values at unmeasured locations or to validate predictions made
        at measured locations.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.
      in_locations (Feature Layer):
          Point locations where predictions or validations will be performed.
      z_field {Field}:
          If this field is left blank, predictions are made at the location
          points. If a field is selected, predictions are made at the location
          points, compared to their Z_value_field values, and a validation
          analysis is performed.
      append_all_fields {Boolean}:
          Determines whether all fields will be copied from the input features
          to the output feature class.

          * ALL-All fields from the input features will be copied to the output
          feature class. This is the default.

          * FID_ONLY-Only the feature ID will be copied, and it will be named
          Source_ID on the output feature class.
      elevation_field {Field}:
          The field containing the elevation of each input point. The parameter
          only applies to 3D geostatistical models. If the elevation values are
          stored as geometry attributes in Shape.Z, it is recommended to use
          that field. If the elevations are stored in an attribute field, the
          elevations must indicate distance from sea level. Positive values
          indicate distance above sea level, and negative values indicate
          distance below sea level.
      elevation_units {String}:
          The units of the elevation field. This parameter only applies to 3D
          geostatistical models. If Shape.Z is provided as the elevation field,
          the units will automatically match the Z-units of the vertical
          coordinate system.

          * INCH-Elevations are in inches.

          * FOOT-Elevations are in feet.

          * YARD-Elevations are in yards.

          * MILE_US-Elevations are in U.S. miles.

          * NAUTICAL_MILE-Elevations are in nautical miles.

          * MILLIMETER-Elevations are in millimeters.

          * CENTIMETER-Elevations are in centimeters.

          * DECIMETER-Elevations are in decimeters.

          * METER-Elevations are in meters.

          * KILOMETER-Elevations are in kilometers.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class containing either the predictions or the
          predictions and the validation results.The fields in this feature
          class can include the following fields
          (where applicable):

          * Source_ID (Source ID)-The object ID of the source feature in the
          Input point observation locations.

          * The feature or object identifier of the input dataset that was used.

          * Included (Included)-Indicates whether a prediction was calculated
          for this feature. The values in this field can be one of the
          following:

          * Yes-There are no problems making a prediction at this point.

          * Not enough neighbors-There are not enough neighbors to make a
          prediction.

          * Weight parameter is too small-The weight parameter is too small.

          * Overfilling-Overflow of floating-point calculations.

          * Problem with data transformation-The value to be transformed is
          outside of the supported range for the selected transformation (only
          in kriging).

          *  No explanatory rasters-The value cannot be calculated because one
          of the explanatory variables is not defined. The point could be
          outside the extent of at least one explanatory variable raster, or the
          point could be on top of a NoData cell in at least one of the
          explanatory variable rasters. This only applies to EBK Regression
          Prediction models.

          * Predicted (Predicted)-The prediction value at this location.

          * Error (Error)-The predicted value minus the value in the validation
          field.

          * StdError (Standard Error)-The kriging standard error.

          * Stdd_Error (Standardized Error)-The standardized prediction errors.
          Ideally, the standardized prediction errors are distributed normally.

          * NormValue (Normal Value)-The normal distribution value (x-axis) that
          corresponds to the standardized prediction errors (y-axis) in the
          normal QQplot.

          * CRPS (Continuous Ranked Probability Score)-The continuous ranked
          probability score is a diagnostic that measures the deviation from the
          predictive cumulative distribution function to each observed data
          value. This value should be as small as possible. This diagnostic has
          advantages over cross-validation diagnostics because it compares the
          data to a full distribution rather than to single-point predictions.
          This field is only created for Empirical Bayesian Kriging and EBK
          Regression Prediction models.

          * Interval90 (Inside 90 Percent Interval)-Indicates whether or not the
          validation point is inside of a 90 percent confidence interval. This
          field is only created for Empirical Bayesian Kriging and EBK
          Regression Prediction models. If the model fits the data,
          approximately 90 percent of the features should be contained in a 90
          percent confidence interval. This field can contain the following
          values:

          * Yes-The validation point is inside the 90 percent confidence
          interval.

          * No-The validation point is not inside the 90 percent confidence
          interval.

          * Excluded-A prediction cannot be made at this location.

          * Interval95 (Inside 95 Percent Interval)-Indicates whether or not the
          validation point is inside of a 95 percent confidence interval. This
          field is only created for Empirical Bayesian Kriging and EBK
          Regression Prediction models. If the model fits the data,
          approximately 95 percent of the features should be contained in a 95
          percent confidence interval. This field can contain the following
          values:

          * Yes-The validation point is inside the 95 percent confidence
          interval.

          * No-The validation point is not inside the 95 percent confidence
          interval.

          * Excluded-A prediction cannot be made at this location.

          * QuanVal (Validation Quantile)-The quantile of the measured value at
          the feature with respect to the prediction distribution. This value
          can range from 0 to 1, and values close to 0 indicate that the
          measured value is on the far left tail of the distribution, and values
          close to 1 indicate that the measured value is on the right tail of
          the distribution. If many values are close to either extreme, this
          could indicate that the prediction distributions do not model the data
          well, and some of the interpolation parameters need to be altered.
          This field is only created for Empirical Bayesian Kriging and EBK
          Regression Prediction models."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToPoints_ga(*gp_fixargs((in_geostat_layer, in_locations, z_field, out_feature_class, append_all_fields, elevation_field, elevation_units), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GALayerToRasters_ga', None)
def GALayerToRasters(in_geostat_layer=None, out_raster=None, output_type=None, quantile_probability_value=None, cell_size=None, points_per_block_horz=None, points_per_block_vert=None, additional_rasters=None, out_elevation=None):
    """GALayerToRasters_ga(in_geostat_layer, out_raster, {output_type}, {quantile_probability_value}, {cell_size}, {points_per_block_horz}, {points_per_block_vert}, {additional_rasters;additional_rasters...}, {out_elevation})

        Exports a geostatistical layer to one or multiple rasters.

     INPUTS:
      in_geostat_layer (Geostatistical Layer):
          The geostatistical layer to be analyzed.
      output_type {String}:
          The surface type of the output raster.For more information, see What
          output surface types can the
          interpolation models generate?

          * PREDICTION-A raster of predicted values.

          * PREDICTION_STANDARD_ERROR-A raster of standard errors of prediction.

          * PROBABILITY-A raster predicting the probability that a threshold is
          exceeded.

          * QUANTILE-A raster predicting the quantile of the predicted value.

          * STANDARD_ERROR_INDICATORS-A raster of standard errors of indicators.

          * CONDITION_NUMBER-A raster showing the condition number for
          predictions in Local Polynomial Interpolation. The condition number
          surface indicates the stability of calculations at a particular
          location. The larger the condition number, the more unstable the
          prediction, so locations with large condition numbers may be prone to
          artifacts and erratic predicted values.
      quantile_probability_value {Double}:
          If the Output surface type is set to Quantile, use this parameter to
          enter the requested quantile. If the Output surface type is set to
          Probability, use this parameter to enter the requested threshold
          value, then the probability that the threshold is exceeded will be
          calculated.If the Input geostatistical layer is a probability or
          standard errors
          of indicators map that was created with the Not exceed option, then
          the probability that this threshold is not exceeded will be
          calculated. This will apply to all probability raster outputs from
          this tool.
      cell_size {Analysis Cell Size}:
          The cell size of the output rasters. This value will be shared by the
          Output raster and the Additional output rasters parameters.
      points_per_block_horz {Long}:
          The number of predictions for each cell in the horizontal direction
          for block interpolation.
      points_per_block_vert {Long}:
          The number of predictions for each cell in the vertical direction for
          block interpolation.
      additional_rasters {Value Table}:
          Provide the name, output type, and quantile or probability value for
          each additional output raster. See the descriptions of parameters
          above for more information. These additional rasters will be saved in
          the same location as the Output raster.
      out_elevation {Linear Unit}:
          For 3D interpolation models, you can export rasters at any elevation.
          Use this parameter to specify the elevation you want to export. If
          left empty, the elevation will be inherited from the input layer. The
          units will default to the same units of the input layer.

     OUTPUTS:
      out_raster (Raster Dataset):
          The primary output raster to be created. Additional rasters can be
          created with the Additional output rasters parameter."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GALayerToRasters_ga(*gp_fixargs((in_geostat_layer, out_raster, output_type, quantile_probability_value, cell_size, points_per_block_horz, points_per_block_vert, additional_rasters, out_elevation), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GASetModelParameter_ga', None)
def GASetModelParameter(in_ga_model_source=None, model_param_xpath=None, in_param_value=None, out_ga_model=None):
    """GASetModelParameter_ga(in_ga_model_source, model_param_xpath, in_param_value, out_ga_model)

        Sets parameter values in an existing geostatistical model source.

     INPUTS:
      in_ga_model_source (Geostatistical Layer / File):
          The geostatistical model source to be analyzed.
      model_param_xpath (String):
          XML path to the required model parameter.
      in_param_value (String):
          Value for the parameter defined by the XML path.

     OUTPUTS:
      out_ga_model (File):
          Geostatistical model created with the parameter value defined in the
          XML path."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GASetModelParameter_ga(*gp_fixargs((in_ga_model_source, model_param_xpath, in_param_value, out_ga_model), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject