# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The ArcGIS Pro Maritime toolbox contains tools that manage S-100 data."""
__all__ = ['ExportS101Cell', 'ImportS100Cell', 'ImportS100FeatureCatalogue']
__alias__ = 'maritime'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('ExportS101Cell_maritime', None)
def ExportS101Cell(in_feature_catalogue=None, in_s101_workspace=None, product=None, export_type=None, output_location=None):
    """ExportS101Cell_maritime(in_feature_catalogue, in_s101_workspace, product, export_type, output_location)

        Exports S-101 hydrographic data from a geodatabase to an S-101 file.

     INPUTS:
      in_feature_catalogue (File):
          An  S-100 feature catalog document that describes the content of a
          data product and specification.
      in_s101_workspace (Workspace):
          The workspace that contains the product.
      product (String):
          The name of the product to export.This information must exist in the
          ProductCoverage feature class and
          ProductDefinition table before using this tool.
      export_type (String):
          The type of file created during export.

          * NEW_EDITION-A new edition of a dataset, including new information
          that has not been previously distributed by updates. This is the
          default.
      output_location (Folder):
          The location where the export package will be written."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportS101Cell_maritime(*gp_fixargs((in_feature_catalogue, in_s101_workspace, product, export_type, output_location), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportS100Cell_maritime', None)
def ImportS100Cell(in_feature_catalogue=None, in_base_cell=None, target_workspace=None, in_update_cells=None):
    """ImportS100Cell_maritime(in_feature_catalogue, in_base_cell, target_workspace, {in_update_cells;in_update_cells...})

        Imports S-100 hydrographic data into a geodatabase created from a
        related S-100 feature catalogue.

     INPUTS:
      in_feature_catalogue (File):
          An  S-100 feature catalogue document that describes the content of a
          data product and specification.
      in_base_cell (File):
          The base file in the S-100 format.
      target_workspace (Workspace):
          The geodatabase to which all output data will be written.
      in_update_cells {File}:
          An update to a base file in the S-100 format."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportS100Cell_maritime(*gp_fixargs((in_feature_catalogue, in_base_cell, target_workspace, in_update_cells), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportS100FeatureCatalogue_maritime', None)
def ImportS100FeatureCatalogue(in_feature_catalogue=None, target_workspace=None, admin_connection=None):
    """ImportS100FeatureCatalogue_maritime(in_feature_catalogue, target_workspace, {admin_connection})

        Imports the contents of an S-100 feature catalogue into an existing
        geodatabase. A feature catalogue is an XML document that describes the
        content of a data product.Examples of S-100 data products include the
        following:

        * S-101 Electronic Navigation Chart

        * S-111 Surface Currents

     INPUTS:
      in_feature_catalogue (File):
          An S-100 feature catalogue document that describes the content of a
          data product and specification.
      target_workspace (Workspace):
          The geodatabase to which output data will be written.
      admin_connection {File}:
          Optional enterprise geodatabase administrator connection file that
          should be used when importing into an enterprise geodatabase, for
          example, the SDE user."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportS100FeatureCatalogue_maritime(*gp_fixargs((in_feature_catalogue, target_workspace, admin_connection), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject