# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Raster Analysis toolbox contains a set of powerful tools for
performing raster analysis on data in your portal. By distributing the
processing between multiple server nodes, you can efficiently process
large datasets in less time than ever before."""
__all__ = ['CalculateDensity', 'CalculateDistance', 'CalculateTravelCost',
           'ClassifyPixelsUsingDeepLearning', 'ConvertFeatureToRaster',
           'ConvertRasterToFeature', 'CreateViewshed',
           'DetectObjectsUsingDeepLearning',
           'DetermineOptimumTravelCostNetwork',
           'DetermineTravelCostPathAsPolyline',
           'DetermineTravelCostPathsToDestinations', 'Fill', 'FlowAccumulation',
           'FlowDirection', 'FlowDistance', 'InterpolatePoints', 'Nibble',
           'StreamLink', 'SummarizeRasterWithin', 'Watershed']
__alias__ = 'ra'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Analyze Patterns toolset
@gptooldoc('CalculateDensity_ra', None)
def CalculateDensity(inputPointOrLineFeatures=None, outputName=None, countField=None, searchDistance=None, outputAreaUnits=None, outputCellSize=None):
    """CalculateDensity_ra(inputPointOrLineFeatures, outputName, {countField}, {searchDistance}, {outputAreaUnits}, {outputCellSize})

        Creates a density map from point or line features by spreading known
        quantities of some phenomenon (represented as attributes of the points
        or lines) across the map. The result is a layer of areas classified
        from least dense to most dense.

     INPUTS:
      inputPointOrLineFeatures (Feature Set):
          The input point or line features that will be used to calculate the
          density raster.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      countField {Field}:
          Provide a field indicating the number of incidents at each location.
          For example, if you are making a population density raster, and the
          input points are cities, it would be appropriate to use the population
          of the city for the count field so cities with larger populations have
          more impact on the density calculations.
      searchDistance {Linear Unit}:
          Choose the search distance and units for the distance. When
          calculating the density at a cell, all features within this distance
          will be used in the density calculation for that cell.The units can be
          in Kilometers, Meters, Miles, or Feet.The default units are Meters.
      outputAreaUnits {String}:
          Choose the area units. Density is count divided by area, and this
          parameter sets the units of the area in the density calculation.

          * SQUARE_METERS-Calculate the density per square meter.

          * SQUARE_KILOMETERS-Calculate the density per square kilometer.

          * SQUARE_FEET-Calculate the density per square foot.

          * SQUARE_MILES-Calculate the density per square mile.
      outputCellSize {Linear Unit}:
          Set the cell size and units for the output raster.The units can be in
          Kilometers, Meters, Miles, or Feet.The default units are Meters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDensity_ra(*gp_fixargs((inputPointOrLineFeatures, outputName, countField, searchDistance, outputAreaUnits, outputCellSize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('InterpolatePoints_ra', None)
def InterpolatePoints(inputPointFeatures=None, interpolateField=None, outputName=None, optimizeFor=None, transformData=None, sizeOfLocalModels=None, numberOfNeighbors=None, outputCellSize=None, outputPredictionError=None):
    """InterpolatePoints_ra(inputPointFeatures, interpolateField, outputName, {optimizeFor}, {transformData}, {sizeOfLocalModels}, {numberOfNeighbors}, {outputCellSize}, {outputPredictionError})

        Predict values at new locations based on measurements from a
        collection of points. The tool takes point data with values at each
        point and returns a raster of predicted values.

     INPUTS:
      inputPointFeatures (Feature Set):
          The input point features you want to interpolate.
      interpolateField (Field):
          The field containing the data values you want to interpolate. The
          field must be numeric.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      optimizeFor {String}:
          Choose your preference for speed versus accuracy. More accurate
          predictions will take longer to calculate.

          * SPEED-The operation is optimized for speed.

          * BALANCE-A balance between speed and accuracy. This is the default.

          * ACCURACY-The operation is optimized for accuracy.
      transformData {Boolean}:
          Choose whether to transform your data to a normal distribution before
          performing analysis. If your data values do not appear to be normally
          distributed (bell-shaped), it is recommended to perform a
          transformation.

          * NO_TRANSFORM-No transformation is applied. This is the default.

          * TRANSFORM-A transformation to the normal distribution is applied.
      sizeOfLocalModels {Long}:
          Choose the number of points in each of the local models. A larger
          value will make the interpolation more global and stable, but small-
          scale effects may be missed. Smaller values will make the
          interpolation more local, so small-scale effects are more likely to be
          captured, but the interpolation may be unstable.
      numberOfNeighbors {Long}:
          The number of neighbors to use when calculating the prediction at a
          particular cell.
      outputCellSize {Linear Unit}:
          Set the cell size and units of the output raster. If a prediction
          error raster is created, it will also use this cell size.The units can
          be in Kilometers, Meters, Miles, or Feet.The default units are Meters.
      outputPredictionError {Boolean}:
          Choose whether to output a raster of standard errors of the
          interpolated predictions.Standard errors are useful because they
          provide information about the
          reliability of the predicted values. A simple rule of thumb is that
          the true value will fall within two standard errors of the predicted
          value 95 percent of the time. For example, suppose a new location gets
          a predicted value of 50 with a standard error of 5. This means that
          this task's best guess is that the true value at that location is 50,
          but it reasonably could be as low as 40 or as high as 60. To calculate
          this range of reasonable values, multiply the standard error by 2, add
          this value to the predicted value to get the upper end of the range,
          and subtract it from the predicted value to get the lower end of the
          range.If a raster of standard errors for the interpolated predictions
          is
          requested, it will have the same name as the Result layer name but
          with Errors appended.

          * OUTPUT_ERROR-Create a prediction error raster.

          * NO_OUTPUT_ERROR-Do not create a prediction error raster. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.InterpolatePoints_ra(*gp_fixargs((inputPointFeatures, interpolateField, outputName, optimizeFor, transformData, sizeOfLocalModels, numberOfNeighbors, outputCellSize, outputPredictionError), True)))
        return retval
    except Exception as e:
        raise e


# Analyze Terrain toolset
@gptooldoc('CreateViewshed_ra', None)
def CreateViewshed(inputElevationSurface=None, inputObserverFeatures=None, outputName=None, optimizeFor=None, maximumViewingDistanceType=None, maximumViewingDistance=None, maximumViewingDistanceField=None, minimumViewingDistanceType=None, minimumViewingDistance=None, minimumViewingDistanceField=None, viewingDistanceIs3D=None, observersElevationType=None, observersElevation=None, observersElevationField=None, observersHeightType=None, observersHeight=None, observersHeightField=None, targetHeightType=None, targetHeight=None, targetHeightField=None, aboveGroundLevelOutputName=None):
    """CreateViewshed_ra(inputElevationSurface, inputObserverFeatures, outputName, {optimizeFor}, {maximumViewingDistanceType}, {maximumViewingDistance}, {maximumViewingDistanceField}, {minimumViewingDistanceType}, {minimumViewingDistance}, {minimumViewingDistanceField}, {viewingDistanceIs3D}, {observersElevationType}, {observersElevation}, {observersElevationField}, {observersHeightType}, {observersHeight}, {observersHeightField}, {targetHeightType}, {targetHeight}, {targetHeightField}, {aboveGroundLevelOutputName})

        Creates areas where an observer can see objects on the ground. The
        input observer points can represent either observers (such as people
        on the ground or lookouts in a fire tower) or observed objects (such
        as wind turbines, water towers, vehicles, or other people).Both the
        observers and the observed objects can have a height above
        ground, and these heights are used to determine visibility. For
        example, a viewshed computed for 300-foot wind turbines and a 6-foot
        tall person standing on the ground will typically be larger than a
        viewshed computed for 200-foot turbines and a 5-foot tall person.The
        result layer records the number of times that each cell location
        in the input surface raster can be seen by the input observation
        points. Nonvisible cells are given NoData values.

     INPUTS:
      inputElevationSurface (Image Service / Raster Layer / String):
          The elevation surface to use for calculating the viewshed.If the
          vertical unit of the input surface is different from the
          horizontal unit, such as when the elevation values are represented in
          feet but the coordinate system is in meters, the surface must have a
          defined vertical coordinate system. The reason for this is that the
          tool uses the vertical (Z) and horizontal (XY) units to compute a
          z-factor for the viewshed analysis. Without a vertical coordinate
          system, and thus having no Z unit information available, the tool will
          assume that the Z unit is the same as the XY unit. The result of this
          is that an internal Z factor of 1.0 will be used for the analysis,
          which may give unexpected results.The elevation surface can be integer
          or floating point.
      inputObserverFeatures (Feature Set):
          The point features that represent the observer locations when
          calculating the viewsheds.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      optimizeFor {String}:
          The optimization method to use for calculating the viewshed.

          * SPEED-This method optimizes the processing speed, trading some
          accuracy in the result for higher performance. This is the default.

          * ACCURACY-This method is optimized for accuracy in the results, at
          the expense of a longer processing time.
      maximumViewingDistanceType {String}:
          The method by which the maximum viewing distance will be determined.

          * DISTANCE-The maximum distance is defined by a value you specify.
          This is the default method.

          * FIELD-The maximum distance for each observer location is determined
          by the values in a field you specify.
      maximumViewingDistance {Linear Unit}:
          This is a cutoff distance, where the computation of visible areas
          stops. Beyond this distance, it is unknown whether the observer points
          and the other objects can see each other.The units can be in
          Kilometers, Meters, Miles, Yards, or Feet.The default is miles.
      maximumViewingDistanceField {Field}:
          This is a field you can use to specify the maximum viewing distance
          for each observer. The values contained in the field must be in the
          same unit as the XY unit of the input elevation surface.The maximum
          viewing distance is a cutoff distance where the
          computation of visible areas stops. Beyond this distance, it is
          unknown whether the observer points and the other objects can see each
          other.
      minimumViewingDistanceType {String}:
          Choose the method by which the minimum visible distance will be
          determined.

          * DISTANCE-The minimum distance is defined by a value you specify.
          This is the default method.

          * FIELD-The minimum distance for each observer location is determined
          by the values in a field you specify.
      minimumViewingDistance {Linear Unit}:
          This is a distance where the computation of visible areas begins.
          Cells on the surface closer than this distance are not visible in the
          output but can still block visibility of the cells between the minimum
          and maximum viewing distance.The units can be in Kilometers, Meters,
          Miles, Yards, or Feet.The default units are Meters.
      minimumViewingDistanceField {Field}:
          This is a field you can use to specify the minimum viewing distance
          for each observer. The values contained in the field must be in the
          same unit as the XY unit of the input elevation surface.The minimum
          viewing distance defines where the computation of visible
          areas begins. Cells on the surface closer than this distance are not
          visible in the output but can still block visibility of the cells
          between the minimum and maximum viewing distance.
      viewingDistanceIs3D {Boolean}:
          Specify whether the minimum and maximum viewing distance parameters
          are measured in a three-dimensional way or a simpler, two-dimensional
          way. A 2D distance is the simple linear distance measured between an
          observer and the target using their projected locations at sea level.
          A 3D distance gives a more realistic value by taking their relative
          heights into consideration.

          * 2D-The viewing distance is measured in 2D distance. This is the
          default.

          * 3D-The viewing distance is measured in 3D distance.
      observersElevationType {String}:
          The method by which the elevation of the observers will be determined.

          * ELEVATION-The observer elevation is defined by a value you specify.
          This is the default method.

          * FIELD-The elevation for each observer location is determined by the
          values in a field you specify.
      observersElevation {Linear Unit}:
          This is the elevation of your observer locations.If this parameter is
          not specified, the observer elevation will be
          obtained from the surface raster using bilinear interpolation. If this
          parameter is set to a value, that value will be applied to all the
          observers. To specify different values for each observer, set this
          parameter to a field in the input observer features.The units can be
          in Kilometers, Meters, Miles, Yards, or Feet.The default units are
          Meters.
      observersElevationField {Field}:
          This is a field you can use to specify the elevation for the
          observers. The value contained in the field must be in the same unit
          as the Z unit of the input elevation surface.If this parameter is not
          specified, the observer elevation will be
          obtained from the surface raster using bilinear interpolation.
      observersHeightType {String}:
          The method by which the height of the observers will be determined.

          * HEIGHT-The observer height is obtained from the value you specify.
          This is the default method.

          * FIELD-The height for each observer location is determined by the
          values in a field you specify.
      observersHeight {Linear Unit}:
          This is the height used for your observer locations.The units can be
          in Kilometers, Meters, Miles, Yards, or Feet.The default units are
          Meters.
      observersHeightField {Field}:
          This is a field you can use to specify the height for the observers.
          The value contained in the field must be in the same unit as the Z
          unit of the input elevation surface.
      targetHeightType {String}:
          The method by which the height of the targets will be determined.

          * HEIGHT-The target height is obtained from the value you specify.
          This is the default method.

          * FIELD-The height for each target is determined by the values in a
          field you specify.
      targetHeight {Linear Unit}:
          This is the height of structures or people on the ground used to
          establish visibility. The result viewshed are those areas where an
          observer point can see these other objects. The converse is also true;
          the other objects can see an observer point.The units can be in
          Kilometers, Meters, Miles, Yards, or Feet.The default units are
          Meters.
      targetHeightField {Field}:
          This is a field used to specify the height for the targets. The value
          contained in the field must be in the same unit as the Z unit of the
          input elevation surface.
      aboveGroundLevelOutputName {String}:
          The name of the output aboveground-level (AGL) raster. The AGL result
          is a raster where each cell value is the minimum height that must be
          added to an otherwise nonvisible cell to make it visible by at least
          one observer. Cells that were already visible will be assigned 0 in
          this output raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateViewshed_ra(*gp_fixargs((inputElevationSurface, inputObserverFeatures, outputName, optimizeFor, maximumViewingDistanceType, maximumViewingDistance, maximumViewingDistanceField, minimumViewingDistanceType, minimumViewingDistance, minimumViewingDistanceField, viewingDistanceIs3D, observersElevationType, observersElevation, observersElevationField, observersHeightType, observersHeight, observersHeightField, targetHeightType, targetHeight, targetHeightField, aboveGroundLevelOutputName), True)))
        return retval
    except Exception as e:
        raise e


# Deep Learning toolset
@gptooldoc('ClassifyPixelsUsingDeepLearning_ra', None)
def ClassifyPixelsUsingDeepLearning(inputRaster=None, inputModel=None, outputName=None, modelArguments=None):
    """ClassifyPixelsUsingDeepLearning_ra(inputRaster, inputModel, outputName, {modelArguments;modelArguments...})

        In a raster analysis deployment, this tool runs a trained deep
        learning model on an input image to produce a classified raster
        published as a hosted imagery layer in your portal.

     INPUTS:
      inputRaster (Image Service / Raster Layer / MapServer / Map Server Layer / Internet Tiled Layer / String):
          The input image to classify. It can be an image service URL, a raster
          layer, an image service, a map server layer, or an Internet tiled
          layer.
      inputModel (File):
          The input is a URL of a deep learning package (.dlpk) item. It
          contains the path to the deep learning binary model file, the path to
          the Python raster function to be used, and other parameters such as
          preferred tile size or padding.
      outputName (String):
          The name of the image service of the classified pixels.
      modelArguments {Value Table}:
          The function arguments are defined in the Python raster function class
          referenced by the input model. This is where you list additional deep
          learning parameters and arguments for experiments and refinement, such
          as a confidence threshold for adjusting the sensitivity. The names of
          the arguments are populated by the tool from reading the Python module
          on the RA server."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ClassifyPixelsUsingDeepLearning_ra(*gp_fixargs((inputRaster, inputModel, outputName, modelArguments), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DetectObjectsUsingDeepLearning_ra', None)
def DetectObjectsUsingDeepLearning(inputRaster=None, inputModel=None, outputName=None, modelArguments=None, runNMS=None, confidenceScoreField=None, classValueField=None, maxOverlapRatio=None):
    """DetectObjectsUsingDeepLearning_ra(inputRaster, inputModel, outputName, {modelArguments;modelArguments...}, {runNMS}, {confidenceScoreField}, {classValueField}, {maxOverlapRatio})

        In a raster analysis deployment, this tool runs a trained deep
        learning model on an input raster to produce a feature class
        containing the objects it identifies. The feature class can be shared
        as a hosted feature layer in your portal. The features can be bounding
        boxes or polygons around the objects found, or points at the centers
        of the objects.

     INPUTS:
      inputRaster (Image Service / Raster Layer / MapServer / Map Server Layer / Internet Tiled Layer / String):
          The input image to classify. It can be an image service URL, a raster
          layer, an image service, a map server layer, or an internet tiled
          layer.
      inputModel (File):
          The input model can be a file or a URL of a deep learning package
          (.dlpk) item from the portal.
      outputName (String):
          The name of the output feature service of detected objects.
      modelArguments {Value Table}:
          The function model arguments are defined in the Python raster function
          class referenced by the input model. This is where you list additional
          deep learning parameters and arguments for experiments and refinement,
          such as a confidence threshold for fine tuning the sensitivity. The
          names of the arguments are populated by the tool from reading the
          Python module on the RA server.
      runNMS {Boolean}:
          Specifies whether non maximum suppression, where duplicate objects are
          identified and the duplicate feature with a lower confidence value is
          removed, will be performed.

          * NO_NMS-All detected objects will be in the output feature class.
          This is the default.

          * NMS-Duplicate detected objects will be removed.
      confidenceScoreField {String}:
          The field in the feature service that contains the confidence scores
          that will be used as output by the object detection method.This
          parameter is required when the NMS keyword is used for the runNMS
          parameter.
      classValueField {String}:
          The class value field in the feature service. If not specified, the
          tool will use the standard class value fields Classvalue and Value. If
          these fields do not exist, all features will be treated as the same
          object class.
      maxOverlapRatio {Double}:
          The maximum overlap ratio for two overlapping features, which is
          defined as the ratio of intersection area over union area. The default
          is 0."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetectObjectsUsingDeepLearning_ra(*gp_fixargs((inputRaster, inputModel, outputName, modelArguments, runNMS, confidenceScoreField, classValueField, maxOverlapRatio), True)))
        return retval
    except Exception as e:
        raise e


# Generalize toolset
@gptooldoc('Nibble_ra', None)
def Nibble(inputRaster=None, inputMaskRaster=None, outputName=None, nibbleValues=None, nibbleNodata=None, inputZoneRaster=None):
    """Nibble_ra(inputRaster, inputMaskRaster, outputName, {nibbleValues}, {nibbleNodata}, {inputZoneRaster})

        Replaces cells of a raster corresponding to a mask with the values of
        the nearest neighbors.

     INPUTS:
      inputRaster (Image Service / Raster Layer / String):
          The input raster that will be nibbled.The raster can be either integer
          or floating point type.
      inputMaskRaster (Image Service / Raster Layer / String):
          The raster used as the mask.The cells that are NoData define the cells
          that will be nibbled, or
          replaced, by the value of the closest nearest neighbour.
      outputName (String):
          The name of the output nibble raster service.The default name is based
          on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      nibbleValues {Boolean}:
          Keywords defining if NoData values in the input raster are allowed to
          nibble into the area defined by the mask raster.

          * ALL_VALUES-Specifies that the nearest neighbor value will be used
          whether it is NoData or another data value in the input raster. NoData
          values in the input raster are free to nibble into areas defined in
          the mask if they are the nearest neighbor. This is the default.

          * DATA_ONLY-Specifies that only data values are free to nibble into
          areas defined in the mask raster. NoData values in the input raster
          are not allowed to nibble into areas defined in the mask raster even
          if they are the nearest neighbor.
      nibbleNodata {Boolean}:
          Keywords defining if NoData cells in the input raster that are within
          the mask will remain NoData in the output raster.

          * PRESERVE_NODATA-Specifies that NoData cells in the input raster and
          within the mask will remain NoData in the output. This is the default.

          * PROCESS_NODATA-Specifies that NoData cells in the input raster and
          within the mask can be nibbled into valid output cell values.
      inputZoneRaster {Image Service / Raster Layer / String}:
          The input zone raster. For each zone, input cells that are within the
          mask will be replaced only by the nearest cell values within that same
          zone.A zone is all the cells in a raster that have the same value,
          whether
          or not they are contiguous. The input zone layer defines the shape,
          values, and locations of the zones. The zone raster can be either
          integer or floating point type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Nibble_ra(*gp_fixargs((inputRaster, inputMaskRaster, outputName, nibbleValues, nibbleNodata, inputZoneRaster), True)))
        return retval
    except Exception as e:
        raise e


# Hydrology toolset
@gptooldoc('Fill_ra', None)
def Fill(inputSurfaceRaster=None, outputName=None, zLimit=None):
    """Fill_ra(inputSurfaceRaster, outputName, {zLimit})

        Fills sinks in a surface raster to remove small imperfections in the
        data.

     INPUTS:
      inputSurfaceRaster (Image Service / Raster Layer / String):
          The input raster representing a continuous surface.
      outputName (String):
          The name of the output fill raster service.The default name is based
          on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      zLimit {Double}:
          Maximum elevation difference between a sink and its pour point to be
          filled."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Fill_ra(*gp_fixargs((inputSurfaceRaster, outputName, zLimit), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FlowAccumulation_ra', None)
def FlowAccumulation(inputFlowDirectionRaster=None, outputName=None, inputWeightRaster=None, dataType=None, flowDirectionType=None):
    """FlowAccumulation_ra(inputFlowDirectionRaster, outputName, {inputWeightRaster}, {dataType}, {flowDirectionType})

        Creates a raster of accumulated flow into each cell.

     INPUTS:
      inputFlowDirectionRaster (Image Service / Raster Layer / String):
          The input raster that shows the direction of flow out of each cell.The
          flow direction raster can be created using the D8, Multiple Flow
          Direction (MFD), or D-Infinity method. Use the flowDirectionType
          parameter to specify the method used when the flow direction raster
          was created.
      outputName (String):
          The name of the output flow accumulation raster service.The default
          name is based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      inputWeightRaster {Image Service / Raster Layer / String}:
          An optional integer input raster for applying a weight to each cell.
      dataType {String}:
          The output accumulation raster can be integer, floating or double
          type.

          * FLOAT-The output raster will be floating point type. This is the
          default.

          * INTEGER-The output raster will be integer type.

          * DOUBLE-The output raster will be double type.
      flowDirectionType {String}:
          Specifies the input flow direction raster type.

          * D8-The input flow direction raster is of type D8. This is the
          default.

          * MFD-The input flow direction raster is of type Multi Flow Direction
          (MFD).

          * DINF-The input flow direction raster is of type D-Infinity (DINF)."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FlowAccumulation_ra(*gp_fixargs((inputFlowDirectionRaster, outputName, inputWeightRaster, dataType, flowDirectionType), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FlowDirection_ra', None)
def FlowDirection(inputSurfaceRaster=None, outputFlowDirectionName=None, forceFlow=None, flowDirectionType=None, outputDropName=None):
    """FlowDirection_ra(inputSurfaceRaster, outputFlowDirectionName, {forceFlow}, {flowDirectionType}, {outputDropName})

        Calculates the direction of flow from each cell to its downslope
        neighbor or neighbors using the D8, D-Infinity (DINF), or Multiple
        Flow Direction (MFD) method.

     INPUTS:
      inputSurfaceRaster (Image Service / Raster Layer / String):
          The input raster representing a continuous surface.
      outputFlowDirectionName (String):
          The name of the output flow direction raster service.The default name
          is based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      forceFlow {Boolean}:
          Keywords defining if NoData values in the input raster are allowed to
          nibble into the area defined by the mask raster.

          * NORMAL-If the maximum drop on the inside of an edge cell is greater
          than zero, the flow direction will be determined as usual; otherwise,
          the flow direction will be toward the edge. Cells that should flow
          from the edge of the surface raster inward will do so. This is the
          default.

          * FORCE-All cells at the edge of the surface raster will flow outward
          from the surface raster.
      flowDirectionType {String}:
          Specifies the type of flow method to use while computing flow
          directions.

          * D8-Assign a flow direction based on the D8 flow method. This method
          assigns flow direction to the steepest downslope neighbor. This is the
          default.

          * MFD-Assign a flow direction based on the MFD flow method. This
          method assigns multiple flow directions towards all downslope
          neighbors.

          * DINF-Assign a flow direction based on the D-Infinity flow method
          using the steepest slope of a triangular facet.
      outputDropName {String}:
          The name of the output drop raster service.The default name is based
          on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FlowDirection_ra(*gp_fixargs((inputSurfaceRaster, outputFlowDirectionName, forceFlow, flowDirectionType, outputDropName), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FlowDistance_ra', None)
def FlowDistance(inputStreamRaster=None, inputSurfaceRaster=None, outputName=None, inputFlowDirectionRaster=None, distanceType=None, flowDirectionType=None, statisticsType=None):
    """FlowDistance_ra(inputStreamRaster, inputSurfaceRaster, outputName, {inputFlowDirectionRaster}, {distanceType}, {flowDirectionType}, {statisticsType})

        Computes, for each cell, the horizontal or vertical component of
        downslope distance, following the flow paths, to cells on a stream
        into which they flow. In case of multiple flow paths, minimum,
        weighted mean, or maximum flow distance can be computed.If an optional
        flow direction raster is provided, the down slope
        directions will be limited to those defined by the input flow
        direction raster.

     INPUTS:
      inputStreamRaster (Image Service / Raster Layer / String):
          The input raster that defines the stream network.
      inputSurfaceRaster (Image Service / Raster Layer / String):
          The input raster representing a continuous surface.
      outputName (String):
          The name of the output flow distance raster service.The default name
          is based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      inputFlowDirectionRaster {Image Service / Raster Layer / String}:
          The input raster that shows the direction of flow out of each
          cell.When a flow direction raster is provided, the down slope
          direction(s)
          will be limited to those defined by the input flow directions.The flow
          direction raster can be created using the D8, Multiple Flow
          Direction (MFD), or D-Infinity method. Use the flowDirectionType
          parameter to specify the method used when the flow direction raster
          was created.
      distanceType {String}:
          The distance type to be calculated.

          * VERTICAL-The flow distance calculations represent the vertical
          component of minimum flow distance, following the flow path, from each
          cell in the domain to cell(s) on the stream into which they flow. This
          is the default.

          * HORIZONTAL-The flow distance calculations represent the horizontal
          component of minimum flow distance, following the flow path, from each
          cell in the domain to cell(s) on the stream into which they flow.
      flowDirectionType {String}:
          Specifies the input flow direction raster type.

          * D8-The input flow direction raster is of type D8. This is the
          default.

          * MFD-The input flow direction raster is of type Multi Flow Direction
          (MFD).

          * DINF-The input flow direction raster is of type D-Infinity (DINF).
      statisticsType {String}:
          Determines the statistics type used to compute flow distance over
          multiple flow paths.If there exists only a single flow path from each
          cell to a cell on
          the stream, all statistics types produce the same result.

          * MINIMUM-Where multiple flow paths exist, minimum flow distance is
          computed. This is the default.

          * WEIGHTED_MEAN-Where multiple flow paths exist, a weighted mean of
          flow distance is computed. Flow proportion from a cell to its
          downstream neighboring cells is used as a weight for computing
          weighted mean.

          * MAXIMUM-When multiple flow paths exist, maximum flow distance is
          computed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FlowDistance_ra(*gp_fixargs((inputStreamRaster, inputSurfaceRaster, outputName, inputFlowDirectionRaster, distanceType, flowDirectionType, statisticsType), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StreamLink_ra', None)
def StreamLink(inputStreamRaster=None, inputFlowDirectionRaster=None, outputName=None):
    """StreamLink_ra(inputStreamRaster, inputFlowDirectionRaster, outputName)

        Assigns unique values to sections of a raster linear network between
        intersections.

     INPUTS:
      inputStreamRaster (Image Service / Raster Layer / String):
          An input raster that represents a linear stream network.
      inputFlowDirectionRaster (Image Service / Raster Layer / String):
          The input raster that shows the direction of flow out of each cell.
      outputName (String):
          The name of the output stream link raster service.The default name is
          based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StreamLink_ra(*gp_fixargs((inputStreamRaster, inputFlowDirectionRaster, outputName), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Watershed_ra', None)
def Watershed(inputFlowDirectionRaster=None, inPourPointRasterOrFeatures=None, outputName=None, pourPointField=None):
    """Watershed_ra(inputFlowDirectionRaster, inPourPointRasterOrFeatures, outputName, {pourPointField})

        Determines the contributing area above a set of cells in a raster.

     INPUTS:
      inputFlowDirectionRaster (Image Service / Raster Layer / String):
          The input raster that shows the direction of flow out of each cell.
      inPourPointRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          The input pour point locations.
      outputName (String):
          The name of the output watershed raster service.The default name is
          based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      pourPointField {String}:
          Field used to assign values to the pour point locations."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Watershed_ra(*gp_fixargs((inputFlowDirectionRaster, inPourPointRasterOrFeatures, outputName, pourPointField), True)))
        return retval
    except Exception as e:
        raise e


# Manage Data toolset
@gptooldoc('ConvertFeatureToRaster_ra', None)
def ConvertFeatureToRaster(inputFeatures=None, valueField=None, outputName=None, outputCellSize=None):
    """ConvertFeatureToRaster_ra(inputFeatures, valueField, outputName, {outputCellSize})

        Converts features to a raster dataset.

     INPUTS:
      inputFeatures (Feature Set):
          The input feature layer.
      valueField (Field):
          Choose the field that will be used to assign values to the output
          raster.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      outputCellSize {Linear Unit}:
          Enter the cell size and unit for the output raster.The units can be in
          Kilometers, Meters, Miles, or Feet.The default units are Meters."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertFeatureToRaster_ra(*gp_fixargs((inputFeatures, valueField, outputName, outputCellSize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ConvertRasterToFeature_ra', None)
def ConvertRasterToFeature(inputRaster=None, field=None, outputType=None, simplifyLinesOrPolygons=None, outputName=None):
    """ConvertRasterToFeature_ra(inputRaster, {field}, {outputType}, {simplifyLinesOrPolygons}, outputName)

        Converts a raster to a feature dataset, as points, lines, or polygons.

     INPUTS:
      inputRaster (Image Service / Raster Layer / String):
          The input raster layer.
      field {String}:
          Provide a field that specifies which value will be used for the
          conversion.It can be any integer or text value.A field containing
          floating-point values can only be used if the
          output is to a point dataset.The default choice is to use the Value
          field, which contains the value
          in each raster cell.
      outputType {String}:
          Choose the output type between point, line, or polygon.

          * POINT-The raster will be converted to a point dataset. This is the
          default.

          * LINE-The raster will be converted to a line feature dataset.

          * POLYGON-The raster will be converted to a polygon feature dataset.
      simplifyLinesOrPolygons {Boolean}:
          Set if lines should be simplified.

          * SIMPLIFY-The line or polygon features will be smoothed out to
          produce a more generalized result. This is the default.

          * NO_SIMPLIFY-The line or polygon features will follow the cell
          boundaries of the raster dataset.
          This parameter is only supported if the outputType is line or polygon.
      outputName (String):
          The output feature class that will contain the converted point, line
          or polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ConvertRasterToFeature_ra(*gp_fixargs((inputRaster, field, outputType, simplifyLinesOrPolygons, outputName), True)))
        return retval
    except Exception as e:
        raise e


# Summarize Data toolset
@gptooldoc('SummarizeRasterWithin_ra', None)
def SummarizeRasterWithin(inputZoneLayer=None, zoneField=None, inputRasterLayertoSummarize=None, outputName=None, statisticType=None, ignoreMissingValues=None):
    """SummarizeRasterWithin_ra(inputZoneLayer, zoneField, inputRasterLayertoSummarize, outputName, {statisticType}, {ignoreMissingValues})

        Summarizes a raster based on areas (zones) defined by the first input
        layer.

     INPUTS:
      inputZoneLayer (Image Service / Feature Layer / Raster Layer / String):
          The layer that defines the boundaries of the areas. Both raster and
          feature services can be used for the zone input.You specify a field to
          define the boundaries of the zones.
      zoneField (String):
          The field that defines each zone.It can be an integer or a string
          field of the zone dataset.
      inputRasterLayertoSummarize (Image Service / Raster Layer / String):
          Choose the raster layer you want to summarize.
      outputName (String):
          The name of the output raster service.The default name is based on the
          tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      statisticType {String}:
          Choose the statistic to calculate.The available options when the
          summarize raster is integer are
          Average, Majority, Maximum, Median, Minimum, Minority, Range, Standard
          deviation, Sum, and Variety.If the summarize raster is float, the
          options are Average, Maximum,
          Minimum, Range, Standard deviation, and Sum.

          * MEAN-Calculates the average of all cells in the raster layer to be
          summarized that belong to the same zone as the output cell. This is
          the default.

          * MAJORITY-Determines the value that occurs most often of all cells
          in the raster layer to be summarized that belong to the same zone as
          the output cell.

          * MAXIMUM-Determines the largest value of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * MEDIAN-Determines the median value of all cells in the raster layer
          to be summarized that belong to the same zone as the output cell.

          * MINIMUM-Determines the smallest value of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * MINORITY-Determines the value that occurs least often of all cells
          in the raster layer to be summarized that belong to the same zone as
          the output cell.

          * RANGE-Calculates the difference between the largest and smallest
          value of all cells in the raster layer to be summarized that belong to
          the same zone as the output cell.

          * STD-Calculates the standard deviation of all cells in the raster
          layer to be summarized that belong to the same zone as the output
          cell.

          * SUM-Calculates the total value of all cells in the raster layer to
          be summarized that belong to the same zone as the output cell.

          * VARIETY-Calculates the number of unique values for all cells in the
          raster layer to be summarized that belong to the same zone as the
          output cell.
      ignoreMissingValues {Boolean}:
          Specify whether missing values in the raster layer to summarize will
          influence the results of the areas they fall within.

          * DATA-Within any particular area, only cells that have a value in the
          raster layer being summarized will be used in determining the output
          value for that area. Any missing or NoData cells will be ignored in
          the statistic calculation. This is the default.

          * NODATA-Within any particular area, if any cells in the raster layer
          being summarized do not have a value, it is deemed that there is
          insufficient information to perform statistical calculations for all
          the cells in that zone; therefore, the entire zone will receive the
          NoData value on the output raster."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeRasterWithin_ra(*gp_fixargs((inputZoneLayer, zoneField, inputRasterLayertoSummarize, outputName, statisticType, ignoreMissingValues), True)))
        return retval
    except Exception as e:
        raise e


# Use Proximity toolset
@gptooldoc('CalculateDistance_ra', None)
def CalculateDistance(inputSourceRasterOrFeatures=None, outputDistanceName=None, maximumDistance=None, outputCellSize=None, outputDirectionName=None, outputAllocationName=None, allocationField=None):
    """CalculateDistance_ra(inputSourceRasterOrFeatures, outputDistanceName, {maximumDistance}, {outputCellSize}, {outputDirectionName}, {outputAllocationName}, {allocationField})

        Calculates the Euclidean distance from a single source or set of
        sources.

     INPUTS:
      inputSourceRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          The layer that defines the sources to calculate the distance to. The
          layer can be image service or feature service.For image service, the
          input type can be integer or floating point.For feature service, the
          input can be point, line or polygon.
      outputDistanceName (String):
          The name of the output distance raster service.
      maximumDistance {Linear Unit}:
          The maximum distance to calculate out to.The units can be in
          Kilometers, Meters, Miles, Yards, or Feet.The default units are
          Meters.
      outputCellSize {Linear Unit}:
          Set the cell size and units for the output raster.The units can be in
          Kilometers, Meters, Miles, Yards, or Feet.The default units are
          Meters.
      outputDirectionName {String}:
          The name of the output direction raster service.
      outputAllocationName {String}:
          The name of the output allocation raster service.
      allocationField {String}:
          A field on the source input that holds the values that define each
          source."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateDistance_ra(*gp_fixargs((inputSourceRasterOrFeatures, outputDistanceName, maximumDistance, outputCellSize, outputDirectionName, outputAllocationName, allocationField), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CalculateTravelCost_ra', None)
def CalculateTravelCost(inputSourceRasterOrFeatures=None, outputDistanceName=None, inputCostRaster=None, inputSurfaceRaster=None, maximumDistance=None, inputHorizontalRaster=None, horizontalFactor=None, inputVerticalRaster=None, verticalFactor=None, sourceCostMultiplier=None, sourceStartCost=None, sourceResistanceRate=None, sourceCapacity=None, sourceTravelDirection=None, outputBacklinkName=None, outputAllocationName=None, allocationField=None):
    """CalculateTravelCost_ra(inputSourceRasterOrFeatures, outputDistanceName, {inputCostRaster}, {inputSurfaceRaster}, {maximumDistance}, {inputHorizontalRaster}, {horizontalFactor}, {inputVerticalRaster}, {verticalFactor}, {sourceCostMultiplier}, {sourceStartCost}, {sourceResistanceRate}, {sourceCapacity}, {sourceTravelDirection}, {outputBacklinkName}, {outputAllocationName}, {allocationField})

        Calculates the least accumulative cost distance from or to the least-
        cost source, while accounting for surface distance along with
        horizontal and vertical cost factors.

     INPUTS:
      inputSourceRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          The layer that defines the sources to calculate the distance to. The
          layer can be raster or feature.
      outputDistanceName (String):
          The name of the output distance raster service.The cost distance image
          service identifies, for each cell, the least
          accumulative cost distance over a cost surface to the identified
          source locations.
      inputCostRaster {Image Service / Raster Layer / String}:
          A raster defining the impedance or cost to move planimetrically
          through each cell.The value at each cell location represents the cost-
          per-unit distance
          for moving through the cell. Each cell location value is multiplied by
          the cell resolution while also compensating for diagonal movement to
          obtain the total cost of passing through the cell.The values of the
          cost raster can be integer or floating point, but
          they cannot be negative or zero (you cannot have a negative or zero
          cost).
      inputSurfaceRaster {Image Service / Raster Layer / String}:
          A raster defining the elevation values at each cell location. The
          values are used to calculate the actual surface distance covered when
          passing between cells.
      maximumDistance {Double}:
          Defines the threshold that the accumulative cost values cannot exceed.
      inputHorizontalRaster {Image Service / Raster Layer / String}:
          A raster defining the horizontal direction at each cell.The values on
          the raster must be integers ranging from 0 to 360, with
          0 degrees being north, or toward the top of the screen, and increasing
          clockwise. Flat areas should be given a value of -1.The values at each
          location will be used in conjunction with the
          {horizontal_factor} to determine the horizontal cost incurred when
          moving from a cell to its neighbors.
      horizontalFactor {Horizontal Factor}:
          The Horizontal Factor defines the relationship between the horizontal
          cost factor and the horizontal relative moving angle.There are several
          factors with modifiers from which to select that
          identify a defined horizontal factor graph. Additionally, a table can
          be used to create a custom graph. The graphs are used to identify the
          horizontal factor used in calculating the total cost of moving into a
          neighboring cell.In the explanations below, two acronyms are used: HF
          stands for
          horizontal factor, which defines the horizontal difficulty encountered
          when moving from one cell to the next; and HRMA stands for horizontal
          relative moving angle, which identifies the angle between the
          horizontal direction from a cell and the moving direction.There are
          several types of horizontal factor available:

          * Binary-Indicates that if the HRMA is less than the cut angle, the HF
          is set to the value associated with the zero factor; otherwise, it is
          infinity.

          * Forward-Establishes that only forward movement is allowed. The HRMA
          must be greater or equal to 0 and less than 90 degrees (0 <= HRMA <
          90). If the HRMA is greater than 0 and less than 45 degrees, the HF
          for the cell is set to the value associated with the zero factor. If
          the HRMA is greater than or equal to 45 degrees, the side value
          modifier value is used. The HF for any HRMA equal to or greater than
          90 degrees is set to infinity.

          * Linear-Specifies that the HF is a linear function of the HRMA.

          * Inverse Linear-Specifies that the HF is an inverse linear function
          of the HRMA.
          The default is Binary.Characteristics for the horizontal keywords:

          * Zero factor-Establishes the horizontal factor to be used when the
          HRMA is zero. This factor positions the y-intercept for any of the
          horizontal factor functions.

          * Cut angle-Defines the HRMA angle beyond which the HF will be set to
          infinity.

          * Slope-Establishes the slope of the straight line used with the
          Linear and Inverse Linear horizontal factor keywords. The slope is
          specified as a fraction of rise over run (for example, 45 percent
          slope is 1/45, which is input as 0.02222).

          * Side value-Establishes the HF when the HRMA is greater than or equal
          to 45 degrees and less than 90 degrees when the Forward horizontal
          factor keyword is specified.
      inputVerticalRaster {Image Service / Raster Layer / String}:
          A raster defining the vertical (z) value for each cell.
      verticalFactor {Vertical Factor}:
          The Vertical Factor defines the relationship between the vertical cost
          factor and the vertical relative moving angle (VRMA).There are several
          factors with modifiers from which to select that
          identify a defined vertical factor graph. Additionally, a table can be
          used to create a custom graph. The graphs are used to identify the
          vertical factor used in calculating the total cost for moving into a
          neighboring cell.In the explanations below, two acronyms are used: VF
          stands for
          vertical factor, which defines the vertical difficulty encountered in
          moving from one cell to the next; and VRMA stands for vertical
          relative moving angle, which identifies the slope angle between the
          FROM or processing cell and the TO cell.There are several types of
          vertical factor available:

          * Binary-Specifies that if the VRMA is greater than the low-cut angle
          and less than the high-cut angle, the VF is set to the value
          associated with the zero factor; otherwise, it is infinity.

          * Linear-Indicates that the VF is a linear function of the VRMA.

          * Symmetric Linear-Specifies that the VF is a linear function of the
          VRMA in either the negative or positive side of the VRMA,
          respectively, and the two linear functions are symmetrical with
          respect to the VF (y) axis.

          * Inverse Linear-Indicates that the VF is an inverse linear function
          of the VRMA.

          * Symmetric Inverse Linear-Specifies that the VF is an inverse linear
          function of the VRMA in either the negative or positive side of the
          VRMA, respectively, and the two linear functions are symmetrical with
          respect to the VF (y) axis.

          * Cos-Identifies the VF as the cosine-based function of the VRMA.

          * Sec-Identifies the VF as the secant-based function of the VRMA.

          * Cos-Sec-Specifies that the VF is the cosine-based function of the
          VRMA when the VRMA is negative and the secant-based function of the
          VRMA when the VRMA is nonnegative.

          * Sec-Cos-Specifies that the VF is the secant-based function of the
          VRMA when the VRMA is negative and the cosine-based function of the
          VRMA when the VRMA is nonnegative.
          The default is Binary.Characteristics for the vertical keywords:

          * Zero factor-Establishes the vertical factor used when the VRMA is
          zero. This factor positions the y-intercept of the specified function.
          By definition, the zero factor is not applicable to any of the
          trigonometric vertical functions (COS, SEC, COS-SEC, or SEC-COS). The
          y-intercept is defined by these functions.

          * Low Cut angle-Defines the VRMA angle below which the VF will be set
          to infinity.

          * High Cut angle-Defines the VRMA angle above which the VF will be set
          to infinity.

          * Slope-Establishes the slope of the straight line used with the
          Linear and Inverse Linear vertical-factor keywords. The slope is
          specified as a fraction of rise over run (for example, 45 percent
          slope is 1/45, which is input as 0.02222).
      sourceCostMultiplier {String}:
          Multiplier to apply to the cost values.Allows for control of the mode
          of travel or the magnitude at a source.
          The greater the multiplier, the greater the cost to move through each
          cell.The values must be greater than zero. The default is 1.
      sourceStartCost {String}:
          The starting cost from which to begin the cost calculations.Allows for
          the specification of the fixed cost associated with a
          source. Instead of starting at a cost of zero, the cost algorithm will
          begin with the value set by sourceStartCost.The values must be zero or
          greater. The default is 0.
      sourceResistanceRate {String}:
          This parameter simulates the increase in the effort to overcome costs
          as the accumulative cost increases. It is used to model fatigue of the
          traveler. The growing accumulative cost to reach a cell is multiplied
          by the resistance rate and added to the cost to move into the
          subsequent cell.It is a modified version of a compound interest rate
          formula that is
          used to calculate the apparent cost of moving through a cell. As the
          value of the resistance rate increases, it increases the cost of the
          cells that are visited later. The greater the resistance rate, the
          more additional cost is added to reach the next cell, which is
          compounded for each subsequent movement. Since the resistance rate is
          similar to a compound rate and generally the accumulative cost values
          are very large, small resistance rates are suggested, such as 0.02,
          0.005, or even smaller, depending on the accumulative cost values.The
          values must be zero or greater. The default is 0.
      sourceCapacity {String}:
          Defines the cost capacity for the traveler for a source.The cost
          calculations continue for each source until the specified
          capacity is reached.The values must be greater than zero. The default
          capacity is to the
          edge of the output raster.
      sourceTravelDirection {String}:
          Defines the direction of the traveler when applying horizontal and
          vertical factors, the source resistance rate, and the source starting
          cost.

          * FROM_SOURCE-The horizontal factor, vertical factor, source
          resistance rate, and source starting cost will be applied beginning at
          the input source, and moving out to the non-source cells. This is the
          default.

          * TO_SOURCE-The horizontal factor, vertical factor, source resistance
          rate, and source starting cost will be applied beginning at each non-
          source cell and moving back to the input source.
          Either specify the FROM_SOURCE or TO_SOURCE keyword, which will be
          applied to all sources, or specify a field in the source data that
          contains the keywords to identify the direction of travel for each
          source. That field must contain the strings FROM_SOURCE or TO_SOURCE.
      outputBacklinkName {String}:
          The name of the output backlink raster service.The backlink raster
          contains values of 0 through 8, which define the
          direction or identify the next neighboring cell (the succeeding cell)
          along the least accumulative cost path from a cell to reach its least-
          cost source, while accounting for surface distance as well as
          horizontal and vertical surface factors.If the path is to pass into
          the right neighbor, the cell will be
          assigned the value 1, 2 for the lower right diagonal cell, and
          continuing clockwise. The value 0 is reserved for source cells.
      outputAllocationName {String}:
          The name of the output allocation raster service.This raster
          identifies the zone of each source location (cell or
          feature) that could be reached with the least accumulative cost.The
          output raster is of integer type.
      allocationField {String}:
          A field on the source input that holds the values that define each
          source."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CalculateTravelCost_ra(*gp_fixargs((inputSourceRasterOrFeatures, outputDistanceName, inputCostRaster, inputSurfaceRaster, maximumDistance, inputHorizontalRaster, horizontalFactor, inputVerticalRaster, verticalFactor, sourceCostMultiplier, sourceStartCost, sourceResistanceRate, sourceCapacity, sourceTravelDirection, outputBacklinkName, outputAllocationName, allocationField), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DetermineOptimumTravelCostNetwork_ra', None)
def DetermineOptimumTravelCostNetwork(inputRegionsRasterOrFeatures=None, inputCostRaster=None, outputOptimumNetworkName=None, outputNeighborNetworkName=None):
    """DetermineOptimumTravelCostNetwork_ra(inputRegionsRasterOrFeatures, inputCostRaster, outputOptimumNetworkName, {outputNeighborNetworkName})

        Calculates the optimum cost network from a set of input regions.

     INPUTS:
      inputRegionsRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          The input regions that are to be connected by the least-cost
          network.Regions can be defined by either an image service or a feature
          service.If the region input is a raster, the regions are defined by
          groups of
          contiguous (adjacent) cells of the same value. Each region must be
          uniquely numbered. The cells that are not part of any region must be
          NoData. The raster type must be integer, and the values can be either
          positive or negative.If the region input is a feature, it can be
          polygons, lines, or
          points. Polygon feature regions cannot be composed of multipart
          polygons.
      inputCostRaster (Image Service / Raster Layer / String):
          A raster defining the impedance or cost to move planimetrically
          through each cell.The value at each cell location represents the cost-
          per-unit distance
          for moving through the cell. Each cell location value is multiplied by
          the cell resolution while also compensating for diagonal movement to
          obtain the total cost of passing through the cell.The values of the
          cost raster can be integer or floating point, but
          they cannot be negative or zero (you cannot have a negative or zero
          cost).
      outputOptimumNetworkName (String):
          The name of the output optimum network feature service.The polyline
          feature service of the optimum (least-cost) network of
          paths necessary to connect each of the input regions.Each path (or
          line) is uniquely numbered, and additional fields in the
          attribute table store specific information about the path. Those
          fields include the following:

          * PATHID-Unique identifier for the path

          * PATHCOST-Total accumulative cost for the path

          * REGION1-The first region the path connects

          * REGION2-The other region the path connects
          This information provides you insight into the paths within the
          network.Since each path is represented by a unique line, there will be
          multiple lines in locations where paths travel the same route.
      outputNeighborNetworkName {String}:
          The name of the output Neighbor network feature service.The polyline
          feature service identifying all paths from each region to
          each of its closest-cost neighbors.Each path (or line) is uniquely
          numbered, and additional fields in the
          attribute table store specific information about the path. Those
          fields include the following:

          * PATHID-Unique identifier for the path

          * PATHCOST-Total accumulative cost for the path

          * REGION1-The first region the path connects

          * REGION2-The other region the path connects
          This information provides you insight into the paths within the
          network and is particularly useful when deciding which paths should be
          removed if necessary.Since each path is represented by a unique line,
          there will be
          multiple lines in locations where paths travel the same route."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetermineOptimumTravelCostNetwork_ra(*gp_fixargs((inputRegionsRasterOrFeatures, inputCostRaster, outputOptimumNetworkName, outputNeighborNetworkName), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DetermineTravelCostPathAsPolyline_ra', None)
def DetermineTravelCostPathAsPolyline(inputSourceRasterOrFeatures=None, inputCostRaster=None, inputDestinationRasterOrFeatures=None, outputPolylineName=None, pathType=None):
    """DetermineTravelCostPathAsPolyline_ra(inputSourceRasterOrFeatures, inputCostRaster, inputDestinationRasterOrFeatures, outputPolylineName, {pathType})

        Calculates the least cost polyline path between sources and
        destinations.

     INPUTS:
      inputSourceRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          An image service or feature service that identifies the cells from
          which the least-cost path is determined to the destinations.If the
          input is an image service, the input consists of cells that
          have valid values (zero is a valid value), and the remaining cells
          must be assigned NoData.
      inputCostRaster (Image Service / Raster Layer / String):
          The name of a cost raster image service to be used to determine the
          least-cost path from the sources to the destinations.The value at each
          cell location represents the cost-per-unit distance
          for moving through the cell. Each cell location value is multiplied by
          the cell resolution while also compensating for diagonal movement to
          obtain the total cost of passing through the cell.The values of the
          cost raster can be integer or floating point, but
          they cannot be negative or zero (you cannot have a negative or zero
          cost).
      inputDestinationRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          An image service or feature service that identifies the cells to which
          the least-cost path is calculated.
      outputPolylineName (String):
          The name of the output polyline feature service.The polyline feature
          service of the optimum (least-cost) paths
          connecting sources and destinations.Each path (or line) is uniquely
          numbered, and has an additional field
          in the attribute table called DestID, which connects it back to the
          unique identifier on the destination raster.Since each path is
          represented by a unique line, there can be multiple
          lines in locations where paths travel the same route.
      pathType {String}:
          Specifies the manner in which the values and zones on the input
          destination data will be interpreted in the cost path calculations.

          * EACH_CELL-For each cell or location with valid values on the input
          destination data, a least-cost path is determined and saved on the
          output. With this option, each cell or location of the input
          destination data is treated separately, and a least-cost path is
          determined for each from cell.

          * EACH_ZONE-For each zone on the input destination data, a least-cost
          path is determined and saved to the output. With this option, the
          least-cost path for each zone begins at the location with the lowest
          cost distance weighting in the zone.

          * BEST_SINGLE-For all locations on the input destination data, the
          least-cost path is derived from the location with the minimum of the
          least-cost paths to source locations. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetermineTravelCostPathAsPolyline_ra(*gp_fixargs((inputSourceRasterOrFeatures, inputCostRaster, inputDestinationRasterOrFeatures, outputPolylineName, pathType), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DetermineTravelCostPathsToDestinations_ra', None)
def DetermineTravelCostPathsToDestinations(inputDestinationRasterOrFeatures=None, inputCostDistanceRaster=None, inputCostBacklinkRaster=None, outputName=None, destinationField=None, pathType=None):
    """DetermineTravelCostPathsToDestinations_ra(inputDestinationRasterOrFeatures, inputCostDistanceRaster, inputCostBacklinkRaster, outputName, {destinationField}, {pathType})

        Calculates specific paths between known sources and known
        destinations.

     INPUTS:
      inputDestinationRasterOrFeatures (Image Service / Feature Layer / Raster Layer / String):
          An image service or feature service that identifies the cells from
          which the least-cost path is determined to the least costly source.If
          the input is an image service, the input consists of cells that
          have valid values (zero is a valid value), and the remaining cells
          must be assigned NoData.
      inputCostDistanceRaster (Image Service / Raster Layer / String):
          The name of a cost distance image service to be used to determine the
          least-cost path from the destination locations to a source.The cost
          distance raster is usually created with the Calculate Travel
          Cost tool. The cost distance raster stores, for each cell, the minimum
          accumulative cost distance over a cost surface from each cell to a set
          of source cells.
      inputCostBacklinkRaster (Image Service / Raster Layer / String):
          The name of a cost back link raster used to determine the path to
          return to a source via the least-cost path.For each cell in the back
          link raster, a value identifies the neighbor
          that is the next cell on the least accumulative cost path from the
          cell to a single source cell or set of source cells.
      outputName (String):
          The name of the output travel cost paths raster service.The default
          name is based on the tool name and the input layer name.
          If the layer already exists, you will be prompted to provide another
          name.
      destinationField {String}:
          A field on the destination layer that holds the values that define
          each destination.Input feature service must contain at least one valid
          field.
      pathType {String}:
          Defines the manner in which the values and zones on the input
          destination data will be interpreted in the cost path calculations.

          * EACH_CELL-For each cell with valid values on the input destination
          data, a least-cost path is determined and saved on the output raster.
          With this option, each cell of the input destination data is treated
          separately, and a least-cost path is determined for each from cell.
          This is the default.

          * EACH_ZONE-For each zone on the input destination data, a least-cost
          path is determined and saved on the output raster. With this option,
          the least-cost path for each zone begins at the cell with the lowest
          cost distance weighting in the zone.

          * BEST_SINGLE-For all cells on the input destination data, the least-
          cost path is derived from the cell with the minimum of the least-cost
          paths to source cells."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DetermineTravelCostPathsToDestinations_ra(*gp_fixargs((inputDestinationRasterOrFeatures, inputCostDistanceRaster, inputCostBacklinkRaster, outputName, destinationField, pathType), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject