# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""Ready To Use tools are ArcGIS Online geoprocessing services which use
ArcGIS Online’s hosted data and analysis capabilities. You only need
to provide a few input features, as all the other data needed for the
analysis, as well as the computation, are hosted in ArcGIS Online. You
can use these tools to solve diverse spatial and network analysis
problems. Tools include viewshed, profile, watershed, routing,
directions, and service areas."""
__all__ = ['CreateMapArea', 'FindClosestFacilities', 'FindRoutes',
           'GenerateOriginDestinationCostMatrix', 'GenerateServiceAreas',
           'Profile', 'RefreshMapAreaPackage', 'SetupMapArea',
           'SolveLocationAllocation', 'SolveVehicleRoutingProblem',
           'SummarizeElevation', 'TraceDownstream', 'Viewshed', 'Watershed']
__alias__ = 'agolservices'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('CreateMapArea_agolservices', None)
def CreateMapArea(mapItemId=None, bookmark=None, extent=None, outputName=None):
    """CreateMapArea_agolservices(mapItemId, {bookmark}, {extent}, {outputName})

     INPUTS:
      mapItemId (String):
          Map Item ID
      bookmark {String}:
          Map Bookmark
      extent {String}:
          Extent
      outputName {String}:
          Output Name"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateMapArea_agolservices(*gp_fixargs((mapItemId, bookmark, extent, outputName), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindClosestFacilities_agolservices', None)
def FindClosestFacilities(Incidents=None, Facilities=None, Measurement_Units=None, Analysis_Region=None, Number_of_Facilities_to_Find=None, Cutoff=None, Travel_Direction=None, Use_Hierarchy=None, Time_of_Day=None, Time_of_Day_Usage=None, UTurn_at_Junctions=None, Point_Barriers=None, Line_Barriers=None, Polygon_Barriers=None, Restrictions=None, Attribute_Parameter_Values=None, Route_Shape=None, Route_Line_Simplification_Tolerance=None, Populate_Directions=None, Directions_Language=None, Directions_Distance_Units=None, Directions_Style_Name=None, Time_Zone_for_Time_of_Day=None, Travel_Mode=None, Impedance=None, Save_Output_Network_Analysis_Layer=None, Overrides=None, Save_Route_Data=None):
    """FindClosestFacilities_agolservices(Incidents, Facilities, Measurement_Units, {Analysis_Region}, {Number_of_Facilities_to_Find}, {Cutoff}, {Travel_Direction}, {Use_Hierarchy}, {Time_of_Day}, {Time_of_Day_Usage}, {UTurn_at_Junctions}, {Point_Barriers}, {Line_Barriers}, {Polygon_Barriers}, {Restrictions;Restrictions...}, {Attribute_Parameter_Values}, {Route_Shape}, {Route_Line_Simplification_Tolerance}, {Populate_Directions}, {Directions_Language}, {Directions_Distance_Units}, {Directions_Style_Name}, {Time_Zone_for_Time_of_Day}, {Travel_Mode}, {Impedance}, {Save_Output_Network_Analysis_Layer}, {Overrides}, {Save_Route_Data})

        Finds one or more facilities that are closest from an incident based
        on travel time or travel distance and outputs the best routes, driving
        directions between the incidents and the chosen facilities, and a copy
        of the chosen facilities. You can use the tool, for example, to find
        the closest hospital to an accident, the closest police cars to a
        crime scene, or the closest store to a customer's address., When
        finding closest facilities, you can specify how many to find and
        whether the direction of travel is toward or away from them. You can
        also specify the time of day to account for travel times based on live
        or predictive traffic conditions for that time and date. For instance,
        you can use the tool to search for hospitals within a 15-minute drive
        time of the site of an accident at a given time of day. Any hospitals
        that take longer than 15 minutes to reach based on the traffic
        conditions will not be included in the results.

     INPUTS:
      Incidents (Feature Set):
          Specify one or more incidents (up to 1,000). These are the locations
          from which the tool searches for the nearby locations.When specifying
          the incidents, you can set properties for each one,
          such as its name or service time, by using attributes. The incidents
          can be specified with the following attributes: Name-The name of the
          incident. The name is used in the driving
          directions. If the name is not specified, a unique name prefixed with
          Location is automatically generated in the output routes and
          directions. ID-A unique identifier for the incident. The identifier is
          included
          in the output routes (as the IncidentID field) and can help join
          additional information from the output routes, such as the total
          travel time or total distance, to attributes from your incidents or
          vice versa. If the ID isn't specified, the service autogenerates a
          unique identifier for each incident. AdditionalTime-The amount of time
          spent at the incident, which is
          added to the total time of the route. The units for this attribute
          value are specified by the Measurement Units parameter. The attribute
          value is included in the analysis only when the measurement units are
          time based. The default value is 0.If you are finding the closest fire
          stations from fire incidents to
          estimate response times, the AdditionalTime attribute can store the
          amount of time it takes firefighters to hook up their equipment at the
          location of the incident before they can begin fighting the fire.
          AdditionalDistance-The extra distance traveled at the incident, which
          is added to the total distance of the route. The units for this
          attribute value are specified by the Measurement Units parameter. The
          attribute value is included in the analysis only when the measurement
          units are distance based. The default value is 0.Generally, the
          location of an incident, such as a home, isn't exactly
          on the streets; it is set back somewhat from the road. This attribute
          value can be used to model the distance between the actual incident
          location and its location on the street, if it is important to include
          that distance in the total travel distance. CurbApproach-Specifies the
          direction a vehicle may arrive at and
          depart from the incident. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          *  0 (Either side of vehicle)-The vehicle can approach and depart the
          incident in either direction, so a U-turn is allowed at the incident.
          This setting can be chosen if it is possible and practical for your
          vehicle to turn around at the incident. This decision may depend on
          the width of the road and the amount of traffic or whether the
          incident has a parking lot where vehicles can pull in and turn around.

          * 1 ( Right side of vehicle)-When the vehicle approaches and departs
          the incident, the incident must be on the right side of the vehicle. A
          U-turn is prohibited. This is typically used for vehicles such as
          buses that must arrive with the bus stop on the right-hand side.

          * 2 (Left side of vehicle)-When the vehicle approaches and departs the
          incident, the curb must be on the left side of the vehicle. A U-turn
          is prohibited. This is typically used for vehicles such as buses that
          must arrive with the bus stop on the left-hand side.

          *  3 (No U-Turn)-When the vehicle approaches the incident, the curb
          can be on either side of the vehicle; however, the vehicle must depart
          without turning around.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider an incident on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach an incident from one of two directions, that is, so it ends
          up on the right or left side of the vehicle. For example, if you want
          to arrive at an incident and not have a lane of traffic between the
          vehicle and the incident, you would choose Right side of vehicle (1)
          in the United States but Left side of vehicle (2) in the United
          Kingdom.
      Facilities (Feature Set):
          Specify one or more facilities (up to 1,000). These are the locations
          that are searched for when finding the closest location.When
          specifying the facilities, you can set properties for each one,
          such as its name or service time, by using attributes. The facilities
          can be specified with the following attributes: Name-The name of the
          facility. The name is used in the driving
          directions. If the name is not specified, a unique name prefixed with
          Location is automatically generated in the output routes and
          directions. ID-A unique identifier for the facility. The identifier is
          included
          in the output routes (as the FacilityID field) and the output closest
          facilities as FacilityID fields. The FacilityID field can be used to
          join additional information from the output routes, such as the total
          travel time or total distance, to attributes from your facilities. If
          the ID isn't specified, the service autogenerates a unique identifier
          for each facility. AdditionalTime-The amount of time spent at the
          facility, which is
          added to the total time of the route. The units for this attribute
          value are specified by the Measurement Units parameter. The attribute
          value is included in the analysis only when the measurement units are
          time based. The default value is 0.If you are finding the closest fire
          stations to fire incidents,
          AdditionalTime can store the time it tends to takes a crew to don the
          appropriate protective equipment and exit the fire station.
          AdditionalDistance-The extra distance traveled at the facility, which
          is added to the total distance of the route. The units for this
          attribute value are specified by the Measurement Units parameter. The
          attribute value is included in the analysis only when the measurement
          units are distance based. The default value is 0.Generally the
          location of a facility, such as a fire station, isn't
          exactly on a street; it is set back somewhat from the road.
          AdditionalDistance can model the distance between the actual facility
          location and its location on the street, if it is important to include
          that distance in the total travel distance. CurbApproach: Specifies
          the direction a vehicle may arrive at and
          depart from the facility. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          *  0 (Either side of vehicle)-The vehicle can approach and depart the
          facility in either direction, so a U-turn is allowed at the facility.
          This setting can be chosen if it is possible and practical for your
          vehicle to turn around at the facility. This decision may depend on
          the width of the road and the amount of traffic or whether the
          facility has a parking lot where vehicles can pull in and turn around.

          *  1 (Right side of vehicle)-When the vehicle approaches and departs
          the facility, the facility must be on the right side of the vehicle. A
          U-turn is prohibited. This is typically used for vehicles such as
          buses that must arrive with the bus stop on the right-hand side.

          *  2 (Left side of vehicle)-When the vehicle approaches and departs
          the facility, the curb must be on the left side of the vehicle. A
          U-turn is prohibited. This is typically used for vehicles such as
          buses that must arrive with the bus stop on the left-hand side.

          * 3 (No U-Turn)-When the vehicle approaches the facility, the curb can
          be on either side of the vehicle; however, the vehicle must depart
          without turning around.
          The CurbApproach property was designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider a facility on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach a facility from one of two directions, that is, so it ends up
          on the right or left side of the vehicle. For example, if you want to
          arrive at a facility and not have a lane of traffic between the
          vehicle and the facility, you would choose Right side of vehicle (1)
          in the United States but Left side of vehicle (2) in the United
          Kingdom.
      Measurement_Units (String):
          Specify the units that should be used to measure and report the total
          travel time or travel distance for the output routes. The tool finds
          the closest facility by measuring the travel time or the travel
          distance along streets.The units you choose for this parameter
          determine whether the tool
          will measure driving distance or driving time to find what is closest.
          Choose a time unit to measure driving time. To measure driving
          distance, choose a distance unit. Your choice also determines in which
          units the tool will report total driving time or distance in the
          results. The choices include the following:

          * Meters

          * Kilometers

          * Feet

          * Yards

          * Miles

          * NauticalMiles

          * Seconds

          * Minutes

          * Hours

          * Days
      Analysis_Region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      Number_of_Facilities_to_Find {Long}:
          Specify the number of closest facilities to find per incident. This
          is useful in situations, such as a fire, where multiple fire engines
          may be required from different fire stations. You can specify, for
          example, to find the three nearest fire stations to a fire.The tool
          can find up to 100 facilities from each incident.
      Cutoff {Double}:
          Specify the travel time or travel distance value at which to stop
          searching for facilities for a given incident. For instance, while
          finding the closest hospitals from the site of an accident, a cutoff
          value of 15 minutes would mean that the tool would search for the
          closest hospital within 15 minutes from the incident. If the closest
          hospital is 17 minutes away, no routes will be returned in the output
          routes. A cutoff value is especially useful when searching for
          multiple facilities. The units for this parameter is specified by the
          Measurement Units
          parameter.
      Travel_Direction {String}:
          Specify whether you want to search for the closest facility as
          measured from the incident to the facility or from the facility to the
          incident.

          *  Facility to Incident-Direction of travel is from facilities to
          incidents.

          *  Incident to Facility-Direction of travel is from incidents to
          facilities.
           Using one of the parameter values can find different facilities as
          the travel time along some streets may vary based on the travel
          direction and one-way restrictions. For instance, a facility may be a
          10-minute drive from the incident while traveling from the incident to
          the facility, but while traveling from the facility to the incident,
          it may be a 15-minute journey because of different travel time in that
          direction. If you are setting a value for Time of Day, traffic may
          also cause the Facility to Incident and Incident to Facility options
          to return different results. Fire departments commonly use the
          Facility to Incident value for the
          parameter since they are concerned with the time it takes to travel
          from the fire station (facility) to the location of the emergency
          (incident). A retail store (facility) is more concerned with the time
          it takes the shoppers (incidents) to reach the store; therefore,
          stores commonly choose Incident to Facility.
      Use_Hierarchy {Boolean}:
          Specify whether hierarchy should be used when finding the best route
          between the facility and the incident.

          *  Checked (True)-Use hierarchy when finding routes. When hierarchy is
          used, the tool prefers higher-order streets (such as freeways) to
          lower-order streets (such as local roads), and can be used to simulate
          the driver preference of traveling on freeways instead of local roads
          even if that means a longer trip. This is especially true when finding
          routes to faraway facilities, because drivers on long-distance trips
          tend to prefer traveling on freeways where stops, intersections, and
          turns can be avoided. Using hierarchy is computationally faster,
          especially for long-distance routes, as the tool has to select the
          best route from a relatively smaller subset of streets.

          *  Unchecked (False)-Do not use hierarchy when finding routes. If
          hierarchy is not used, the tool considers all the streets and doesn't
          prefer higher-order streets when finding the route. This is often used
          when finding short-distance routes within a city.
           The tool automatically reverts to using hierarchy if the straight-
          line distance between facilities and incidents is greater than 50
          miles, even if you have set this parameter to not use hierarchy.
      Time_of_Day {Date}:
          Specifies the time and date at which the routes should begin or end.
          The value is used as the start time or end time for the route
          depending on the value for the Time of Day Usage parameter. If you
          specify the current date and time as the value for this parameter, the
          tool will use live traffic conditions to find the closest facilities
          and the total travel time will be based on traffic conditions.
          Specifying a time of day results in more accurate estimation of
          travel time between the incident and facility because the travel times
          account for the traffic conditions that are applicable for that date
          and time.The Time Zone for Time of Day parameter specifies whether
          this time
          and date refer to UTC or the time zone in which the facility or
          incident is located.
      Time_of_Day_Usage {String}:
          Indicates whether the Time of Day parameter value represents the
          arrival or departure time for the routes.

          *  Start Time-When this option is chosen, the tool finds the best
          route considering the Time of Day parameter value as the departure
          time from the facility or incident.

          *  End Time-When this option is chosen, the tool considers the Time of
          Day parameter value as the arrival time at the facility or incident.
          This option is useful if you want to know what time to depart from a
          location so you arrive at the destination at the time specified in
          Time of Day.
      UTurn_at_Junctions {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges connect to the junction,
          which is known as junction valency. The acceptable values for this
          parameter are listed below; each is followed by a description of its
          meaning in terms of junction valency.

          *  Allowed-U-turns are permitted at junctions with any number of
          connected edges. This is the default value.

          *  Not Allowed-U-turns are prohibited at all junctions, regardless of
          junction valency. Note, however, that U-turns are still permitted at
          network locations even when this setting is chosen; however, you can
          set the individual network locations' CurbApproach property to
          prohibit U-turns there as well.

          *  Allowed only at Dead Ends-U-turns are prohibited at all junctions,
          except those that have only one adjacent edge (a dead end).

          *  Allowed only at Intersections and Dead Ends-U-turns are prohibited
          at junctions where exactly two adjacent edges meet but are permitted
          at intersections (junctions with three or more adjacent edges) and
          dead ends (junctions with exactly one adjacent edge). Oftentimes,
          networks have extraneous junctions in the middle of road segments.
          This option prevents vehicles from making U-turns at these locations.
      Point_Barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
           Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Measurement Units parameter.
          Additional_Distance: Indicates how much distance is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Measurement Units parameter.
      Line_Barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      Polygon_Barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
           ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the measurement
          units are time based. The field value must be greater than zero.
          ScaledDistanceFactor: This is the factor by which the distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the measurement
          units are distance based. The attribute value must be greater than
          zero.
      Restrictions {String}:
          Specify which restrictions should be honored by the tool when finding
          the best routes between incidents and facilities. A restriction
          represents a driving preference or requirement. In most cases,
          restrictions cause roads to be prohibited, but they can also cause
          them to be avoided or preferred. For instance, using an Avoid Toll
          Roads restriction will result in a route that will include toll roads
          only when it is absolutely required to travel on toll roads in order
          to visit an incident or a facility. Height Restriction makes it
          possible to route around any clearances that are lower than the height
          of your vehicle. If you are carrying corrosive materials on your
          vehicle, using the Any Hazmat Prohibited restriction prevents hauling
          the materials along roads where it is marked as illegal to do so.Below
          is a list of available restrictions and a short description.Some
          restrictions require an additional value to be specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      Attribute_Parameter_Values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The values you
          provide for this parameter are ignored unless Travel
          Mode is set to Custom. If you specify the Attribute Parameter Values
          parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      Route_Shape {String}:
          Specify the type of route features that are output by the tool. The
          parameter can be specified using one of the following values:

          *  True Shape:  Return the exact shape of the resulting route that is
          based on the
          underlying streets.

          *  True Shape with Measures:  Return the exact shape of the resulting
          route that is based on the
          underlying streets. Additionally, construct measures so the shape may
          be used in linear referencing. The measurements increase from the
          first stop and record the cumulative travel time or travel distance in
          the units specified by the Measurement Units parameter.

          *  Straight Line:  Return a straight line between two stops.

          *  None:  Do not return any shapes for the routes. This value can be
          useful, and
          return results quickly, in cases where you are only interested in
          determining the total travel time or travel distance of a route.
           When the Route Shape parameter is set to True Shape or True Shape
          with Measures, the generalization of the route shape can be further
          controlled using the appropriate value for the Route Line
          Simplification Tolerance parameter. No matter which value you choose
          for the Route Shape parameter, the
          best route is always determined by minimizing the travel time or the
          travel distance, never using the straight-line distance between stops.
          This means that only the route shapes are different, not the
          underlying streets that are searched when finding the route.
      Route_Line_Simplification_Tolerance {Linear Unit}:
          Specify by how much you want to simplify the geometry of the output
          lines for routes and directions.The tool ignores this parameter if the
          Route Shape parameter isn't set
          to True Shape. Simplification maintains critical points on a route,
          such as turns at
          intersections, to define the essential shape of the route and removes
          other points. The simplification distance you specify is the maximum
          allowable offset that the simplified line can deviate from the
          original line. Simplifying a line reduces the number of vertices that
          are part of the route geometry. This improves the tool execution time.
      Populate_Directions {Boolean}:
          Specify whether the tool should generate driving directions for each
          route.

          *  Checked (True):  Indicates that the directions will be generated
          and configured based
          on the values for the Directions Language, Directions Style Name, and
          Directions Distance Units parameters.

          *  Unchecked (False):  Directions are not generated, and the tool
          returns an empty Directions
          layer.
      Directions_Language {String}:
          Specify the language that should be used when generating driving
          directions.This parameter is used only when the Populate Directions
          parameter is
          checked, or set to True.The parameter value can be specified using one
          of the following two-
          or five-character language codes:

          *  ar-Arabic

          * cs-Czech

          *  de-German

          *  el-Greek

          *  en-English

          *  es-Spanish

          * et-Estonian

          *  fr-French

          *  he-Hebrew

          *  it-Italian

          *  ja-Japanese

          *  ko-Korean

          *  lt-Lithuanian

          * lv-Latvian

          *  nl-Dutch

          *  pl-Polish

          *  pt-BR-Brazilian Portuguese

          *  pt-PT-European Portuguese

          *  ru-Russian

          *  sv-Swedish

          * tr-Turkish

          *  zh-CN-Simplified Chinese
           If an unsupported language code is specified, the tool returns the
          directions using the default language, English.
      Directions_Distance_Units {String}:
          Specify the units for displaying travel distance in the driving
          directions. This parameter is used only when the Populate Directions
          parameter is checked, or set to True.

          * Miles

          * Kilometers

          * Meters

          * Feet

          * Yards

          * NauticalMiles
      Directions_Style_Name {String}:
          Specify the name of the formatting style for the directions. This
          parameter is used only when the Populate Directions parameter is
          checked, or set to True. The parameter can be specified using the
          following values:

          *  NA Desktop:  Generates turn-by-turn directions suitable for
          printing.

          *  NA Navigation:  Generates turn-by-turn directions designed for an
          in-vehicle
          navigation device.
      Time_Zone_for_Time_of_Day {String}:
          Specifies the time zone of the Time of Day parameter.

          *  Geographically Local:  The Time of Day parameter refers to the time
          zone in which the
          facilities or incidents are located.  If Time of Day Usage is set to
          Start Time and Travel Direction is
          Facility to Incident, this is the time zone of the facilities.  If
          Time of Day Usage is set to Start Time and Travel Direction is
          Incident to Facility, this is the time zone of the incidents.  If Time
          of Day Usage is set to End Time and Travel Direction is
          Facility to Incident, this is the time zone of the incidents.  If Time
          of Day Usage is set to End Time and Travel Direction is
          Incident to Facility, this is the time zone of the facilities.

          *  UTC:  The Time of Day parameter refers to Coordinated Universal
          Time (UTC).
          Choose this option if you want to find what's nearest for a specific
          time, such as now, but aren't certain in which time zone the
          facilities or incidents will be located.
           Irrespective of the Time Zone for Time of Day setting, if your
          facilities and incidents are in multiple time zones, the following
          rules are enforced by the tool:

          *  All incidents must be in the same time zone when:

          *  Specifying a start time and traveling from incident to facility.

          *  Specifying an end time and traveling from facility to incident.

          *  All facilities must be in the same time zone when:

          *  Specifying a start time and traveling from facility to incident.

          *  Specifying an end time and traveling from incident to facility.
      Travel_Mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, use the same GIS server
          connection you used to access this tool, and from the Utilities
          toolbox, run GetTravelModes. The GetTravelModes tool adds a table,
          Supported Travel Modes, to the application. Any value in the Travel
          Mode Name field from the Supported Travel Modes table can be specified
          as input. You can also specify the value from the Travel Mode Settings
          field as input. This speeds up the tool execution because the tool
          does not have to look up the settings based on the travel mode
          name.The default value, Custom, allows you to configure your own
          travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          traveling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get the analysis results you want. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of a new
          or existing travel mode so that everyone in your organization can
          rerun the analysis with the same settings.By choosing Custom, the
          values you set for the custom travel mode
          parameters are included in the analysis. Specifying another travel
          mode, as defined by your organization, causes any values you set for
          the custom travel mode parameters to be ignored; the tool overrides
          them with values from your specified travel mode.
      Impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel distance is an impedance; the length of
          a road in kilometers
          can be thought of as impedance. Travel distance in this sense is the
          same for all modes-a kilometer for a pedestrian is also a kilometer
          for a car. (What may change is the pathways on which the different
          modes are allowed to travel, which affects distance between points,
          and this is modeled by travel mode settings.)Travel time can also be
          an impedance; a car may take one minute to
          travel a mile along an empty road. Travel times can vary by travel
          mode-a pedestrian may take more than 20 minutes to walk the same mile,
          so it is important to choose the right impedance for the travel mode
          you are modeling.Choose from the following impedance values:

          *  Drive Time-Models travel times for a car. These travel times are
          dynamic and fluctuate according to traffic flows in areas where
          traffic data is available. This is the default value.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.

          *  Travel Distance-Stores length measurements along roads and paths.
          To
          model walk distance, choose this option and ensure Walking is set in
          the Restriction parameter. Similarly, to model drive or truck
          distance, choose Travel Distance here and set the appropriate
          restrictions so your vehicle travels only on roads where it is
          permitted to do so.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.If you choose Drive Time,
          Truck Time, or Walk Time, the Measurement
          Units parameter must be set to a time-based value; if you choose
          Travel Distance for Impedance, Measurement Units must be distance-
          based.
      Save_Output_Network_Analysis_Layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      Overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotation
          marks. The values can be a number, Boolean, or a string. The default
          value for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support.
      Save_Route_Data {Boolean}:
          Choose whether the output includes a zip file that contains a file
          geodatabase holding the inputs and outputs of the analysis in a format
          that can be used to share route layers with ArcGIS Online or Portal
          for ArcGIS.

          *  Checked (True)-Save the route data as a zip file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Route Data parameter in the entry corresponding
          to the tool execution in the Geoprocessing history of your Project. In
          ArcMap, the location of the file can be determined by accessing the
          Copy Location option in the shortcut menu on the Output Route Data
          parameter in the entry corresponding to the tool execution in the
          Geoprocessing Results window.

          *  Unchecked (False)-Do not save the route data. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindClosestFacilities_agolservices(*gp_fixargs((Incidents, Facilities, Measurement_Units, Analysis_Region, Number_of_Facilities_to_Find, Cutoff, Travel_Direction, Use_Hierarchy, Time_of_Day, Time_of_Day_Usage, UTurn_at_Junctions, Point_Barriers, Line_Barriers, Polygon_Barriers, Restrictions, Attribute_Parameter_Values, Route_Shape, Route_Line_Simplification_Tolerance, Populate_Directions, Directions_Language, Directions_Distance_Units, Directions_Style_Name, Time_Zone_for_Time_of_Day, Travel_Mode, Impedance, Save_Output_Network_Analysis_Layer, Overrides, Save_Route_Data), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('FindRoutes_agolservices', None)
def FindRoutes(Stops=None, Measurement_Units=None, Analysis_Region=None, Reorder_Stops_to_Find_Optimal_Routes=None, Preserve_Terminal_Stops=None, Return_to_Start=None, Use_Time_Windows=None, Time_of_Day=None, Time_Zone_for_Time_of_Day=None, UTurn_at_Junctions=None, Point_Barriers=None, Line_Barriers=None, Polygon_Barriers=None, Use_Hierarchy=None, Restrictions=None, Attribute_Parameter_Values=None, Route_Shape=None, Route_Line_Simplification_Tolerance=None, Populate_Route_Edges=None, Populate_Directions=None, Directions_Language=None, Directions_Distance_Units=None, Directions_Style_Name=None, Travel_Mode=None, Impedance=None, Time_Zone_for_Time_Windows=None, Save_Output_Network_Analysis_Layer=None, Overrides=None, Save_Route_Data=None):
    """FindRoutes_agolservices(Stops, Measurement_Units, {Analysis_Region}, {Reorder_Stops_to_Find_Optimal_Routes}, {Preserve_Terminal_Stops}, {Return_to_Start}, {Use_Time_Windows}, {Time_of_Day}, {Time_Zone_for_Time_of_Day}, {UTurn_at_Junctions}, {Point_Barriers}, {Line_Barriers}, {Polygon_Barriers}, {Use_Hierarchy}, {Restrictions;Restrictions...}, {Attribute_Parameter_Values}, {Route_Shape}, {Route_Line_Simplification_Tolerance}, {Populate_Route_Edges}, {Populate_Directions}, {Directions_Language}, {Directions_Distance_Units}, {Directions_Style_Name}, {Travel_Mode}, {Impedance}, {Time_Zone_for_Time_Windows}, {Save_Output_Network_Analysis_Layer}, {Overrides}, {Save_Route_Data})

        FindRoutes determines the shortest paths to visit the input stops
        and returns the driving directions, information about the visited
        stops, and the route paths, including travel time and distance. The
        tool is capable of finding routes that visit several input stops in a
        sequence you predetermine or in the sequence that minimizes overall
        travel. You can group the input stops into different routes using the
        RouteName field, and the tool will output one route for each group of
        stops, allowing you to generate routes for many vehicles in a single
        solve operation. When using FindRoutes to route multiple vehicles, you
        need to assign stops to routes before solving. If you need a tool that
        determines the best way to divide stops among different vehicles, and
        then route the vehicles, use the SolveVehicleRoutingProblem tool
        instead.

     INPUTS:
      Stops (Feature Set):
          Specify two or more stops to route between. You can add up to 10,000
          stops and assign up to 150 stops to a single route. (Assign stops to
          routes using the RouteName attribute.)When specifying the stops, you
          can set properties for each one, such
          as its name or service time, by using attributes. The stops can be
          specified with the following attributes:Name-The name of the stop. The
          name is used in the driving directions.
          If the name is not specified, a unique name prefixed with Location is
          automatically generated in the output stops, routes, and
          directions.RouteName-The name of the route to which the stop is
          assigned.
          Assigning the same route name to different stops causes those stops to
          be grouped together and visited by the same route. You can generate
          many routes in a single solve by assigning unique route names to
          different groups of stops. With this tool you can group up to 150
          stops into one route.Sequence-The output routes will visit the stops
          in the order you
          specify with this attribute. Within a group of stops that have the
          same RouteName value, the sequence number should be greater than 0 but
          not greater than the total number of stops. Also, the sequence number
          should not be duplicated.If Reorder Stops To Find Optimal Routes is
          checked (True), all but
          possibly the first and last sequence values for each route name are
          ignored so the tool can find the sequence that minimizes overall
          travel for each route. (The settings for Preserve Ordering of Stops
          and Return to Start determine whether the first or last sequence
          values for each route are ignored.)AdditionalTime-The amount of time
          spent at the stop, which is added to
          the total time of the route. The units for this attribute value are
          specified by the Measurement Units parameter. The attribute value is
          included in the analysis only when the measurement units are time
          based. The default value is 0.You can account for the extra time it
          takes at the stop to complete a
          task, such as to repair an appliance, deliver a package, or inspect
          the premises.AdditionalDistance-The extra distance traveled at the
          stops, which is
          added to the total distance of the route. The units for this attribute
          value are specified by the Measurement Units parameter. The attribute
          value is included in the analysis only when the measurement units are
          distance based. The default value is 0.Generally, the location of a
          stop, such as a home, isn't exactly on
          the streets; it is set back somewhat from the road. This attribute
          value can be used to model the distance between the actual stop
          location and its location on the street, if it is important to include
          that distance in the total travel distance.TimeWindowStart-The
          earliest time the stop can be visited. Make sure
          you specify the value as a date and time value, such as 8/12/2015
          12:15 PM. By specifying a start and end time for a stop's time window,
          you are defining when a route should visit the stop. As long as Use
          Time Windows is checked and you've chosen a time-based unit for
          Measurement Units, the tool will try to find a solution that minimizes
          overall travel and reaches the stop within the prescribed time window.
          When solving a problem that spans multiple time zones, time-window
          values refer to the time zone in which the stop is located.This field
          can contain a null value; a null value indicates a route
          can arrive at any time before the time indicated in the TimeWindowEnd
          attribute. If a null value is also present in TimeWindowEnd, a route
          can visit the stop at any time.TimeWindowEnd-The latest time the stop
          can be visited. Make sure you
          specify the value as a date and time value, such as 8/12/2015 12:15
          PM. By specifying a start and end time for a stop's time window, you
          are defining when a route should visit the stop. As long as Use Time
          Windows is checked and you've chosen a time-based unit for Measurement
          Units, the tool will try to find a solution that minimizes overall
          travel and reaches the stop within the prescribed time window. When
          solving a problem that spans multiple time zones, time-window
          values refer to the time zone in which the stop is located.This field
          can contain a null value; a null value indicates a route
          can arrive at any time after the time indicated in the TimeWindowStart
          attribute. If a null value is also present in TimeWindowStart, a route
          can visit the stop at any time.CurbApproach-Specifies the direction a
          vehicle may arrive at and
          depart from the stop. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          *  0 (Either side of vehicle)-The vehicle can approach and depart the
          stop in either direction, so a U-turn is allowed at the stop. This
          setting can be chosen if it is possible and practical for your vehicle
          to turn around at the stop. This decision may depend on the width of
          the road and the amount of traffic or whether the stop has a parking
          lot where vehicles can enter and turn around.

          * 1 ( Right side of vehicle)-When the vehicle approaches and departs
          the stop, the stop must be on the right side of the vehicle. A U-turn
          is prohibited. This is typically used for vehicles such as buses that
          must arrive with the bus stop on the right-hand side.

          * 2 (Left side of vehicle)-When the vehicle approaches and departs the
          stop, the curb must be on the left side of the vehicle. A U-turn is
          prohibited. This is typically used for vehicles such as buses that
          must arrive with the bus stop on the left-hand side.

          *  3 (No U-Turn)-When the vehicle approaches the stop, the curb can be
          on either side of the vehicle; however, the vehicle must depart
          without turning around.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider a stop on the left
          side of a vehicle. It is always on the left side regardless of whether
          the vehicle travels on the left or right half of the road. What may
          change with national driving standards is your decision to approach a
          stop from one of two directions, that is, so it ends up on the right
          or left side of the vehicle. For example, if you want to arrive at a
          stop and not have a lane of traffic between the vehicle and the stop,
          you would choose Right side of vehicle (1) in the United States but
          Left side of vehicle (2) in the United Kingdom.LocationType-
          Specifies the stop type. The field value is specified
          as one of the following integers (use the numeric code, not the name
          in the parentheses):

          * 0 (Stop)-A location that the route should visit. This is the
          default.

          * 1 (Waypoint)-A location that the route should travel through
          without making a stop. Waypoints can be used to force the route to
          take a specific path (to go through the waypoint) without being
          considered an actual stop. Waypoints do not appear in directions.
      Measurement_Units (String):
          Specify the units that should be used to measure and report the total
          travel time or travel distance for the output routes.The units you
          choose for this parameter determine whether the tool
          will measure distance or time to find the best routes. Choose a time
          unit to minimize travel time for your chosen travel mode (driving or
          walking time, for instance). To minimize travel distance for the given
          travel mode, choose a distance unit. Your choice also determines in
          which units the tool will report total time or distance in the
          results. The choices include the following:

          * Meters

          * Kilometers

          * Feet

          * Yards

          * Miles

          * NauticalMiles

          * Seconds

          * Minutes

          * Hours

          * Days
      Analysis_Region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      Reorder_Stops_to_Find_Optimal_Routes {Boolean}:
          Specify whether to visit the stops in the order you define or the
          order the tool determines will minimize overall travel.

          *  Checked (True):  The tool determines the sequence that will
          minimize overall travel
          distance or time. It can reorder stops and account for time windows at
          stops. Additional parameters allow you to preserve the first or last
          stops while allowing the tool to reorder the intermediary stops.

          *  Unchecked (False):  The stops are visited in the order you define.
          This is the default
          option. You can set the order of stops using a Sequence attribute in
          the input stops features or let the sequence be determined by the
          Object ID of the stops.
           Finding the optimal stop order and the best routes is commonly known
          as solving the traveling salesman problem (TSP).
      Preserve_Terminal_Stops {String}:
          When Reorder Stops to Find Optimal Routes is checked (or True), you
          have options to preserve the starting or ending stops and the tool can
          reorder the rest.The first and last stops are determined by their
          Sequence attribute
          values or, if the Sequence values are null, by their Object ID values.

          *  Preserve First:  The tool won't reorder the first stop. Choose this
          option if you are
          starting from a known location, such as your home, headquarters, or
          current location.

          *  Preserve Last:  The tool won't reorder the last stop. The output
          routes may start from
          any stop feature but must end at the predetermined last stop.

          *  Preserve First and Last:  The tool won't reorder the first and last
          stops.

          *  Preserve None:  The tool may reorder any stop, including the first
          and last stops. The
          route may start or end at any of the stop features.
          Preserve Terminal Stops is ignored when Reorder Stops to Find Optimal
          Routes is unchecked (or False).
      Return_to_Start {Boolean}:
          Choose whether routes should start and end at the same location. With
          this option you can avoid duplicating the first stop feature and
          sequencing the duplicate stop at the end.The starting location of the
          route is the stop feature with the lowest
          value in the Sequence attribute. If the Sequence values are null, it
          is the stop feature with the lowest Object ID value.

          *  Checked (True):  The route should start and end at the first stop
          feature. This is the
          default value.  When Reorder Stops to Find Optimal Routes and Return
          to Start are both
          checked (or True), Preserve Terminal Stops must be set to Preserve
          First.

          *  Unchecked (False):  The route won't start and end at the first stop
          feature.
      Use_Time_Windows {Boolean}:
          Check this option (or set it to True) if any input stops have time
          windows that specify when the route should reach the stop. You can add
          time windows to input stops by entering time values in the
          TimeWindowStart and TimeWindowEnd attributes.

          *  Checked (True):  The input stops have time windows and you want the
          tool to try to
          honor them.

          *  Unchecked (False):  The input stops don't have time windows, or if
          they do, you don't want
          the tool to try to honor them. This is the default value.
          The tool will take slightly longer to run when Use Time Windows is
          checked (or True), even when none of the input stops have time
          windows, so it is recommended to uncheck this option (set to False) if
          possible.
      Time_of_Day {Date}:
          Specifies the time and date at which the routes should begin.If you
          are modeling the driving travel mode and specify the current
          date and time as the value for this parameter, the tool will use live
          traffic conditions to find the best routes and the total travel time
          will be based on traffic conditions. Specifying a time of day results
          in more accurate routes and
          estimations of travel times because the travel times account for the
          traffic conditions that are applicable for that date and time.The Time
          Zone for Time of Day parameter specifies whether this time
          and date refer to UTC or the time zone in which the stop is
          located.The tool ignores this parameter when Measurement Units isn't
          set to a
          time-based unit.
      Time_Zone_for_Time_of_Day {String}:
          Specifies the time zone of the Time of Day parameter.

          *  Geographically Local:  The Time of Day parameter refers to the time
          zone in which the first
          stop of a route is located.  If you are generating many routes that
          start in multiple times zones,
          the start times are staggered in Coordinated Universal Time (UTC). For
          example, a Time of Day value of 10:00 a.m., 2 January, would mean a
          start time of 10:00 a.m. Eastern Standard Time (3:00 p.m. UTC) for
          routes beginning in the Eastern Time Zone and 10:00 a.m. Central
          Standard Time (4:00 p.m. UTC) for routes beginning in the Central Time
          Zone. The start times are offset by one hour in UTC.  The arrive and
          depart times and dates recorded in the output Stops
          feature class will refer to the local time zone of the first stop for
          each route.

          *  UTC:  The Time of Day parameter refers to Coordinated Universal
          Time (UTC).
          Choose this option if you want to generate a route for a specific
          time, such as now, but aren't certain in which time zone the first
          stop will be located.  If you are generating many routes spanning
          multiple times zones, the
          start times in UTC are simultaneous. For example, a Time of Day value
          of 10:00 a.m., 2 January, would mean a start time of 5:00 a.m. Eastern
          Standard Time(UTC-5:00) for routes beginning in the Eastern Time Zone
          and 4:00 a.m. Central Standard Time (UTC-6:00) for routes beginning in
          the Central Time Zone. Both routes would start at 10:00 a.m. UTC.  The
          arrive and depart times and dates recorded in the output Stops
          feature class will refer to UTC.
      UTurn_at_Junctions {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges, or streets, connect to the
          junction, which is known as junction valency. The acceptable values
          for this parameter are listed below; each is followed by a description
          of its meaning in terms of junction valency.

          *  Allowed:  U-turns are permitted at junctions with any number of
          connected edges,
          or streets. This is the default value.

          *  Not Allowed:  U-turns are prohibited at all junctions, regardless
          of junction
          valency.

          *  Allowed only at Dead Ends:  U-turns are prohibited at all
          junctions, except those that have only
          one adjacent edge (a dead end).

          *  Allowed only at Intersections and Dead Ends:  U-turns are
          prohibited at junctions where exactly two adjacent edges
          meet but are permitted at intersections (junctions with three or more
          adjacent edges) and dead ends (junctions with exactly one adjacent
          edge). Oftentimes, networks modeling streets have extraneous junctions
          in the middle of road segments. This option prevents vehicles from
          making U-turns at these locations.
          This parameter is ignored unless Travel Mode is set to Custom.
      Point_Barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
           Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Measurement Units parameter.
          Additional_Distance: Indicates how much distance is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Measurement Units parameter.
      Line_Barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      Polygon_Barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
           ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the measurement
          units are time based. The field value must be greater than zero.
          ScaledDistanceFactor: This is the factor by which the distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the measurement
          units are distance based. The attribute value must be greater than
          zero.
      Use_Hierarchy {Boolean}:
          Specify whether hierarchy should be used when finding the shortest
          paths between stops.

          *  Checked (True):  Use hierarchy when finding routes. When hierarchy
          is used, the tool
          prefers higher-order streets (such as freeways) to lower-order streets
          (such as local roads), and can be used to simulate the driver
          preference of traveling on freeways instead of local roads even if
          that means a longer trip. This is especially true when finding routes
          to faraway locations, because drivers on long-distance trips tend to
          prefer traveling on freeways where stops, intersections, and turns can
          be avoided. Using hierarchy is computationally faster, especially for
          long-distance routes, since the tool can determine the best route from
          a relatively smaller subset of streets.

          *  Unchecked (False):  Do not use hierarchy when finding routes. If
          hierarchy is not used,
          the tool considers all the streets and doesn't prefer higher-order
          streets when finding the route. This is often used when finding short
          routes within a city.
           The tool automatically reverts to using hierarchy if the straight-
          line distance between facilities and demand points is greater than 50
          miles (80.46 kilometers), even if you have set this parameter to not
          use hierarchy.This parameter is ignored unless Travel Mode is set to
          Custom. When
          modeling a custom walking mode, it is recommended to turn off
          hierarchy since the hierarchy is designed for motorized vehicles.
      Restrictions {String}:
          Specify which restrictions should be honored by the tool when finding
          the best routes. A restriction represents a driving preference or
          requirement. In most cases, restrictions cause roads to be prohibited,
          but they can also cause them to be avoided or preferred. For instance,
          using an Avoid Toll Roads restriction will result in a route that will
          include toll roads only when it is absolutely required to travel on
          toll roads in order to visit a stop. Height Restriction makes it
          possible to route around any clearances that are lower than the height
          of your vehicle. If you are carrying corrosive materials on your
          vehicle, using the Any Hazmat Prohibited restriction prevents hauling
          the materials along roads where it is marked as illegal to do so.The
          values you provide for this parameter are ignored unless Travel
          Mode is set to Custom.Below is a list of available restrictions and a
          short description.Some restrictions require an additional value to be
          specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      Attribute_Parameter_Values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The values you
          provide for this parameter are ignored unless Travel
          Mode is set to Custom. If you specify the Attribute Parameter Values
          parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      Route_Shape {String}:
          Specify the type of route features that are output by the tool. The
          parameter can be specified using one of the following values:

          *  True Shape:  Return the exact shape of the resulting route that is
          based on the
          underlying streets.

          *  True Shape with Measures:  Return the exact shape of the resulting
          route that is based on the
          underlying streets. Additionally, construct measures so the shape may
          be used in linear referencing. The measurements increase from the
          first stop and record the cumulative travel time or travel distance in
          the units specified by the Measurement Units parameter.

          *  Straight Line:  Return a straight line between two stops.

          *  None:  Do not return any shapes for the routes. This value can be
          useful, and
          return results quickly, in cases where you are only interested in
          determining the total travel time or travel distance of a route.
           When the Route Shape parameter is set to True Shape or True Shape
          with Measures, the generalization of the route shape can be further
          controlled using the appropriate value for the Route Line
          Simplification Tolerance parameter. No matter which value you choose
          for the Route Shape parameter, the
          best route is always determined by minimizing the travel time or the
          travel distance, never using the straight-line distance between stops.
          This means that only the route shapes are different, not the
          underlying streets that are searched when finding the route.
      Route_Line_Simplification_Tolerance {Linear Unit}:
          Specify by how much you want to simplify the geometry of the output
          lines for routes, directions, and route edges.The tool ignores this
          parameter if the Route Shape parameter isn't set
          to True Shape. Simplification maintains critical points on a route,
          such as turns at
          intersections, to define the essential shape of the route and removes
          other points. The simplification distance you specify is the maximum
          allowable offset that the simplified line can deviate from the
          original line. Simplifying a line reduces the number of vertices that
          are part of the route geometry. This improves the tool execution time.
      Populate_Route_Edges {Boolean}:
          Specify whether the tool should generate edges for each route. Route
          edges represent the individual street features or other similar
          features that are traversed by a route. The output Route Edges layer
          is commonly used to see which streets or paths are traveled on the
          most or least by the resultant routes.

          *  Checked (True):  Generate route edges. The output Route Edges layer
          is populated with
          line features.

          *  Unchecked (False):  Don't generate route edges. The output Route
          Edges layer is returned,
          but it is empty.
      Populate_Directions {Boolean}:
          Specify whether the tool should generate driving directions for each
          route.

          *  Checked (True):  Indicates that the directions will be generated
          and configured based
          on the values for the Directions Language, Directions Style Name, and
          Directions Distance Units parameters.

          *  Unchecked (False):  Directions are not generated, and the tool
          returns an empty Directions
          layer.
      Directions_Language {String}:
          Specify the language that should be used when generating driving
          directions.This parameter is used only when the Populate Directions
          parameter is
          checked, or set to True.The parameter value can be specified using one
          of the following two-
          or five-character language codes:

          *  ar-Arabic

          * cs-Czech

          *  de-German

          *  el-Greek

          *  en-English

          *  es-Spanish

          * et-Estonian

          *  fr-French

          *  he-Hebrew

          *  it-Italian

          *  ja-Japanese

          *  ko-Korean

          *  lt-Lithuanian

          * lv-Latvian

          *  nl-Dutch

          *  pl-Polish

          *  pt-BR-Brazilian Portuguese

          *  pt-PT-European Portuguese

          *  ru-Russian

          *  sv-Swedish

          * tr-Turkish

          *  zh-CN-Simplified Chinese
           If an unsupported language code is specified, the tool returns the
          directions using the default language, English.
      Directions_Distance_Units {String}:
          Specify the units for displaying travel distance in the driving
          directions. This parameter is used only when the Populate Directions
          parameter is checked, or set to True.

          * Miles

          * Kilometers

          * Meters

          * Feet

          * Yards

          * NauticalMiles
      Directions_Style_Name {String}:
          Specify the name of the formatting style for the directions. This
          parameter is used only when the Populate Directions parameter is
          checked, or set to True. The parameter can be specified using the
          following values:

          *  NA Desktop:  Generates turn-by-turn directions suitable for
          printing.

          *  NA Navigation:  Generates turn-by-turn directions designed for an
          in-vehicle
          navigation device.
      Travel_Mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, use the same GIS server
          connection you used to access this tool, and from the Utilities
          toolbox, run GetTravelModes. The GetTravelModes tool adds a table,
          Supported Travel Modes, to the application. Any value in the Travel
          Mode Name field from the Supported Travel Modes table can be specified
          as input. You can also specify the value from the Travel Mode Settings
          field as input. This speeds up the tool execution because the tool
          does not have to look up the settings based on the travel mode
          name.The default value, Custom, allows you to configure your own
          travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          traveling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get the analysis results you want. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of a new
          or existing travel mode so that everyone in your organization can
          rerun the analysis with the same settings.By choosing Custom, the
          values you set for the custom travel mode
          parameters are included in the analysis. Specifying another travel
          mode, as defined by your organization, causes any values you set for
          the custom travel mode parameters to be ignored; the tool overrides
          them with values from your specified travel mode.
      Impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel distance is an impedance; the length of
          a road in kilometers
          can be thought of as impedance. Travel distance in this sense is the
          same for all modes-a kilometer for a pedestrian is also a kilometer
          for a car. (What may change is the pathways on which the different
          modes are allowed to travel, which affects distance between points,
          and this is modeled by travel mode settings.)Travel time can also be
          an impedance; a car may take one minute to
          travel a mile along an empty road. Travel times can vary by travel
          mode-a pedestrian may take more than 20 minutes to walk the same mile,
          so it is important to choose the right impedance for the travel mode
          you are modeling.Choose from the following impedance values:

          *  Drive Time-Models travel times for a car. These travel times are
          dynamic and fluctuate according to traffic flows in areas where
          traffic data is available. This is the default value.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.

          *  Travel Distance-Stores length measurements along roads and paths.
          To
          model walk distance, choose this option and ensure Walking is set in
          the Restriction parameter. Similarly, to model drive or truck
          distance, choose Travel Distance here and set the appropriate
          restrictions so your vehicle travels only on roads where it is
          permitted to do so.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.If you choose Drive Time,
          Truck Time, or Walk Time, the Measurement
          Units parameter must be set to a time-based value; if you choose
          Travel Distance for Impedance, Measurement Units must be distance-
          based.
      Time_Zone_for_Time_Windows {String}:
          Specifies the time zone for the time window values on stops. The time
          windows are specified as part of TimeWindowStart and TimeWindowEnd
          fields on stops. This parameter is applicable only when the Use Time
          Windows parameter is checked (or set to True). The parameter can be
          specified using one of the following values:

          * Geographically Local-The time window values associated with the
          stops are in the time zone in which the stops are located. For
          example, if the stop is located in an area that follows Eastern
          Standard Time and has time window values of 8 AM and 10 AM, the time
          window values will be treated as 8 AM and 10 AM in Eastern Standard
          Time. This is the default value.

          * UTC-The time window values associated with the stops are in the
          Coordinated Universal Time (UTC). For example, if the stop is located
          in an area that follows Eastern Standard Time and has time window
          values of 8 AM and 10 AM, the time window values will be treated as 12
          PM and 2 PM Eastern Standard Time assuming the Eastern Standard Time
          is obeying the Daylight Saving Time. Specifying the time window values
          in UTC is useful if you do not know the time zone in which the stops
          are located or when you have stops in multiple time zones and you want
          all the time windows to start simultaneously.
      Save_Output_Network_Analysis_Layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      Overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotation
          marks. The values can be a number, Boolean, or a string. The default
          value for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support.
      Save_Route_Data {Boolean}:
          Choose whether the output includes a zip file that contains a file
          geodatabase holding the inputs and outputs of the analysis in a format
          that can be used to share route layers with ArcGIS Online or Portal
          for ArcGIS.

          *  Checked (True)-Save the route data as a zip file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Route Data parameter in the entry corresponding
          to the tool execution in the Geoprocessing history of your Project. In
          ArcMap, the location of the file can be determined by accessing the
          Copy Location option in the shortcut menu on the Output Route Data
          parameter in the entry corresponding to the tool execution in the
          Geoprocessing Results window.

          *  Unchecked (False)-Do not save the route data. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.FindRoutes_agolservices(*gp_fixargs((Stops, Measurement_Units, Analysis_Region, Reorder_Stops_to_Find_Optimal_Routes, Preserve_Terminal_Stops, Return_to_Start, Use_Time_Windows, Time_of_Day, Time_Zone_for_Time_of_Day, UTurn_at_Junctions, Point_Barriers, Line_Barriers, Polygon_Barriers, Use_Hierarchy, Restrictions, Attribute_Parameter_Values, Route_Shape, Route_Line_Simplification_Tolerance, Populate_Route_Edges, Populate_Directions, Directions_Language, Directions_Distance_Units, Directions_Style_Name, Travel_Mode, Impedance, Time_Zone_for_Time_Windows, Save_Output_Network_Analysis_Layer, Overrides, Save_Route_Data), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateOriginDestinationCostMatrix_agolservices', None)
def GenerateOriginDestinationCostMatrix(Origins=None, Destinations=None, Travel_Mode=None, Time_Units=None, Distance_Units=None, Analysis_Region=None, Number_of_Destinations_to_Find=None, Cutoff=None, Time_of_Day=None, Time_Zone_for_Time_of_Day=None, Point_Barriers=None, Line_Barriers=None, Polygon_Barriers=None, UTurn_at_Junctions=None, Use_Hierarchy=None, Restrictions=None, Attribute_Parameter_Values=None, Impedance=None, Origin_Destination_Line_Shape=None, Save_Output_Network_Analysis_Layer=None, Overrides=None):
    """GenerateOriginDestinationCostMatrix_agolservices(Origins, Destinations, {Travel_Mode}, {Time_Units}, {Distance_Units}, {Analysis_Region}, {Number_of_Destinations_to_Find}, {Cutoff}, {Time_of_Day}, {Time_Zone_for_Time_of_Day}, {Point_Barriers}, {Line_Barriers}, {Polygon_Barriers}, {UTurn_at_Junctions}, {Use_Hierarchy}, {Restrictions;Restrictions...}, {Attribute_Parameter_Values}, {Impedance}, {Origin_Destination_Line_Shape}, {Save_Output_Network_Analysis_Layer}, {Overrides})

        The GenerateOriginDestinationCostMatrix tool creates an origin-
        destination (OD) cost matrix from multiple origins to multiple
        destinations. An OD cost matrix is a table that contains the travel
        time and travel distance from each origin to each destination.
        Additionally, it ranks the destinations that each origin connects to
        in ascending order based on the minimum time or distance required to
        travel from that origin to each destination. The best path on the
        street network is discovered for each origin-destination pair, and the
        travel times and travel distances are stored as attributes of the
        output lines. Even though the lines are straight for performance
        reasons, they always store the travel time and travel distance along
        the street network, not straight-line distance.

     INPUTS:
      Origins (Feature Set):
          Specify locations that function as starting points in generating the
          paths to destinations. You can add up to 1000 origins.When specifying
          the origins, you can set properties for each one, such
          as its name or the number of destinations to find from the origin, by
          using attributes. The origins can be specified with the following
          attributesName-The name of the origin. The name can be an unique
          identifier for
          the origin. The name is included in the output lines (as the
          OriginName field) and in the output origins (as the Name field) and
          can be used to join additional information from the tool outputs to
          the attributes of your origins.If the name is not specified, a unique
          name prefixed with Location is
          automatically generated in the output origins. An auto-generated
          origin name is not included in the output lines.
          TargetDestinationCount-The maximum number of destinations that must
          be found for the origin. If a value is not specified, the value from
          the Number of Destinations to Find parameter is used.Cutoff-Specify
          the travel time or travel distance value at which to
          stop searching for destinations from the origin. Any destination
          beyond the cutoff value will not be considered.The value needs to be
          in the units specified by the Time Units
          parameter if the impedance attribute in your travel mode is time based
          or in the units specified by the Distance Units parameter if the
          impedance attribute in your travel mode is distance based. If a value
          is not specified, the value from the Cutoff parameter is used.
          CurbApproach-Specifiy the direction a vehicle may depart from the
          origin. The field value is specified as one of the following integers
          (use the numeric code, not the name in parentheses):

          * 0 (Either side of vehicle)-The vehicle can depart the origin in
          either direction, so a U-turn is allowed at the origin. This setting
          can be chosen if it is possible and practical for your vehicle to turn
          around at the origin. This decision may depend on the width of the
          road and the amount of traffic or whether the origin has a parking lot
          where vehicles can enter and turn around.

          * 1 ( Right side of vehicle)-When the vehicle departs the origin, the
          origin must be on the right side of the vehicle. A U-turn is
          prohibited. This is typically used for vehicles such as buses that
          must depart from the bus stop on the right-hand side.

          *  2 (Left side of vehicle)-When the vehicle departs the origin, the
          curb must be on the left side of the vehicle. A U-turn is prohibited.
          This is typically used for vehicles such as buses that must depart
          from the bus stop on the left-hand side.

          * 3 (No U-Turn)-For this tool, the No U-turn (3) value functions the
          same as Either side of vehicle.
           The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider an origin on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          depart the origin from one of two directions, that is, so it ends up
          on the right or left side of the vehicle. For example, if you want to
          depart from an origin and not have a lane of traffic between the
          vehicle and the origin, you would choose Right side of vehicle (1) in
          the United States but Left side of vehicle (2) in the United Kingdom.
      Destinations (Feature Set):
          Specify locations that function as ending points in generating the
          paths from origins. You can add up to 1000 destinations.When
          specifying the destinations, you can set properties for each one,
          such as its name, by using attributes. The destinations can be
          specified with the following attributes: Name-The name of the
          destination. The name can be an unique
          identifier for the destination. The name is included in the output
          lines (as the DestinationName field) and in the output destinations
          (as the Name field) and can be used to join additional information
          from the tool outputs to the attributes of your destinations. If the
          name is not specified, a unique name prefixed with Location is
          automatically generated in the output destinations. An auto-generated
          destination name is not included in the output lines. CurbApproach-
          Specifiy the direction a vehicle may depart from the
          origin. The field value is specified as one of the following integers
          (use the numeric code, not the name in parentheses):

          * 0 (Either side of vehicle)-The vehicle can depart the origin in
          either direction, so a U-turn is allowed at the origin. This setting
          can be chosen if it is possible and practical for your vehicle to turn
          around at the origin. This decision may depend on the width of the
          road and the amount of traffic or whether the origin has a parking lot
          where vehicles can enter and turn around.

          * 1 ( Right side of vehicle)-When the vehicle departs the origin, the
          origin must be on the right side of the vehicle. A U-turn is
          prohibited. This is typically used for vehicles such as buses that
          must depart from the bus stop on the right-hand side.

          *  2 (Left side of vehicle)-When the vehicle departs the origin, the
          curb must be on the left side of the vehicle. A U-turn is prohibited.
          This is typically used for vehicles such as buses that must depart
          from the bus stop on the left-hand side.

          * 3 (No U-Turn)-For this tool, the No U-turn (3) value functions the
          same as Either side of vehicle.
           The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider an origin on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          depart the origin from one of two directions, that is, so it ends up
          on the right or left side of the vehicle. For example, if you want to
          depart from an origin and not have a lane of traffic between the
          vehicle and the origin, you would choose Right side of vehicle (1) in
          the United States but Left side of vehicle (2) in the United Kingdom.
      Travel_Mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, run the GetTravelModes
          tool from the Utilities toolbox available under the same GIS Server
          connection you used to access the tool. The GetTravelModes tool adds a
          table, Supported Travel Modes, to the application. Any value in the
          Travel Mode Name field from the Supported Travel Modes table can be
          specified as input. You can also specify the value from Travel Mode
          Settings field as input. This speeds up the tool execution as the tool
          does not have to lookup the settings based on the travel mode name.The
          default value, Custom, allows you to configure your own travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          travelling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get desired analysis results. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of new or
          existing travel mode so that everyone in your organization can rerun
          the analysis with the same settings.
      Time_Units {String}:
          Specify the units that should be used to measure and report the total
          travel time between each origin-destination pair.The choices include
          the following:

          * Seconds

          * Minutes

          * Hours

          * Days
      Distance_Units {String}:
          Specify the units that should be used to measure and report the total
          travel distance between each origin-destination pair.The choices
          include the following:

          * Meters

          * Kilometers

          * Feet

          * Yards

          * Miles

          * NauticalMiles
      Analysis_Region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      Number_of_Destinations_to_Find {Long}:
          Specify the maximum number of destinations to find per origin. If a
          value for this parameter is not specified, the output matrix includes
          travel costs from each origin to every destination. Individual origins
          can have their own values (specified as the TargetDestinationCount
          field) that override the Number of Destinations to Find parameter
          value.
      Cutoff {Double}:
          Specify the travel time or travel distance value at which to stop
          searching for destinations from a given origin. Any destination beyond
          the cutoff value will not be considered. Individual origins can have
          their own values (specified as the Cutoff field) that override the
          Cutoff parameter value.The value needs to be in the units specified by
          the Time Units
          parameter if the impedance attribute of your travel mode is time based
          or in the units specified by the Distance Units parameter if the
          impedance attribute of your travel mode is distance based. If a value
          is not specified, the tool will not enforce any travel time or travel
          distance limit when searching for destinations.
      Time_of_Day {Date}:
          Specifies the time and date at which the routes should begin.If you
          are modeling the driving travel mode and specify the current
          date and time as the value for this parameter, the tool will use live
          traffic conditions to find the best routes and the total travel time
          will be based on traffic conditions. Specifying a time of day results
          in more accurate routes and
          estimations of travel times because the travel times account for the
          traffic conditions that are applicable for that date and time.The Time
          Zone for Time of Day parameter specifies whether this time
          and date refer to UTC or the time zone in which the stop is
          located.The tool ignores this parameter when Measurement Units isn't
          set to a
          time-based unit.
      Time_Zone_for_Time_of_Day {String}:
          Specifies the time zone of the Time of Day parameter.

          *  Geographically Local:  The Time of Day parameter refers to the time
          zone in which the first
          stop of a route is located.  If you are generating many routes that
          start in multiple times zones,
          the start times are staggered in Coordinated Universal Time (UTC). For
          example, a Time of Day value of 10:00 a.m., 2 January, would mean a
          start time of 10:00 a.m. Eastern Standard Time (3:00 p.m. UTC) for
          routes beginning in the Eastern Time Zone and 10:00 a.m. Central
          Standard Time (4:00 p.m. UTC) for routes beginning in the Central Time
          Zone. The start times are offset by one hour in UTC.  The arrive and
          depart times and dates recorded in the output Stops
          feature class will refer to the local time zone of the first stop for
          each route.

          *  UTC:  The Time of Day parameter refers to Coordinated Universal
          Time (UTC).
          Choose this option if you want to generate a route for a specific
          time, such as now, but aren't certain in which time zone the first
          stop will be located.  If you are generating many routes spanning
          multiple times zones, the
          start times in UTC are simultaneous. For example, a Time of Day value
          of 10:00 a.m., 2 January, would mean a start time of 5:00 a.m. Eastern
          Standard Time(UTC-5:00) for routes beginning in the Eastern Time Zone
          and 4:00 a.m. Central Standard Time (UTC-6:00) for routes beginning in
          the Central Time Zone. Both routes would start at 10:00 a.m. UTC.  The
          arrive and depart times and dates recorded in the output Stops
          feature class will refer to UTC.
      Point_Barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
           Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Measurement Units parameter.
          Additional_Distance: Indicates how much distance is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Measurement Units parameter.
      Line_Barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      Polygon_Barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
           ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the measurement
          units are time based. The field value must be greater than zero.
          ScaledDistanceFactor: This is the factor by which the distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the measurement
          units are distance based. The attribute value must be greater than
          zero.
      UTurn_at_Junctions {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges, or streets, connect to the
          junction, which is known as junction valency. The acceptable values
          for this parameter are listed below; each is followed by a description
          of its meaning in terms of junction valency.

          *  Allowed:  U-turns are permitted at junctions with any number of
          connected edges,
          or streets. This is the default value.

          *  Not Allowed:  U-turns are prohibited at all junctions, regardless
          of junction
          valency.

          *  Allowed only at Dead Ends:  U-turns are prohibited at all
          junctions, except those that have only
          one adjacent edge (a dead end).

          *  Allowed only at Intersections and Dead Ends:  U-turns are
          prohibited at junctions where exactly two adjacent edges
          meet but are permitted at intersections (junctions with three or more
          adjacent edges) and dead ends (junctions with exactly one adjacent
          edge). Oftentimes, networks modeling streets have extraneous junctions
          in the middle of road segments. This option prevents vehicles from
          making U-turns at these locations.
          This parameter is ignored unless Travel Mode is set to Custom.
      Use_Hierarchy {Boolean}:
          Specify whether hierarchy should be used when finding the shortest
          paths between stops.

          *  Checked (True):  Use hierarchy when finding routes. When hierarchy
          is used, the tool
          prefers higher-order streets (such as freeways) to lower-order streets
          (such as local roads), and can be used to simulate the driver
          preference of traveling on freeways instead of local roads even if
          that means a longer trip. This is especially true when finding routes
          to faraway locations, because drivers on long-distance trips tend to
          prefer traveling on freeways where stops, intersections, and turns can
          be avoided. Using hierarchy is computationally faster, especially for
          long-distance routes, since the tool can determine the best route from
          a relatively smaller subset of streets.

          *  Unchecked (False):  Do not use hierarchy when finding routes. If
          hierarchy is not used,
          the tool considers all the streets and doesn't prefer higher-order
          streets when finding the route. This is often used when finding short
          routes within a city.
           The tool automatically reverts to using hierarchy if the straight-
          line distance between facilities and demand points is greater than 50
          miles (80.46 kilometers), even if you have set this parameter to not
          use hierarchy.This parameter is ignored unless Travel Mode is set to
          Custom. When
          modeling a custom walking mode, it is recommended to turn off
          hierarchy since the hierarchy is designed for motorized vehicles.
      Restrictions {String}:
          Specify which restrictions should be honored by the tool when finding
          the best routes. A restriction represents a driving preference or
          requirement. In most cases, restrictions cause roads to be prohibited,
          but they can also cause them to be avoided or preferred. For instance,
          using an Avoid Toll Roads restriction will result in a route that will
          include toll roads only when it is absolutely required to travel on
          toll roads in order to visit a stop. Height Restriction makes it
          possible to route around any clearances that are lower than the height
          of your vehicle. If you are carrying corrosive materials on your
          vehicle, using the Any Hazmat Prohibited restriction prevents hauling
          the materials along roads where it is marked as illegal to do so.The
          values you provide for this parameter are ignored unless Travel
          Mode is set to Custom.Below is a list of available restrictions and a
          short description.Some restrictions require an additional value to be
          specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      Attribute_Parameter_Values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The values you
          provide for this parameter are ignored unless Travel
          Mode is set to Custom. If you specify the Attribute Parameter Values
          parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      Impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel distance is an impedance; the length of
          a road in kilometers
          can be thought of as impedance. Travel distance in this sense is the
          same for all modes-a kilometer for a pedestrian is also a kilometer
          for a car. (What may change is the pathways on which the different
          modes are allowed to travel, which affects distance between points,
          and this is modeled by travel mode settings.)Travel time can also be
          an impedance; a car may take one minute to
          travel a mile along an empty road. Travel times can vary by travel
          mode-a pedestrian may take more than 20 minutes to walk the same mile,
          so it is important to choose the right impedance for the travel mode
          you are modeling.Choose from the following impedance values:

          *  Drive Time-Models travel times for a car. These travel times are
          dynamic and fluctuate according to traffic flows in areas where
          traffic data is available. This is the default value.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.

          *  Travel Distance-Stores length measurements along roads and paths.
          To
          model walk distance, choose this option and ensure Walking is set in
          the Restriction parameter. Similarly, to model drive or truck
          distance, choose Travel Distance here and set the appropriate
          restrictions so your vehicle travels only on roads where it is
          permitted to do so.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.If you choose Drive Time,
          Truck Time, or Walk Time, the Measurement
          Units parameter must be set to a time-based value; if you choose
          Travel Distance for Impedance, Measurement Units must be distance-
          based.
      Origin_Destination_Line_Shape {String}:
          The resulting lines of an OD cost matrix can be represented with
          either straight-line geometry or no geometry at all. In both cases,
          the route is always computed along the street network by minimizing
          the travel time or the travel distance, never using the straight-line
          distance between origins and destinations.

          * Straight Line-Straight lines connect origins and destinations.

          *  None-Do not return any shapes for the lines that connect origins
          and destinations. This is useful when you have a large number of
          origins and destinations and are interested only in the OD cost matrix
          table (and not the output line shapes).
      Save_Output_Network_Analysis_Layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      Overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotes. The
          values can be either a number, Boolean, or a string. The default value
          for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateOriginDestinationCostMatrix_agolservices(*gp_fixargs((Origins, Destinations, Travel_Mode, Time_Units, Distance_Units, Analysis_Region, Number_of_Destinations_to_Find, Cutoff, Time_of_Day, Time_Zone_for_Time_of_Day, Point_Barriers, Line_Barriers, Polygon_Barriers, UTurn_at_Junctions, Use_Hierarchy, Restrictions, Attribute_Parameter_Values, Impedance, Origin_Destination_Line_Shape, Save_Output_Network_Analysis_Layer, Overrides), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GenerateServiceAreas_agolservices', None)
def GenerateServiceAreas(Facilities=None, Break_Values=None, Break_Units=None, Analysis_Region=None, Travel_Direction=None, Time_of_Day=None, Use_Hierarchy=None, UTurn_at_Junctions=None, Polygons_for_Multiple_Facilities=None, Polygon_Overlap_Type=None, Detailed_Polygons=None, Polygon_Trim_Distance=None, Polygon_Simplification_Tolerance=None, Point_Barriers=None, Line_Barriers=None, Polygon_Barriers=None, Restrictions=None, Attribute_Parameter_Values=None, Time_Zone_for_Time_of_Day=None, Travel_Mode=None, Impedance=None, Save_Output_Network_Analysis_Layer=None, Overrides=None):
    """GenerateServiceAreas_agolservices(Facilities, Break_Values, Break_Units, {Analysis_Region}, {Travel_Direction}, {Time_of_Day}, {Use_Hierarchy}, {UTurn_at_Junctions}, {Polygons_for_Multiple_Facilities}, {Polygon_Overlap_Type}, {Detailed_Polygons}, {Polygon_Trim_Distance}, {Polygon_Simplification_Tolerance}, {Point_Barriers}, {Line_Barriers}, {Polygon_Barriers}, {Restrictions;Restrictions...}, {Attribute_Parameter_Values}, {Time_Zone_for_Time_of_Day}, {Travel_Mode}, {Impedance}, {Save_Output_Network_Analysis_Layer}, {Overrides})

        GenerateServiceAreas determines network service areas around
        facilities. A network service area is a region that encompasses all
        streets that can be accessed within a given distance or travel time
        from one or more facilities. For instance, the 10-minute service area
        for a facility includes all the streets that can be reached within 10
        minutes from that facility. Service areas are commonly used to
        visualize and measure accessibility. For example, a three-minute
        drive-time polygon around a grocery store can determine which
        residents are able to reach the store within three minutes and are
        thus more likely to shop there.

     INPUTS:
      Facilities (Feature Set):
          The facilities around which service areas are generated. You can load
          up to 1,000 facilities. The facilities feature set has an associated
          attribute table. The
          fields in the attribute table are listed below and described.ObjectID:
          The system-managed ID field.Name: The name of the facility. If the
          name is not specified, a name
          is automatically generated at solve time.All fields from the input
          facilities are included in the output
          polygons when the Polygons for Multiple Facilities parameter is set to
          Overlapping or Not Overlapping. The ObjectID field on the input
          facilities is transferred to the FacilityOID field on the output
          polygons.
      Break_Values (String):
          Specifies the size and number of service area polygons to generate
          for each facility. The units are determined by the Break Units value.
          Multiple polygon breaks can be set to create concentric service areas
          per facility. For instance, to find 2-, 3-, and 5-mile service areas
          for each facility, type 2 3 5, separating the values with a space, and
          set Break Units to Miles. There is no limit to the number of break
          values you specify.The size of the maximum break value can't exceed
          the equivalent of 300
          minutes or 300 miles (482.80 kilometers). When generating detailed
          polygons, the maximum service-area size is limited to 15 minutes and
          15 miles (24.14 kilometers).
      Break_Units (String):
          The unit for the Break Values parameter.The units you choose for this
          parameter determine whether the tool
          will create service areas by measuring driving distance or driving
          time. Choose a time unit to measure driving time. To measure driving
          distance, choose a distance unit. Your choice also determines in which
          units the tool will report total driving time or distance in the
          results. The choices are:

          * Meters

          * Kilometers

          * Feet

          * Yards

          * Miles

          * Nautical Miles

          * Seconds

          * Minutes

          * Hours

          * Days
      Analysis_Region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      Travel_Direction {String}:
          Specifies whether the direction of travel used to generate the
          service area polygons is toward or away from the facilities.

          *  Away From Facility-The service area is generated in the direction
          away from the facilities.

          *  Towards Facility-The service area is created in the direction
          towards the facilities.
           The direction of travel may change the shape of the polygons because
          impedances on opposite sides of streets may differ or one-way
          restrictions may exist, such as one-way streets. The direction you
          should choose depends on the nature of your service area analysis. The
          service area for a pizza delivery store, for example, should be
          created away from the facility, whereas the service area of a hospital
          should be created toward the facility.
      Time_of_Day {Date}:
          The time to depart from or arrive at the facilities. The
          interpretation of this value depends on whether travel is toward or
          away from the facilities.

          *  It represents the departure time if Travel Direction is set to Away
          from Facility.

          *  It represents the arrival time if Travel Direction is set to Toward
          Facility.
          You can use the Time Zone for Time of Day parameter to specify whether
          this time and date refers to UTC or the time zone in which the
          facility is located. Repeatedly solving the same analysis, but using
          different Time of Day
          values, allows you to see how a facility's reach changes over time.
          For instance, the five-minute service area around a fire station may
          start out large in the early morning, diminish during the morning rush
          hour, grow in the late morning, and so on, throughout the day.
      Use_Hierarchy {Boolean}:
          Specify whether hierarchy should be used when finding the best route
          between the facility and the incident.

          * Checked (True)-Use the hierarchy attribute for the analysis. Using a
          hierarchy results in the solver preferring higher-order edges to
          lower-order edges. Hierarchical solves are faster, and they can be
          used to simulate the preference of a driver who chooses to travel on
          freeways over local roads when possible-even if that means a longer
          trip.

          *  Unchecked (False)-Do not use the hierarchy attribute for the
          analysis. Not using a hierarchy yields an accurate service area
          measured along all edges of the network dataset regardless of
          hierarchy level.
          Regardless of whether the Use Hierarchy parameter is checked (True),
          hierarchy is always used when the largest break value exceeds 240
          minutes or 240 miles (386.24 kilometers).
      UTurn_at_Junctions {String}:
          Use this parameter to restrict or permit the service area to make
          U-turns at junctions. In order to understand the parameter values,
          consider for a moment the following terminology: a junction is a point
          where a street segment ends and potentially connects to one or more
          other segments; a pseudo-junction is a point where exactly two streets
          connect to one another; an intersection is a point where three or more
          streets connect; and a dead-end is where one street segment ends
          without connecting to another. Given this information, the parameter
          can have the following values:

          *  Allowed-U-turns are permitted everywhere. Allowing U-turns implies
          that the vehicle can turn around at any junction and double back on
          the same street. This is the default value.

          *  Not Allowed-U-turns are prohibited at all junctions: pseudo-
          junctions, intersections, and dead-ends.

          *  Allowed only at Dead Ends-U-turns are prohibited at all junctions,
          except those that have only one connected street feature (a dead end).

          *  Allowed only at Intersections and Dead Ends-U-turns are prohibited
          at pseudo-junctions where exactly two adjacent streets meet, but
          U-turns are permitted at intersections and dead ends. This prevents
          turning around in the middle of the road where one length of road
          happened to be digitized as two street features.
      Polygons_for_Multiple_Facilities {String}:
          Choose how service area polygons are generated when multiple
          facilities are present in the analysis.

          *  Overlapping-Creates individual polygons for each facility. The
          polygons can overlap each other. This is the default value.

          *  Not Overlapping-Creates individual polygons such that a polygon
          from one facility cannot overlap polygons from other facilities;
          furthermore, any portion of the network can only be covered by the
          service area of the nearest facility.

          *  Merge by Break Value-Creates and joins the polygons of different
          facilities that have the same break value.
          When using Overlapping or Not Overlapping, all fields from the input
          facilities are included in the output polygons, with the exception
          that values from the input ObjectID field are transferred to the
          FacilityOID field of the output polygons. The FacilityOID field is
          null when merging by break value, and the input fields are not
          included in the output.
      Polygon_Overlap_Type {String}:
          Specifies the option to create concentric service area polygons as
          disks or rings. This option is applicable only when multiple break
          values are specified for the facilities.

          *  Rings-The polygons representing larger breaks exclude the polygons
          of smaller breaks. This creates polygons going between consecutive
          breaks. Use this option if you want to find the area from one break to
          another. For instance, if you create 5- and 10-minute service areas,
          then the 10-minute service area polygon will exclude the area under
          the 5-minute service area polygon. This is the default value.

          *  Disks-Creates polygons going from the facility to the break. For
          instance, if you create 5- and 10-minute service areas, then the
          10-minute service area polygon will include the area under the
          5-minute service area polygon.
      Detailed_Polygons {Boolean}:
          Specifies the option to create detailed or generalized polygons.

          *  Unchecked (False)-Creates generalized polygons, which are generated
          quickly and are fairly accurate. This is the default.

          *  Checked (True)-Creates detailed polygons, which accurately model
          the service area lines and may contain islands of unreached areas.
          This option is much slower than generating generalized polygons. This
          option isn't supported when using hierarchy.
           If your facilities are in an urban area with a grid-like street
          network, the difference between generalized and detailed service areas
          would be minimal. However, if your facilities are in a region
          containing mountain and rural roads, the detailed service areas may
          present significantly more accurate results than generalized service
          areas.The tool supports generating detailed polygons only if the
          largest
          value specified in the Break Values parameter is less than or equal to
          15 minutes or 15 miles (24.14 kilometers).
      Polygon_Trim_Distance {Linear Unit}:
          Specifies the distance within which the service area polygons are
          trimmed. This is useful when finding service areas in places that have
          a sparse street network and you don't want the service area to cover
          large areas where there are no street features. The default value is
          100 meters. No value or a value of 0 for this
          parameter specifies that the service area polygons should not be
          trimmed. This parameter value is ignored when using hierarchy.
      Polygon_Simplification_Tolerance {Linear Unit}:
          Specify by how much you want to simplify the polygon geometry.
          Simplification maintains critical vertices of a polygon to define its
          essential shape and removes other vertices. The simplification
          distance you specify is the maximum offset the simplified polygon
          boundaries can deviate from the original polygon boundaries.
          Simplifying a polygon reduces the number of vertices and tends to
          reduce drawing times.
      Point_Barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
          Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the Break Units value is time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Break Units
          parameter.Additional_Distance: Indicates how much distance is added
          when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the Break Units value is distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Break Units parameter.
      Line_Barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      Polygon_Barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
          ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the Break Units
          value is time based. The field value must be greater than zero and its
          units are the same as those specified in the Break Units
          parameter.ScaledDistanceFactor: This is the factor by which the
          distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the Break Units
          value is distance based. The attribute value must be greater than
          zero.
      Restrictions {String}:
          Specify which travel restrictions should be honored by the tool when
          determining the service areas.The values you provide for this
          parameter are ignored unless Travel
          Mode is set to Custom.A restriction represents a driving preference or
          requirement. In most
          cases, restrictions cause roads to be prohibited. For instance, using
          an Avoid Toll Roads restriction will result in a route that will
          include toll roads only when it is absolutely required to travel on
          toll roads in order to visit an incident or a facility. Height
          Restriction makes it possible to route around any clearances that are
          lower than the height of your vehicle. If you are carrying corrosive
          materials on your vehicle, using the Any Hazmat Prohibited restriction
          prevents hauling the materials along roads where it is marked as
          illegal to do so.When generating detailed polygons, prohibited roads
          that are not
          covered by service area polygons may result in polygons with
          untraversable holes; however, when generating general or hierarchical
          service areas, restricted roads that are completely surrounded by
          traversable roads will be covered by the simplified service area
          polygon.Below is a list of available restrictions and a short
          description.Some restrictions require an additional value to be
          specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      Attribute_Parameter_Values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The values you
          provide for this parameter are ignored unless Travel
          Mode is set to Custom. If you specify the Attribute Parameter Values
          parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      Time_Zone_for_Time_of_Day {String}:
          Specifies the time zone or zones of the Time of Day parameter.

          *  Geographically Local:  The Time of Day parameter refers to the time
          zone or zones in which
          the facilities are located. Therefore, the start or end times of the
          service areas are staggered by time zone.  Setting Time of Day to 9:00
          a.m., choosing geographically local for
          Time Zone for Time of Day, and solving causes service areas to be
          generated for 9:00 a.m. Eastern Time for any facilities in the Eastern
          Time Zone, 9:00 a.m. Central Time for facilities in the Central Time
          Zone, 9:00 a.m. Mountain Time for facilities in the Mountain Time
          Zone, and so on, for facilities in different time zones.  If stores in
          a chain that span the U.S. open at 9:00 a.m. local time,
          this parameter value could be chosen to find market territories at
          opening time for all stores in one solve. First, the stores in the
          Eastern Time Zone open and a polygon is generated, then an hour later
          stores open in Central Time, and so on. Nine o'clock is always in
          local time but staggered in real time.

          *  UTC:  The Time of Day parameter refers to Coordinated Universal
          Time (UTC).
          Therefore, all facilities are reached or departed from simultaneously,
          regardless of the time zone each is in.  Setting Time of Day to 2:00
          p.m., choosing UTC, then solving causes
          service areas to be generated for 9:00 a.m. Eastern Standard Time for
          any facilities in the Eastern Time Zone, 8:00 a.m. Central Standard
          Time for facilities in the Central Time Zone, 7:00 a.m. Mountain
          Standard Time for facilities in the Mountain Time Zone, and so on, for
          facilities in different time zones.  The scenario above assumes
          standard time. During daylight saving time,
          the Eastern, Central, and Mountain Times would each be one hour ahead
          (that is, 10:00, 9:00, and 8:00 a.m., respectively).  One of the cases
          in which the UTC option is useful is to visualize
          emergency-response coverage for a jurisdiction that is split into two
          time zones. The emergency vehicles are loaded as facilities. Time of
          Day is set to now in UTC. (You need to determine what the current time
          and date are in terms of UTC to correctly use this option.) Other
          properties are set and the analysis is solved. Even though a time-zone
          boundary divides the vehicles, the results show areas that can be
          reached given current traffic conditions. This same process can be
          used for other times as well, not just for now.
          Irrespective of the Time Zone for Time of Day setting, all facilities
          must be in the same time zone when Time of Day has a nonnull value and
          Polygons for Multiple Facilities is set to create merged or
          nonoverlapping polygons.
      Travel_Mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, use the same GIS server
          connection you used to access this tool, and from the Utilities
          toolbox, run GetTravelModes. The GetTravelModes tool adds a table,
          Supported Travel Modes, to the application. Any value in the Travel
          Mode Name field from the Supported Travel Modes table can be specified
          as input. You can also specify the value from the Travel Mode Settings
          field as input. This speeds up the tool execution because the tool
          does not have to look up the settings based on the travel mode
          name.The default value, Custom, allows you to configure your own
          travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          traveling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get the analysis results you want. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of a new
          or existing travel mode so that everyone in your organization can
          rerun the analysis with the same settings.By choosing Custom, the
          values you set for the custom travel mode
          parameters are included in the analysis. Specifying another travel
          mode, as defined by your organization, causes any values you set for
          the custom travel mode parameters to be ignored; the tool overrides
          them with values from your specified travel mode.
      Impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel distance is an impedance; the length of
          a road in kilometers
          can be thought of as impedance. Travel distance in this sense is the
          same for all modes-a kilometer for a pedestrian is also a kilometer
          for a car. (What may change is the pathways on which the different
          modes are allowed to travel, which affects distance between points,
          and this is modeled by travel mode settings.)Travel time can also be
          an impedance; a car may take one minute to
          travel a mile along an empty road. Travel times can vary by travel
          mode-a pedestrian may take more than 20 minutes to walk the same mile,
          so it is important to choose the right impedance for the travel mode
          you are modeling.Choose from the following impedance values:

          *  Drive Time-Models travel times for a car. These travel times are
          dynamic and fluctuate according to traffic flows in areas where
          traffic data is available. This is the default value.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.

          *  Travel Distance-Stores length measurements along roads and paths.
          To
          model walk distance, choose this option and ensure Walking is set in
          the Restriction parameter. Similarly, to model drive or truck
          distance, choose Travel Distance here and set the appropriate
          restrictions so your vehicle travels only on roads where it is
          permitted to do so.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.If you choose Drive Time,
          Truck Time, or Walk Time, the Measurement
          Units parameter must be set to a time-based value; if you choose
          Travel Distance for Impedance, Measurement Units must be distance-
          based.
      Save_Output_Network_Analysis_Layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      Overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotation
          marks. The values can be a number, Boolean, or a string. The default
          value for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GenerateServiceAreas_agolservices(*gp_fixargs((Facilities, Break_Values, Break_Units, Analysis_Region, Travel_Direction, Time_of_Day, Use_Hierarchy, UTurn_at_Junctions, Polygons_for_Multiple_Facilities, Polygon_Overlap_Type, Detailed_Polygons, Polygon_Trim_Distance, Polygon_Simplification_Tolerance, Point_Barriers, Line_Barriers, Polygon_Barriers, Restrictions, Attribute_Parameter_Values, Time_Zone_for_Time_of_Day, Travel_Mode, Impedance, Save_Output_Network_Analysis_Layer, Overrides), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Profile_agolservices', None)
def Profile(InputLineFeatures=None, ProfileIDField=None, DEMResolution=None, MaximumSampleDistance=None, MaximumSampleDistanceUnits=None):
    """Profile_agolservices(InputLineFeatures, {ProfileIDField}, {DEMResolution}, {MaximumSampleDistance}, {MaximumSampleDistanceUnits})

        Returns elevation profiles for the input line features.

     INPUTS:
      InputLineFeatures (Feature Set):
          The line features that will be profiled over the surface inputs.
      ProfileIDField {String}:
          A unique identifier to tie profiles to their corresponding input
          line features.
      DEMResolution {String}:
          The approximate spatial resolution (cell size) of the source
          elevation data used for the calculation. The default is 90m.  The
          resolution keyword is an approximation of the spatial resolution of
          the digital elevation model. Many elevation sources are distributed
          with units of arc seconds, the keyword is an approximation in meters
          for easier understanding.   FINEST-The finest units available for
          the extent are used.   10m-the elevation source resolution is 1/3
          arc second, or approximately 10 meters.   24m-the elevation source
          is the Airbus WorldDEM4Ortho dataset at 24 meters resolution.   30m-
          the elevation source resolution is 1 arc second, or approximately 30
          meters.   90m-the elevation source resolution is 3 arc second, or
          approximately 90 meters.   1000m-the elevation source resolution is
          30 arc seconds, or approximately 1000 meters.
      MaximumSampleDistance {Double}:
          The maximum sample distance along the line to sample elevation
          values.
      MaximumSampleDistanceUnits {String}:
          The units for the Maximum Sample Distance parameter.  The default is
          meters.   Meters-The units are meters. This is the default.
          Kilometers-The units are kilometers.   Feet-The units are feet.
          Yards-The units are yards.   Miles-The units are miles."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Profile_agolservices(*gp_fixargs((InputLineFeatures, ProfileIDField, DEMResolution, MaximumSampleDistance, MaximumSampleDistanceUnits), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('RefreshMapAreaPackage_agolservices', None)
def RefreshMapAreaPackage(packages=None):
    """RefreshMapAreaPackage_agolservices(packages)

     INPUTS:
      packages (String):
          List of packages to update"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.RefreshMapAreaPackage_agolservices(*gp_fixargs((packages,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetupMapArea_agolservices', None)
def SetupMapArea(mapAreaItemId=None, mapLayersToIgnore=None, tileServices=None, featureServices=None):
    """SetupMapArea_agolservices(mapAreaItemId, {mapLayersToIgnore}, {tileServices}, {featureServices})

     INPUTS:
      mapAreaItemId (String):
          Map Area Item ID
      mapLayersToIgnore {String}:
          Map layers to ignore
      tileServices {String}:
          Tile Services
      featureServices {String}:
          Feature Services"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetupMapArea_agolservices(*gp_fixargs((mapAreaItemId, mapLayersToIgnore, tileServices, featureServices), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SolveLocationAllocation_agolservices', None)
def SolveLocationAllocation(Facilities=None, Demand_Points=None, Measurement_Units=None, Analysis_Region=None, Problem_Type=None, Number_of_Facilities_to_Find=None, Default_Measurement_Cutoff=None, Default_Capacity=None, Target_Market_Share=None, Measurement_Transformation_Model=None, Measurement_Transformation_Factor=None, Travel_Direction=None, Time_of_Day=None, Time_Zone_for_Time_of_Day=None, UTurn_at_Junctions=None, Point_Barriers=None, Line_Barriers=None, Polygon_Barriers=None, Use_Hierarchy=None, Restrictions=None, Attribute_Parameter_Values=None, Allocation_Line_Shape=None, Travel_Mode=None, Impedance=None, Save_Output_Network_Analysis_Layer=None, Overrides=None):
    """SolveLocationAllocation_agolservices(Facilities, Demand_Points, Measurement_Units, {Analysis_Region}, {Problem_Type}, {Number_of_Facilities_to_Find}, {Default_Measurement_Cutoff}, {Default_Capacity}, {Target_Market_Share}, {Measurement_Transformation_Model}, {Measurement_Transformation_Factor}, {Travel_Direction}, {Time_of_Day}, {Time_Zone_for_Time_of_Day}, {UTurn_at_Junctions}, {Point_Barriers}, {Line_Barriers}, {Polygon_Barriers}, {Use_Hierarchy}, {Restrictions;Restrictions...}, {Attribute_Parameter_Values}, {Allocation_Line_Shape}, {Travel_Mode}, {Impedance}, {Save_Output_Network_Analysis_Layer}, {Overrides})

        The SolveLocationAllocation tool chooses the best location or
        locations from a set of input locations. Input to this tool includes
        facilities, which provide goods or services, and demand points, which
        consume the goods and services. The objective is to find the
        facilities that supply the demand points most efficiently. The tool
        solves this problem by analyzing various ways the demand points can be
        assigned to the different facilities. The solution is the scenario
        that allocates the most demand to facilities and minimizes overall
        travel. The output includes the solution facilities, demand points
        associated with their assigned facilities, and lines connecting demand
        points to their facilities. The location-allocation tool can be
        configured to solve specific problem types. Examples include the
        following: A retail store wants to see which potential store locations
        would need to be developed to capture 10 percent of the retail market
        in the area. A fire department wants to determine where it should
        locate fire stations to reach 90 percent of the community within a
        four-minute response time. A police department wants to preposition
        personnel given past criminal activity at night. After a storm, a
        disaster response agency wants to find the best locations to set up
        triage facilities, with limited patient capacities, to tend to the
        affected population.

     INPUTS:
      Facilities (Feature Set):
          Specify one or more facilities (up to 1,000). The tool chooses the
          best locations from the set of facilities you specify here.In a
          competitive analysis, in which you try to find the best locations
          in the face of competition, the facilities of the competitors are
          specified here as well.When defining the facilities, you can set
          properties for each one,
          such as the facility name or type, by using attributes. Facilities can
          be specified with the following fields:Name-The name of the facility.
          The name is included in the name of
          output allocation lines if the facility is part of the
          solution.FacilityType-Specifies whether the facility is a candidate,
          required,
          or competitor facility. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          * 0 (Candidate)-A facility that may be part of the solution.

          * 1 (Required)-A facility that must be part of the solution.

          * 2 (Competitor)-A rival facility that potentially removes demand from
          your facilities. Competitor facilities are specific to the Maximize
          Market Share and Target Market Share problem types; they are ignored
          in other problem types.
          Weight-The relative weighting of the facility, which is used to rate
          the attractiveness, desirability, or bias of one facility compared to
          another. For example, a value of 2.0 could capture the preference of
          customers
          who prefer, at a ratio of 2 to 1, shopping in one facility over
          another facility. Factors that potentially affect facility weight
          include square footage, neighborhood, and age of the building. Weight
          values other than one are only honored by the maximize market share
          and target market share problem types; they are ignored in other
          problem types.Capacity-The Capacity field is specific to the Maximize
          Capacitated
          Coverage problem type; the other problem types ignore this
          field.Capacity specifies how much weighted demand the facility is
          capable of
          supplying. Excess demand won't be allocated to a facility even if that
          demand is within the facility's default measurement cutoff.Any value
          assigned to the Capacity field overrides the Default
          Capacity parameter (Default_Capacity in Python) for the given
          facility. CurbApproach-Specifies the direction a vehicle may arrive at
          or
          depart from the facility. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          *  0 (Either side of vehicle)-The facility can be visited from either
          the right or left side of the vehicle.

          * 1 (Right side of vehicle)-Arrive at or depart the facility so that
          it is on the right side of the vehicle. This is typically used for
          vehicles such as buses that must arrive with the bus stop on the
          right-hand side so that passengers can disembark at the curb.

          * 2 (Left side of vehicle)-Arrive at or depart the facility so that it
          is on the left side of the vehicle. When the vehicle approaches and
          departs the facility, the curb must be on the left side of the
          vehicle. This is typically used for vehicles such as buses that must
          arrive with the bus stop on the left-hand side so that passengers can
          disembark at the curb.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider a facility on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach a facility from one of two directions, that is, so it ends up
          on the right or left side of the vehicle. For example, if you want to
          arrive at a facility and not have a lane of traffic between the
          vehicle and the incident, you would choose Right side of vehicle (1)
          in the United States but Left side of vehicle (2) in the United
          Kingdom.
      Demand_Points (Feature Set):
          Specify one or more demand points (up to 10,000). The tool chooses
          the best facilities based in large part on how they serve the demand
          points specified here.When defining the demand points, you can set
          properties for each one,
          such as the demand-point name or weight, by using attributes. Demand
          points can be specified with the following fields:Name-The name of the
          demand point. The name is included in the name of
          an output allocation line or lines if the demand point is part of the
          solution.GroupName-The name of the group the demand point is part of.
          This
          property is ignored for the maximize capacitated coverage, target
          market share, and maximize market share problem types.If demand points
          share a group name, the solver allocates all members
          of the group to the same facility. (If constraints, such as a cutoff
          distance, prevent any of the demand points in the group from reaching
          the same facility, none of the demand points are allocated.)Weight-The
          relative weighting of the demand point. A value of 2.0
          means the demand point is twice as important as one with a weight of
          1.0. If demand points represent households, weight could indicate the
          number of people in each household.Cutoff_Time-The demand point can't
          be allocated to a facility that is
          beyond the travel time indicated here. This field value overrides the
          value of the Default Measurement Cutoff parameter. The units for this
          attribute value are specified by the Measurement
          Units parameter. The attribute value is referenced during the analysis
          only when the measurement units are time based. The default value is
          null, which means there isn't an override cutoff.Cutoff_Distance-The
          demand point can't be allocated to a facility that
          is beyond the travel distance indicated here. This field value
          overrides the value of the Default Measurement Cutoff parameter. The
          units for this attribute value are specified by the Measurement
          Units parameter. The attribute value is referenced during the analysis
          only when the measurement units are distance based. The default value
          is null, which means there isn't an override
          cutoff.CurbApproach-Specifies the direction a vehicle may arrive at or
          depart
          from the demand point. The field value is specified as one of the
          following integers (use the numeric code, not the name in
          parentheses):

          *  0 (Either side of vehicle)-The demand point can be visited from
          either the right or left side of the vehicle.

          * 1 (Right side of vehicle)-Arrive at or depart the demand point so
          that it is on the right side of the vehicle. This is typically used
          for vehicles such as buses that must arrive with the bus stop on the
          right-hand side so that passengers can disembark at the curb.

          * 2 (Left side of vehicle)-Arrive at or depart the demand point so
          that it is on the left side of the vehicle. When the vehicle
          approaches and departs the demand point, the curb must be on the left
          side of the vehicle. This is typically used for vehicles such as buses
          that must arrive with the bus stop on the left-hand side so that
          passengers can disembark at the curb.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider a demand point on
          the left side of a vehicle. It is always on the left side regardless
          of whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach a demand point from one of two directions, that is, so it
          ends up on the right or left side of the vehicle. For example, if you
          want to arrive at a demand point and not have a lane of traffic
          between the vehicle and the demand point, you would choose Right side
          of vehicle (1) in the United States but Left side of vehicle (2) in
          the United Kingdom.
      Measurement_Units (String):
          Specify the units that should be used to measure the travel times or
          travel distances between demand points and facilities. The tool
          chooses the best facilities based on which ones can reach, or be
          reached by, the most amount of weighted demand with the least amount
          travel.The output allocation lines report travel distance or travel
          time in
          different units, including the units you specify for this parameter.
          The choices are

          * Meters

          * Kilometers

          * Feet

          * Yards

          * Miles

          * NauticalMiles

          * Seconds

          * Minutes

          * Hours

          * Days
      Analysis_Region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      Problem_Type {String}:
          Specifies the objective of the location-allocation analysis. The
          default objective is to minimize impedance.

          *  Minimize Impedance:  This is also known as the P-Median problem
          type. Facilities are
          located such that the sum of all weighted travel time or distance
          between demand points and solution facilities is minimized. (Weighted
          travel is the amount of demand allocated to a facility multiplied by
          the travel distance or time to the facility.)  This problem type is
          traditionally used to locate warehouses, because
          it can reduce the overall transportation costs of delivering goods to
          outlets. Since Minimize Impedance reduces the overall distance the
          public needs to travel to reach the chosen facilities, the minimize
          impedance problem without an impedance cutoff is ordinarily regarded
          as more equitable than other problem types for locating some public-
          sector facilities such as libraries, regional airports, museums,
          department of motor vehicles offices, and health clinics.  The
          following list describes how the minimize impedance problem type
          handles demand:

          * A demand point that cannot reach any facilities, due to setting a
          cutoff distance or time, is not allocated.

          * A demand point that can only reach one facility has all its demand
          weight allocated to that facility.

          * A demand point that can reach two or more facilities has all its
          demand weight allocated to the nearest facility only.

          *  Maximize Coverage:  Facilities are located such that as much demand
          as possible is
          allocated to solution facilities within the impedance cutoff.
          Maximize Coverage is frequently used to locate fire stations, police
          stations, and ERS centers, because emergency services are often
          required to arrive at all demand points within a specified response
          time. Note that it is important for all organizations, and critical
          for emergency services, to have accurate and precise data so that
          analysis results correctly model real-world results.  Pizza delivery
          businesses, as opposed to eat-in pizzerias, try to
          locate stores where they can cover the most people within a certain
          drive time. People who order pizzas for delivery don't typically worry
          about how far away the pizzeria is; they are mainly concerned with the
          pizza arriving within an advertised time window. Therefore, a pizza-
          delivery business would subtract pizza-preparation time from their
          advertised delivery time and solve a maximize coverage problem to
          choose the candidate facility that would capture the most potential
          customers in the coverage area. (Potential customers of eat-in
          pizzerias are more affected by distance, since they need to travel to
          the restaurant; thus, the attendance maximizing or market share
          problem types would better suit eat-in restaurants.)  The following
          list describes how the Maximize Coverage problem handles
          demand:

          * A demand point that cannot reach any facilities due to cutoff
          distance or time is not allocated.

          * A demand point that can only reach one facility has all its demand
          weight allocated to that facility.

          * A demand point that can reach two or more facilities has all its
          demand weight allocated to the nearest facility only.

          *  Maximize Capacitated Coverage:  Facilities are located such that
          all or the greatest amount of demand
          can be served without exceeding the capacity of any facility.
          Maximize Capacitated Coverage behaves like either the Minimize
          Impedance or Maximize Coverage problem type but with the added
          constraint of capacity. You can specify a capacity for an individual
          facility by assigning a numeric value to its corresponding Capacity
          field on the input facilities. If the Capacity field value is null,
          the facility is assigned a capacity from the Default Capacity
          property.  Use-cases for Maximize Capacitated Coverage include
          creating
          territories that encompass a given number of people or businesses,
          locating hospitals or other medical facilities with a limited number
          of beds or patients who can be treated, or locating warehouses whose
          inventory isn't assumed to be unlimited.  The following list describes
          how the Maximize Capacitated Coverage
          problem handles demand:

          * Unlike Maximize Coverage, Maximize Capacitated Coverage doesn't
          require a value for the Default Measurement Cutoff; however, when an
          cutoff is specified, any demand point outside the cutoff time or
          distance of all facilities is not allocated.

          * An allocated demand point has all or none of its demand weight
          assigned to a facility; that is, demand isn't apportioned with this
          problem type.

          * If the total demand that can reach a facility is greater than the
          capacity of the facility, only the demand points that maximize total
          captured demand and minimize total weighted travel are allocated.  You
          may notice an apparent inefficiency when a demand point is
          allocated to a facility that isn't the nearest solution facility. This
          may occur when demand points have varying weights and when the demand
          point in question can reach more than one facility. This kind of
          result indicates the nearest solution facility didn't have adequate
          capacity for the weighted demand, or the most efficient solution for
          the entire problem required one or more local inefficiencies. In
          either case, the solution is correct.

          *  Minimize Facilities:  Facilities are chosen such that as much
          weighted demand as possible
          are allocated to solution facilities within the travel time or
          distance cutoff; additionally, the number of facilities required to
          cover demand is minimized.  Minimize Facilities is the same as
          Maximize Coverage but with the
          exception of the number of facilities to locate, which in this case is
          determined by the solver. When the cost of building facilities is not
          a limiting factor, the same kinds of organizations that use Maximize
          Coverage (emergency response, for instance) use Minimize Facilities so
          that all possible demand points will be covered.  The following list
          describes how the Minimize Facilities problem
          handles demand:

          * A demand point that cannot reach any facilities due to a cutoff
          distance or time is not allocated.

          * A demand point that can only reach one facility has all its demand
          weight allocated to that facility.

          * A demand point that can reach two or more facilities has all its
          demand weight allocated to the nearest facility only.

          *  Maximize Attendance:  Facilities are chosen such that as much
          demand weight as possible is
          allocated to facilities while assuming the demand weight decreases in
          relation to the distance between the facility and the demand point.
          Specialty stores that have little or no competition benefit from this
          problem type, but it may also be beneficial to general retailers and
          restaurants that don't have the data on competitors necessary to
          perform market share problem types. Some businesses that might benefit
          from this problem type include coffee shops, fitness centers, dental
          and medical offices, and electronics stores. Public transit bus stops
          are often chosen with the help of Maximize Attendance. Maximize
          Attendance assumes that the farther people have to travel to reach
          your facility, the less likely they are to use it. This is reflected
          in how the amount of demand allocated to facilities diminishes with
          distance.  The following list describes how the Maximize Attendance
          problem
          handles demand:

          * A demand point that cannot reach any facilities due to a cutoff
          distance or time is not allocated.

          * When a demand point can reach a facility, its demand weight is only
          partially allocated to the facility. The amount allocated decreases as
          a function of the maximum cutoff distance (or time) and the travel
          distance (or time) between the facility and the demand point.

          * The weight of a demand point that can reach more than one facility
          is proportionately allocated to the nearest facility only.

          *  Maximize Market Share:  A specific number of facilities are chosen
          such that the allocated
          demand is maximized in the presence of competitors. The goal is to
          capture as much of the total market share as possible with a given
          number of facilities, which you specify. The total market share is the
          sum of all demand weight for valid demand points.  The market share
          problem types require the most data because, along
          with knowing your own facilities' weight, you also need to know that
          of your competitors' facilities. The same types of facilities that use
          the Maximize Attendance problem type can also use market share problem
          types given that they have comprehensive information that includes
          competitor data. Large discount stores typically use Maximize Market
          Share to locate a finite set of new stores. The market share problem
          types use a Huff model, which is also known as a gravity model or
          spatial interaction.  The following list describes how the Maximize
          Market Share problem
          handles demand:

          * A demand point that cannot reach any facilities due to a cutoff
          distance or time is not allocated.

          * A demand point that can only reach one facility has all its demand
          weight allocated to that facility.

          * A demand point that can reach two or more facilities has all its
          demand weight allocated to them; furthermore, the weight is split
          among the facilities proportionally to the facilities' attractiveness
          (facility weight) and inversely proportional to the distance between
          the facility and demand point. Given equal facility weights, this
          means more demand weight is assigned to near facilities than far
          facilities.

          * The total market share, which can be used to calculate the captured
          market share, is the sum of the weight of all valid demand points.

          *  Target Market Share:  Target Market Share chooses the minimum
          number of facilities necessary
          to capture a specific percentage of the total market share in the
          presence of competitors. The total market share is the sum of all
          demand weight for valid demand points. You set the percent of the
          market share you want to reach and let the solver choose the fewest
          number of facilities necessary to meet that threshold.  The market
          share problem types require the most data because, along
          with knowing your own facilities' weight, you also need to know that
          of your competitors' facilities. The same types of facilities that use
          the Maximize Attendance problem type can also use market share problem
          types given that they have comprehensive information that includes
          competitor data.  Large discount stores typically use the Target
          Market Share problem
          type when they want to know how much expansion would be required to
          reach a certain level of the market share or see what strategy would
          be needed just to maintain their current market share given the
          introduction of new competing facilities. The results often represent
          what stores would like to do if budgets weren't a concern. In other
          cases where budget is a concern, stores revert to the Maximize Market
          Share problem and simply capture as much of the market share as
          possible with a limited number of facilities.  The following list
          describes how the target market share problem
          handles demand:

          * The total market share, which is used in calculating the captured
          market share, is the sum of the weight of all valid demand points.

          * A demand point that cannot reach any facilities due to a cutoff
          distance or time is not allocated.

          * A demand point that can only reach one facility has all its demand
          weight allocated to that facility.

          * A demand point that can reach two or more facilities has all its
          demand weight allocated to them; furthermore, the weight is split
          among the facilities proportionally to the facilities' attractiveness
          (facility weight) and inversely proportional to the distance between
          the facility and demand point. Given equal facility weights, this
          means more demand weight is assigned to near facilities than far
          facilities.
      Number_of_Facilities_to_Find {Long}:
          Specify the number of facilities the solver should choose. The
          default value is 1.The facilities with a FacilityType field value of 1
          (Required) are
          always chosen first. Any excess facilities to choose are picked from
          candidate facilities, which have a FacilityType field value of 2.Any
          facilities that have a FacilityType value of 3 (Chosen) before
          solving are treated as candidate facilities at solve time.If the
          number of facilities to find is less than the number of
          required facilities, an error occurs.Number of Facilities to Find is
          disabled for the Minimize Facilities
          and Target Market Share problem types since the solver determines the
          minimum number of facilities needed to meet the objectives.
      Default_Measurement_Cutoff {Double}:
          Specifies the maximum travel time or distance allowed between a
          demand point and the facility it is allocated to. If a demand point is
          outside the cutoff of a facility, it cannot be allocated to that
          facility.The default value is none, which means the cutoff limit
          doesn't apply.The units for this parameter are the same as those
          specified by the
          Measurement Units parameter.The travel time or distance cutoff is
          measured by the shortest path
          along roads.This property might be used to model the maximum distance
          that people
          are willing to travel to visit stores or the maximum time that is
          permitted for a fire department to reach anyone in the community.Note
          that demand points have Cutoff_Time and Cutoff_Distance fields,
          which, if set accordingly, overrides the Default Measurement Cutoff
          parameter. You might find that people in rural areas are willing to
          travel up to 10 miles to reach a facility while urbanites are only
          willing to travel up to two miles. Assuming Measurement Units is set
          to Miles, you can model this behavior by setting the default
          measurement cutoff to 10 and the Cutoff_Distance field value of the
          demand points in urban areas to 2.
      Default_Capacity {Double}:
          This property is specific to the Maximize Capacitated Coverage problem
          type. It is the default capacity assigned to all facilities in the
          analysis. You can override the default capacity for a facility by
          specifying a value in the facility's Capacity field. The default value
          is 1.
      Target_Market_Share {Double}:
          This parameter is specific to the Target Market Share problem type.
          It is the percentage of the total demand weight that you want the
          chosen and required facilities to capture. The solver chooses the
          minimum number of facilities needed to capture the target market share
          specified here. The default value is 10 percent.
      Measurement_Transformation_Model {String}:
          This sets the equation for transforming the network cost between
          facilities and demand points. This property, coupled with the
          Impedance Parameter, specifies how severely the network impedance
          between facilities and demand points influences the solver's choice of
          facilities.In the following list of transformation options, d refers
          to demand
          points and f, facilities. "Impedance" refers to the shortest travel
          distance or time between two locations. So impedancedf is the
          shortest-path (time or distance) between demand point d and facility
          f, and costdf is the transformed travel time or distance between the
          facility and demand point. Lambda (λ) denotes the impedance parameter.
          The Measurement Units setting determines whether travel time or
          distance is analyzed.

          *  Linear:  costdf = λ * impedancedf  The transformed travel time or
          distance between the facility and the
          demand point is the same as the time or distance of the shortest path
          between the two locations. With this option, the impedance parameter
          (λ) is always set to one. This is the default.

          *  Power:  costdf = impedancedfλ  The transformed travel time or
          distance between the facility and the
          demand point is equal to the time or distance of the shortest path
          raised to the power specified by the impedance parameter (λ). Use the
          Power option with a positive impedance parameter to specify higher
          weight to nearby facilities.

          *  Exponential:  costdf = e(λ * impedancedf)  The transformed travel
          time or distance between the facility and the
          demand point is equal to the mathematical constant e raised to the
          power specified by the shortest-path network impedance multiplied with
          the impedance parameter (λ). Use the Exponential option with a
          positive impedance parameter to specify a high weight to nearby
          facilities.
      Measurement_Transformation_Factor {Double}:
          Provides a parameter value to the equations specified in the
          Measurement Transformation Model parameter. The parameter value is
          ignored when the impedance transformation is of type linear. For power
          and exponential impedance transformations, the value should be
          nonzero.The default value is 1.
      Travel_Direction {String}:
          Specify whether to measure travel times or distances from facilities
          to demand points or from demand points to facilities. The default
          value is to measure from facilities to demand points.

          *  Facility to Demand:  Direction of travel is from facilities to
          demand points. This is the
          default.

          *  Demand to Facility:  Direction of travel is from demand points to
          facilities.
          Travel times and distances may change based on direction of travel. If
          going from point A to point B, you may encounter less traffic or have
          a shorter path, due to one-way streets and turn restrictions, than if
          you were traveling in the opposite direction. For instance, going from
          point A to point B may only take 10 minutes, but going the other
          direction may take 15 minutes. These differing measurements may affect
          whether demand points can be assigned to certain facilities because of
          cutoffs or, in problem types where demand is apportioned, affect how
          much demand is captured.Fire departments commonly measure from
          facilities to demand points
          since they are concerned with the time it takes to travel from the
          fire station to the location of the emergency. A retail store is more
          concerned with the time it takes shoppers to reach the store;
          therefore, stores commonly measure from demand points to
          facilities.Travel Direction also determines the meaning of any start
          time that is
          provided. See the Time of Day parameter for more information.
      Time_of_Day {Date}:
          Specify the time at which travel begins. This property is ignored
          unless Measurement Units are time based. The default is no time or
          date. When Time of Day isn't specified, the solver uses generic
          speeds-typically those from posted speed limits.Traffic constantly
          changes in reality, and as it changes, travel times
          between facilities and demand points also fluctuate. Therefore,
          indicating different time and date values over several analyses may
          affect how demand is allocated to facilities and which facilities are
          chosen in the results.The time of day always indicates a start time.
          However, travel may
          start from facilities or demand points; it depends on what you choose
          for the Travel Direction parameter.The Time Zone for Time of Day
          parameter specifies whether this time
          and date refer to UTC or the time zone in which the facility or demand
          point is located.
      Time_Zone_for_Time_of_Day {String}:
          Specifies the time zone of the Time of Day parameter. The default is
          geographically local.

          *  Geographically Local:  The Time of Day parameter refers to the time
          zone in which the
          facilities or demand points are located. If Travel Direction is
          facilities to demand points, this is the time zone of the facilities.
          If Travel Direction is demand points to facilities, this is the time
          zone of the demand points.

          *  UTC:  The Time of Day parameter refers to Coordinated Universal
          Time (UTC).
          Choose this option if you want to choose the best location for a
          specific time, such as now, but aren't certain in which time zone the
          facilities or demand points will be located.
           Irrespective of the Time Zone for Time of Day setting, the following
          rules are enforced by the tool if your facilities and demand points
          are in multiple time zones:

          * All facilities must be in the same time zone when specifying a time
          of day and travel is from facility to demand.

          * All demand points must be in the same time zone when specifying a
          time of day and travel is from demand to facility.
      UTurn_at_Junctions {String}:
          The U-Turn policy at junctions. Allowing U-turns implies the solver
          can turn around at a junction and double back on the same street.
          Given that junctions represent street intersections and dead ends,
          different vehicles may be able to turn around at some junctions but
          not at others-it depends on whether the junction represents an
          intersection or dead end. To accommodate, the U-turn policy parameter
          is implicitly specified by how many edges, or streets, connect to the
          junction, which is known as junction valency. The acceptable values
          for this parameter are listed below; each is followed by a description
          of its meaning in terms of junction valency.

          *  Allowed:  U-turns are permitted at junctions with any number of
          connected edges,
          or streets. This is the default value.

          *  Not Allowed:  U-turns are prohibited at all junctions, regardless
          of junction
          valency.

          *  Allowed only at Dead Ends:  U-turns are prohibited at all
          junctions, except those that have only
          one adjacent edge (a dead end).

          *  Allowed only at Intersections and Dead Ends:  U-turns are
          prohibited at junctions where exactly two adjacent edges
          meet but are permitted at intersections (junctions with three or more
          adjacent edges) and dead ends (junctions with exactly one adjacent
          edge). Oftentimes, networks modeling streets have extraneous junctions
          in the middle of road segments. This option prevents vehicles from
          making U-turns at these locations.
          This parameter is ignored unless Travel Mode is set to Custom.
      Point_Barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
           Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Measurement Units parameter.
          Additional_Distance: Indicates how much distance is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Measurement Units parameter.
      Line_Barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      Polygon_Barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
           ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the measurement
          units are time based. The field value must be greater than zero.
          ScaledDistanceFactor: This is the factor by which the distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the measurement
          units are distance based. The attribute value must be greater than
          zero.
      Use_Hierarchy {Boolean}:
          Specify whether hierarchy should be used when finding the shortest
          path between the facilities and demand points.

          *  Checked (True):  Use hierarchy when measuring between facilities
          and demand points.
          When hierarchy is used, the tool prefers higher-order streets (such as
          freeways) to lower-order streets (such as local roads), and can be
          used to simulate the driver preference of traveling on freeways
          instead of local roads even if that means a longer trip. This is
          especially true when finding routes to faraway locations, because
          drivers on long-distance trips tend to prefer traveling on freeways
          where stops, intersections, and turns can be avoided. Using hierarchy
          is computationally faster, especially for long-distance routes, since
          the tool can determine the best route from a relatively smaller subset
          of streets.

          *  Unchecked (False):  Do not use hierarchy when measuring between
          facilities and demand
          points. If hierarchy is not used, the tool considers all the streets
          and doesn't prefer higher-order streets when finding the route. This
          is often used when finding short-distance routes within a city.
           The tool automatically reverts to using hierarchy if the straight-
          line distance between facilities and demand points is greater than 50
          miles, even if you have set this parameter to not use hierarchy.
      Restrictions {String}:
          Specify which restrictions should be honored by the tool when finding
          the best routes between facilities and demand points.A restriction
          represents a driving preference or requirement. In most
          cases, restrictions cause roads to be prohibited. For instance, using
          an Avoid Toll Roads restriction will result in a route that will
          include toll roads only when it is absolutely required to travel on
          toll roads in order to visit an incident or a facility. Height
          Restriction makes it possible to route around any clearances that are
          lower than the height of your vehicle. If you are carrying corrosive
          materials on your vehicle, using the Any Hazmat Prohibited restriction
          prevents hauling the materials along roads where it is marked as
          illegal to do so.Below is a list of available restrictions and a short
          description.Some restrictions require an additional value to be
          specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      Attribute_Parameter_Values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The values you
          provide for this parameter are ignored unless Travel
          Mode is set to Custom. If you specify the Attribute Parameter Values
          parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      Allocation_Line_Shape {String}:
          The default is to output straight lines. Specify the type of line
          features that are output by the tool. The
          parameter accepts one of the following values:

          *  Straight Line:  Return straight lines between solution facilities
          and the demand
          points allocated to them. This is the default. Drawing straight lines
          on a map helps you visualize how demand is allocated.

          *  None:  Return a table containing data about the shortest paths
          between
          solution facilities and the demand points allocated to them, but don't
          return lines.
           No matter which value you choose for the Allocation Line Shape
          parameter, the shortest route is always determined by minimizing the
          travel time or the travel distance, never using the straight-line
          distance between demand points and facilities. That is, this parameter
          only changes the output line shapes; it doesn't change the measurement
          method.
      Travel_Mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, use the same GIS server
          connection you used to access this tool, and from the Utilities
          toolbox, run GetTravelModes. The GetTravelModes tool adds a table,
          Supported Travel Modes, to the application. Any value in the Travel
          Mode Name field from the Supported Travel Modes table can be specified
          as input. You can also specify the value from the Travel Mode Settings
          field as input. This speeds up the tool execution because the tool
          does not have to look up the settings based on the travel mode
          name.The default value, Custom, allows you to configure your own
          travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          traveling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get the analysis results you want. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of a new
          or existing travel mode so that everyone in your organization can
          rerun the analysis with the same settings.By choosing Custom, the
          values you set for the custom travel mode
          parameters are included in the analysis. Specifying another travel
          mode, as defined by your organization, causes any values you set for
          the custom travel mode parameters to be ignored; the tool overrides
          them with values from your specified travel mode.
      Impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel distance is an impedance; the length of
          a road in kilometers
          can be thought of as impedance. Travel distance in this sense is the
          same for all modes-a kilometer for a pedestrian is also a kilometer
          for a car. (What may change is the pathways on which the different
          modes are allowed to travel, which affects distance between points,
          and this is modeled by travel mode settings.)Travel time can also be
          an impedance; a car may take one minute to
          travel a mile along an empty road. Travel times can vary by travel
          mode-a pedestrian may take more than 20 minutes to walk the same mile,
          so it is important to choose the right impedance for the travel mode
          you are modeling.Choose from the following impedance values:

          *  Drive Time-Models travel times for a car. These travel times are
          dynamic and fluctuate according to traffic flows in areas where
          traffic data is available. This is the default value.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.

          *  Travel Distance-Stores length measurements along roads and paths.
          To
          model walk distance, choose this option and ensure Walking is set in
          the Restriction parameter. Similarly, to model drive or truck
          distance, choose Travel Distance here and set the appropriate
          restrictions so your vehicle travels only on roads where it is
          permitted to do so.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.If you choose Drive Time,
          Truck Time, or Walk Time, the Measurement
          Units parameter must be set to a time-based value; if you choose
          Travel Distance for Impedance, Measurement Units must be distance-
          based.
      Save_Output_Network_Analysis_Layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      Overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotation
          marks. The values can be a number, Boolean, or a string. The default
          value for this parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SolveLocationAllocation_agolservices(*gp_fixargs((Facilities, Demand_Points, Measurement_Units, Analysis_Region, Problem_Type, Number_of_Facilities_to_Find, Default_Measurement_Cutoff, Default_Capacity, Target_Market_Share, Measurement_Transformation_Model, Measurement_Transformation_Factor, Travel_Direction, Time_of_Day, Time_Zone_for_Time_of_Day, UTurn_at_Junctions, Point_Barriers, Line_Barriers, Polygon_Barriers, Use_Hierarchy, Restrictions, Attribute_Parameter_Values, Allocation_Line_Shape, Travel_Mode, Impedance, Save_Output_Network_Analysis_Layer, Overrides), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SolveVehicleRoutingProblem_agolservices', None)
def SolveVehicleRoutingProblem(orders=None, depots=None, routes=None, breaks=None, time_units=None, distance_units=None, analysis_region=None, default_date=None, uturn_policy=None, time_window_factor=None, spatially_cluster_routes=None, route_zones=None, route_renewals=None, order_pairs=None, excess_transit_factor=None, point_barriers=None, line_barriers=None, polygon_barriers=None, use_hierarchy_in_analysis=None, restrictions=None, attribute_parameter_values=None, populate_route_lines=None, route_line_simplification_tolerance=None, populate_directions=None, directions_language=None, directions_style_name=None, travel_mode=None, impedance=None, time_zone_usage_for_time_fields=None, save_output_layer=None, overrides=None, save_route_data=None):
    """SolveVehicleRoutingProblem_agolservices(orders, depots, routes, breaks, time_units, distance_units, {analysis_region}, {default_date}, {uturn_policy}, {time_window_factor}, {spatially_cluster_routes}, {route_zones}, {route_renewals}, {order_pairs}, {excess_transit_factor}, {point_barriers}, {line_barriers}, {polygon_barriers}, {use_hierarchy_in_analysis}, {restrictions;restrictions...}, {attribute_parameter_values}, {populate_route_lines}, {route_line_simplification_tolerance}, {populate_directions}, {directions_language}, {directions_style_name}, {travel_mode}, {impedance}, {time_zone_usage_for_time_fields}, {save_output_layer}, {overrides}, {save_route_data})

        SolveVehicleRoutingProblem tool solves a vehicle routing problem
        (VRP) to find the best routes for a fleet of vehicles. A dispatcher
        managing a fleet of vehicles is often required to make decisions about
        vehicle routing. One such decision involves how to best assign a group
        of customers to a fleet of vehicles and to sequence and schedule their
        visits. The objectives in solving such vehicle routing problems (VRP)
        are to provide a high level of customer service by honoring any time
        windows while keeping the overall operating and investment costs for
        each route as low as possible. The constraints are to complete the
        routes with available resources and within the time limits imposed by
        driver work shifts, driving speeds, and customer commitments., This
        service can be used to determine solutions for such complex fleet
        management tasks. Consider an example of delivering goods to grocery
        stores from a central warehouse location. A fleet of three trucks is
        available at the warehouse. The warehouse operates only within a
        certain time window-from 8:00 a.m. to 5:00 p.m.-during which all
        trucks must return back to the warehouse. Each truck has a capacity of
        15,000 pounds, which limits the amount of goods it can carry. Each
        store has a demand for a specific amount of goods (in pounds) that
        needs to be delivered, and each store has time windows that confine
        when deliveries should be made. Furthermore, the driver can work only
        eight hours per day, requires a break for lunch, and is paid for the
        time spent on driving and servicing the stores. The goal is to come up
        with an itinerary for each driver (or route) such that the deliveries
        can be made while honoring all the service requirements and minimizing
        the total time spent on a particular route by the driver.

     INPUTS:
      orders (Feature Set):
          Specify one or more orders (up to 2,000). These are the
          locations that the routes of the VRP analysis should visit. An order
          can represent a delivery (for example, furniture delivery), a pickup
          (such as an airport shuttle bus picking up a passenger), or some type
          of service or inspection (a tree trimming job or building inspection
          for instance).When specifying the orders, you can set properties for
          each one, such
          as its name or service time, by using attributes. The orders can be
          specified with the following attributes:        ObjectID: The system-
          managed ID field.        Name: The name of the order. The name must be
          unique. If the
          name is left null, a name is automatically generated at solve time.
          ServiceTime: This property specifies how much time will be
          spent at the network location when the route visits it; that is, it
          stores the impedance value for the network location. A zero or null
          value indicates the network location requires no service time. The
          unit for this field value is specified by the time_units
          parameter.        TimeWindowStart1: The beginning time of the first
          time window
          for the network location. This field can contain a null value; a null
          value indicates no beginning time. A time window only states when a
          vehicle can arrive at an order; it
          doesn't state when the service time must be completed. To account for
          service time and leave before the time window is over, subtract
          ServiceTime from the TimeWindowEnd1 field. The time window fields can
          contain a time-only value or a date and
          time value. If a time field such as TimeWindowStart1 has a time-only
          value (for example, 8:00 AM), the date is assumed to be the date
          specified by the Default Date parameter. Using date and time values
          (for example, 7/11/2010 8:00 AM) allows you to set time windows that
          span multiple days. When solving a problem that spans multiple time
          zones, each order's
          time-window values refer to the time zone in which the order is
          located.        TimeWindowEnd1: The ending time of the first window
          for the
          network location. This field can contain a null value; a null value
          indicates no ending time.        TimeWindowStart2: The beginning time
          of the second time window
          for the network location. This field can contain a null value; a null
          value indicates that there is no second time window. If the first time
          window is null, as specified by the
          TimeWindowStart1 and TimeWindowEnd1 fields, the second time window
          must also be null. If both time windows are nonnull, they can't
          overlap. Also, the
          second time window must occur after the first.        TimeWindowEnd2:
          The ending time of the second time window for
          the network location. This field can contain a null value. When
          TimeWindowStart2 and TimeWindowEnd2 are both null, there is no
          second time window. When TimeWindowStart2 is not null but
          TimeWindowEnd2 is null, there
          is a second time window that has a starting time but no ending time.
          This is valid.        MaxViolationTime1: A time window is considered
          violated if the
          arrival time occurs after the time window has ended. This field
          specifies the maximum allowable violation time for the first time
          window of the order. It can contain a zero value but can't contain
          negative values. A zero value indicates that a time window violation
          at the first time window of the order is unacceptable; that is, the
          first time window is hard. On the other hand, a null value indicates
          that there is no limit on the allowable violation time. A nonzero
          value specifies the maximum amount of lateness; for example, a route
          can arrive at an order up to 30 minutes beyond the end of its first
          time window. The unit for this field value is specified by the Time
          Field Units
          parameter Time window violations can be tracked and weighted by the
          solver.
          Because of this, you can direct the VRP solver to take one of three
          approaches:

          *  Minimize the overall violation time, regardless of the increase in
          travel cost for the fleet.

          *  Find a solution that balances overall violation time and travel
          cost.

          *  Ignore the overall violation time; instead, minimize the travel
          cost for the fleet.
           By assigning an importance level for the Time Window Violation
          Importance parameter, you are essentially choosing one of these three
          approaches. In any case, however, the solver will return an error if
          the value set for MaxViolationTime1 is surpassed.
          MaxViolationTime2: The maximum allowable violation time for
          the second time window of the order. This field is analogous to the
          MaxViolationTime1 field.        InboundArriveTime:Defines when the
          item to be delivered to the order will be ready at
          the starting depot.The order can be assigned to a route only if the
          inbound arrive time
          precedes the route's latest start time value; this way, the route
          cannot leave the depot before the item is ready to be loaded onto
          it.This field can help model scenarios involving inbound-wave
          transshipments. For example, a job at an order requires special
          materials that are not currently available at the depot. The materials
          are being shipped from another location and will arrive at the depot
          at 11:00 a.m. To ensure a route that leaves before the shipment
          arrives isn't assigned to the order, the order's inbound arrive time
          is set to 11:00 a.m. The special materials arrive at 11:00 a.m., they
          are loaded onto the vehicle, and the vehicle departs from the depot to
          visit its assigned orders.Notes:

          * The route's start time, which includes service times, must occur
          after
          the inbound arrive time. If a route begins before an order's inbound
          arrive time, the order cannot be assigned to the route. The assignment
          is invalid even if the route has a start-depot service time that lasts
          until after the inbound arrive time.

          * This time field can contain a time-only value or a date and time
          value. If a time-only value is set (for example, 11:00 AM), the date
          is assumed to be the date specified by the Default Date parameter. The
          default date is ignored, however, when any time field in the Depots,
          Routes, Orders, or Breaks includes a date with the time. In that case,
          specify all such fields with a date and time (for example, 7/11/2015
          11:00 AM).

          * The VRP solver honors InboundArriveTime regardless of the
          DeliveryQuantities value.

          * If an outbound depart time is also specified, its time value must
          occur after the inbound arrive time.
                  OutboundDepartTime:Defines when the item to be picked up at
          the order must arrive at the
          ending depot.The order can be assigned to a route only if the route
          can visit the
          order and reach its end depot before the specified outbound depart
          time.This field can help model scenarios involving outbound-wave
          transshipments. For instance, a shipping company sends out delivery
          trucks to pick up packages from orders and bring them into a depot
          where they are forwarded on to other facilities, en route to their
          final destination. At 3:00 p.m. every day, a semitrailer stops at the
          depot to pick up the high-priority packages and take them directly to
          a central processing station. To avoid delaying the high-priority
          packages until the next day's 3:00 p.m. trip, the shipping company
          tries to have delivery trucks pick up the high-priority packages from
          orders and bring them to the depot before the 3:00 p.m. deadline. This
          is done by setting the outbound depart time to 3:00 p.m.Notes:

          * The route's end time, including service times, must occur before the
          outbound depart time. If a route reaches a depot but doesn't complete
          its end-depot service time prior to the order's outbound depart time,
          the order cannot be assigned to the route.

          * This time field can contain a time-only value or a date and time
          value. If a time-only value is set (for example, 11:00 AM), the date
          is assumed to be the date specified by the Default Date parameter. The
          default date is ignored, however, when any time field in Depots,
          Routes, Orders, or Breaks includes a date with the time. In that case,
          specify all such fields with a date and time (for example, 7/11/2015
          11:00 AM).

          * The VRP solver honors OutboundDepartTime regardless of the
          PickupQuantities value.

          * If an inbound arrive time is also specified, its time value must
          occur
          before the outbound depart time.
                  DeliveryQuantities: The size of the delivery. You can specify
          size in any dimension you want, such as weight, volume, or quantity.
          You can even specify multiple dimensions, for example, weight and
          volume. Enter delivery quantities without indicating units. For
          example, if a
          300-pound object needs to be delivered to an order, enter 300. You
          will need to remember that the value is in pounds. If you are tracking
          multiple dimensions, separate the numeric values
          with a space. For instance, if you are recording the weight and volume
          of a delivery that weighs 2,000 pounds and has a volume of 100 cubic
          feet, enter 2000 100. Again, you need to remember the units-in this
          case, pounds and cubic feet. You also need to remember the sequence in
          which the values and their corresponding units are entered. Make sure
          that Capacities for Routes and DeliveryQuantities and
          PickupQuantities for Orders are specified in the same manner; that is,
          the values need to be in the same units, and if you are using multiple
          dimensions, the dimensions need to be listed in the same sequence for
          all parameters. So if you specify weight in pounds, followed by volume
          in cubic feet for DeliveryQuantities, the capacity of your routes and
          the pickup quantities of your orders need to be specified the same
          way: weight in pounds, then volume in cubic feet. If you mix units or
          change the sequence, you will get unwanted results without receiving
          any warning messages. An empty string or null value is equivalent to
          all dimensions being
          zero. If the string has an insufficient number of values in relation
          to the capacity count, or dimensions being tracked, the remaining
          values are treated as zeros. Delivery quantities can't be negative.
          PickupQuantities: The size of the pickup. You can specify size
          in any dimension you want, such as weight, volume, or quantity. You
          can even specify multiple dimensions, for example, weight and volume.
          You cannot, however, use negative values. This field is analogous to
          the DeliveryQuantities field of Orders. In the case of an exchange
          visit, an order can have both delivery and
          pickup quantities.        Revenue: The income generated if the order
          is included in a
          solution. This field can contain a null value-a null value indicates
          zero revenue-but it can't have a negative value. Revenue is included
          in optimizing the objective function value but is
          not part of the solution's operating cost; that is, the TotalCost
          field in the route class never includes revenue in its output.
          However, revenue weights the relative importance of servicing orders.
          SpecialtyNames: A space-separated string containing the names
          of the specialties required by the order. A null value indicates that
          the order doesn't require specialties. The spelling of any specialties
          listed in the Orders and Routes
          classes must match exactly so that the VRP solver can link them
          together. To illustrate what specialties are and how they work, assume
          a lawn
          care and tree trimming company has a portion of its orders that
          requires a bucket truck to trim tall trees. The company would enter
          BucketTruck in the SpecialtyNames field for these orders to indicate
          their special need. SpecialtyNames would be left as null for the other
          orders. Similarly, the company would also enter BucketTruck in the
          SpecialtyNames field of routes that are driven by trucks with
          hydraulic booms. It would leave the field null for the other routes.
          At solve time, the VRP solver assigns orders without special needs to
          any route, but it only assigns orders that need bucket trucks to
          routes that have them.        AssignmentRule: This field specifies the
          rule for assigning
          the order to a route. It is constrained by a domain of values, which
          are listed below (use the numeric code, not the name in parentheses).

          *  0 (Exclude)-The order is to be excluded from the subsequent solve
          operation.

          * 1 (Preserve route and relative sequence)-The solver must always
          assign the order to the preassigned route and at the preassigned
          relative sequence during the solve operation. If this assignment rule
          can't be followed, it results in an order violation. With this
          setting, only the relative sequence is maintained, not the absolute
          sequence. To illustrate what this means, imagine there are two orders:
          A and B. They have sequence values of 2 and 3, respectively. If you
          set their AssignmentRule field values to Preserve route and relative
          sequence, A and B's actual sequence values may change after solving
          because other orders, breaks, and depot visits could still be
          sequenced before, between, or after A and B. However, B cannot be
          sequenced before A.

          *  2 (Preserve route)-The solver must always assign the order to the
          preassigned route during the solve operation. A valid sequence must
          also be set even though the sequence may or may not be preserved. If
          the order can't be assigned to the specified route, it results in an
          order violation.

          *  3 (Override)-The solver tries to preserve the route and sequence
          preassignment for the order during the solve operation. However, a new
          route or sequence for the order may be assigned if it helps minimize
          the overall value of the objective function. This is the default
          value.

          * 4 (Anchor first)-The solver ignores the route and sequence
          preassignment (if any) for the order during the solve operation. It
          assigns a route to the order, and makes it the first order on that
          route, so as to minimize the overall value of the objective function.

          * 5 (Anchor last)-The solver ignores the route and sequence
          preassignment (if any) for the order during the solve operation. It
          assigns a route to the order, and makes it the last order on that
          route, so as to minimize the overall value of the objective function.
           This field can't contain a null value.        CurbApproach: Specifies
          the direction a vehicle may arrive at
          and depart from the order. The field value is specified as one of the
          following integers shown in the parentheses (use the numeric code, not
          the name in parentheses):

          *  0 (Either side of vehicle)-The vehicle can approach and depart the
          order in either direction, so a U-turn is allowed at the incident.
          This setting can be chosen if it is possible and desirable for your
          vehicle to turn around at the order. This decision may depend on the
          width of the road and the amount of traffic or whether the order has a
          parking lot where vehicles can pull in and turn around.

          *  1 (Right side of vehicle)-When the vehicle approaches and departs
          the order, the order must be on the right side of the vehicle. A
          U-turn is prohibited. This is typically used for vehicles like buses
          that must arrive with the bus stop on the right-hand side.

          *  2 (Left side of vehicle)-When the vehicle approaches and departs
          the order, the curb must be on the left side of the vehicle. A U-turn
          is prohibited. This is typically used for vehicles like buses that
          must arrive with the bus stop on the left-hand side.

          * 3 (No U-Turn)-When the vehicle approaches the order, the curb can be
          on either side of the vehicle; however, the vehicle must depart
          without turning around.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider an order on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach an order from one of two directions, that is, so it ends up
          on the right or left side of the vehicle. For example, if you want to
          arrive at an order and not have a lane of traffic between the vehicle
          and the order, you would choose 1 (Right side of vehicle) in the
          United States but 2 (Left side of vehicle) in the United Kingdom.
          RouteName: The name of the route to which the order is
          assigned. As an input field, this field is used to preassign an order
          to a
          specific route. (A maximum of 200 orders can be preassigned to one
          route name.) It can contain a null value, indicating that the order is
          not preassigned to any route, and the solver determines the best
          possible route assignment for the order. If this is set to null, the
          sequence field must also be set to null. After a solve operation, if
          the order is routed, the RouteName field
          contains the name of the route to which the order is assigned.
          Sequence: This indicates the sequence of the order on its
          assigned route. As an input field, this field is used to specify the
          relative
          sequence for an order on the route. This field can contain a null
          value specifying that the order can be placed anywhere along the
          route. A null value can only occur together with a null RouteName
          value. The input sequence values are positive and unique for each
          route
          (shared across renewal depot visits, orders, and breaks) but do not
          need to start from 1 or be contiguous. After a solve operation, the
          Sequence field contains the sequence
          value of the order on its assigned route. Output sequence values for a
          route are shared across depot visits, orders, and breaks; start from 1
          (at the starting depot); and are consecutive. So the smallest possible
          output sequence value for a routed order is 2, since a route always
          begins at a depot
      depots (Feature Set):
          Specify one or more depots for the given vehicle routing problem. A
          depot is a location that a vehicle departs from at the beginning of
          its workday and returns to at the end of the workday. Vehicles are
          loaded (for deliveries) or unloaded (for pickups) at depots at the
          start of the route. In some cases, a depot can also act as a renewal
          location whereby the vehicle can unload or reload and continue
          performing deliveries and pickups. A depot has open and close times,
          as specified by a hard time window. Vehicles can't arrive at a depot
          outside of this time window.When specifying the orders, you can set
          properties for each one, such
          as its name or service time, by using attributes. The orders can be
          specified with the following attributes:        ObjectID: The system-
          managed ID field.        Name: The name of the depot. The
          StartDepotName and
          EndDepotName fields of the Routes record set reference the names you
          specify here. It is also referenced by the Route Renewals record set,
          when used. Depot names are case insensitive and have to be nonempty
          and unique.        TimeWindowStart1: The beginning time of the first
          time window
          for the network location. This field can contain a null value; a null
          value indicates no beginning time. Time window fields can contain a
          time-only value or a date and time
          value. If a time field has a time-only value (for example, 8:00 AM),
          the date is assumed to be the date specified by the Default Date
          parameter of the analysis layer. Using date and time values (for
          example, 7/11/2010 8:00 AM) allows you to set time windows that span
          multiple days. When solving a problem that spans multiple time zones,
          each depot's
          time-window values refer to the time zone in which the depot is
          located.        TimeWindowEnd1: The ending time of the first window
          for the
          network location. This field can contain a null value; a null value
          indicates no ending time.        TimeWindowStart2: The beginning time
          of the second time window
          for the network location. This field can contain a null value; a null
          value indicates that there is no second time window. If the first time
          window is null, as specified by the
          TimeWindowStart1 and TimeWindowEnd1 fields, the second time window
          must also be null. If both time windows are nonnull, they can't
          overlap. Also, the
          second time window must occur after the first.        TimeWindowEnd2:
          The ending time of the second time window for
          the network location. This field can contain a null value. When
          TimeWindowStart2 and TimeWindowEnd2 are both null, there is no
          second time window. When TimeWindowStart2 is not null but
          TimeWindowEnd2 is null, there
          is a second time window that has a starting time but no ending time.
          This is valid.        CurbApproach: Specifies the direction a vehicle
          may arrive at
          and depart from the depot. The field value is specified as one of the
          following integers shown in the parentheses (use the numeric code, not
          the name in parentheses):

          *  0 (Either side of vehicle)-The vehicle can approach and depart the
          depot in either direction, so a U-turn is allowed at the incident.
          This setting can be chosen if it is possible and desirable for your
          vehicle to turn around at the depot. This decision may depend on the
          width of the road and the amount of traffic or whether the depot has a
          parking lot where vehicles can pull in and turn around.

          *  1 (Right side of vehicle)-When the vehicle approaches and departs
          the depot, the depot must be on the right side of the vehicle. A
          U-turn is prohibited. This is typically used for vehicles like buses
          that must arrive with the bus stop on the right-hand side.

          *  2 (Left side of vehicle)-When the vehicle approaches and departs
          the depot, the curb must be on the left side of the vehicle. A U-turn
          is prohibited. This is typically used for vehicles like buses that
          must arrive with the bus stop on the left-hand side.

          * 3 (No U-Turn)-When the vehicle approaches the depot, the curb can be
          on either side of the vehicle; however, the vehicle must depart
          without turning around.
          The CurbApproach property is designed to work with both kinds of
          national driving standards: right-hand traffic (United States) and
          left-hand traffic (United Kingdom). First, consider a depot on the
          left side of a vehicle. It is always on the left side regardless of
          whether the vehicle travels on the left or right half of the road.
          What may change with national driving standards is your decision to
          approach a depot from one of two directions, that is, so it ends up on
          the right or left side of the vehicle. For example, if you want to
          arrive at a depot and not have a lane of traffic between the vehicle
          and the depot, you would choose 1 (Right side of vehicle) in the
          United States but 2 (Left side of vehicle) in the United Kingdom.
          Bearing: The direction in which a point is moving. The units
          are degrees and measured in a clockwise fashion from true north. This
          field is used in conjunction with the BearingTol field. Bearing data
          is usually sent automatically from a mobile device
          equipped with a GPS receiver. Try to include bearing data if you are
          loading an order that is moving, such as a pedestrian or a vehicle.
          Using this field tends to prevent adding locations to the wrong
          edges, which can occur when a vehicle is near an intersection or an
          overpass for example. Bearing also helps the tool determine on which
          side of the street the point is. For more information, see the Bearing
          and Bearing Tolerance Help
          topic (http://links.esri.com/bearing-and-bearing-tolerance).
          BearingTol: The bearing tolerance value creates a range of
          acceptable bearing values when locating moving points on an edge using
          the Bearing field. If the value from the Bearing field is within the
          range of acceptable values that are generated from the bearing
          tolerance on an edge, the point can be added as a network location
          there; otherwise, the closest point on the next-nearest edge is
          evaluated. The units are in degrees and the default value is 30.
          Values must be
          greater than zero and less than 180. A value of 30 means that when
          Network Analyst attempts to add a
          network location on an edge, a range of acceptable bearing values is
          generated 15 degrees to either side of the edge (left and right) and
          in both digitized directions of the edge. For more information, see
          the Bearing and Bearing Tolerance topic in
          the ArcGIS help system (http://links.esri.com/bearing-and-bearing-
          tolerance).        NavLatency: This field is only used in the solve
          process if
          Bearing and BearingTol also have values; however, entering a
          NavLatency value is optional, even when values are present in Bearing
          and BearingTol. NavLatency indicates how much time is expected to
          elapse from the moment GPS information is sent from a moving vehicle
          to a server and the moment the processed route is received by the
          vehicle's navigation device. The time units of NavLatency are the same
          as the units of the cost attribute specified by the parameter Time
          Attribute.
      routes (Record Set):
          Specify one or more routes (up to 100). A route specifies vehicle and
          driver characteristics; after solving, it also represents the path
          between depots and orders. A route can have start and end depot
          service times, a fixed or
          flexible starting time, time-based operating costs, distance-based
          operating costs, multiple capacities, various constraints on a
          driver's workday, and so on. When specifying the routes, you can set
          properties for each one by using attributes. The routes can be
          specified with the following attributes:        Name: The name of the
          route. The name must be unique. The tool generates a unique name at
          solve time if the field value is
          null; therefore, entering a value is optional in most cases. However,
          you must enter a name if your analysis includes breaks, route
          renewals, route zones, or orders that are preassigned to a route
          because the route name is used as a foreign key in these cases. Note
          that route names are case insensitive.        StartDepotName: The name
          of the starting depot for the route.
          This field is a foreign key to the Name field in Depots. If the
          StartDepotName value is null, the route will begin from the
          first order assigned. Omitting the start depot is useful when the
          vehicle's starting location is unknown or irrelevant to your problem.
          However, when StartDepotName is null, EndDepotName cannot also be
          null.Virtual start depots are not allowed if orders or depots are in
          multiple time zones. If the route is making deliveries and
          StartDepotName is null, it is
          assumed the cargo is loaded on the vehicle at a virtual depot before
          the route begins. For a route that has no renewal visits, its delivery
          orders (those with nonzero DeliveryQuantities values in the Orders
          class) are loaded at the start depot or virtual depot. For a route
          that has renewal visits, only the delivery orders before the first
          renewal visit are loaded at the start depot or virtual depot.
          EndDepotName: The name of the ending depot for the route. This
          field is a foreign key to the Name field in the Depots class.
          StartDepotServiceTime: The service time at the starting depot.
          This can be used to model the time spent loading the vehicle. This
          field can contain a null value; a null value indicates zero service
          time. The unit for this field value is specified by the Time Field
          Units
          parameter. The service times at the start and end depots are fixed
          values (given
          by the StartDepotServiceTime and EndDepotServiceTime field values) and
          do not take into account the actual load for a route. For example, the
          time taken to load a vehicle at the starting depot may depend on the
          size of the orders. As such, the depot service times could be given
          values corresponding to a full truckload or an average truckload, or
          you could make your own time estimate.        EndDepotServiceTime: The
          service time at the ending depot.
          This can be used to model the time spent unloading the vehicle. This
          field can contain a null value; a null value indicates zero service
          time. The unit for this field value is specified by the Time Field
          Units
          parameter. The service times at the start and end depots are fixed
          values (given
          by the StartDepotServiceTime and EndDepotServiceTime field values) and
          do not take into account the actual load for a route. For example, the
          time taken to load a vehicle at the starting depot may depend on the
          size of the orders. As such, the depot service times could be given
          values corresponding to a full truckload or an average truckload, or
          you could make your own time estimate.        EarliestStartTime: The
          earliest allowable starting time for
          the route. This is used by the solver in conjunction with the time
          window of the starting depot for determining feasible route start
          times. This field can't contain null values and has a default time-
          only
          value of 8:00 AM; the default value is interpreted as 8:00 a.m. on the
          date given by the Default Date parameter. When solving a problem that
          spans multiple time zones, the time zone
          for EarliestStartTime is the same as the time zone in which the
          starting depot is located.        LatestStartTime: The latest
          allowable starting time for the
          route. This field can't contain null values and has a default time-
          only value of 10:00 AM; the default value is interpreted as 10:00 a.m.
          on the date given by the Default Date property of the analysis layer.
          When solving a problem that spans multiple time zones, the time zone
          for LatestStartTime is the same as the time zone in which the starting
          depot is located.        ArriveDepartDelay: This field stores the
          amount of travel time
          needed to accelerate the vehicle to normal travel speeds, decelerate
          it to a stop, and move it off and on the network (for example, in and
          out of parking). By including an ArriveDepartDelay value, the VRP
          solver is deterred from sending many routes to service physically
          coincident orders. The cost for this property is incurred between
          visits to
          noncoincident orders, depots, and route renewals. For example, when a
          route starts from a depot and visits the first order, the total
          arrive/depart delay is added to the travel time. The same is true when
          traveling from the first order to the second order. If the second and
          third orders are coincident, the ArriveDepartDelay value is not added
          between them since the vehicle doesn't need to move. If the route
          travels to a route renewal, the value is added to the travel time
          again. Although a vehicle needs to slow down and stop for a break and
          accelerate afterwards, the VRP solver cannot add the ArriveDepartDelay
          value for breaks. This means that if a route leaves an order, stops
          for a break, and continues to the next order, the arrive/depart delay
          is added only once, not twice. To illustrate, assume there are five
          coincident orders in a high-rise
          building, and they are serviced by three different routes. This means
          three arrive/depart delays would be incurred; that is, three drivers
          would need to separately find parking places and enter the same
          building. However, if the orders could be serviced by just one route
          instead, only one driver would need to park and enter the
          building-only one arrive/depart delay would be incurred. Since the VRP
          solver tries to minimize cost, it will try to limit the arrive/depart
          delays and thus choose the single-route option. (Note that multiple
          routes may need to be sent when other constraints-such as specialties,
          time windows, or capacities-require it.) The unit for this field value
          is specified by the time_units
          parameter.        Capacities: The maximum capacity of the vehicle. You
          can
          specify capacity in any dimension you want, such as weight, volume, or
          quantity. You can even specify multiple dimensions, for example,
          weight and volume. Enter capacities without indicating units. For
          example, assume your
          vehicle can carry a maximum of 40,000 pounds; you would enter 40000.
          You need to remember for future reference that the value is in pounds.
          If you are tracking multiple dimensions, separate the numeric values
          with a space. For instance, if you are recording both weight and
          volume and your vehicle can carry a maximum weight of 40,000 pounds
          and a maximum volume of 2,000 cubic feet, Capacities should be entered
          as 40000 2000. Again, you need to remember the units. You also need to
          remember the sequence in which the values and their corresponding
          units are entered (pounds followed by cubic feet in this case).
          Remembering the units and the unit sequence is important for a couple
          of reasons: one, so you can reinterpret the information later; two, so
          you can properly enter values for the DeliveryQuantities and
          PickupQuantities fields for the orders. To elaborate on the second
          point, note that the VRP solver simultaneously refers to Capacities,
          DeliveryQuantities, and PickupQuantities to make sure that a route
          doesn't become overloaded. Since units can't be entered in the field,
          the VRP tool can't make unit conversions, so you need to enter the
          values for the three fields using the same units and the same unit
          sequence to ensure the values are correctly interpreted. If you mix
          units or change the sequence in any of the three fields, you will get
          unwanted results without receiving any warning messages. Thus, it is a
          good idea to set up a unit and unit-sequence standard beforehand and
          continually refer to it whenever entering values for these three
          fields. An empty string or null value is equivalent to all values
          being zero.
          Capacity values can't be negative. If the Capacities string has an
          insufficient number of values in
          relation to the DeliveryQuantities or PickupQuantities fields for
          orders, the remaining values are treated as zero. The VRP solver only
          performs a simple Boolean test to determine
          whether capacities are exceeded. If a route's capacity value is
          greater than or equal to the total quantity being carried, the VRP
          solver will assume the cargo fits in the vehicle. This could be
          incorrect, depending on the actual shape of the cargo and the vehicle.
          For example, the VRP solver allows you to fit a 1,000-cubic-foot
          sphere into a 1,000-cubic-foot truck that is 8 feet wide. In reality,
          however, since the sphere is 12.6 feet in diameter, it won't fit in
          the 8-foot wide truck.        FixedCost: A fixed monetary cost that is
          incurred only if the
          route is used in a solution (that is, it has orders assigned to it).
          This field can contain null values; a null value indicates zero fixed
          cost. This cost is part of the total route operating cost.
          CostPerUnitTime: The monetary cost incurred-per unit of work
          time-for the total route duration, including travel times as well as
          service times and wait times at orders, depots, and breaks. This field
          can't contain a null value and has a default value of 1.0. The unit
          for this field value is specified by the time_units
          parameter.        CostPerUnitDistance: The monetary cost incurred-per
          unit of
          distance traveled-for the route length (total travel distance). This
          field can contain null values; a null value indicates zero cost. The
          unit for this field value is specified by the distance_units
          parameter.        OvertimeStartTime: The duration of regular work time
          before
          overtime computation begins. This field can contain null values; a
          null value indicates that overtime does not apply. The unit for this
          field value is specified by the time_units
          parameter. For example, if the driver is to be paid overtime pay when
          the total
          route duration extends beyond eight hours, OvertimeStartTime is
          specified as 480 (8 hours * 60 minutes/hour), given the time_units
          parameter is set to Minutes.        CostPerUnitOvertime: The monetary
          cost incurred per time unit
          of overtime work. This field can contain null values; a null value
          indicates that the CostPerUnitOvertime value is the same as the
          CostPerUnitTime value.        MaxOrderCount: The maximum allowable
          number of orders on the
          route. This field can't contain null values and has a default value of
          30. This value cannot exceed 200.        MaxTotalTime: The maximum
          allowable route duration. The route
          duration includes travel times as well as service and wait times at
          orders, depots, and breaks. This field can contain null values; a null
          value indicates that there is no constraint on the route duration. The
          unit for this field value is specified by the time_units
          parameter.        MaxTotalTravelTime: The maximum allowable travel
          time for the
          route. The travel time includes only the time spent driving on the
          network and does not include service or wait times. This field can
          contain null values; a null value indicates there is
          no constraint on the maximum allowable travel time. This field value
          can't be larger than the MaxTotalTime field value. The unit for this
          field value is specified by the time_units
          parameter.        MaxTotalDistance: The maximum allowable travel
          distance for
          the route. The unit for this field value is specified by the
          distance_units
          parameter. This field can contain null values; a null value indicates
          that there
          is no constraint on the maximum allowable travel distance.
          SpecialtyNames: A space-separated string containing the names
          of the specialties supported by the route. A null value indicates that
          the route does not support any specialties. This field is a foreign
          key to the SpecialtyNames field in the orders
          class. To illustrate what specialties are and how they work, assume a
          lawn
          care and tree trimming company has a portion of its orders that
          requires a bucket truck to trim tall trees. The company would enter
          BucketTruck in the SpecialtyNames field for these orders to indicate
          their special need. SpecialtyNames would be left as null for the other
          orders. Similarly, the company would also enter BucketTruck in the
          SpecialtyNames field of routes that are driven by trucks with
          hydraulic booms. It would leave the field null for the other routes.
          At solve time, the VRP solver assigns orders without special needs to
          any route, but it only assigns orders that need bucket trucks to
          routes that have them.        AssignmentRule: This specifies whether
          the route can be used
          or not when solving the problem. This field is constrained by a domain
          of values, which are listed below (use the numeric code, not the name
          in parentheses).

          * 1 (Include)-The route is included in the solve operation. This is
          the default value.

          *  2 (Exclude)-The route is excluded from the solve operation.
      breaks (Record Set):
          These are the rest periods, or breaks, for the routes in a given
          vehicle routing problem. A break is associated with exactly one route,
          and it can be taken after completing an order, while en route to an
          order, or prior to servicing an order. It has a start time and a
          duration for which the driver may or may not be paid. There are three
          options for establishing when a break begins: using a time window, a
          maximum travel time, or a maximum work time.When specifying the
          breaks, you can set properties for each one, such
          as its name or service time, by using attributes. The orders can be
          specified with the following attributes:        ObjectID: The system-
          managed ID field.        RouteName: The name of the route to which the
          break applies.
          Although a break is assigned to exactly one route, many breaks can be
          assigned to the same route. This field is a foreign key to the Name
          field in the routes
          parameter, so it can't have a null value.        Precedence:
          Precedence values sequence the breaks of a given
          route. Breaks with a precedence value of 1 occur before those with a
          value of 2, and so on. All breaks must have a precedence value,
          regardless of whether they
          are time-window, maximum-travel-time, or maximum-work-time breaks.
          ServiceTime: The duration of the break. This field can contain
          null values; a null value indicates no service time. The unit for this
          field value is specified by the time_units
          parameter.        TimeWindowStart: The starting time of the break's
          time window. If this field is null and TimeWindowEnd has a valid time-
          of-day
          value, the break is allowed to start any time before the TimeWindowEnd
          value. If this field has a value, the MaxTravelTimeBetweenBreaks and
          MaxCumulWorkTime field values must be null; moreover, all other breaks
          in the analysis layer must have null values for
          MaxTravelTimeBetweenBreaks and MaxCumulWorkTime. An error will occur
          at solve time if a route has multiple breaks with
          overlapping time windows. The time window fields in breaks can contain
          a time-only value or a
          date and time value. If a time field, such as TimeWindowStart, has a
          time-only value (for example, 12:00 PM), the date is assumed to be the
          date specified by the default_date parameter. Using date and time
          values (for example, 7/11/2012 12:00 PM) allows you to specify time
          windows that span two or more days. This is especially beneficial when
          a break should be taken sometime before and after midnight. When
          solving a problem that spans multiple time zones, each break's
          time-window values refer to the time zone in which the associated
          route, as specified by the RouteName field, is located.
          TimeWindowEnd: The ending time of the break's time window. If this
          field is null and TimeWindowStart has a valid time-of-day
          value, the break is allowed to start any time after the
          TimeWindowStart value. If this field has a value,
          MaxTravelTimeBetweenBreaks and
          MaxCumulWorkTime must be null; moreover, all other breaks in the
          analysis layer must have null values for MaxTravelTimeBetweenBreaks
          and MaxCumulWorkTime.        MaxViolationTime: This field specifies
          the maximum allowable
          violation time for a time-window break. A time window is considered
          violated if the arrival time falls outside the time range. A zero
          value indicates the time window cannot be violated; that is,
          the time window is hard. A nonzero value specifies the maximum amount
          of lateness; for example, the break can begin up to 30 minutes beyond
          the end of its time window, but the lateness is penalized as per the
          Time Window Violation Importance parameter. This property can be null;
          a null value with TimeWindowStart and
          TimeWindowEnd values indicates that there is no limit on the allowable
          violation time. If MaxTravelTimeBetweenBreaks or MaxCumulWorkTime has
          a value, MaxViolationTime must be null. The unit for this field value
          is specified by the time_units
          parameter.        MaxTravelTimeBetweenBreaks: The maximum amount of
          travel time
          that can be accumulated before the break is taken. The travel time is
          accumulated either from the end of the previous break or, if a break
          has not yet been taken, from the start of the route. If this is the
          route's final break, MaxTravelTimeBetweenBreaks also
          indicates the maximum travel time that can be accumulated from the
          final break to the end depot. This field is designed to limit how long
          a person can drive until a
          break is required. For instance, if the Time Field Units parameter
          (time_units for Python) of the analysis is set to Minutes, and
          MaxTravelTimeBetweenBreaks has a value of 120, the driver will get a
          break after two hours of driving. To assign a second break after two
          more hours of driving, the second break's MaxTravelTimeBetweenBreaks
          property should be 120. If this field has a value, TimeWindowStart,
          TimeWindowEnd,
          MaxViolationTime, and MaxCumulWorkTime must be null for an analysis to
          solve successfully. The unit for this field value is specified by the
          time_units
          parameter.        MaxCumulWorkTime: The maximum amount of work time
          that can be accumulated before the
          break is taken. Work time is always accumulated from the beginning of
          the route. Work time is the sum of travel time and service times at
          orders,
          depots, and breaks. Note, however, that this excludes wait time, which
          is the time a route (or driver) spends waiting at an order or depot
          for a time window to begin. This field is designed to limit how long a
          person can work until a
          break is required. For instance, if the time_units parameter is set to
          Minutes, MaxCumulWorkTime has a value of 120, and ServiceTime has a
          value of 15, the driver will get a 15-minute break after two hours of
          work. Continuing with the last example, assume a second break is
          needed
          after three more hours of work. To specify this break, you would enter
          315 (five hours and 15 minutes) as the second break's MaxCumulWorkTime
          value. This number includes the MaxCumulWorkTime and ServiceTime
          values of the preceding break, along with the three additional hours
          of work time before granting the second break. To avoid taking
          maximum-work-time breaks prematurely, remember that they accumulate
          work time from the beginning of the route and that work time includes
          the service time at previously visited depots, orders, and breaks. If
          this field has a value, TimeWindowStart, TimeWindowEnd,
          MaxViolationTime, and MaxTravelTimeBetweenBreaks must be null for an
          analysis to solve successfully. The unit for this field value is
          specified by the time_units
          parameter.        IsPaid: A Boolean value indicating whether the break
          is paid
          or unpaid. A True value indicates that the time spent at the break is
          included in the route cost computation and overtime determination. A
          False value indicates otherwise. The default value is True.
          Sequence: As an input field, this indicates the sequence of
          the break on its route. This field can contain null values. The input
          sequence values are positive and unique for each route (shared across
          renewal depot visits, orders, and breaks) but need not start from 1 or
          be contiguous. The solver modifies the sequence field. After solving,
          this field
          contains the sequence value of the break on its route. Output sequence
          values for a route are shared across depot visits, orders, and breaks;
          start from 1 (at the starting depot); and are consecutive.
      time_units (String):
          The time units for all time-based field values in the analysis. Many
          features and records in a VRP analysis have fields for storing time
          values, such as ServiceTime for orders and CostPerUnitTime for routes.
          To minimize data entry requirements, these field values don't include
          units. Instead, all distance-based field values must be entered in the
          same units, and this parameter is used to specify the units of those
          values. Note that output time-based fields use the same units
          specified by
          this parameter.
      distance_units (String):
          The distance units for all distance-based field values in the
          analysis. Many features and records in a VRP analysis have fields for
          storing distance values, such as MaxTotalDistance and
          CostPerUnitDistance for Routes. To minimize data entry requirements,
          these field values don't include units. Instead, all distance-based
          field values must be entered in the same units, and this parameter is
          used to specify the units of those values. Note that output distance-
          based fields use the same units specified
          by this parameter.
      analysis_region {String}:
          Specify the region in which to perform the analysis. If a value is
          not specified for this parameter, the tool will automatically
          calculate the region name based on the location of the input points.
          Setting the name of the region is recommended to speed up the tool
          execution. To specify a region, use one of the following values:

          *  Europe

          * Greece

          *  India

          *  Japan

          * Korea

          *  MiddleEastAndAfrica

          *  NorthAmerica

          *  Oceania

          *  SouthAmerica

          *  SouthEastAsia

          * Taiwan

          * Thailand
      default_date {Date}:
          The default date for time field values that specify a time of day
          without including a date. You can find these time fields in various
          input parameters, such as the ServiceTime attributes in the orders and
          breaks parameters.
      uturn_policy {String}:
          Use this parameter to restrict or permit the service area to make
          U-turns at junctions. To understand the parameter values, consider for
          a moment the following terminology: a junction is a point where a
          street segment ends and potentially connects to one or more other
          segments; a pseudo-junction is a point where exactly two streets
          connect to one another; an intersection is a point where three or more
          streets connect; and a dead-end is where one street segment ends
          without connecting to another. Given this information, the parameter
          can have the following values:

          *  ALLOW_UTURNS-U-turns are permitted everywhere. Allowing U-turns
          implies that the vehicle can turn around at any junction and double
          back on the same street. This is the default value.

          *  NO_UTURNS-U-turns are prohibited at all junctions: pseudo-
          junctions, intersections, and dead-ends. Note, however, that U-turns
          may be permitted even when this option is chosen. To prevent U-turns
          at incidents and facilities, set the CurbApproach field value to
          prohibit U-turns.

          *  ALLOW_DEAD_ENDS_ONLY-U-turns are prohibited at all junctions,
          except those that have only one connected street feature (a dead end).

          * ALLOW_DEAD_ENDS_AND_INTERSECTIONS_ONLY-U-turns are prohibited at
          pseudo-junctions where exactly two adjacent streets meet, but U-turns
          are permitted at intersections and dead ends. This prevents turning
          around in the middle of the road where one length of road happened to
          be digitized as two street features.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.
      time_window_factor {String}:
          Rates the importance of honoring time windows. There are three
          options described below.

          *  High-Places more importance on arriving at stops on time than on
          minimizing drive times. Organizations that make time-critical
          deliveries or that are very concerned with customer service would
          choose High.

          *  Medium-This is the default value. Balances the importance of
          minimizing drive times and arriving within time windows.

          *  Low-Places more importance on minimizing drive times and less on
          arriving at stops on time. You may want to use this setting if you
          have a growing backlog of service requests. For the purpose of
          servicing more orders in a day and reducing the backlog, you can
          choose Low even though customers might be inconvenienced with your
          late arrivals.
      spatially_cluster_routes {Boolean}:
          *  CLUSTER (True)-Dynamic seed points are automatically created for
          all routes, and the orders assigned to an individual route are
          spatially clustered. Clustering orders tends to keep routes in smaller
          areas and reduce how often different route lines intersect one
          another; yet, clustering also tends to increase overall travel times.

          *  NO_CLUSTER (False)-Dynamic seed points aren't created. Choose this
          option if route zones are specified.
      route_zones {Feature Set}:
          Delineates work territories for given routes. A route zone is a
          polygon feature and is used to constrain routes to servicing only
          those orders that fall within or near the specified area. Here are
          some examples of when route zones may be useful:

          *  Some of your employees don't have the required permits to perform
          work in certain states or communities. You can create a hard route
          zone so they only visit orders in areas where they meet the
          requirements.

          *  One of your vehicles breaks down frequently so you want to minimize
          response time by having it only visit orders that are close to your
          maintenance garage. You can create a soft or hard route zone to keep
          the vehicle nearby.
          When specifying the route zones, you need to set properties for each
          one, such as its associated route, by using attributes. The route
          zones can be specified with the following attributes:        ObjectID:
          The system-managed ID field.        RouteName: The name of the route
          to which this zone applies. A
          route zone can have a maximum of one associated route. This field
          can't contain null values, and it is a foreign key to the Name field
          in the feature in the routes parameter.        IsHardZone: A Boolean
          value indicating a hard or soft route
          zone. A True value indicates that the route zone is hard; that is, an
          order that falls outside the route zone polygon can't be assigned to
          the route. The default value is 1 (True). A False value (0) indicates
          that such orders can still be assigned, but the cost of servicing the
          order is weighted by a function that is based on the Euclidean
          distance from the route zone. Basically, this means that as the
          straight-line distance from the soft zone to the order increases, the
          likelihood of the order being assigned to the route decreases.
      route_renewals {Record Set}:
          Specifies the intermediate depots that routes can visit to reload or
          unload the cargo they are delivering or picking up. Specifically, a
          route renewal links a route to a depot. The relationship indicates the
          route can renew (reload or unload while en route) at the associated
          depot. Route renewals can be used to model scenarios in which a
          vehicle
          picks up a full load of deliveries at the starting depot, services the
          orders, returns to the depot to renew its load of deliveries, and
          continues servicing more orders. For example, in propane gas delivery,
          the vehicle may make several deliveries until its tank is nearly or
          completely depleted, visit a refueling point, and make more
          deliveries. Here are a few rules and options to consider when also
          working with
          route seed points:

          *  The reload/unload point, or renewal location, can be different from
          the start or end depot.

          *  Each route can have one or many predetermined renewal locations.

          *  A renewal location may be used more than once by a single route.

          *  In some cases where there may be several potential renewal
          locations for a route, the closest available renewal location is
          chosen by the solver.
          When specifying the route renewals, you need to set properties for
          each one, such as the name of the depot where the route renewal can
          occur, by using attributes. The route renewals can be specified with
          the following attributes:        ObjectID: The system-managed ID
          field.        DepotName: The name of the depot where this renewal
          takes
          place. This field can't contain a null value and is a foreign key to
          the Name field in the depots parameter.        RouteName: The name of
          the route to which this renewal
          applies. This field can't contain a null value and is a foreign key to
          the Name field in the routes parameter.        ServiceTime: The
          service time for the renewal. This field can
          contain a null value; a null value indicates zero service time. The
          unit for this field value is specified by the time_units
          parameter. The time taken to load a vehicle at a renewal depot may
          depend on the
          size of the vehicle and how full or empty the vehicle is. However, the
          service time for a route renewal is a fixed value and does not take
          into account the actual load. As such, the renewal service time should
          be given a value corresponding to a full truckload, an average
          truckload, or another time estimate of your choice.
      order_pairs {Record Set}:
          This parameter pairs pickup and delivery orders so they are serviced
          by the same route. Sometimes it is required that the pickup and
          delivery for orders be
          paired. For example, a courier company might need to have a route pick
          up a high-priority package from one order and deliver it to another
          without returning to a depot, or sorting station, to minimize delivery
          time. These related orders can be assigned to the same route with the
          appropriate sequence by using order pairs. Moreover, restrictions on
          how long the package can stay in the vehicle can also be assigned; for
          example, the package might be a blood sample that has to be
          transported from the doctor's office to the lab within two hours.When
          specifying the order pairs, you need to set properties for each
          one, such as the names of the two orders, by using attributes. The
          order pairs can be specified with the following attributes:
          ObjectID: The system-managed ID field.        FirstOrderName: The name
          of the first order of the pair. This
          field is a foreign key to the Name field in the orders parameter.
          SecondOrderName: The name of the second order of the pair.
          This field is a foreign key to the name field in the orders parameter.
          The first order in the pair must be a pickup order; that is, the
          value for its DeliveryQuantities field is null. The second order in
          the pair must be a delivery order; that is, the value for its
          PickupQuantities field is null. The quantity picked up at the first
          order must agree with the quantity delivered at the second order. As a
          special case, both orders may have zero quantities for scenarios where
          capacities are not used. The order quantities are not loaded or
          unloaded at depots.        MaxTransitTime: The maximum transit time
          for the pair. The
          transit time is the duration from the departure time of the first
          order to the arrival time at the second order. This constraint limits
          the time-on-vehicle, or ride time, between the two orders. When a
          vehicle is carrying people or perishable goods, the ride time is
          typically shorter than that of a vehicle carrying packages or
          nonperishable goods. This field can contain null values; a null value
          indicates that there is no constraint on the ride time. The unit for
          this field value is specified by the time_units
          parameter. Excess transit time (measured with respect to the direct
          travel time
          between order pairs) can be tracked and weighted by the solver.
          Because of this, you can direct the VRP solver to take one of three
          approaches:

          *  Minimize the overall excess transit time, regardless of the
          increase in travel cost for the fleet.

          *  Find a solution that balances overall violation time and travel
          cost.

          *  Ignore the overall excess transit time and, instead, minimize the
          travel cost for the fleet.
           By assigning an importance level for the excess_transit_factor
          parameter, you are, in effect, choosing one of these three approaches.
          Regardless of the importance level, the solver will always return an
          error if the MaxTransitTime value is surpassed.
      excess_transit_factor {String}:
          Rates the importance of reducing excess transit time of order pairs.
          Excess transit time is the amount of time exceeding the time required
          to travel directly between the paired orders. Excess time can be
          caused by driver breaks or travel to intermediate orders and depots.
          Listed below are the three values you can choose from.

          *  High-The solver tries to find a solution with the least excess
          transit time between paired orders at the expense of increasing the
          overall travel costs. It makes sense to use this setting if you are
          transporting people between paired orders and you want to shorten
          their ride time. This is characteristic of taxi services.

          *  Medium-This is the default setting. The solver looks for a balance
          between reducing excess transit time and reducing the overall solution
          cost.

          *  Low-The solver tries to find a solution that minimizes overall
          solution cost, regardless of excess transit time. This setting is
          commonly used with courier services. Since couriers transport packages
          as opposed to people, they don't need to worry about ride time. Using
          Low allows the couriers to service paired orders in the proper
          sequence and minimize the overall solution cost.
      point_barriers {Feature Set}:
          Specify one or more points to act as temporary restrictions or
          represent additional time or distance that may be required to travel
          on the underlying streets. For example, a point barrier can be used to
          represent a fallen tree along a street or time delay spent at a
          railroad crossing. The tool imposes a limit of 250 points that can be
          added as barriers.When specifying the point barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The point
          barriers can be specified with the following attributes: Name: The
          name of the barrier. BarrierType: Specifies whether the point barrier
          restricts travel
          completely or adds time or distance when it is crossed. The value for
          this attribute is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits travel through the barrier. The barrier
          is referred to as a restriction point barrier since it acts as a
          restriction.

          *  2 (Added Cost)-Traveling through the barrier increases the travel
          time or distance by the amount specified in the Additional_Time or
          Additional_Distance field. This barrier type is referred to as an
          added-cost point barrier.
           Additional_Time: Indicates how much travel time is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are time based. This field
          value must be greater than or equal to zero, and its units are the
          same as those specified in the Measurement Units parameter.
          Additional_Distance: Indicates how much distance is added when the
          barrier is traversed. This field is applicable only for added-cost
          barriers and only if the measurement units are distance based. The
          field value must be greater than or equal to zero, and its units are
          the same as those specified in the Measurement Units parameter.
      line_barriers {Feature Set}:
          Specify one or more lines that prohibit travel anywhere the lines
          intersect the streets. For example, a parade or protest that blocks
          traffic across several street segments can be modeled with a line
          barrier. A line barrier can also quickly fence off several roads from
          being traversed, thereby channeling possible routes away from
          undesirable parts of the street network. The tool imposes a limit on
          the number of streets you can restrict
          using the Line Barriers parameter. While there is no limit on the
          number of lines you can specify as line barriers, the combined number
          of streets intersected by all the lines cannot exceed 500.When
          specifying the line barriers, you can set a name property for
          each one by using the following attribute: Name: The name of the
          barrier.
      polygon_barriers {Feature Set}:
          Specify polygons that either completely restrict travel or
          proportionately scale the time or distance required to travel on the
          streets intersected by the polygons. The service imposes a limit on
          the number of streets you can restrict
          using the Polygon Barriers parameter. While there is no limit on the
          number of polygons you can specify as the polygon barriers, the
          combined number of streets intersected by all the polygons should not
          exceed 2,000.When specifying the polygon barriers, you can set
          properties for each
          one, such as its name or barrier type, by using attributes. The
          polygon barriers can be specified with the following attributes: Name:
          The name of the barrier. BarrierType: Specifies whether the barrier
          restricts travel
          completely or scales the time or distance for traveling through it.
          The field value is specified as one of the following integers (use the
          numeric code, not the name in parentheses):

          *  0 (Restriction)-Prohibits traveling through any part of the
          barrier. The barrier is referred to as a restriction polygon barrier
          since it prohibits traveling on streets intersected by the barrier.
          One use of this type of barrier is to model floods covering areas of
          the street that make traveling on those streets impossible.

          *  1 (Scaled Cost)-Scales the time or distance required to travel the
          underlying streets by a factor specified using the ScaledTimeFactor or
          ScaledDistanceFactor field. If the streets are partially covered by
          the barrier, the travel time or distance is apportioned and then
          scaled. For example, a factor 0.25 would mean that travel on
          underlying streets is expected to be four times faster than normal. A
          factor of 3.0 would mean it is expected to take three times longer
          than normal to travel on underlying streets. This barrier type is
          referred to as a scaled-cost polygon barrier. It might be used to
          model storms that reduce travel speeds in specific regions.
           ScaledTimeFactor: This is the factor by which the travel time of the
          streets intersected by the barrier is multiplied. This field is
          applicable only for scaled-cost barriers and only if the measurement
          units are time based. The field value must be greater than zero.
          ScaledDistanceFactor: This is the factor by which the distance of the
          streets intersected by the barrier is multiplied. This attribute is
          applicable only for scaled-cost barriers and only if the measurement
          units are distance based. The attribute value must be greater than
          zero.
      use_hierarchy_in_analysis {Boolean}:
          Specify whether hierarchy should be used when finding the best
          routes.

          *  Checked (True)-Use hierarchy when finding routes. When hierarchy is
          used, the tool prefers higher-order streets, such as freeways, to
          lower-order streets, such as local roads, and can be used to simulate
          the driver preference of traveling on freeways instead of local roads
          even if that means a longer trip. This is especially true when finding
          routes to faraway locations, because drivers on long-distance trips
          tend to prefer traveling on freeways where stops, intersections, and
          turns can be avoided. Using hierarchy is computationally faster,
          especially for long-distance routes, as the tool has to select the
          best route from a relatively smaller subset of streets.

          *  Unchecked (False)-Do not use hierarchy when finding routes. If
          hierarchy is not used, the tool considers all the streets and doesn't
          prefer higher-order streets when finding the route. This is often used
          when finding short-distance routes within a city.
           The tool automatically reverts to using hierarchy if the straight-
          line distance between orders, depots, or orders and depots is greater
          than 50 miles, even if you have set this parameter to not use
          hierarchy.The value you provide for this parameter is ignored unless
          Travel Mode
          is set to Custom, which is the default value.
      restrictions {String}:
          Specify which restrictions should be honored by the tool when finding
          the best routes.The value you provide for this parameter is ignored
          unless Travel Mode
          is set to Custom, which is the default value.A restriction represents
          a driving preference or requirement. In most
          cases, restrictions cause roads to be prohibited. For instance, using
          an Avoid Toll Roads restriction will result in a route that will
          include toll roads only when it is absolutely required to travel on
          toll roads in order to visit an incident or a facility. Height
          Restriction makes it possible to route around any clearances that are
          lower than the height of your vehicle. If you are carrying corrosive
          materials on your vehicle, using the Any Hazmat Prohibited restriction
          prevents hauling the materials along roads where it is marked as
          illegal to do so.Below is a list of available restrictions and a short
          description.Some restrictions require an additional value to be
          specified for
          their desired use. This value needs to be associated with the
          restriction name and a specific parameter intended to work with the
          restriction. You can identify such restrictions if their names appear
          under the AttributeName column in the Attribute Parameter Values
          parameter. The ParameterValue field should be specified in the
          Attribute Parameter Values parameter for the restriction to be
          correctly used when finding traversable roads.Some restrictions are
          supported only in certain countries; their
          availability is stated by region in the list below. Of the
          restrictions that have limited availability within a region, you can
          check whether the restriction is available in a particular country by
          looking at the table in the Country List section of the Data coverage
          for network analysis services web page. If a country has a value of
          Yes in the Logistics Attribute column, the restriction with select
          availability in the region is supported in that country. If you
          specify restriction names that are not available in the country where
          your incidents are located, the service ignores the invalid
          restrictions. The service also ignores restrictions whose Restriction
          Usage parameter value is between 0 and 1 (see the Attribute Parameter
          Value parameter). It prohibits all restrictions whose Restriction
          Usage parameter value is greater than 0.The tool supports the
          following restrictions:

          * Any Hazmat Prohibited-The results will not include roads where
          transporting any kind of hazardous material is prohibited.
          Availability: Select countries in North America and Europe

          * Avoid Carpool Roads-The results will avoid roads that are designated
          exclusively for carpool (high-occupancy) vehicles. Availability: All
          countries

          * Avoid Express Lanes-The results will avoid roads designated as
          express
          lanes. Availability: All countries

          * Avoid Ferries-The results will avoid ferries. Availability: All
          countries

          * Avoid Gates-The results will avoid roads where there are gates such
          as
          keyed access or guard-controlled entryways. Availability: All
          countries

          * Avoid Limited Access Roads-The results will avoid roads that are
          limited access highways. Availability: All countries

          * Avoid Private Roads-The results will avoid roads that are not
          publicly
          owned and maintained. Availability: All countries

          * Avoid Toll Roads-The results will avoid toll roads. Availability:
          All countries

          * Avoid Truck Restricted Roads-The results will avoid roads where
          trucks
          are not allowed, except when making deliveries. Availability: All
          countries

          *  Avoid Unpaved Roads-The results will avoid roads that are not paved
          (for example, dirt, gravel, and so on). Availability: All countries

          * Axle Count Restriction-The results will not include roads where
          trucks
          with the specified number of axles are prohibited. The number of axles
          can be specified using the Number of Axles restriction parameter.
          Availability: Select countries in North America and Europe

          * Driving a Bus-The results will not include roads where buses are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Delivery Vehicle-The results will not include roads where
          delivery vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Driving a Taxi-The results will not include roads where taxis are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving a Truck-The results will not include roads where trucks are
          prohibited. Using this restriction will also ensure that the results
          will honor one-way streets. Availability: All countries

          * Driving an Automobile-The results will not include roads where
          automobiles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Driving an Emergency Vehicle-The results will not include roads
          where
          emergency vehicles are prohibited. Using this restriction will also
          ensure that the results will honor one-way streets. Availability: All
          countries

          * Height Restriction-The results will not include roads where the
          vehicle height exceeds the maximum allowed height for the road. The
          vehicle height can be specified using the Vehicle Height (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Kingpin to Rear Axle Length Restriction-The results will not include
          roads where the vehicle length exceeds the maximum allowed kingpin to
          rear axle for all trucks on the road. The length between the vehicle
          kingpin and the rear axle can be specified using the Vehicle Kingpin
          to Rear Axle Length (meters) restriction parameter. Availability:
          Select countries in North America and Europe

          * Length Restriction-The results will not include roads where the
          vehicle length exceeds the maximum allowed length for the road. The
          vehicle length can be specified using the Vehicle Length (meters)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Riding a Motorcycle-The results will not include roads where
          motorcycles are prohibited. Using this restriction will also ensure
          that the results will honor one-way streets. Availability: All
          countries

          * Roads Under Construction Prohibited-The results will not include
          roads
          that are under construction. Availability: All countries

          * Semi or Tractor with One or More Trailers Prohibited-The results
          will
          not include roads where semis or tractors with one or more trailers
          are prohibited. Availability: Select countries in North America and
          Europe

          * Single Axle Vehicles Prohibited-The results will not include roads
          where vehicles with single axles are prohibited. Availability: Select
          countries in North America and Europe

          * Tandem Axle Vehicles Prohibited-The results will not include roads
          where vehicles with tandem axles are prohibited. Availability: Select
          countries in North America and Europe

          * Through Traffic Prohibited-The results will not include roads where
          through traffic (non local) is prohibited. Availability: All countries

          * Truck with Trailers Restriction-The results will not include roads
          where trucks with the specified number of trailers on the truck are
          prohibited. The number of trailers on the truck can be specified using
          the Number of Trailers on Truck restriction parameter. Availability:
          Select countries in North America and Europe

          * Use Preferred Hazmat Routes-The results will prefer roads that are
          designated for transporting any kind of hazardous materials.
          Availability: Select countries in North America and Europe

          * Use Preferred Truck Routes-The results will prefer roads that are
          designated as truck routes, such as the roads that are part of the
          national network as specified by the National Surface Transportation
          Assistance Act in the United States, or roads that are designated as
          truck routes by the state or province, or roads that are preferred by
          the trucks when driving in an area. Availability: Select countries in
          North America and Europe

          * Walking-The results will not include roads where pedestrians are
          prohibited. Availability: All countries

          * Weight Restriction-The results will not include roads where the
          vehicle weight exceeds the maximum allowed weight for the road. The
          vehicle weight can be specified using the Vehicle Weight (kilograms)
          restriction parameter. Availability: Select countries in North America
          and Europe

          * Weight per Axle Restriction-The results will not include roads where
          the vehicle weight per axle exceeds the maximum allowed weight per
          axle for the road. The vehicle weight per axle can be specified using
          the Vehicle Weight per Axle (kilograms) restriction parameter.
          Availability: Select countries in North America and Europe

          * Width Restriction-The results will not include roads where the
          vehicle
          width exceeds the maximum allowed width for the road. The vehicle
          width can be specified using the Vehicle Width (meters) restriction
          parameter. Availability: Select countries in North America and Europe
          The Driving a Delivery Vehicle restriction attribute is deprecated and
          will be unavailable in future releases. To achieve similar results,
          use the Driving a Truck restriction attribute along with the Avoid
          Truck Restricted Roads restriction attribute.
      attribute_parameter_values {Record Set}:
          Specify additional values required by some restrictions, such as the
          weight of a vehicle for Weight Restriction. You can also use the
          attribute parameter to specify whether any restriction prohibits,
          avoids, or prefers travel on roads that use the restriction. If the
          restriction is meant to avoid or prefer roads, you can further specify
          the degree to which they are avoided or preferred using this
          parameter. For example, you can choose to never use toll roads, avoid
          them as much as possible, or even highly prefer them.The value you
          provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value. If you specify the
          Attribute Parameter Values parameter from a
          feature class, the field names on the feature class must match the
          fields as described below: AttributeName: Lists the name of the
          restriction. ParameterName: Lists the name of the parameter associated
          with the
          restriction. A restriction can have one or more ParameterName field
          values based on its intended use. ParameterValue: The value for
          ParameterName used by the tool when
          evaluating the restriction. Attribute Parameter Values is dependent on
          the Restrictions
          parameter. The ParameterValue field is applicable only if the
          restriction name is specified as the value for the Restrictions
          parameter. In Attribute Parameter Values, each restriction (listed as
          AttributeName) has a ParameterName field value, Restriction Usage,
          that specifies whether the restriction prohibits, avoids, or prefers
          travel on the roads associated with the restriction and the degree to
          which the roads are avoided or preferred. The Restriction Usage
          ParameterName can be assigned any of the following string values or
          their equivalent numeric values listed within the parentheses:

          *  PROHIBITED (-1)-Travel on the roads using the restriction is
          completely prohibited.

          *  AVOID_HIGH (5)-It is highly unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_MEDIUM (2)-It is unlikely for the tool to include in the
          route the roads that are associated with the restriction.

          *  AVOID_LOW (1.3)-It is somewhat unlikely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_LOW (0.8)-It is somewhat likely for the tool to include in
          the route the roads that are associated with the restriction.

          *  PREFER_MEDIUM (0.5)-It is likely for the tool to include in the
          route the roads that are associated with the restriction.

          *  PREFER_HIGH (0.2)-It is highly likely for the tool to include in
          the route the roads that are associated with the restriction.
           In most cases, you can use the default value, PROHIBITED, for the
          Restriction Usage if the restriction is dependent on a vehicle-
          characteristic such as vehicle height. However, in some cases, the
          value for Restriction Usage depends on your routing preferences. For
          example, the Avoid Toll Roads restriction has the default value of
          AVOID_MEDIUM for the Restriction Usage parameter. This means that when
          the restriction is used, the tool will try to route around toll roads
          when it can. AVOID_MEDIUM also indicates how important it is to avoid
          toll roads when finding the best route; it has a medium priority.
          Choosing AVOID_LOW would put lower importance on avoiding tolls;
          choosing AVOID_HIGH instead would give it a higher importance and thus
          make it more acceptable for the service to generate longer routes to
          avoid tolls. Choosing PROHIBITED would entirely disallow travel on
          toll roads, making it impossible for a route to travel on any portion
          of a toll road. Keep in mind that avoiding or prohibiting toll roads,
          and thus avoiding toll payments, is the objective for some; in
          contrast, others prefer to drive on toll roads because avoiding
          traffic is more valuable to them than the money spent on tolls. In the
          latter case, you would choose PREFER_LOW, PREFER_MEDIUM, or
          PREFER_HIGH as the value for Restriction Usage. The higher the
          preference, the farther the tool will go out of its way to travel on
          the roads associated with the restriction.
      populate_route_lines {Boolean}:
          *  Checked (True)-The output routes will have the exact shape of the
          underlying streets.

          *  Unchecked (False)-No shape is generated for the output routes, yet
          the routes will still contain tabular information about the solution.
          You won't be able to generate driving directions if route lines aren't
          created.
           When the Route Shape parameter is set to True Shape, the
          generalization of the route shape can be further controlled using the
          appropriate values for the Route Line Simplification Tolerance
          parameters. No matter which value you choose for the Route Shape
          parameter, the
          best routes are always determined by minimizing the travel along the
          streets, never using the straight-line distance. This means that only
          the route shapes are different, not the underlying streets that are
          searched when finding the route.
      route_line_simplification_tolerance {Linear Unit}:
          Specify by how much you want to simplify the geometry of the output
          lines for routes and directions.The value you provide for this
          parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.The tool also ignores
          this parameter if the populate_route_lines
          parameter is unchecked (False). Simplification maintains critical
          points on a route, such as turns at
          intersections, to define the essential shape of the route and removes
          other points. The simplification distance you specify is the maximum
          allowable offset that the simplified line can deviate from the
          original line. Simplifying a line reduces the number of vertices that
          are part of the route geometry. This improves the tool execution time.
      populate_directions {Boolean}:
          Specify whether the tool should generate driving directions for each
          route.

          *  Checked (True):  Indicates that the directions will be generated
          and configured based
          on the values for the Directions Language, Directions Style Name, and
          Directions Distance Units parameters.

          *  Unchecked (False):  Directions are not generated, and the tool
          returns an empty Directions
          layer.
      directions_language {String}:
          Specify the language that should be used when generating driving
          directions.This parameter is used only when the populate_directions
          parameter is
          checked or set to True.The parameter value can be specified using one
          of the following two-
          or five-character language codes:

          *  ar-Arabic

          * cs-Czech

          *  de-German

          *  el-Greek

          *  en-English

          *  es-Spanish

          * et-Estonian

          *  fr-French

          *  he-Hebrew

          *  it-Italian

          *  ja-Japanese

          *  ko-Korean

          *  lt-Lithuanian

          * lv-Latvian

          *  nl-Dutch

          *  pl-Polish

          *  pt-BR-Brazilian Portuguese

          *  pt-PT-European Portuguese

          *  ru-Russian

          *  sv-Swedish

          * tr-Turkish

          *  zh-CN-Simplified Chinese
           If an unsupported language code is specified, the tool returns the
          directions using the default language, English.
      directions_style_name {String}:
          Specify the name of the formatting style for the directions. This
          parameter is used only when the Populate Directions parameter is
          checked, or set to True. The parameter can be specified using the
          following values:

          *  NA Desktop:  Generates turn-by-turn directions suitable for
          printing.

          *  NA Navigation:  Generates turn-by-turn directions designed for an
          in-vehicle
          navigation device.
      travel_mode {String}:
          Specify the mode of transportation to model in the analysis. Travel
          modes are managed in ArcGIS Online and can be configured by the
          administrator of your organization to better reflect your
          organization's workflows. You need to specify the name of a travel
          mode supported by your organization.To get a list of supported travel
          mode names, use the same GIS server
          connection you used to access this tool, and from the Utilities
          toolbox, run GetTravelModes. The GetTravelModes tool adds a table,
          Supported Travel Modes, to the application. Any value in the Travel
          Mode Name field from the Supported Travel Modes table can be specified
          as input. You can also specify the value from the Travel Mode Settings
          field as input. This speeds up the tool execution because the tool
          does not have to look up the settings based on the travel mode
          name.The default value, Custom, allows you to configure your own
          travel
          mode using the custom travel mode parameters (UTurn at Junctions, Use
          Hierarchy, Restrictions, Attribute Parameter Values, and Impedance).
          The default values of the custom travel mode parameters model
          traveling by car. You may want to choose Custom and set the custom
          travel mode parameters listed above to model a pedestrian with a fast
          walking speed or a truck with a given height, weight, and cargo of
          certain hazardous materials. You may choose to do this to try out
          different settings to get the analysis results you want. Once you have
          identified the analysis settings, you should work with your
          organization's administrator and save these settings as part of a new
          or existing travel mode so that everyone in your organization can
          rerun the analysis with the same settings.By choosing Custom, the
          values you set for the custom travel mode
          parameters are included in the analysis. Specifying another travel
          mode, as defined by your organization, causes any values you set for
          the custom travel mode parameters to be ignored; the tool overrides
          them with values from your specified travel mode.
      impedance {String}:
          Specify the impedance, which is a value that represents the effort or
          cost of traveling along road segments or on other parts of the
          transportation network.Travel time is an impedance; a car taking one
          minute to travel a mile
          along an empty road is an example of impedance. Travel times can vary
          by travel mode-a pedestrian may take more than 20 minutes to walk the
          same mile-so it is important to choose the right impedance for the
          travel mode you are modeling.Choose from the following impedance
          values:

          *  Drive Time-Models travel times for a car. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Truck Time-Models travel times for a truck. These travel times are
          static for each road and don't fluctuate with traffic.

          *  Walk Time-Models travel times for a pedestrian.
          The value you provide for this parameter is ignored unless Travel Mode
          is set to Custom, which is the default value.
      time_zone_usage_for_time_fields {String}:
          Specifies the time zone for the input date-time fields supported by
          the tool. This parameter specifies the time zone for the following
          fields: TimeWindowStart1, TimeWindowEnd1, TimeWindowStart2,
          TimeWindowEnd2, InboundArriveTime, and OutboundDepartTime on orders.
          TimeWindowStart1, TimeWindowEnd1, TimeWindowStart2, and TimeWindowEnd2
          on depots. EarliestStartTime and LatestStartTime on routes.
          TimeWindowStart and TimeWindowEnd on breaks.

          * GEO_LOCAL-The date-time values associated with the orders or depots
          are in the time zone in which the orders and depots are located. For
          routes, the date-time values are based on the time zone in which the
          starting depot for the route is located. If a route does not have a
          starting depot, all orders and depots across all the routes must be in
          a single time zone. For breaks, the date-time values are based on the
          time zone of the routes. For example, if your depot is located in an
          area that follows eastern standard time and has the first time window
          values (specified as TimeWindowStart1 and TimeWindowEnd1) of 8 AM and
          5 PM, the time window values will be treated as 8:00 a.m. and 5:00
          p.m. eastern standard time.

          * UTC-The date-time values associated with the orders or depots are
          in the in coordinated universal time (UTC) and are not based on the
          time zone in which the orders or depots are located. For example, if
          your depot is located in an area that follows eastern standard time
          and has the first time window values (specified as TimeWindowStart1
          and TimeWindowEnd1) of 8 AM and 5 PM, the time window values will be
          treated as 12:00 p.m. and 9:00 p.m. eastern standard time assuming the
          eastern standard time is obeying the daylight saving time.
           Specifying the date-time values in UTC is useful if you do not know
          the time zone in which the orders or depots are located or when you
          have orders and depots in multiple time zones, and you want all the
          date-time values to start simultaneously. The UTC option is applicable
          only when your network dataset defines a time zone attribute.
          Otherwise, all the date-time values are always treated as GEO_LOCAL.
      save_output_layer {Boolean}:
          Specify if the tool should save the analysis settings as a network
          analysis layer file. You cannot directly work with this file even when
          you open the file in an ArcGIS Desktop application like ArcMap. It is
          meant to be sent to Esri Technical Support to diagnose the quality of
          results returned from the tool.

          *  Checked (True)-Save the network analysis layer file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Network Analysis Layer parameter in the entry
          corresponding to the tool execution in the Geoprocessing history of
          your Project. In ArcMap, the location of the file can be determined by
          accessing the Copy Location option in the shortcut menu on the Output
          Network Analysis Layer parameter in the entry corresponding to the
          tool execution in the Geoprocessing Results window.

          *  Unchecked (False)-Do not save the network analysis layer file. This
          is
          the default.
      overrides {String}:
          Specify additional settings that can influence the behavior of the
          solver when finding solutions for the network analysis problems. The
          value for this parameter needs to be specified in JavaScript
          Object Notation (JSON). For example, a valid value is of the following
          form {"overrideSetting1" : "value1", "overrideSetting2" : "value2"}.
          The override setting name is always enclosed in double quotes. The
          values can be a number, Boolean, or string. The default value for this
          parameter is no value, which indicates not
          to override any solver settings. Overrides are advanced settings that
          should be used only after
          careful analysis of the results obtained before and after applying the
          settings. A list of supported override settings for each solver and
          their acceptable values can be obtained by contacting Esri Technical
          Support.
      save_route_data {Boolean}:
          Choose whether the output includes a zip file that contains a file
          geodatabase holding the inputs and outputs of the analysis in a format
          that can be used to share route layers with ArcGIS Online or Portal
          for ArcGIS.

          *  Checked (True)-Save the route data as a zip file. The file is
          downloaded in a temporary directory on your machine. In ArcGIS Pro,
          the location of the downloaded file can be determined by viewing the
          value for the Output Route Data parameter in the entry corresponding
          to the tool execution in the Geoprocessing history of your Project. In
          ArcMap, the location of the file can be determined by accessing the
          Copy Location option in the shortcut menu on the Output Route Data
          parameter in the entry corresponding to the tool execution in the
          Geoprocessing Results window.

          *  Unchecked (False)-Do not save the route data. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SolveVehicleRoutingProblem_agolservices(*gp_fixargs((orders, depots, routes, breaks, time_units, distance_units, analysis_region, default_date, uturn_policy, time_window_factor, spatially_cluster_routes, route_zones, route_renewals, order_pairs, excess_transit_factor, point_barriers, line_barriers, polygon_barriers, use_hierarchy_in_analysis, restrictions, attribute_parameter_values, populate_route_lines, route_line_simplification_tolerance, populate_directions, directions_language, directions_style_name, travel_mode, impedance, time_zone_usage_for_time_fields, save_output_layer, overrides, save_route_data), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SummarizeElevation_agolservices', None)
def SummarizeElevation(InputFeatures=None, FeatureIDField=None, DEMResolution=None, IncludeSlopeAspect=None):
    """SummarizeElevation_agolservices(InputFeatures, {FeatureIDField}, {DEMResolution}, {IncludeSlopeAspect})

        Calculates summary statistics of elevation for each input feature.

     INPUTS:
      InputFeatures (Feature Set):
          Input point, line, or area features to summarize the elevation for.
      FeatureIDField {String}:
          The Unique ID field to use for the input features.
      DEMResolution {String}:
          The approximate spatial resolution (cell size) of the source
          elevation data used for the calculation. The default is 90m.  The
          resolution keyword is an approximation of the spatial resolution of
          the digital elevation model. Many elevation sources are distributed
          with units of arc seconds, the keyword is an approximation in meters
          for easier understanding.   FINEST-The finest units available for
          the extent are used.   10m-the elevation source resolution is 1/3
          arc second, or approximately 10 meters.   24m-the elevation source
          is the Airbus WorldDEM4Ortho dataset at 24 meters resolution.   30m-
          the elevation source resolution is 1 arc second, or approximately 30
          meters.   90m-the elevation source resolution is 3 arc second, or
          approximately 90 meters.
      IncludeSlopeAspect {Boolean}:
          Determines if slope and aspect for the input feature(s) will be
          included in the output.   True-Slope and aspect values will be
          included in the output.   False-Only the elevation values will be
          included in the output."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SummarizeElevation_agolservices(*gp_fixargs((InputFeatures, FeatureIDField, DEMResolution, IncludeSlopeAspect), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('TraceDownstream_agolservices', None)
def TraceDownstream(InputPoints=None, PointIDField=None, DataSourceResolution=None, Generalize=None):
    """TraceDownstream_agolservices(InputPoints, {PointIDField}, {DataSourceResolution}, {Generalize})

        Trace Downstream determines the path water will take from a
        particular location to its furthest downhill path, often this is the
        ocean.

     INPUTS:
      InputPoints (Feature Set):
          The point features used for calculating downstream trace.
      PointIDField {String}:
          The field used to identify to the input points.  It can be an
          integer or string field. The default is to use the unique ID field.
      DataSourceResolution {String}:
          Keyword indicating the source data that will be used in the
          analysis. The keyword is an approximation of the spatial resolution of
          the digital elevation model used to build the foundation hydrologic
          database. Since many elevation sources are distributed with units of
          arc seconds, we provide an approximation in meters for easier
          understanding.   Blank  - The hydrologic source was built from 3 arc
          second, approximately 90 meter resolution elevation data. This is the
          default.    FINEST- Finest resolution available at each location from
          all possible data sources.   10m - The hydrologic source was built
          from 1/3 arc-second, approximately 10 meter resolution elevation data.
          30m - The hydrologic source was built from 1 arc second, approximately
          30 meter resolution elevation data.   90m - The hydrologic source was
          built from 3 arc second, approximately 90 meter resolution elevation
          data.
      Generalize {Boolean}:
          Determines if the output downstream trace lines will be smoothed
          into simpler lines.   Fasle-The lines will not be smoothed. The
          ungeneralized stream trace is more accurate but has more vertices so
          the result is larger. This is the default.   True-The lines will be
          smoothed into simpler lines. The generalized stream trace looks best.
          It also has fewer vertices and therefore a smaller result file to
          transmit."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.TraceDownstream_agolservices(*gp_fixargs((InputPoints, PointIDField, DataSourceResolution, Generalize), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Viewshed_agolservices', None)
def Viewshed(InputPoints=None, MaximumDistance=None, MaximumDistanceUnits=None, DEMResolution=None, ObserverHeight=None, ObserverHeightUnits=None, SurfaceOffset=None, SurfaceOffsetUnits=None, GeneralizeViewshedPolygons=None):
    """Viewshed_agolservices(InputPoints, {MaximumDistance}, {MaximumDistanceUnits}, {DEMResolution}, {ObserverHeight}, {ObserverHeightUnits}, {SurfaceOffset}, {SurfaceOffsetUnits}, {GeneralizeViewshedPolygons})

        Returns polygons of visible areas for a given set of input
        observation points.

     INPUTS:
      InputPoints (Feature Set):
          The point features to use as the observer locations.
      MaximumDistance {Double}:
          The maximum distance to calculate the viewshed.
      MaximumDistanceUnits {String}:
          The units for the Maximum Distance parameter.   The default is
          meters.   Meters-The units are meters. This is the default.
          Kilometers-The units are kilometers.   Feet-The units are feet.
          Yards-The units are yards.   Miles-The units are miles.
      DEMResolution {String}:
          The approximate spatial resolution (cell size) of the source
          elevation data used for the calculation. The default is 90m.  The
          resolution keyword is an approximation of the spatial resolution of
          the digital elevation model. Many elevation sources are distributed
          with units of arc seconds, the keyword is an approximation in meters
          for easier understanding.   FINEST-The finest units available for
          the extent are used.   10m-the elevation source resolution is 1/3
          arc second, or approximately 10 meters.   24m-the elevation source
          is the Airbus WorldDEM4Ortho dataset at 24 meters resolution.   30m-
          the elevation source resolution is 1 arc second, or approximately 30
          meters.   90m-the elevation source resolution is 3 arc second, or
          approximately 90 meters.
      ObserverHeight {Double}:
          The height above the surface of the observer. The default value of
          1.75 meters is an average height of a person. If you are looking from
          an elevated location such as an observation tower or a tall building,
          use that height instead.
      ObserverHeightUnits {String}:
          The units for the Observer Height parameter.   The default is
          meters.   Meters-The units are meters. This is the default.
          Kilometers-The units are kilometers.   Feet-The units are feet.
          Yards-The units are yards.   Miles-The units are miles.
      SurfaceOffset {Double}:
          The height above the surface of the object you are trying to see.
          The default value is 0. If you are trying to see buildings or wind
          turbines use their height here.
      SurfaceOffsetUnits {String}:
          The units for the Surface Offset parameter.   The default is
          meters.   Meters-The units are meters. This is the default.
          Kilometers-The units are kilometers.   Feet-The units are feet.
          Yards-The units are yards.   Miles-The units are miles.
      GeneralizeViewshedPolygons {Boolean}:
          Determine if the viewshed polygons are to be generalized or not.
          The viewshed calculation is based upon a raster elevation model which
          creates a result with stair-stepped edges. To create a more pleasing
          appearance and improve performance, the default behavior is to
          generalize the polygons. This generalization will not change the
          accuracy of the result for any location more than one half of the
          DEM's resolution.   True-Generalizes the results. This is the
          default   False-No generalization of the output polygons will occur"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Viewshed_agolservices(*gp_fixargs((InputPoints, MaximumDistance, MaximumDistanceUnits, DEMResolution, ObserverHeight, ObserverHeightUnits, SurfaceOffset, SurfaceOffsetUnits, GeneralizeViewshedPolygons), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Watershed_agolservices', None)
def Watershed(InputPoints=None, PointIDField=None, SnapDistance=None, SnapDistanceUnits=None, DataSourceResolution=None, Generalize=None, ReturnSnappedPoints=None):
    """Watershed_agolservices(InputPoints, {PointIDField}, {SnapDistance}, {SnapDistanceUnits}, {DataSourceResolution}, {Generalize}, {ReturnSnappedPoints})

        Watershed determines the contributing area above each input point. A
        watershed is the upslope area that contributes flow.

     INPUTS:
      InputPoints (Feature Set):
          The point features used for calculating watersheds. These are
          referred to as pour points, because it is the location at which water
          pours out of the watershed.
      PointIDField {String}:
          The field used to identify to the input points.  It can be an
          integer or string field. The default is to use the unique ID field.
      SnapDistance {String}:
          The maximum distance to move the location of an input point.
          Interactive input points and documented gage locations may not exactly
          align with the stream location in the DEM. This parameter allows the
          service to move the point to a nearby location with the largest
          contributing area.  By default, the snapping distance is calculated as
          the resolution of the source data multiplied by 5.
      SnapDistanceUnits {String}:
          The linear units specified for the snap distance.  Values: <SPAN />
          Meters: The units are meters. This is the default.   Kilometers: The
          units are kilometers.   Feet: The units are feet.   Yards: The units
          are yards.   Miles: The units are miles.
      DataSourceResolution {String}:
          Keyword indicating the source data that will be used in the
          analysis. The keyword is an approximation of the spatial resolution of
          the digital elevation model used to build the foundation hydrologic
          database. Since many elevation sources are distributed with units of
          arc seconds, we provide an approximation in meters for easier
          understanding.   Blank  - - The hydrologic source was built from 3 arc
          second, approximately 90 meter resolution elevation data. This is the
          default.    FINEST- Finest resolution available at each location from
          all possible data sources.   10m - The hydrologic source was built
          from 1/3 arc-second, approximately 10 meter resolution elevation data.
          30m - The hydrologic source was built from 1 arc second, approximately
          30 meter resolution elevation data.   90m - The hydrologic source was
          built from 3 arc second, approximately 90 meter resolution elevation
          data.
      Generalize {Boolean}:
          Determines if the output watersheds will be smoothed into simpler
          shapes or conform to the cell edges of the original DEM.   False-The
          edge of the polygons will conform to the cell edges of the original
          DEM. This is the default.   True-The polygon boundaries will be
          smoothed into simpler shapes.
      ReturnSnappedPoints {Boolean}:
          Determines if a point feature at the watershed's pour point will be
          returned. If snapping is enabled, this might not be the same as the
          input point.   False-No point features will be returned.This is the
          default.   True-A point feature will be returned."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Watershed_agolservices(*gp_fixargs((InputPoints, PointIDField, SnapDistance, SnapDistanceUnits, DataSourceResolution, Generalize, ReturnSnappedPoints), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject