# -*- coding: utf-8 -*-
#COPYRIGHT 2018 ESRI
#
#TRADE SECRETS: ESRI PROPRIETARY AND CONFIDENTIAL
#Unpublished material - all rights reserved under the
#Copyright Laws of the United States.
#
#For additional information, contact:
#Environmental Systems Research Institute, Inc.
#Attn: Contracts Dept
#380 New York Street
#Redlands, California, USA 92373
#
#email: contracts@esri.com
r"""The Utility Network toolbox contains tools to create, configure, and
work with utility networks."""
__all__ = ['AddAngleDirectedLayout', 'AddCollapseContainerByAttributeRule',
           'AddCollapseContainerRule', 'AddCompressionLayout',
           'AddConnectivityAssociationsRule', 'AddDiagramTemplate',
           'AddDomainNetwork', 'AddExpandContainerByAttributeRule',
           'AddExpandContainerRule', 'AddForceDirectedLayout', 'AddGridLayout',
           'AddLinearDispatchLayout', 'AddMainRingLayout',
           'AddMainlineTreeLayout', 'AddNetworkAttribute', 'AddNetworkCategory',
           'AddPartialOverlappingEdgesLayout', 'AddRadialTreeLayout',
           'AddReduceEdgeByAttributeRule', 'AddReduceJunctionByAttributeRule',
           'AddReduceJunctionRule', 'AddRelativeMainlineLayout',
           'AddRemoveFeatureByAttributeRule', 'AddRemoveFeatureRule',
           'AddReshapeDiagramEdgesLayout', 'AddRule',
           'AddSetRootJunctionByAttributeRule',
           'AddSetStartingPointByAttributeRule', 'AddSmartTreeLayout',
           'AddSpatialDispatchLayout', 'AddSpatialQueryRule',
           'AddStartIterationRule', 'AddStopIterationRule',
           'AddStructuralAttachmentsRule', 'AddTerminalConfiguration',
           'AddTier', 'AddTierGroup', 'AddTraceLocations', 'AddTraceRule',
           'AlterDiagramProperties', 'AlterDiagramTemplate', 'AppendToDiagram',
           'ApplyAngleDirectedLayout', 'ApplyCompressionLayout',
           'ApplyForceDirectedLayout', 'ApplyGeoPositionsLayout',
           'ApplyGridLayout', 'ApplyLinearDispatchLayout',
           'ApplyMainRingLayout', 'ApplyMainlineTreeLayout',
           'ApplyPartialOverlappingEdgesLayout', 'ApplyRadialTreeLayout',
           'ApplyRelativeMainlineLayout', 'ApplyRotateTreeLayout',
           'ApplySmartTreeLayout', 'ApplySpatialDispatchLayout',
           'ApplyTemplateLayouts', 'CreateDiagram',
           'CreateDiagramLayerDefinition', 'CreateUtilityNetwork',
           'DeleteDiagram', 'DeleteDiagramTemplate', 'DeleteNetworkCategory',
           'DeleteRule', 'DeleteTerminalConfiguration',
           'DisableNetworkTopology', 'EnableNetworkTopology',
           'ExportAssociations', 'ExportDiagramContent',
           'ExportDiagramLayerDefinition', 'ExportDiagramTemplateDefinitions',
           'ExportRules', 'ExportSubnetwork', 'ExportSubnetworkControllers',
           'ExtendDiagram', 'GetDiagramTemplateNames', 'ImportAssociations',
           'ImportDiagramTemplateDefinitions', 'ImportRules',
           'ImportSubnetworkControllers', 'MakeDiagramLayer',
           'OverwriteDiagram', 'PurgeTemporaryDiagrams',
           'ReshapeDiagramEdgesLayout', 'SetAssociationRole',
           'SetEdgeConnectivity', 'SetNetworkAttribute', 'SetNetworkCategory',
           'SetSubnetworkDefinition', 'SetTerminalConfiguration',
           'StoreDiagram', 'Trace', 'UpdateDiagram', 'UpdateIsConnected',
           'UpdateSubnetwork', 'UpdateUtilityNetworkSchema',
           'ValidateNetworkTopology']
__alias__ = 'un'
from arcpy.geoprocessing._base import gptooldoc, gp, gp_fixargs
from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject

# Tools
@gptooldoc('AddTraceLocations_un', None)
def AddTraceLocations(in_utility_network=None, out_feature_class=None, load_selected_features=None, clear_trace_locations=None, trace_locations=None):
    """AddTraceLocations_un(in_utility_network, out_feature_class, {load_selected_features}, {clear_trace_locations}, {trace_locations;trace_locations...})

        Creates a feature class to be used as the starting points and barriers
        input for the Trace tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network where the trace locations will be added.
      load_selected_features {Boolean}:
          Loads selected features in the active map as trace locations.

          * LOAD_SELECTED_FEATURES-Loads trace locations based on the selection
          in the map.

          * DO_NOT_LOAD_SELECTED_FEATURES-Does not load trace locations based on
          the selection in the map, but trace locations can be loaded using the
          trace_locations parameter. This is the default.
      clear_trace_locations {Boolean}:
          Specifies whether to clear or keep trace locations in the output
          feature class.

          * CLEAR_LOCATIONS-Clears existing trace locations.

          * KEEP_LOCATIONS-Keeps existing trace locations. This is the default.
      trace_locations {Value Table}:
          The trace locations that will be added to the output feature class.
          If you are not using the load_selected_features parameter in an active
          map, you can use this parameter to specify the utility network
          features to add as trace locations by providing the required values in
          the value table.The trace locations properties are as follows:

          * Layer Name-The layer or feature class participating in the utility
          network that contains a starting point or barrier location to be
          added. If there is an active map, only layers from the map are
          allowed; if not, this will be the feature class name.

          * Global ID-The Global ID of the feature for the location to add.

          * Terminal ID-The terminal ID of the feature for the location to add.

          * Percent Along-The percent along value of the feature. For line
          features, the default value is 0.5.

     OUTPUTS:
      out_feature_class (Feature Class):
          The output feature class containing the trace locations. If you
          specify a new feature class name, a new output feature class will be
          created. If you want to use an existing feature class that was
          previously created by this tool and append or overwrite the existing
          locations, specify the name of the existing feature class."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTraceLocations_un(*gp_fixargs((in_utility_network, out_feature_class, load_selected_features, clear_trace_locations, trace_locations), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportSubnetwork_un', None)
def ExportSubnetwork(in_utility_network=None, domain_network=None, tier=None, subnetwork_name=None, export_acknowledged=None, out_json_file=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None, include_geometry=None, result_types=None, result_network_attributes=None, result_fields=None):
    """ExportSubnetwork_un(in_utility_network, domain_network, tier, subnetwork_name, export_acknowledged, out_json_file, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...}, {include_geometry}, {result_types;result_types...}, {result_network_attributes;result_network_attributes...}, {result_fields;result_fields...})

        Exports subnetworks from a utility network into a JSON file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the subnetwork to export.
      domain_network (String):
          The domain network that contains the subnetwork.
      tier (String):
          The tier that contains the subnetwork.
      subnetwork_name (String):
          The name of the subnetwork to export. Select a specific source to
          export the corresponding subnetwork information.
      export_acknowledged (Boolean):
          Specifies whether the LASTACKEXPORTSUBNETWORK attribute for the
          corresponding controller in the Subnetworks table and feature in the
          SubnetLine feature class is updated.

          * ACKNOWLEDGE-Updates the LASTACKEXPORTSUBNETWORK attribute for the
          corresponding controller in the Subnetworks table. If the source has
          been marked for deletion (Is deleted = True), choosing this option
          will delete it from the Subnetworks table.

          * NO_ACKNOWLEDGE-Does not update the LASTACKEXPORTSUBNETWORK attribute
          for the corresponding controller in the Subnetworks table. This is the
          default.
      condition_barriers {Value Table}:
          Sets a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and a type,
          and an attribute value. For example, stop a trace when a feature has
          the attribute Device Status equal to the specific value of Open. When
          a feature meets this condition, the trace stops. If you're using more
          than one attribute, you can use the Combine using parameter to define
          an And or an Or condition.Condition barrier components are as follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Set a specific value of the input attribute type that would
          cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can combine them using an And or an Or condition.
          The condition barrier operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The condition barrier type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
          This parameter is only available via Python.
      function_barriers {Value Table}:
          Sets a traversability barrier on features based on a function.
          Function barriers can be used to do such things as restrict how far
          the trace travels from the starting point, or set a maximum value to
          stop a trace. For example, the length of each line traveled is added
          to the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Set a specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculate values in each direction as opposed to an
          overall global value. For example, use for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values. Subnetwork controllers and loops trace
          types do not support the subtract function.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you use the minimum function, the
          result is 20. Maximum is 30, add is 50, average is 25, count is 2, and
          subtract is -10.The function barrier operator value options are as
          follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      include_barriers {Boolean}:
          Specifies whether the traversability barrier features are included in
          the trace results. Traversability barriers are optional even if they
          have been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are not included in the
          trace results.
          This parameter is only available via Python.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if
          DEVICESTATUS is set to Open and the traversability scope is set to
          edges only, the trace would not stop even if the trace encounters an
          open device, because DEVICESTATUS is only applicable for junctions. In
          other words, this parameter indicates to the trace whether or not to
          ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
          This parameter is only available via Python.
      propagators {Value Table}:
          Specifies the network attributes to propagate as well as how that
          propagation should occur during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you can propagate the phase
          value.Propagators components are as follows:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated. A
          substitution is a mapping of each bit in phase to another bit. For
          example, for Phase AC, one substitution could map bit A to B, and bit
          C to null. In this example, the substitution for 1010 (Phase AC) is
          0000-0010-0000-0000 (512). The substitution captures the mapping so
          you know that Phase A was mapped to B, and Phase C was mapped to null
          and not the other way around (that is, Phase A was not mapped to null
          and Phase C was not mapped to B).

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES NOT INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INLCUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      include_geometry {Boolean}:
          Choose to include the geometry in the results.

          * INCLUDE_GEOMETRY-Include the geometry in the results.

          * EXCLUDE_GEOMETRY-Do not include the geometry in the results. This is
          the default.
      result_types {String}:
          Choose the type of results to export.

          * CONNECTIVITY-Return features that are connected via spatial co-
          incidence or connectivity associations. This is the default.

          * FEATURES-Return feature level information in the response.
      result_network_attributes {String}:
          Specify the network attributes that will be included in the results.
      result_fields {Value Table}:
          Specify a feature class and then a field from that feature class. The
          values of the field specified will be returned in the results for the
          features in the subnetwork.

     OUTPUTS:
      out_json_file (File):
          The name and location of the JSON file to be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportSubnetwork_un(*gp_fixargs((in_utility_network, domain_network, tier, subnetwork_name, export_acknowledged, out_json_file, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators, include_geometry, result_types, result_network_attributes, result_fields), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('Trace_un', None)
def Trace(in_utility_network=None, trace_type=None, starting_points=None, barriers=None, domain_network=None, tier=None, target_tier=None, subnetwork_name=None, shortest_path_network_attribute_name=None, include_containers=None, include_content=None, include_structures=None, include_barriers=None, validate_consistency=None, condition_barriers=None, function_barriers=None, traversability_scope=None, filter_barriers=None, filter_function_barriers=None, filter_scope=None, filter_bitset_network_attribute_name=None, filter_nearest=None, nearest_count=None, nearest_cost_network_attribute=None, nearest_categories=None, nearest_assets=None, functions=None, propagators=None, output_assettypes=None, output_conditions=None, include_isolated_features=None):
    """Trace_un(in_utility_network, trace_type, {starting_points}, {barriers}, {domain_network}, {tier}, {target_tier}, {subnetwork_name}, {shortest_path_network_attribute_name}, {include_containers}, {include_content}, {include_structures}, {include_barriers}, {validate_consistency}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {traversability_scope}, {filter_barriers;filter_barriers...}, {filter_function_barriers;filter_function_barriers...}, {filter_scope}, {filter_bitset_network_attribute_name}, {filter_nearest}, {nearest_count}, {nearest_cost_network_attribute}, {nearest_categories;nearest_categories...}, {nearest_assets;nearest_assets...}, {functions;functions...}, {propagators;propagators...}, {output_assettypes;output_assettypes...}, {output_conditions;output_conditions...}, {include_isolated_features})

        Returns selected features based on connectivity or traversability from
        the specified starting points. Utility network tracing capabilities
        allow you to analyze the paths
        in your network. This tool runs a trace that returns features based on
        connectivity or traversability from the specified starting points.
        Traversability refers to paths established by connected or associated
        features that also meet configuration requirements. Results from a
        trace operation are returned as a selection set of the
        appropriate network features. The resulting selection set of a trace
        can then be propagated to another map, propagated to a diagram view of
        the network, or used as input to another tool or trace.Learn more
        about tracing utility networks

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to run the trace against. The input utility
          network must be from a feature service environment. A utility network
          from an enterprise geodatabase connection file is not supported.
      trace_type (String):
          The type of trace to execute.

          * CONNECTED-A connected trace begins at one or more starting points
          and spans outward along connected features. This is the default.

          * SUBNETWORK-A subnetwork trace begins at one or more starting points
          and spans outward to encompass the extent of the subnetwork.

          * SUBNETWORK_CONTROLLERS-A subnetwork controllers trace locates
          sources and sinks on subnetwork controllers associated with a
          subnetwork.

          * UPSTREAM-An upstream trace discovers features upstream from a
          location in the network.

          * DOWNSTREAM-A downstream trace discovers features downstream from a
          location in the network.

          * LOOPS-Loops are areas of the network where flow direction is
          ambiguous. A loops trace spans outward from the starting point based
          on connectivity.

          * SHORTEST_PATH-A shortest path trace identifies the shortest path
          between two starting points.

          * ISOLATION-An isolation trace discovers features that isolate an area
          of a network.
      starting_points {Feature Layer}:
          A point feature class containing one or more features that represent
          the starting points of the trace. This feature class must have a
          specific format, including fields that store the asset group, asset
          type, terminal id, and percent along edge of the starting point. To
          view the specific format, create starting points using the Starting
          Points tool on the Trace Locations pane and view the schema of the
          UN_Temp_Starting_Points feature class stored in your default
          geodatabase.
      barriers {Feature Layer}:
          A feature class containing one or more features that represent the
          barriers of the trace that prevents the trace from traversing beyond
          that point. This feature class must have a specific format, including
          fields that store the asset group, asset type, and terminal id. To
          view the specific format, create starting points using the Barriers
          tool on the Trace Locations pane and view the schema of the
          UN_Temp_Barriers feature class stored in your default geodatabase.
      domain_network {String}:
          The name of the domain network where the trace will be run. This
          parameter is required when running the subnetwork, subnetwork
          controllers, upstream, and downstream trace types.
      tier {String}:
          The name of the tier to start the trace. This parameter is required
          when running the subnetwork, subnetwork controllers, upstream, and
          downstream trace types.
      target_tier {String}:
          The name of the target tier to which the input tier flows.  If this
          parameter is missing for upstream and downstream traces, those traces
          will stop when they reach the boundary of the starting subnetwork.
          This parameter can be used to allow these traces to continue either
          farther up or farther down the hierarchy.
      subnetwork_name {String}:
          The name of the subnetwork where the trace will be run. This
          parameter can be used when running a subnetwork trace type. If a
          subnetwork name is specified, the starting_points parameter is not
          required.
      shortest_path_network_attribute_name {String}:
          The network attribute used to calculate the shortest path. When
          running a shortest path trace type, the shortest path is calculated
          using a numeric network attribute such as Shape length. Cost and
          distance based paths can both be achieved. This parameter is required
          when running a shortest path trace.
      include_containers {Boolean}:
          Defines whether the container features are included in the trace
          results.

          * INCLUDE_CONTAINERS-Container features are included in the trace
          results.

          * EXCLUDE_CONTAINERS-Container features are not included in the trace
          results. This is the default.
      include_content {Boolean}:
          Defines whether the trace returns content in containers in the
          results.

          * INCLUDE_CONTENT-Content in container features are included in the
          trace results.

          * EXCLUDE_CONTENT-Content in container features are not included in
          the trace results. This is the default.
      include_structures {Boolean}:
          Defines whether structure features are included in the trace results.

          * INCLUDE_STRUCTURES-Structure features are included in the trace
          results.

          * EXCLUDE_STRUCTURES-Structure features are not included in the trace
          results. This is the default.
      include_barriers {Boolean}:
          Defines whether the traversability barrier features are included in
          the trace results. Traversability barriers are optional even if they
          have been preset in the subnetwork definition. This parameter does not
          apply to device features with terminals.

          * INCLUDE_BARRIERS-Traversability barrier features are included in the
          trace results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barrier features are not included in
          the trace results.
      validate_consistency {Boolean}:
          If dirty areas are encountered for any of the traversed features,
          setting the trace to validate consistency will return a warning. This
          is the only way to guarantee a trace is passing through features with
          consistent status in the network. To remove dirty areas, the network
          topology should be validated.

          * VALIDATE_CONSISTENCY-A warning will be returned if dirty areas are
          encountered for any of the traversed features.

          * DO_NOT_VALIDATE_CONSISTENCY-No warning will be returned if dirty
          areas are encountered for any of the traversed features. This is the
          default.
      condition_barriers {Value Table}:
          Sets a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and a type,
          and an attribute value. For example, stop a trace when a feature has
          the attribute Device Status equal to the specific value of Open. When
          a feature meets this condition, the trace stops. If you're using more
          than one attribute, you can use the Combine using parameter to define
          an And or an Or condition.Condition barrier components are as follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The condition barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The condition barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The condition barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      function_barriers {Value Table}:
          Sets a traversability barrier on features based on a function.
          Function barriers can be used to do such things as restrict how far
          the trace travels from the starting point, or set a maximum value to
          stop a trace. For example, the length of each line traveled is added
          to the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, and the trace
          continues.
          The function barrier function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The function barrier Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device, the trace would not
          stop because Device Status is only applicable to junctions. In other
          words, this parameter indicates to the trace whether to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      filter_barriers {Value Table}:
          Specifies when a trace should stop for a specific category or network
          attribute. For example, stop a trace at features that have a life
          cycle status attribute that is equal to a certain value. This
          parameter is used to set a terminator based on a value of a network
          attribute that is defined in the system. If using more than one
          attribute, you can use the Combine Using option to define an And or an
          Or condition.Filter barrier components are as follows:

          * Name-Choose to filter by category or any network attribute defined
          in the system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value of the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The filter barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES NOT INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INLCUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The filter barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      filter_function_barriers {Value Table}:
          Filters the results of the trace for a specific category.Filter
          function barriers components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, or the trace
          continues.
          The filter function barriers function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The filter function barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter function barriers Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      filter_scope {String}:
          Determines whether the filter for a specific category is enforced at
          junctions, edges, or both. For example, if a filter barrier is defined
          to stop the trace if Device Status is equal to Open and traversability
          scope is set to edges only, then even if the trace encounters an open
          device, the trace will not stop because Device Status is only
          applicable to junctions. In other words, this parameter indicates to
          the trace whether to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply filter to both junctions and edges.
          This is the default.

          * JUNCTIONS_ONLY-Apply filter to only junctions.

          * EDGES_ONLY-Apply filter to only edges.
      filter_bitset_network_attribute_name {String}:
          The name of the network attribute that can be used to filter by
          bitset. This parameter is only applicable to upstream, downstream, and
          loops trace types. This parameter can be used to add special logic
          during a trace so the trace is more reflective of real world
          scenarios. For example, for a loops trace, the Phases current network
          attribute can determine if the loop is a true electrical loop (the
          same phase is energized all around the loop, that is, A) and return
          only real electrical loops for the trace results. An example for an
          upstream trace is when tracing an electric distribution network,
          specify a Phases current network attribute, and the trace results will
          only include valid paths that are the specified in the network
          attribute, not all paths.
      filter_nearest {Boolean}:
          Returns a number of features of a certain type within a given
          distance by using the k-nearest neighbors algorithm. When this
          parameter is used, you can specify a count and a cost as well as a
          collection of categories, an asset type, or both.

          * FILTER_BY_NEAREST-Use k-nearest neighbors to return a number of
          features as specified in the nearest_count,
          nearest_cost_network_attribute, nearest_categories, or nearest_assets
          parameter.

          * DO_NOT_FILTER-Do not filter results using k-nearest neighbors. This
          is the default.
      nearest_count {Long}:
          When filter_nearest is True,you can use this parameter to specify the
          number of features to be returned, for example, 4.
      nearest_cost_network_attribute {String}:
          When filter_nearest is True, you can use this parameter to specify the
          numeric network attribute that will be used to calculate nearness,
          cost, or distance-for example,  Shape length.
      nearest_categories {String}:
          When filter_nearest is True, you can use this parameter to specify the
          categories that will be returned-for example, Protective.
      nearest_assets {String}:
          When filter_nearest is True, you can use this parameter to specify the
          asset groups and asset types that will be returned-for example,
          ElectricDistributionDevice/Transformer/Step Down.
      functions {Value Table}:
          Applies a calculation function to the trace results.Functions
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Filter Name-Choose to filter the function results by attribute name.

          * Filter Operator-Choose from a number of different operators.

          * Filter Type-Choose from a number of different filter types.

          * Filter Value-Provide a specific value for the input filter
          attribute.
          The functions Function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values.Subnetwork controllers
          and loops trace types do not support the subtract function.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you are using the MIN function, the
          result is 20. MAX is 30, ADD is 50, AVERAGE is 25, COUNT is 2, and
          SUBTRACT is -10.The Filter Operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The functions Filter Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
      propagators {Value Table}:
          Specifies the network attributes to propagate as well as how that
          propagation should occur during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you can propagate the phase
          value.Propagators components are as follows:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated. A
          substitution is a mapping of each bit in phase to another bit. For
          example, for Phase AC, one substitution could map bit A to B, and bit
          C to null. In this example, the substitution for 1010 (Phase AC) is
          0000-0010-0000-0000 (512). The substitution captures the mapping so
          you know that Phase A was mapped to B, and Phase C was mapped to null
          and not the other way around (that is, Phase A was not mapped to null
          and Phase C was not mapped to B).

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.
          The propagators function value options are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagators operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      output_assettypes {String}:
          Filter the output asset types to be included in the results-for
          example, only return overhead transformers.
      output_conditions {Value Table}:
          Controls the types of features returned based on a network attribute
          or category. For example, in a trace configured to filter out
          everything but Tap features, any traced features that do not have the
          Tap category assigned to them, are not included in the results. Any
          traced features that do are returned in the result selection set. If
          using more than one attribute, you can use the Combine Using option to
          define an And or an Or condition.Output conditions components are as
          follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value of the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The output conditionsoperator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The output conditions Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The output conditions Combine Using value options are as follows:

          * AND-Combine the conditions.

          * OR-Use if either condition is met.
      include_isolated_features {Boolean}:
          Defines whether the isolated features are included in the trace
          results. This parameter is only used when running an isolation trace.

          * INCLUDE_ISOLATED_FEATURES-Isolated features are included in the
          trace results.

          * EXCLUDE_ISOLATED_FEATURES-Isolated features are not included in the
          trace results. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.Trace_un(*gp_fixargs((in_utility_network, trace_type, starting_points, barriers, domain_network, tier, target_tier, subnetwork_name, shortest_path_network_attribute_name, include_containers, include_content, include_structures, include_barriers, validate_consistency, condition_barriers, function_barriers, traversability_scope, filter_barriers, filter_function_barriers, filter_scope, filter_bitset_network_attribute_name, filter_nearest, nearest_count, nearest_cost_network_attribute, nearest_categories, nearest_assets, functions, propagators, output_assettypes, output_conditions, include_isolated_features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateIsConnected_un', None)
def UpdateIsConnected(in_utility_network=None):
    """UpdateIsConnected_un(in_utility_network)

        Updates the IsConnected attribute on all the network features for the
        specified utility network based on connectivity. Every line and point
        feature participating in the line, device, and junction feature class
        of a utility network has an Is Connected attribute. This attribute
        helps identify isolated features by maintaining whether a feature has
        connectivity to a subnetwork controller.To learn more about this
        field, see Is connected attribute.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network where the IsConnected attribute will be updated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateIsConnected_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateSubnetwork_un', None)
def UpdateSubnetwork(in_utility_network=None, domain_network=None, tier=None, all_subnetworks_in_tier=None, subnetwork_name=None, continue_on_failure=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None):
    """UpdateSubnetwork_un(in_utility_network, domain_network, tier, all_subnetworks_in_tier, {subnetwork_name}, {continue_on_failure}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...})

        Updates the SUBNETWORKNAME attribute on network features and creates
        and updates the SubnetLine feature class and subnetwork system
        diagrams for the specified subnetworks. A record for any new
        subnetworks will be generated, the record for any deleted subnetworks
        will be removed, and the shape and information for any modified
        subnetworks will be updated.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the subnetwork.
      domain_network (String):
          The domain network that contains the subnetwork.
      tier (String):
          The tier that contains the subnetwork.
      all_subnetworks_in_tier (Boolean):
          Specifies whether all subnetworks in the tier are updated. To update
          a subset of subnetworks in the tier, use the subnetwork_name
          parameter.

          * ALL_SUBNETWORKS_IN_TIER-Updates all subnetworks in the tier. This
          option uses asynchronous processing to update the subnetworks using
          the system UtilityNetworkTools geoprocessing service. The service is
          reserved for utility network geoprocessing tasks and has a longer
          default timeout setting. This is the default.

          * SPECIFIC_SUBNETWORK-Updates only the subnetworks specified in the
          subnetwork_name parameter.
      subnetwork_name {String}:
          The name of the subnetworks to update. If all subnetworks will be
          updated using the all_subnetworks_in_tier parameter, this parameter is
          ignored.
      continue_on_failure {Boolean}:
          Specifies whether to stop the update process if a subnetwork fails to
          update when updating multiple subnetworks.

          * CONTINUE_ON_FAILURE-Continues to update subnetworks upon failure.

          * STOP_ON_FAILURE-Stops updating subnetworks if a failure occurs. This
          is the default.
      condition_barriers {Value Table}:
          Sets a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and a type,
          and an attribute value. For example, stop a trace when a feature has
          the attribute Device Status equal to the specific value of Open. When
          a feature meets this condition, the trace stops. If you're using more
          than one attribute, you can use the Combine using parameter to define
          an And or an Or condition.Condition barrier components are as follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Set a specific value of the input attribute type that would
          cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can combine them using an And or an Or condition.
          The condition barrier Operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The condition barrier type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
          This parameter is only available via Python.
      function_barriers {Value Table}:
          Sets a traversability barrier on features based on a function.
          Function barriers can be used to do such things as restrict how far
          the trace travels from the starting point, or set a maximum value to
          stop a trace. For example, the length of each line traveled is added
          to the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Set a specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculate values in each direction as opposed to an
          overall global value, for example, for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values. Subnetwork controllers and loops trace
          types do not support the subtract function.
          For example, there is a starting point feature with a value of 20. The
          next feature has a value of 30. If you use the minimum function, the
          result is 20. Maximum is 30, add is 50, average is 25, count is 2, and
          subtract is -10.The function barrier operator value options are as
          follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      include_barriers {Boolean}:
          Specifies whether the traversability barrier features are included in
          the trace results. Traversability barriers are optional even if they
          have been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are not included in the
          trace results.
          This parameter is only available via Python and ModelBuilder.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if
          DEVICESTATUS is equal to Open and traversability scope is set to edges
          only, the trace would not stop even if the trace encounters an open
          device, because the DEVICESTATUS is only applicable for junctions. In
          other words, this parameter indicates to the trace whether or not to
          ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
          This parameter is only available via Python and ModelBuilder.
      propagators {Value Table}:
          Specifies the network attributes to propagate as well as how that
          propagation should occur during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you can propagate the phase
          value.Propagators components are as follows:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated. A
          substitution is a mapping of each bit in phase to another bit. For
          example, for Phase AC, one substitution could map bit A to B, and bit
          C to null. In this example, the substitution for 1010 (Phase AC) is
          0000-0010-0000-0000 (512). The substitution captures the mapping so
          you know that Phase A was mapped to B, and Phase C was mapped to null
          and not the other way around (that is, Phase A was not mapped to null
          and Phase C was not mapped to B).

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python and ModelBuilder."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateSubnetwork_un(*gp_fixargs((in_utility_network, domain_network, tier, all_subnetworks_in_tier, subnetwork_name, continue_on_failure, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ValidateNetworkTopology_un', None)
def ValidateNetworkTopology(in_utility_network=None, extent=None):
    """ValidateNetworkTopology_un(in_utility_network, {extent})

        Validates the network topology of a utility network after there have
        been spatial edits to features in the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the network topology will be validated.
      extent {Extent}:
          The geographical area for which to validate the network topology. This
          parameter is similar to the extent geoprocessing environment.

          * Extent object-An Extent object can be used to define the extent.

          * MINOF-The extent where all input features or rasters overlap
          (intersect one another).It is possible that none of the features
          overlap and that a null extent (zero width and height) may result. In
          such cases, no features or cells will be processed.

          * MINOF-The combined extent of all input data. All features or cells
          will be processed.

          * Xmin, Ymin, XMax, YMax-Space-delimited coordinates that define the
          extent in the coordinate system where the input data is stored, for
          example, "-107.0 38.0 -104.0 40.0".

          * pathname-Path to a dataset. The extent of the dataset will be used."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ValidateNetworkTopology_un(*gp_fixargs((in_utility_network, extent), True)))
        return retval
    except Exception as e:
        raise e


# Administration toolset
@gptooldoc('AddDomainNetwork_un', None)
def AddDomainNetwork(in_utility_network=None, domain_network_name=None, tier_definition=None, subnetwork_controller_type=None, domain_network_alias_name=None):
    """AddDomainNetwork_un(in_utility_network, domain_network_name, tier_definition, subnetwork_controller_type, {domain_network_alias_name})

        Adds a domain network to a utility network.To learn more about adding
        a domain network, see Add a domain network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to which the domain network will be added.
      domain_network_name (String):
          The name of the new domain network. The domain network name will
          prefix the feature class names that are created. For example, a domain
          named ElectricDistribution would include a feature class named
          ElectricDistributionJunction.
      tier_definition (String):
          The tier definition for the new domain network.

          * HIERARCHICAL-A hierarchical tier definition. In hierarchical domain
          networks, tiers are nested within one another, so features existing in
          subnetworks for a lower tier naturally participate in all higher
          tiers. For example, in a gas network, a valve isolation zone is within
          a pressure zone, which in turn exists within a system zone. A feature
          in the isolation zone also exists in the pressure zone and in the
          system zone.

          * PARTITIONED-A partitioned tier definition. Features in partitioned
          domain networks only exist in one tier. The relationship between tiers
          is ordered and linear. Features can exist in one or multiple
          subnetworks within one tier.
      subnetwork_controller_type (String):
          The subnetwork controller type for the new domain network.

          * SOURCE-The subnetwork controller type is a set of sources. A source
          is an origin of the resource delivered. For example, for an electric
          system, sources of electricity are power generating stations and
          substations.

          * SINK-The subnetwork controller type is a set of sinks. A sink is the
          destination of the gathered resource.
      domain_network_alias_name {String}:
          The alias name of the domain network. This optional parameter is used
          to give a more descriptive name to the domain network."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDomainNetwork_un(*gp_fixargs((in_utility_network, domain_network_name, tier_definition, subnetwork_controller_type, domain_network_alias_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddNetworkAttribute_un', None)
def AddNetworkAttribute(in_utility_network=None, attribute_name=None, attribute_type=None, is_inline=None, is_apportionable=None, domain=None, is_overridable=None, is_nullable=None, is_substitution=None, network_attribute_to_substitute=None):
    """AddNetworkAttribute_un(in_utility_network, attribute_name, attribute_type, {is_inline}, {is_apportionable}, {domain}, {is_overridable}, {is_nullable}, {is_substitution}, {network_attribute_to_substitute})

        Adds a network attribute to a utility network.  A network attribute is
        a value derived from attributes on
        corresponding features in the network and is stored in the network
        topology. While a network attribute can be associated with only one
        attribute on a feature class, there is no limit to the number of
        network attributes a single utility network can have. Network
        attributes are used as weights to control traversability and to model
        the cost of paths in the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network where the network attribute will be added.
      attribute_name (String):
          The name of the network attribute to add to the utility network.
      attribute_type (String):
          The data type of the network attribute.

          * SHORT-Short integer type

          * LONG-Long integer type

          * DOUBLE-Double precision type

          * DATE-Date type
      is_inline {Boolean}:
          Specifies whether the network attribute will be persisted in line. In-
          line network attributes are slightly more efficient, but the number of
          bits for in-line attributes is limited to 28 per utility network. The
          most frequently used network attributes (for example, phase for
          electric networks, pressure for gas and water networks) should be
          stored in line if possible. The size of the bits is determined by the
          domain parameter. In-line attributes are only supported for integer
          network attributes.

          * INLINE-The attribute will be added internally to the topology,
          making retrieval more efficient.

          * NOT_INLINE-The attribute will be stored in an external table, and
          retrieval will require a call to the external weights table. This is
          the default.
      is_apportionable {Boolean}:
          Specifies whether the network attribute will be apportioned across
          multiple edges belonging to the same feature.For example, with the
          shape_length network attribute, if one line
          feature consists of five edge elements, and if the total length of
          that line feature is 100 feet, that attribute will be apportioned
          across all edges, giving 20 feet for each. The distribution of the
          value depends on the percentage along each edge element with respect
          to the from point of the original feature. Apportionable network
          attributes can only be assigned to fields on line feature classes.

          * APPORTIONABLE-The network attribute is apportionable.

          * NOT_APPORTIONABLE-The network attribute is not apportionable. This
          is the default.
      domain {String}:
          The domain with which the network attribute is to be associated. This
          parameter is required when is_inline is True. This domain is used to
          determine how many bits to allocate for the in-line attribute and must
          be a coded value type. For example, the LifeCycleStatusDomain (0,
          Unknown | 1, In-Service | 2, Proposed | 3, Abandoned) domain has four
          entries, which means 2 bits are required to store the in-line
          attribute. The coded value domain must have sequential codes starting
          from 0.
      is_overridable {Boolean}:
          This parameter is not used, and any entered value will be ignored in
          the current release. The functionality of this parameter is still
          under development and will be applicable in a future
          release.Determines whether a network attribute has an external
          override table that the network topology reads and overrides (or
          overwrites) the current value stored in the topology. This can be used
          to input live data from external systems, such as present position in
          the case of electric or pressure value in the case of gas. An example
          is a SCADA system pushing the updated switching positions of Device A
          to the override table of the DeviceStatus network attribute, which the
          topology engine then uses to override its current value of device
          status for Device A with the override value.

          * OVERRIDE-Overrides the current value stored in the topology.

          * NOT_OVERRIDABLE-Does not override the current value stored in the
          topology. This is the default.
      is_nullable {Boolean}:
          Specifies whether the network attribute supports null values.

          * NULLABLE-The network attribute supports null values.

          * NOT_NULLABLE-The network attribute does not support null values.
          This is the default.
      is_substitution {Boolean}:
          Specifies whether the network attribute is to be used as a
          substitution. Substitution network attributes allow a substituted
          value to be used instead of bitset network attribute values during a
          propagation in a trace operation.

          * SUBSTITUTION-The network attribute is a substitution.

          * NOT_SUBSTITUTION-The network attribute is not a substitution. This
          is the default.
      network_attribute_to_substitute {String}:
          The network attribute to use for substitution. Substitutions are
          encoded based on the number of bits in the network attribute being
          propagated. The network attribute must be in-line and an integer field
          type less than or equal to 8 bits."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddNetworkAttribute_un(*gp_fixargs((in_utility_network, attribute_name, attribute_type, is_inline, is_apportionable, domain, is_overridable, is_nullable, is_substitution, network_attribute_to_substitute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddNetworkCategory_un', None)
def AddNetworkCategory(in_utility_network=None, category_name=None):
    """AddNetworkCategory_un(in_utility_network, category_name)

        Adds a network category to an existing utility network. Categories are
        used to control analysis at the asset group and asset
        type levels; for example, you can define whether a particular asset
        group or asset type is a protective device. You can also define a
        category type to control how trace analysis is executed; for example,
        you can specify that a network trace ends at a user-defined category
        type of ProtectiveDevice. This tool allows you to add a new network
        category to a utility
        network that can be later assigned to a feature class at the asset
        group or asset type level using the Set Network Category tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network where the network category will be added.
      category_name (String):
          The name of the category to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddNetworkCategory_un(*gp_fixargs((in_utility_network, category_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRule_un', None)
def AddRule(in_utility_network=None, rule_type=None, from_class=None, from_assetgroup=None, from_assettype=None, to_class=None, to_assetgroup=None, to_assettype=None, from_terminal=None, to_terminal=None, via_class=None, via_assetgroup=None, via_assettype=None, via_terminal=None):
    """AddRule_un(in_utility_network, rule_type, from_class, from_assetgroup, from_assettype, to_class, to_assetgroup, to_assettype, {from_terminal}, {to_terminal}, {via_class}, {via_assetgroup}, {via_assettype}, {via_terminal})

        Adds a rule to a utility network. All rules created within a utility
        network are based on the feature
        class at the asset group and asset type levels and can be used to
        control some behaviors in the utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the rule will be added.
      rule_type (String):
          The type of rule to be created.

          * JUNCTION_JUNCTION_CONNECTIVITY-Creates a junction-junction
          connectivity association rule allowing two points to connect via a
          connectivity association (features are offset geometrically).

          * CONTAINMENT-Creates a containment association rule where the from
          parameters are the container and the to parameters are the contents.

          * STRUCTURAL_ATTACHMENT-Creates a structural attachment association
          rule where the from parameters are the structure and the to parameters
          are the structural attachments.

          * JUNCTION_EDGE_CONNECTIVITY-Creates an edge-junction connectivity
          rule allowing a line and a junction to connect via geometric
          coincidence (features are at the same x, y, z location).

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Creates an edge-junction-edge
          connectivity rule allowing a certain type of line to connect to either
          side of a junction feature.
      from_class (String):
          The from utility network feature class that will be included in the
          rule.Structural attachment and containment association rules require
          the
          container or structure feature be in this parameter.Ordering is
          irrelevant for the junction-junction, junction-edge, and
          edge-junction-edge connectivity rules.
      from_assetgroup (String):
          An asset group for the from_class to which the rule will apply.
      from_assettype (String):
          An asset type for the from_class to which the rule will apply.
      to_class (String):
          The to utility network feature class that will be included in the
          rule.Structural attachment and containment associations rules require
          the
          content or attachment feature be in this parameter.Ordering is
          irrelevant for the junction-junction, junction-edge, and
          edge-junction-edge connectivity rules.
      to_assetgroup (String):
          An asset group for the to_class to which the rule will apply.
      to_assettype (String):
          Specifies an asset type for the to_class to which the rule will apply.
      from_terminal {String}:
          The from terminal to which the rule will apply. This will be a
          terminal in the from_class. When creating a connectivity rule for a
          line or point to connect to a feature with terminals, the terminal
          side to connect to must be specified, for example, the high-side
          terminal on a transformer.This parameter will be ignored for
          structural attachment or
          containment attachment rule types.
      to_terminal {String}:
          The to terminal to which the rule will apply. This will be a terminal
          of the to_class. When creating either type of connectivity rule for a
          line or point to connect to a feature with terminals, the terminal
          side to connect to must be specified, for example, the high-side
          terminal on a transformer.This parameter will be ignored for
          structural attachment or
          containment attachment rule types.
      via_class {String}:
          The junction utility network feature class to which the rule will
          apply. This parameter can be specified only for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type, since three feature classes
          are required to participate in edge-junction-edge connectivity.
      via_assetgroup {String}:
          An  asset group of the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value.
      via_assettype {String}:
          An asset type of the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value.
      via_terminal {String}:
          The terminal from the via_class to which the rule will apply. This
          parameter can only be specified for the
          EDGE_JUNCTION_EDGE_CONNECTIVITY rule_type parameter value."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRule_un(*gp_fixargs((in_utility_network, rule_type, from_class, from_assetgroup, from_assettype, to_class, to_assetgroup, to_assettype, from_terminal, to_terminal, via_class, via_assetgroup, via_assettype, via_terminal), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTerminalConfiguration_un', None)
def AddTerminalConfiguration(in_utility_network=None, terminal_configuration_name=None, traversability_model=None, terminals_directional=None, terminals_bidirectional=None, valid_paths=None, default_path=None):
    """AddTerminalConfiguration_un(in_utility_network, terminal_configuration_name, traversability_model, {terminals_directional;terminals_directional...}, {terminals_bidirectional;terminals_bidirectional...}, {valid_paths;valid_paths...}, {default_path})

        Adds a terminal configuration to an existing utility network. Specific
        devices with terminals require constraints that define the
        valid configuration of the internal connectivity of the device. This
        tool allows you to add a new terminal configuration to a utility
        network that can be later assigned to a feature class at the asset
        group or asset type level using the Set Terminal Configuration tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network to add the terminal configuration to.
      terminal_configuration_name (String):
          The name for the terminal configuration.
      traversability_model (String):
          Choose the directionality of the terminal configuration. A
          directional traversability model means that the flow for the terminal
          will only go in one direction. A bidirectional traversability model
          means that the terminal allows flow in both directions.

          * DIRECTIONAL-Only one flow direction is permissible.

          * BIDIRECTIONAL-Both flow directions are permissible.
      terminals_directional {Value Table}:
          If the traversability model is directional, provide the name of each
          terminal and specify whether the terminal is upstream or not. The
          minimum number of terminals required is 2. This parameter is required
          if you choose a directional traversability model.

          * Name-The name of the terminal.

          * Upstream-Whether the terminal is upstream or downstream. Use the
          keyword True if the terminal is upstream, or False if the terminal is
          downstream.
      terminals_bidirectional {Value Table}:
          If the traversability model is bidirectional, provide the names of
          each bidirectional terminal. A minimum of two terminals is required.
      valid_paths {Value Table}:
          Specify the valid paths for the terminal configuration. For
          bidirectional traversability, this parameter is required if you have
          three or more terminals. If you are using directional traversability,
          one of the terminals must be upstream in order to have any valid
          configurations. Valid paths must be set in order to indicate which of
          the paths within a device are valid for a resource to travel through.
          Provide a name for each valid path and specify a value.

          * Name-The name of the valid path.

          * Value-The value of the path.

          * All-Indicates all paths are valid.

          * None-Indicates no paths are valid.

          * Terminal pair-Indicates a single path from one terminal to another,
          for example, A-B.

          * Collection of terminal pairs-Indicates a collection of single paths
          from one terminal to another, for example, A-B,A-C.
      default_path {String}:
          Of the valid configurations specified, you may set the default path.
          This will be assigned to new features that have this terminal
          configuration assigned to their asset type. If you have not specified
          one of the valid configurations, the default configuration will be
          All.

          * ALL-Indicates all paths are valid. This is the default.

          * NONE-Indicates no paths are valid."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTerminalConfiguration_un(*gp_fixargs((in_utility_network, terminal_configuration_name, traversability_model, terminals_directional, terminals_bidirectional, valid_paths, default_path), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTier_un', None)
def AddTier(in_utility_network=None, domain_network=None, name=None, rank=None, topology_type=None, tier_group_name=None, subnetwork_field_name=None):
    """AddTier_un(in_utility_network, domain_network, name, rank, {topology_type}, {tier_group_name}, {subnetwork_field_name})

        Creates a new tier for a specific domain network in a utility
        network. Tiers are collections of subnetworks that share the same
        level, name
        restrictions, and topology type. Tiers are required for subnetwork
        management. Tier groups can be created using the Add Tier Group tool.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the domain network where the tier
          will be added.
      domain_network (String):
          The domain network where the tier will be created.
      name (String):
          The name of the new tier. The name must be unique in the entire
          utility network.
      rank (Long):
          The rank of the tier being added. The highest rank is the number 1.
      topology_type {String}:
          The topology type for the new tier: RADIAL or MESH. Radial means the
          subnetworks in the tier are provided by one source. Mesh means the
          subnetworks in the tier are provided by multiple sources. If the input
          domain network was created with a hierarchical tier definition, the
          default topology type is MESH. If the input domain network was created
          with a partitioned tier definition, the topology type parameter is
          required.

          * RADIAL-The subnetworks are fed by one source, a nonlooped path with
          only one subnetwork controller.

          * MESH-The subnetworks are fed by multiple sources, a closed path
          (loop) with one or more subnetwork controllers. This is the default
          topology type for a tier created with a hierarchical tier definition.
      tier_group_name {String}:
          The existing tier group to which the new tier will be added. This
          parameter is required for hierarchical tier types.
      subnetwork_field_name {String}:
          The name of the field where the subnetwork names for this tier will
          be stored. This is a system maintained field that will be created the
          first time a tier is added to a tier group and re-used for any
          additional tiers. For example, you have two tier groups: Distribution
          and Transmission. When you add a tier named system to the Distribution
          group and specify the subnetwork field name to be systemsubnet, the
          field is created. Next, you add a second tier named system to the
          Transmission group. This parameter will detect that the systemsubnet
          field should be used as the subnetwork field name. This parameter is
          required for hierarchical tier types."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTier_un(*gp_fixargs((in_utility_network, domain_network, name, rank, topology_type, tier_group_name, subnetwork_field_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTierGroup_un', None)
def AddTierGroup(in_utility_network=None, domain_network=None, name=None):
    """AddTierGroup_un(in_utility_network, domain_network, name)

        Adds a tier group to a domain network in a utility network.This tool
        is used to add a new tier group to an existing domain
        network in a utility network. When a tier group exists, the Add Tier
        tool can be used to add tiers to the tier group.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the domain network where the tier
          group will be added.
      domain_network (String):
          The name of the domain network to which the tier group will be added.
          Tier groups can only be added to domain networks that have a
          hierarchical tier definition.
      name (String):
          A unique name for the new tier group. The name can be a maximum of 64
          characters in length."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTierGroup_un(*gp_fixargs((in_utility_network, domain_network, name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateUtilityNetwork_un', None)
def CreateUtilityNetwork(in_feature_dataset=None, in_utility_network_name=None, service_territory_feature_class=None):
    """CreateUtilityNetwork_un(in_feature_dataset, in_utility_network_name, service_territory_feature_class)

        Creates a utility network in an enterprise geodatabase feature
        dataset. A utility network is created and a structure network is added
        with
        its collection of feature classes in the target feature dataset. The
        structure feature classes will be shared across all domain networks as
        they are created and configured for the utility network.For more
        details about system requirements and supported databases,
        see Create a utility network..

     INPUTS:
      in_feature_dataset (Feature Dataset):
          The enterprise geodatabase feature dataset in which the utility
          network and schema will be created.
      in_utility_network_name (String):
          The name of the utility network that will be created.
      service_territory_feature_class (Polygon):
          The existing polygon feature class that will be used to create the
          utility network's geographical extent. Utility network features cannot
          be created outside of this extent.The feature class must be z- and
          m-enabled."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateUtilityNetwork_un(*gp_fixargs((in_feature_dataset, in_utility_network_name, service_territory_feature_class), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteNetworkCategory_un', None)
def DeleteNetworkCategory(in_utility_network=None, category_name=None):
    """DeleteNetworkCategory_un(in_utility_network, category_name)

        Deletes a network category in a utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network category to be deleted.
      category_name (String):
          The name of the network category to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteNetworkCategory_un(*gp_fixargs((in_utility_network, category_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteRule_un', None)
def DeleteRule(in_utility_network=None, rule_type=None, rule_desc=None):
    """DeleteRule_un(in_utility_network, rule_type, {rule_desc})

        Permanently deletes a rule from a utility network.Caution should be
        taken when deleting rules that support existing
        features in a utility network. Existing features that rely on deleted
        rules are marked with error features when the network topology is re-
        enabled to indicate there is no rule to support the relationship.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the rule will be removed.
      rule_type (String):
          The type of rule being deleted.

          * ALL-Delete all rules.

          * JUNCTION_JUNCTION_CONNECTIVITY-Delete a junction-junction
          connectivity association rule.

          * CONTAINMENT-Delete a containment association rule.

          * STRUCTURAL_ATTACHMENT-Delete a structural attachment association
          rule.

          * JUNCTION_EDGE_CONNECTIVITY-Delete a junction-edge connectivity rule.

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Delete an edge-junction-edge
          connectivity rule.
      rule_desc {String}:
          Specifies which rule to remove. This includes the rule ID and the
          description of the rule. You can find the rule ID by browsing the
          Rules section of the Network
          Properties, which is available on the Layer Properties dialog box."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteRule_un(*gp_fixargs((in_utility_network, rule_type, rule_desc), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteTerminalConfiguration_un', None)
def DeleteTerminalConfiguration(in_utility_network=None, terminal_configuration_name=None):
    """DeleteTerminalConfiguration_un(in_utility_network, terminal_configuration_name)

        Deletes a terminal configuration in a utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the terminal configuration to be
          deleted.
      terminal_configuration_name (String):
          The name of the terminal configuration to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteTerminalConfiguration_un(*gp_fixargs((in_utility_network, terminal_configuration_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DisableNetworkTopology_un', None)
def DisableNetworkTopology(in_utility_network=None):
    """DisableNetworkTopology_un(in_utility_network)

        Disables the network topology for an existing utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network where the network topology will be disabled."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DisableNetworkTopology_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('EnableNetworkTopology_un', None)
def EnableNetworkTopology(in_utility_network=None, max_number_of_errors=None, only_generate_errors=None):
    """EnableNetworkTopology_un(in_utility_network, {max_number_of_errors}, {only_generate_errors})

        Enables a network topology for a utility network.A network topology is
        needed for analytic and diagram operations.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the network topology will be enabled.
      max_number_of_errors {Long}:
          The maximum number of errors before the process of enabling the
          network topology will stop, and errors will be recorded to the errors
          table. The default value is 10000. The maximum number of errors
          restriction is ignored if a value of 0 is set.Increasing the maximum
          number of errors value will increase the length
          of time to enable the topology. Setting a value higher than the
          default value of 10000 is not recommended.
      only_generate_errors {Boolean}:
          Specifies whether to generate network errors only.

          * ONLY_ERRORS-The utility network will only be evaluated for network
          errors. The topology will not be enabled, and the data will not be
          required to be registered as versioned. This allows you to inspect and
          fix errors in the network until you are ready to register the data as
          versioned and enable the topology.

          * ENABLE_TOPO-The topology is enabled. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.EnableNetworkTopology_un(*gp_fixargs((in_utility_network, max_number_of_errors, only_generate_errors), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportAssociations_un', None)
def ExportAssociations(in_utility_network=None, association_type=None, out_csv_file=None):
    """ExportAssociations_un(in_utility_network, association_type, out_csv_file)

        Exports connectivity, containment, and structural attachment
        associations from a utility network into a comma separated values
        (.csv) file. All types of associations can be exported including
        junction-junction
        connectivity, structural attachment, and containment.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network containing the associations to export.
      association_type (String):
          The type of association to export.

          * ALL-All associations in the utility network are exported to a .csv
          file.

          * JUNCTION_JUNCTION_CONNECTIVITY-Connectivity associations allowing
          two junction subtypes to connect via a connectivity association
          (features are offset geometrically) are exported to a .csv file.

          * CONTAINMENT-Containment associations are exported to a .csv file.

          * STRUCTURAL_ATTACHMENT-Structural attachment associations are
          exported to a .csv file.

     OUTPUTS:
      out_csv_file (File):
          The name and location of the .csv file that will be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportAssociations_un(*gp_fixargs((in_utility_network, association_type, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportRules_un', None)
def ExportRules(in_utility_network=None, rule_type=None, out_csv_file=None):
    """ExportRules_un(in_utility_network, rule_type, out_csv_file)

        Exports connectivity, structural attachment, and containment rules
        from a utility network into a comma-separated values file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network to export the rules from.
      rule_type (String):
          The type of rule to export.

          * ALL-All the rules in the utility network will be exported.

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          association rules will be exported.

          * JUNCTION_EDGE_CONNECTIVITY-Junction-edge connectivity rules will be
          exported.

          * CONTAINMENT-Containment association rules will be exported.

          * STRUCTURAL_ATTACHMENT-Structural attachment association rules will
          be exported.

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Edge-junction-edge connectivity
          association rules will be exported.

     OUTPUTS:
      out_csv_file (File):
          The folder location and name of the .csv file to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportRules_un(*gp_fixargs((in_utility_network, rule_type, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportSubnetworkControllers_un', None)
def ExportSubnetworkControllers(in_utility_network=None, out_csv_file=None):
    """ExportSubnetworkControllers_un(in_utility_network, out_csv_file)

        Exports subnetwork controllers from a utility network into a .csv
        file. Subnetwork controllers are features that have been set as
        subnetwork
        controllers using the Modify Subnetwork Controller pane. The exported
        .csv file will contain information about the device features that are
        currently set as subnetwork controllers.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network from which subnetwork controllers will be
          exported.

     OUTPUTS:
      out_csv_file (File):
          The location and name for the .csv file to be generated."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportSubnetworkControllers_un(*gp_fixargs((in_utility_network, out_csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportAssociations_un', None)
def ImportAssociations(in_utility_network=None, association_type=None, csv_file=None):
    """ImportAssociations_un(in_utility_network, association_type, csv_file)

        Imports connectivity, containment, and structural attachment
        associations from a comma-separated values (.csv) file into an
        existing utility network.Associations must be imported from a single
        .csv file.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network receiving the associations.
      association_type (String):
          The type of associations to import.

          * ALL-One or more types of association

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          association type

          * CONTAINMENT-Containment association type

          * STRUCTURAL_ATTACHMENT-Structural attachment association type
      csv_file (File):
          The .csv file containing the associations to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportAssociations_un(*gp_fixargs((in_utility_network, association_type, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportRules_un', None)
def ImportRules(in_utility_network=None, rule_type=None, csv_file=None):
    """ImportRules_un(in_utility_network, rule_type, csv_file)

        Import connectivity, structural attachment, and containment rules
        from a comma-separated values file into an existing utility network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          Specifies the utility network to import the rules to.
      rule_type (String):
          Specifies the type of rules to import.

          * ALL-One or more types of rules

          * JUNCTION_JUNCTION_CONNECTIVITY-Junction-junction connectivity
          association rules

          * JUNCTION_EDGE_CONNECTIVITY-Junction-edge connectivity rules

          * CONTAINMENT-Containment association rules

          * STRUCTURAL_ATTACHMENT-Structural attachment association rules

          * EDGE_JUNCTION_EDGE_CONNECTIVITY-Edge-junction-edge association
          rules
      csv_file (File):
          Specifies the .csv file containing the rules to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportRules_un(*gp_fixargs((in_utility_network, rule_type, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportSubnetworkControllers_un', None)
def ImportSubnetworkControllers(in_utility_network=None, csv_file=None):
    """ImportSubnetworkControllers_un(in_utility_network, csv_file)

        Imports subnetwork controllers from a .csv file into a utility
        network.The imported .csv file will modify properties on existing
        features in
        the utility network to set these features as subnetwork controllers.
        Subnetwork controllers are needed to work with utility network trace
        analytics.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network for which the subnetwork controllers will be
          imported.
      csv_file (File):
          The .csv file containing the subnetwork controllers to import."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportSubnetworkControllers_un(*gp_fixargs((in_utility_network, csv_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetAssociationRole_un', None)
def SetAssociationRole(in_utility_network=None, domain_network=None, featureclass=None, assetgroup=None, assettype=None, association_role_type=None, association_deletion_semantics=None, view_scale=None, split_content=None):
    """SetAssociationRole_un(in_utility_network, domain_network, featureclass, assetgroup, assettype, association_role_type, association_deletion_semantics, {view_scale}, {split_content})

        Alters the role assigned to a class at the asset type level.Roles
        define how an asset type participates in a utility network. To
        learn more about association roles, see Set or modify an association
        role assignment.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the asset type with an association
          role to set.
      domain_network (String):
          The domain network that contains the asset type with an association
          role to set.
      featureclass (String):
          The utility network assembly or structural feature class that
          contains the asset type with an association role to set.
      assetgroup (String):
          The asset group that contains the asset type.
      assettype (String):
          The asset type with the association role to set.
      association_role_type (String):
          The type of association role to assign to the asset type.

          * CONTAINER-Features of this asset type can contain other features as
          contents.

          * STRUCTURE-Features of this asset type can have other features
          attached to them.

          * NONE-No role type. These are features that are neither a container
          nor a structure but do connect to other structures.
      association_deletion_semantics (String):
          The deletion semantics for the features.

          * CASCADE-All content is deleted when the parent container is deleted.
          Content features are permanently deleted.

          * SET_TO_NONE-All containment associations are removed. Content
          features are now regular features in the map.

          * RESTRICTED-Upon deletion, if content exists in the container, an
          error is returned. You must then either delete the content features or
          remove them from the container by deleting the association (placing
          them outside the container).
      view_scale {Double}:
          The scale at which to enter containment mode to edit features
          participating in the container. For example, setting the view scale to
          5 means that when you enter containment mode of the container feature,
          the scale will be 1:5. Units are based on the utility network units,
          which are located on the Source tab of the utility network layer
          properties pane.
      split_content {Boolean}:
          Specify what happens to the associated content of a container if the
          container feature is split. This parameter is only relevant for
          containers that are line features.

          * SPLIT-Split the container's content if the container feature is
          split. If a parallel content line feature is found, the content is
          also split and each section will be contained by the closest container
          feature. If the content line is not parallel, the content will be
          contained by the container feature that is closest to it.

          * DO_NOT_SPLIT-Do not split the container's content if the container
          feature is split. If a parallel content line feature is found, the
          content will be contained by both sections of the container feature.
          If the content line is not parallel, the content will be contained by
          the container feature that is closest to it. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetAssociationRole_un(*gp_fixargs((in_utility_network, domain_network, featureclass, assetgroup, assettype, association_role_type, association_deletion_semantics, view_scale, split_content), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetEdgeConnectivity_un', None)
def SetEdgeConnectivity(in_utility_network=None, domain_network=None, line_featureclass=None, assetgroup=None, assettype=None, edge_connectivity=None):
    """SetEdgeConnectivity_un(in_utility_network, domain_network, line_featureclass, assetgroup, assettype, edge_connectivity)

        Defines how features will connect to a line of a given asset type.
        There are two locations where point features can connect to lines: an
        end point or a midspan vertex. Each asset type in the domain network
        is set with a default edge connectivity setting.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the asset type with the edge
          connectivity to set.
      domain_network (String):
          The domain network that contains the asset type with the edge
          connectivity to set.
      line_featureclass (String):
          The name of the line feature class that contains the asset type with
          the edge connectivity to set.
      assetgroup (String):
          The asset group that contains the asset type with the edge
          connectivity to set.
      assettype (String):
          The asset type that needs the edge connectivity set.
      edge_connectivity (String):
          The edge connectivity type to assign to the asset type.

          * ANY_VERTEX-Allows features to connect anywhere along the line where
          a vertex is present including end vertices.

          * END_VERTEX-Allows features to only connect to the end vertex of the
          line."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetEdgeConnectivity_un(*gp_fixargs((in_utility_network, domain_network, line_featureclass, assetgroup, assettype, edge_connectivity), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetNetworkAttribute_un', None)
def SetNetworkAttribute(in_utility_network=None, network_attribute=None, domain_network=None, featureclass=None, field=None):
    """SetNetworkAttribute_un(in_utility_network, network_attribute, domain_network, featureclass, field)

        Assigns a network attribute to a feature class at the asset type level
        to be used during tracing operations. A utility network can have a set
        of network attributes associated
        with it. A network attribute is a value stored in the network topology
        derived from attributes on corresponding features in the network.
        While a network attribute can be associated with only one attribute on
        a feature class, there is no limit to the number of network attributes
        a single utility network can have. Network attributes are used as
        weights to control traversability and to model the cost of paths in
        the network.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network attribute to set.
      network_attribute (String):
          The network attribute to be assigned to the feature class field.
      domain_network (String):
          The domain network that contains the feature class that will have a
          network attribute set on it.
      featureclass (String):
          The input feature class that contains the field that will be used to
          set the network attribute.
      field (String):
          An existing field that will be assigned the network attribute. The
          field data type must match the data type of the network attribute. For
          example, if the network attribute is a short integer type, the field
          must also be a short integer type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetNetworkAttribute_un(*gp_fixargs((in_utility_network, network_attribute, domain_network, featureclass, field), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetNetworkCategory_un', None)
def SetNetworkCategory(in_utility_network=None, domain_network=None, featureclass=None, assetgroup=None, assettype=None, category=None):
    """SetNetworkCategory_un(in_utility_network, domain_network, featureclass, assetgroup, assettype, {category;category...})

        Assigns a network category to a feature class at the asset type level
        to be used during tracing operations. Categories are defined on asset
        types to constrain the beginning and
        end of several analytical traces.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the network category.
      domain_network (String):
          The domain network within the utility network that contains the
          network category.
      featureclass (String):
          The utility network feature class to which the asset type belongs.
      assetgroup (String):
          The asset group to which the asset type belongs.
      assettype (String):
          The asset type to alter the category configuration.
      category {String}:
          The categories to be assigned to the asset type. The categories that
          are specified for this parameter will replace the current categories
          that are assigned to the asset type. To unassign a network category
          from an asset type, do not specify a category for this
          parameter.Subnetwork controllers in a domain network with a
          partitioned tier
          definition must first have a directional terminal configuration
          assigned before the network category can be set."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetNetworkCategory_un(*gp_fixargs((in_utility_network, domain_network, featureclass, assetgroup, assettype, category), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetSubnetworkDefinition_un', None)
def SetSubnetworkDefinition(in_utility_network=None, domain_network=None, tier_name=None, support_disjoint_subnetwork=None, valid_devices=None, valid_subnetwork_controller=None, valid_lines=None, aggregated_line=None, diagram_template=None, summaries=None, condition_barriers=None, function_barriers=None, include_barriers=None, traversability_scope=None, propagators=None):
    """SetSubnetworkDefinition_un(in_utility_network, domain_network, tier_name, support_disjoint_subnetwork, valid_devices;valid_devices..., valid_subnetwork_controller;valid_subnetwork_controller..., valid_lines;valid_lines..., aggregated_line;aggregated_line..., {diagram_template;diagram_template...}, {summaries;summaries...}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {include_barriers}, {traversability_scope}, {propagators;propagators...})

        Sets the properties for a subnetwork in a utility network. The types
        of features that participate in a tier can be restricted by
        defining valid asset types from the device and line feature classes.
        Defining valid asset types helps enforce data correctness by limiting
        the types of features that can participate in a subnetwork for a
        specific tier.Configuration parameters can be used to set properties
        when a trace is
        executed on the subnetwork.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The input utility network that contains the subnetwork.
      domain_network (String):
          The domain network that contains the subnetwork.
      tier_name (String):
          The name of the tier that contains the subnetwork.
      support_disjoint_subnetwork (Boolean):
          Specifies whether the tier supports disjointed subnetworks.
          Disjointed subnetworks are two or more subnetworks that belong to the
          same tier and have the same subnetwork name but are not traversable.
          This option is only available for tiers within domain networks with a
          partitioned tier definition. Tiers in a domain network with a
          hierarchical tier definition always have this tier property set as
          true to support disjoint subnetworks.

          * SUPPORT_DISJOINT-The input tier supports disjointed subnetworks.

          * NO_DISJOINT-The input tier does not support disjointed subnetworks.
          This is the default.
      valid_devices (String):
          The list of asset group/asset type pairs that will be considered as
          valid devices for the subnetwork.
      valid_subnetwork_controller (String):
          The list of asset group/asset type pairs that can become subnetwork
          controllers in the subnetwork.
      valid_lines (String):
          The list of asset group/asset type pairs that will be considered as
          valid lines for the subnetwork.
      aggregated_line (String):
          The valid lines whose geometry will be aggregated to generate the
          SubnetLine features. This list is a subset of the values specified in
          the valid_lines parameter.
      diagram_template {String}:
          The templates that will be used to generate subnetwork system diagrams
          for each subnetwork.
      summaries {Value Table}:
          Sets the summary field to store function results when inserting or
          updating SubnetLine features.Summaries components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Filter Name-Choose to filter the function results by attribute name.

          * Filter Operator-Choose from a number of different operators.

          * Filter Type-Choose from a number of different filter types.

          * Filter Value-Set a specific value of the input filter attribute.

          * Summary Attribute-The field in the SubnetLine feature class that
          will persist the function result. Depending on the selected function
          and network attribute type, only the applicable type of user-added
          subnetwork attributes will be valid for this parameter. In the case of
          hierarchical domain networks, only the attributes added to SubnetLine
          will be valid for the Summary Attribute parameter. See the following
          matrix of valid field types for the various functions:
          Possible values for the summaries Function options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values. Subnetwork controllers and loops trace
          types do not support the subtract function.
          Possible values for the summaries Filter Type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Filter Operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
      condition_barriers {Value Table}:
          Sets a traversability barrier condition on features based on a
          comparison to a network attribute or check for a category string. A
          condition barrier uses a network attribute, an operator and a type,
          and an attribute value. For example, stop a trace when a feature has
          the attribute Device Status equal to the specific value of Open. When
          a feature meets this condition, the trace stops. If you're using more
          than one attribute, you can use the Combine using parameter to define
          an And or an Or condition.Condition barrier components are as follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Set a specific value of the input attribute type that would
          cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can combine them using an And or an Or condition.
          The condition barriers operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES NOT INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INLCUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          Possible values for the Type options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The Combine Using values are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      function_barriers {Value Table}:
          Sets a traversability barrier on features based on a function.
          Function barriers can be used to do such things as restrict how far
          the trace travels from the starting point, or set a maximum value to
          stop a trace. For example, the length of each line traveled is added
          to the total distance traveled so far. When the total length traveled
          reaches the value specified, the trace stops.Function barrier
          components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Set a specific value of the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculate values in each direction as opposed to an
          overall global value, for example, for a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you have already reached a
          shape length sum of 4, so the trace stops. If local values are used,
          the local values along each path change, so the trace goes farther.
          Possible values for the function barrier function options are as
          follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-Add the values.

          * SUBTRACT-Subtract the values.Subnetwork controllers and loops trace
          types do not support the subtract function.
          The function barrier operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The function barrier Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      include_barriers {Boolean}:
          Defines whether the traversability barrier features are included in
          the trace results. Traversability barriers are optional even if they
          have been preset in the subnetwork definition.

          * INCLUDE_BARRIERS-Traversability barriers are included in the trace
          results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barriers are not included in the
          trace results.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          the trace would not stop even if the trace encounters an open device,
          because Device Status is only applicable for junctions. In other
          words, this parameter indicates to the trace whether or not to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      propagators {Value Table}:
          Specifies the network attributes to propagate as well as how that
          propagation should occur during a trace. Propagated class attributes
          denote the key values on subnetwork controllers that are disseminated
          to the rest of the features in the subnetwork. For example, in an
          electric distribution model, you can propagate the phase
          value.Propagators components are as follows:

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Substitution Attribute-Use a substituted value instead of bitset
          network attribute values. Substitutions are encoded based on the
          number of bits in the network attribute being propagated. A
          substitution is a mapping of each bit in phase to another bit. For
          example, for Phase AC, one substitution could map bit A to B and bit C
          to null. In this example the substitution for 1010 (Phase AC) is
          0000-0010-0000-0000 (512). The substitution captures the mapping so
          you know that Phase A was mapped to B and Phase C was mapped to null
          and not the other way around (that is, Phase A was not mapped to null
          and Phase C was not mapped to B).

          * Function-Choose from a number of different calculation functions.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.

          * Propagated Attribute-The name of the field in your network class
          that is used to store the calculated propagated values. The field type
          should be the same as the field type of the network attribute chosen
          for the Attribute value.
          Possible values for the propagators function are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagator operator values are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetSubnetworkDefinition_un(*gp_fixargs((in_utility_network, domain_network, tier_name, support_disjoint_subnetwork, valid_devices, valid_subnetwork_controller, valid_lines, aggregated_line, diagram_template, summaries, condition_barriers, function_barriers, include_barriers, traversability_scope, propagators), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('SetTerminalConfiguration_un', None)
def SetTerminalConfiguration(in_utility_network=None, domain_network=None, device_featureclass=None, assetgroup=None, assettype=None, terminal_configuration=None):
    """SetTerminalConfiguration_un(in_utility_network, domain_network, device_featureclass, assetgroup, assettype, terminal_configuration)

        Assigns a terminal configuration to an asset type in a utility
        network.Once a terminal configuration has been established, it can be
        assigned
        to an asset type in the device feature class. This tool allows you to
        set the terminal configuration for a utility network asset type in the
        device class. When a terminal configuration is assigned to an asset
        type, a feature created with that asset type will have terminals. More
        specifically, the feature will have the terminals specified for the
        terminal configuration.To understand what the underlying terminals are
        for each asset type,
        refer to the Terminal Configuration section on the Network Properties
        dialog box of the utility network layer properties.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network that contains the terminal configuration that
          will be set on a specific asset type.
      domain_network (String):
          The domain network to which the asset type belongs.
      device_featureclass (String):
          The utility network device feature class to which the asset type
          belongs.
      assetgroup (String):
          The asset group to which the asset type belongs.
      assettype (String):
          The asset type receiving the terminal configuration.
      terminal_configuration (String):
          The terminal configuration to be assigned to the asset type."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.SetTerminalConfiguration_un(*gp_fixargs((in_utility_network, domain_network, device_featureclass, assetgroup, assettype, terminal_configuration), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateUtilityNetworkSchema_un', None)
def UpdateUtilityNetworkSchema(in_utility_network=None, operations=None):
    """UpdateUtilityNetworkSchema_un(in_utility_network, operations)

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          Input Utility Network
      operations (File / String):
          Schema Operations"""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateUtilityNetworkSchema_un(*gp_fixargs((in_utility_network, operations), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams toolset
@gptooldoc('AlterDiagramProperties_un', None)
def AlterDiagramProperties(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """AlterDiagramProperties_un(in_network_diagram_layer, {out_name}, {access_right_type}, {tags})

        Alters properties for any stored network diagram.The diagram owner and
        the utility network owner are the only users who
        can run the Alter Diagram Properties tool.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The stored network diagram to alter.
      out_name {String}:
          The new name for the input network diagram.
      access_right_type {String}:
          The access right level of the input diagram.

          * PUBLIC-Other users will have full access to the diagram; everyone
          can see, edit, update, and overwrite the diagram. However, no one
          except the diagram owner and the utility network owner can delete the
          diagram or change its properties using the Alter Diagram Properties
          tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from other users in the Find
          Diagrams pane.
      tags {String}:
          Specifies one or several tags that would help find the stored diagram.
          These tags are searched through in the Find Diagrams pane afterward.To
          add several tags, use the number sign (#) to separate each tag.
          This also allows more thorough and efficient diagram searching."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramProperties_un(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AppendToDiagram_un', None)
def AppendToDiagram(in_network_diagram_layer=None, map=None):
    """AppendToDiagram_un(in_network_diagram_layer, map)

        Appends selected utility network features to a network diagram.If you
        have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer to which selected utility network features
          will be appended.
      map (Map):
          The map with selected utility network features to append to the
          network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AppendToDiagram_un(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagram_un', None)
def CreateDiagram(in_utility_network=None, template_name=None, features=None):
    """CreateDiagram_un(in_utility_network, template_name, {features;features...})

        Creates a network diagram from utility network features currently
        selected in the active map or from feature layers created from a
        Python script.When feature layers are specified and there are features
        selected in
        the active map, the selected features set is ignored and all the
        features in the specified layers are used as input for the diagram
        creation.When no feature layers or classes are specified, the process
        searches
        for the utility network features selected in the active map and
        creates the diagram from those features.Edits must be saved so that
        the output diagram is in sync with the
        last save moment of the network topology in the database. Otherwise,
        the unsaved edits will not be reflected in the new diagram.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network from which the diagram will be created.
      template_name (String):
          The name of the template that will be used to create the diagram.
      features {Feature Layer}:
          One or more feature layers or feature classes to be used as input for
          diagram generation."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagram_un(*gp_fixargs((in_utility_network, template_name, features), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagram_un', None)
def DeleteDiagram(in_diagrams=None, template_names=None, diagram_names=None):
    """DeleteDiagram_un(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...})

        Deletes one or more network diagrams, which are optionally filtered by
        their diagram template names, related to a given utility network.You
        can specify a single diagram, a set of diagrams, or a diagram
        template name. When you delete a diagram template, all associated
        diagrams are also deleted. You must save any edits prior to deleting a
        diagram.

     INPUTS:
      in_diagrams (Utility Network Layer / Utility Network / Diagram Layer):
          The utility network data element or layer with one or more diagrams
          to be deleted.
      template_names {String}:
          The names of the templates for which the related diagrams are to be
          processed.
      diagram_names {String}:
          The names of the diagrams to be processed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagram_un(*gp_fixargs((in_diagrams, template_names, diagram_names), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramContent_un', None)
def ExportDiagramContent(in_utility_network=None, network_diagram_name=None, out_file=None, include_diagram_properties=None, include_geometries=None, include_attributes=None, include_aggregations=None):
    """ExportDiagramContent_un(in_utility_network, network_diagram_name, out_file, {include_diagram_properties}, {include_geometries}, {include_attributes}, {include_aggregations})

        Exports diagram content in a simple format (JSON file) that reflects
        basic connectivity. Additional optional information such as diagram
        properties, diagram feature geometry, utility network elements
        attributes, and aggregated elements can also be exported.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network layer or utility network data element related to
          the network diagram to export.
      network_diagram_name (String):
          The name of the network diagram to export.
      include_diagram_properties {Boolean}:
          Specifies whether to export the diagram properties.

          *  INCLUDE_DIAGRAM_PROPERTIES-The process exports the diagram
          properties (statistics, creation and update dates, and so on).

          *  EXCLUDE_DIAGRAM_PROPERTIES-The process doesn't export the diagram
          properties. This is the default.
      include_geometries {Boolean}:
          Specifies whether to export the geometry of the diagram features.

          *  INCLUDE_GEOMETRIES-The process exports each diagram feature with
          its geometry.

          *  EXCLUDE_GEOMETRIES-The process exports each diagram feature without
          its geometry. This is the default.
      include_attributes {Boolean}:
          Specifies whether to export the attributes of the associated utility
          network features.

          *  INCLUDE_ATTRIBUTES-The process exports the attributes of the
          utility network feature associated with each diagram feature.

          *  EXCLUDE_ATTRIBUTES-The process doesn't export the associated
          utility network feature attributes. This is the default.
      include_aggregations {Boolean}:
          Specifies whether to export each diagram feature with the list of the
          utility network elements it aggregates.

          *  INCLUDE_AGGREGATIONS-The process exports each diagram feature with
          the list of the utility network elements it aggregates with their
          asset group and asset type values.

          *  EXCLUDE_AGGREGATIONS-The process doesn't export the diagram feature
          aggregations. This is the default.

     OUTPUTS:
      out_file (File):
          The output JSON file to create with the exported diagram content."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramContent_un(*gp_fixargs((in_utility_network, network_diagram_name, out_file, include_diagram_properties, include_geometries, include_attributes, include_aggregations), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExtendDiagram_un', None)
def ExtendDiagram(in_network_diagram_layer=None, ignore_traversability=None, extension_type=None):
    """ExtendDiagram_un(in_network_diagram_layer, {ignore_traversability}, {extension_type})

        Extends a network diagram by one feature level based on network
        connectivity or traversability or on containment or structural
        attachment associations.For example, a diagram with a portion of a
        pipe network in it may have
        many open-ended pipes with connected features. When running the Extend
        Diagram tool on this diagram with the By connectivity extension type,
        any connected features are appended to the diagram.Features can also
        be obtained based on traversability using the By
        traversability extension type. In this case, features are appended to
        the diagram if they allow the network commodity to continue through to
        the next feature. For example, a diagram with a portion of a pipe
        network in it may have a closed valve at the end of a pipe end. Since
        a resource travelling this network cannot travel beyond the closed
        valve, the valve is not returned in the diagram. If this example was
        based on connectivity instead of traversability, the valve would be
        returned as it is connected to the pipe.Extending diagrams can be
        locked on the related diagram template.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to extend.
      ignore_traversability {Boolean}:
          Specifies whether traversability or connectivity is used to extend the
          diagram.This parameter was deprecated at ArcGIS Pro 2.2. It is
          systematically
          ignored regardless of its value when the extension_type is specified.
          To maintain compatibility with models and Python scripts written at
          ArcGIS Pro 2.1, it remains enabled when the extension_type parameter
          is not specified.

          *  IGNORE_TRAVERSABILITY-The traversability of the network is ignored.
          This is the default.

          * HONOR_TRAVERSABILITY-The traversability of the network is honored.
      extension_type {String}:
          Specifies how the diagram will be extended.

          * BY_CONNECTIVITY-Extends the network diagram by one feature level
          based on network connectivity. This is the default.

          * BY_TRAVERSABILITY-Extends the network diagram by one feature level
          based on network traversability.

          * BY_ATTACHMENT-Extends the network diagram by one feature level based
          on structural attachment associations.

          * BY_CONTAINMENT-Extends the network diagram by one feature level
          based on containment associations."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExtendDiagram_un(*gp_fixargs((in_network_diagram_layer, ignore_traversability, extension_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('MakeDiagramLayer_un', None)
def MakeDiagramLayer(in_utility_network=None, network_diagram_name=None, out_layer=None):
    """MakeDiagramLayer_un(in_utility_network, network_diagram_name, out_layer)

        Creates a network diagram layer from a network diagram.

     INPUTS:
      in_utility_network (Utility Network / Utility Network Layer):
          The utility network the diagram is related to.
      network_diagram_name (String):
          The network diagram name.

     OUTPUTS:
      out_layer (Diagram Layer):
          The name of the diagram layer to be created.The output diagram layer
          can be used as input to any geoprocessing
          tool that accepts a diagram layer as input, including the Store
          Diagram, Update Diagram, and Apply Smart Tree Layout tools."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.MakeDiagramLayer_un(*gp_fixargs((in_utility_network, network_diagram_name, out_layer), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('OverwriteDiagram_un', None)
def OverwriteDiagram(in_network_diagram_layer=None, map=None):
    """OverwriteDiagram_un(in_network_diagram_layer, map)

        Overwrites the contents of a network diagram with the network features
        currently selected in the specified map. These network features become
        the new initial content of the diagram.If you have an open edit
        session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram to overwrite.
      map (Map):
          The map referencing the set of selected utility network features to
          use to overwrite the input network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.OverwriteDiagram_un(*gp_fixargs((in_network_diagram_layer, map), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('PurgeTemporaryDiagrams_un', None)
def PurgeTemporaryDiagrams(in_utility_network=None, created_before=None):
    """PurgeTemporaryDiagrams_un(in_utility_network, {created_before})

        Purges temporary network diagrams related to a given utility
        network.This tool must be run by the database owner of the utility
        network
        through a direct connection to the default version.In addition to that
        requirement, the connected portal account must be
        the owner of the utility network to perform this operation. This
        essentially forms two-factor authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network data element with the temporary diagrams to be
          purged.
      created_before {Date}:
          The cutoff date for temporary network diagrams to be purged. All
          temporary network diagrams created before this date will be purged.If
          no date is specified, all temporary diagrams in the database will
          be purged."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.PurgeTemporaryDiagrams_un(*gp_fixargs((in_utility_network, created_before), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('StoreDiagram_un', None)
def StoreDiagram(in_network_diagram_layer=None, out_name=None, access_right_type=None, tags=None):
    """StoreDiagram_un(in_network_diagram_layer, out_name, {access_right_type}, {tags})

        Stores a temporary network diagram in the database. Access rights and
        tags can be assigned to control security and searchability of the
        diagram.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The temporary network diagram layer to be stored.
      access_right_type {String}:
          The access right level of the input diagram.

          * PUBLIC-Other users will have full access to the diagram; everyone
          can see, edit, update, and overwrite the diagram. However, no one
          except the diagram owner and the utility network owner can delete the
          diagram or change its properties using the Alter Diagram Properties
          tool. This is the default.

          * PROTECTED-Other users will have read-only access to the diagram.
          They cannot edit, update, or overwrite the diagram.

          * PRIVATE-Other users will not have access to the diagram. The
          corresponding diagram item will be hidden from other users in the Find
          Diagrams pane.
      tags {String}:
          Tags that can help the querying of the stored diagram using the Find
          Diagrams pane.Use the # character to separate each tag and aid
          efficient diagram
          searches.

     OUTPUTS:
      out_name (Diagram Layer):
          The name of the output network diagram."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.StoreDiagram_un(*gp_fixargs((in_network_diagram_layer, out_name, access_right_type, tags), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('UpdateDiagram_un', None)
def UpdateDiagram(in_diagrams=None, template_names=None, diagram_names=None, update_option=None, autolayout_option=None):
    """UpdateDiagram_un(in_diagrams, {template_names;template_names...}, {diagram_names;diagram_names...}, {update_option}, {autolayout_option})

        Updates one or more network diagrams that are related to a given
        utility network.Diagrams may need to be updated when they are either
        inconsistent or
        consistent. When a diagram is inconsistent, it means the corresponding
        features in the map have been altered, and the diagram is out of date.
        A consistent diagram may need to be updated if the diagram template
        associated with it has been modified.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.

     INPUTS:
      in_diagrams (Utility Network Layer / Utility Network / Diagram Layer):
          The input network diagram layer to update, or the utility network
          data element or layer on which the set of specified input diagram
          names are based to update.
      template_names {String}:
          The names of the templates for which the related diagrams are to be
          processed.
      diagram_names {String}:
          The names of the diagrams to be processed.
      update_option {Boolean}:
          Specifies whether to update only diagrams that are inconsistent
          (default) or all diagrams regardless of their consistency state.

          * INCONSISTENT_DIAGRAMS_ONLY-Only diagrams that are inconsistent will
          be updated. This is the default.

          * ALL_SELECTED_DIAGRAMS-Both consistent and inconsistent diagrams will
          be updated.
      autolayout_option {Boolean}:
          Allows the re-execution of any automatic layouts that may be
          configured on the template on which the diagrams are based during the
          update process. By default, when automatic layouts are specified on a
          template, they are never re-applied during the update process.

          * REAPPLY_AUTOLAYOUT-The automatic layouts that are configured on the
          template will be re-applied to diagrams at the end of the update
          process.

          * DO_NOT_REAPPLY_AUTOLAYOUT-None of the automatic layouts configured
          on the template will be re-applied to diagrams during the update
          process. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.UpdateDiagram_un(*gp_fixargs((in_diagrams, template_names, diagram_names, update_option, autolayout_option), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams\Configuration toolset
@gptooldoc('AddAngleDirectedLayout_un', None)
def AddAngleDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None):
    """AddAngleDirectedLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {number_of_directions})

        Adds the Angle Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the generation of diagrams
        based on a given template. This tool also presets the Angle Directed
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively moves the diagram's edges
        in
        specified alignment directions. For each diagram edge, this layout
        considers its current direction, searches for the nearest desired
        direction among those specified, and moves the edge in that
        direction.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that must be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddAngleDirectedLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, number_of_directions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerByAttributeRule_un', None)
def AddCollapseContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, container_source=None, where_clause=None, description=None, reconnected_edges_option=None):
    """AddCollapseContainerByAttributeRule_un(in_utility_network, template_name, is_active, container_source, {where_clause}, {description}, {reconnected_edges_option})

        Adds a diagram rule to the rule list specified on a diagram template
        to automatically collapse all contents related to containers during
        diagram building. The containers with the contents to be collapsed are
        identified using a SQL query based on their attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      container_source (Feature Class):
          The network container source class that references the containers
          with the contents to be collapsed during the Collapse Container rule
          process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          source class with the contents to be collapsed in the generated
          diagrams. For more information on SQL syntax, see SQL reference for
          query expressions used in ArcGIS.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule must aggregate the edges that should be
          reconnected to the collapsed junctions or not.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content
          junction is kept and simply reconnected to the collapsed container
          junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content junction
          is replaced by a reduction edge that is reconnected to the collapsed
          container junction. Moreover, multiple edges between two collapsed
          junctions are systematically aggregated under the same reduction edge.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, container_source, where_clause, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCollapseContainerRule_un', None)
def AddCollapseContainerRule(in_utility_network=None, template_name=None, is_active=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None, reconnected_edges_option=None):
    """AddCollapseContainerRule_un(in_utility_network, template_name, is_active, container_type, inverse_source_selection, {container_sources;container_sources...}, {description}, {reconnected_edges_option})

        Adds a diagram rule that automatically collapses container contents
        during the building of diagrams based on an existing template. This
        rule collapses the entire contents of containers in the diagrams.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      container_type (String):
          The geometry type of the source class container the rule must process.

          * JUNCTIONS-The Collapse Container rule process will focus on the
          junction container source classes only; that is, the utility network
          polygon or point container source classes.

          * EDGES-The Collapse Container rule process will focus on the edge
          container source classes only; that is, the utility network linear
          container source classes.

          * BOTH-The Collapse Container rule process will operate on any
          container source classes regardless of their type; that is, both
          junction and edge types will be processed. This is the default.
      inverse_source_selection (String):
          Determines how the rule processes the specified container source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Any containers based on the specified source
          classes will not be collapsed, while other containers will be
          collapsed. This is the default.

          * INCLUDE_SOURCE_CLASSES-Any containers based on the specified source
          classes will be collapsed.
      container_sources {Feature Class}:
          The network container source class (or classes) that must be excluded
          or included during the Collapse Container rule execution depending on
          the chosen rule process.With the Exclude Source Classes rule process,
          the rule can be
          configured without specifying any particular network source class, in
          which case it will collapse contents of any container source classes
          in the generated diagrams. However, with the Include Source Classes
          rule process, the particular container source class (or classes) to be
          collapsed must be specified.When running the Exclude Source Classes
          rule process, the contents
          related to any network container features belonging to those classes
          will never be collapsed in the generated diagrams, while contents
          related to network container features that don't belong to those
          classes will be collapsed. Conversely, when running the Include Source
          Classes rule process, the contents related to any network container
          features belonging to those classes will always be collapsed in the
          generated diagrams, while contents related to network container
          features that don't belong to those classes will not be collapsed.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule must aggregate the edges that should be
          reconnected to the collapsed junctions or not.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content
          junction is kept and simply reconnected to the collapsed container
          junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a content junction
          is replaced by a reduction edge that is reconnected to the collapsed
          container junction. Moreover, multiple edges between two collapsed
          junctions are systematically aggregated under the same reduction edge.
          This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCollapseContainerRule_un(*gp_fixargs((in_utility_network, template_name, is_active, container_type, inverse_source_selection, container_sources, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddCompressionLayout_un', None)
def AddCompressionLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None):
    """AddCompressionLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule})

        Adds the Compression Layout algorithm to the layout list of the input
        diagram template so it automatically executes at the end of diagram
        buildings. This tool also presets the Compression Layout algorithm
        parameters for any diagram based on that template.This layout
        algorithm compresses the diagram features toward the
        middle of the diagram while trying to maintain relative positioning.
        It works from a distance that allows it to build junction groups that
        are moved as super nodes during the algorithm execution.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the Compression layout
          algorithm.

          * PRESERVE_CONTAINERS-The Compression layout algorithm executes on
          the top graph of the diagram so containers are preserved. This is the
          default.

          * IGNORE_CONTAINERS-The Compression layout algorithm executes on both
          content and noncontent features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          How vertices along edges in the diagram will be processed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that intersect a container
          polygon. A vertex is automatically inserted at the intersection of the
          edges and container polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddCompressionLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddConnectivityAssociationsRule_un', None)
def AddConnectivityAssociationsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddConnectivityAssociationsRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent connectivity
        associations during the building of diagrams based on an existing
        template. This rule processes connectivity associations for which both
        the from and to junctions are currently represented in the
        diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddConnectivityAssociationsRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddDiagramTemplate_un', None)
def AddDiagramTemplate(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """AddDiagramTemplate_un(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Adds a new diagram template to a utility network. Both a network
        diagram rules and layouts definition file (.ndbd) and a layer
        definition file (.ndld) can be imported.This tool is a configuration
        and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network to which the template will be added.
      template_name (String):
          The name of the output diagram template.
      ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to
          import. This file can be created using the Export Diagram Template
          Definitions tool on an existing template.
      ndld_file {File}:
          The diagram layer definition file (.ndld) to import. This file can be
          created using the Export Diagram Template Definitions or Export
          Diagram Layer Definition tool on an existing template."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerByAttributeRule_un', None)
def AddExpandContainerByAttributeRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_source=None, where_clause=None, description=None):
    """AddExpandContainerByAttributeRule_un(in_utility_network, template_name, is_active, containers_visibility, container_source, {where_clause}, {description})

        Adds a diagram rule to automatically expand contents related to
        containers during the building of diagrams based on an existing
        template. The containers to expand are filtered out from a given
        utility network source class by attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      containers_visibility (Boolean):
          Specifies whether the containers stay visible after they are
          expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers will be hidden after they are expanded.
      container_source (Feature Class):
          The network container source class that references the containers you
          want to be expanded during the Expand Container rule process.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of containers in this
          class that will be expanded in the generated diagrams. For more
          information on SQL syntax, see the SQL reference for query expressions
          used in ArcGIS help topic.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddExpandContainerRule_un', None)
def AddExpandContainerRule(in_utility_network=None, template_name=None, is_active=None, containers_visibility=None, container_type=None, inverse_source_selection=None, container_sources=None, description=None):
    """AddExpandContainerRule_un(in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, {container_sources;container_sources...}, {description})

        Adds a diagram rule that automatically expands container contents
        during the building of diagrams based on an existing template. This
        rule expands the entire contents of containers in the diagrams.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      containers_visibility (Boolean):
          Specifies whether the containers stay visible after they are
          expanded.

          *  KEEP_VISIBLE-The containers will stay visible after they are
          expanded. This is the default.

          * HIDE-The containers will be hidden after they are expanded.
      container_type (String):
          The geometry type of the source class container the rule must process.

          * JUNCTIONS-The Expand Container rule process will operate on the
          junction container source classes only; that is, only the utility
          network polygon or point container source classes will be processed.

          * EDGES-The Expand Container rule process will operate on the edge
          container source classes only; that is, only the utility network
          linear container source classes will be processed.

          * BOTH-The Expand Container rule process will operate on any container
          source classes regardless of their type; that is, both junction and
          edge types will be processed. This is the default.
      inverse_source_selection (String):
          Determines how the rule processes the specified container source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Containers based on the specified source
          classes will not be expanded, while other containers will be expanded.
          This is the default.

          * INCLUDE_SOURCE_CLASSES-Containers based on the specified source
          classes will be expanded.
      container_sources {Feature Class}:
          The network container source class or classes that must be excluded
          or included during the Expand Container rule execution depending on
          the chosen rule process.With the Exclude Source Classes rule process,
          the rule can be
          configured without specifying any particular network source class; in
          which case, it will expand all containers in the generated diagrams
          regardless of their source class. However, with the Include Source
          Classes rule process, the particular container source class or classes
          to be expanded must be specified.When running the Exclude Source
          Classes option
          (inverse_source_selection=EXCLUDE_SOURCE_CLASSES in Python), the
          containers belonging to those classes will never be expanded in the
          generated diagrams, while network container features that don't belong
          to those classes will be expanded. Conversely, when running the
          Include Source Classes option
          (inverse_source_selection=INCLUDE_SOURCE_CLASSES in Python), the
          containers belonging to those classes will always be expanded in the
          generated diagrams, while network container features that don't belong
          to those classes will not be expanded.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddExpandContainerRule_un(*gp_fixargs((in_utility_network, template_name, is_active, containers_visibility, container_type, inverse_source_selection, container_sources, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddForceDirectedLayout_un', None)
def AddForceDirectedLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None, breakpoint_position=None, edge_display_type=None):
    """AddForceDirectedLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom}, {breakpoint_position}, {edge_display_type})

        Adds the Force Directed Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Force Directed Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm uses a physical analogy to draw graphs by
        considering a graph a force system in which it tries to locally
        minimize the energy. It searches for an equilibrium state of the force
        system-a position for each diagram junction where the total force on
        each junction is zero.This tool is a configuration and administration
        tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          Specifies the number of iterations to process. The default is 20.
      repel_factor {Double}:
          Adds distance between diagram junctions that are close together. The
          larger the repel factor, the greater the distance that will be added
          between nearly overlapping diagram junctions. The default is 1.
      degree_freedom {String}:
          Limits the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area used to move the diagram junctions will be moderate.
      breakpoint_position {Double}:
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is set to Curved edges
          (edges_display_type="CURVED_EDGES" in Python). It is a percentage
          between 15 and 40; 30 by default. With a Break Point Relative Position
          (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          The notion of the from and to junctions above is relative to the tree
          direction; it is unrelated to the topology of the network feature
          edge.This parameter is ignored when Edge Display Type is set to
          Regular
          edges (edges_display_type="REGULAR_EDGES" in Python)
      edge_display_type {String}:
          The type of display for the diagram edges.

          * REGULAR_EDGES-All diagram edges display as straight lines. This is
          the default.

          * CURVED_EDGES-All diagram edges are curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddForceDirectedLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, repel_factor, degree_freedom, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddGridLayout_un', None)
def AddGridLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None):
    """AddGridLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute})

        Adds the Grid Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Grid Layout algorithm
        parameters for any diagram based on that template.This algorithm
        positions diagram junctions relative to a magnetic grid
        that has cell sizes fixed by the Cell Width and Cell Height parameter
        values.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddGridLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, cell_width_absolute, cell_height_absolute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddLinearDispatchLayout_un', None)
def AddLinearDispatchLayout(in_utility_network=None, template_name=None, is_active=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None):
    """AddLinearDispatchLayout_un(in_utility_network, template_name, is_active, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional})

        Adds the Linear Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Linear Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm spaces out diagram junctions that are
        visually
        too close, overlapping, or coincident. It moves junctions along their
        connected edges. The movement along the edges depends on the current
        and relative position of junctions and on the layout parameters.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      junction_placement_type {String}:
          Specifies how the junctions will move.

          * EQUAL_DISTANCE-All junctions with two connected edges will move so
          the distances between them and their two connected junctions are
          equal. This is the default.

          * USER_DEFINE_DISTANCE-All junctions with two connected edges will
          move so there is a minimum distance (Minimum Shift value) between them
          and the other end of the edges they connect to. This occurs at the end
          of the layout execution.

          * ITERATIVE_DISTANCE-All the junctions with two connected edges will
          move slightly  according to the Number of Iterations and Maximum Shift
          parameter values.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect. The default is 2 in the
          units of the diagram's coordinate system. At the time this distance is
          reached, junctions are no longer moved during following iterations.
          This parameter is required when using the ITERATIVE_DISTANCE  junction
          placement type and working with absolute units.
      maximum_shift_proportional {Double}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect. The default is 2. At the
          time this distance is reached, junctions are no longer moved during
          the following iterations. This parameter is required when using the
          ITERATIVE_DISTANCE  junction placement type and working with
          proportional units.
      minimum_shift_absolute {Linear Unit}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2 units in the units of the diagram's
          coordinate system. When this parameter value is too large, the
          junctions with two connections are moved so the distances between each
          moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is required when
          using the USER_DEFINE_DISTANCE  junction placement type and working
          with absolute units.
      minimum_shift_proportional {Double}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2. When this parameter value is too large,
          the junctions with two connections are moved so the distances between
          each moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is expected when
          using the USER_DEFINE_DISTANCE junction placement type and working
          with proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          is required when using the ITERATIVE_DISTANCE  junction placement type
      is_path_preserved {Boolean}:
          Specifies how vertices along edges will be processed:

          *  PRESERVE_PATH-All vertices along the connected edges will be kept,
          and new vertices will be added at the moved junctions' original
          location. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          Specifies whether the leaf junctions-the junctions with one
          connection-can be moved during the algorithm execution:

          *  MOVE_LEAVES-Leaf junctions will be moved.

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Specifies whether the leaf junctions can be expanded:

          *  EXPAND_LEAVES-The leaves can be expanded. The expand_shift_absolute
          value specifies the maximum distance those leaf junctions can be
          expanded away from the junctions to which they connect.

          *  DO_NOT_EXPAND_LEAVES-The leaves cannot be expanded. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          The maximum distance the leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 in the units of the
          diagram's coordinate system unless the specified input network diagram
          is based on a template for which the Linear Dispatch Layout algorithm
          has been configured with another parameter value. At the time this
          distance is reached, leaf nodes are no longer moved during the
          following iterations. This parameter is required when enabling the
          Expand leaves parameter and working with absolute units.
      expand_shift_proportional {Double}:
          The maximum distance the leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 unless the specified
          input network diagram is based on a template for which the Linear
          Dispatch Layout algorithm has been configured with another parameter
          value. At the time this distance is reached, leaf nodes are no longer
          moved during the following iterations. This parameter is required when
          enabling the Expand leaves parameter and working with proportional
          units."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddLinearDispatchLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddMainRingLayout_un', None)
def AddMainRingLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, ring_type=None, is_unit_absolute=None, ring_width_absolute=None, ring_width_proportional=None, ring_height_absolute=None, ring_height_proportional=None, tree_type=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, breakpoint_position=None, edge_display_type=None):
    """AddMainRingLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {ring_type}, {is_unit_absolute}, {ring_width_absolute}, {ring_width_proportional}, {ring_height_absolute}, {ring_height_proportional}, {tree_type}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {breakpoint_position}, {edge_display_type})

        Adds the Main Ring Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Main Ring Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features around the main
        ring and hierarchically lays out the subset of diagram features that
        connect to each diagram junction placed along the main ring.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      ring_type {String}:
          The type of ring.

          * ELLIPSE-The diagram features of the detected main ring will display
          along an ellipse. This is the default.

          * RECTANGLE-The diagram features of the detected main ring will
          display along a rectangle.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      ring_width_absolute {Linear Unit}:
          Specifies the width of the ring. The default is in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      ring_width_proportional {Double}:
          Specifies the width of the ring. The default is 50. This parameter is
          required when using proportional units.
      ring_height_absolute {Linear Unit}:
          Specifies the height of the ring. The default is in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      ring_height_proportional {Double}:
          Specifies the height of the ring. The default is 20. This parameter
          is required when using proportional units.
      tree_type {String}:
          Specifies how the trees coming out of the main ring's junctions will
          be positioned.

          * BOTH_SIDES-Each tree will be displayed along a main line, and its
          related branches will be arranged on both the left and right sides of
          this main line.

          * LEFT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the left side of
          this main line.

          * RIGHT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the right side of
          this main line.

          * SMART_TREE-Each tree will be displayed hierarchically as a smart
          tree. This is the default.
      perpendicular_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the tree direction and belong to the same subtree
          level. The default is 2 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      perpendicular_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the tree direction and belong to the same subtree
          level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          along the tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          along the tree direction. The default is 2. This parameter is required
          when using proportional units.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddMainRingLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, ring_type, is_unit_absolute, ring_width_absolute, ring_width_proportional, ring_height_absolute, ring_height_proportional, tree_type, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddMainlineTreeLayout_un', None)
def AddMainlineTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """AddMainlineTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Adds the Mainline Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Mainline Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the junctions and edges in the input
        network diagram hierarchically along a main line and places its
        related branches on the left side, the right side, or both sides of
        the main line.This tool is a configuration and administration tool
        that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The main line will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The main line will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          Specifies how branches from the main line are relatively placed with
          regard to its direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the main line. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the main
          line.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          main line.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2 in the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2. This parameter
          is required when using proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          main line. It also dictates the spacing between diagram junctions that
          are displayed along the axis parallel to this main line. This
          parameter is required when using absolute units. The default is 2 in
          the units of the diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          main line and diagram junctions that are displayed along the axis
          parallel to this main line. This parameter is expected when using
          proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches
          display.This parameter is deprecated at ArcGIS Pro 2.3. It is
          systematically
          ignored regardless of its value when the edge_display_type is
          specified. However, to maintain compatibility with ArcGIS Pro 2.1, it
          remains enabled when the edge_display_type parameter is not specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddMainlineTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddPartialOverlappingEdgesLayout_un', None)
def AddPartialOverlappingEdgesLayout(in_utility_network=None, template_name=None, is_active=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None):
    """AddPartialOverlappingEdgesLayout_un(in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, {optimize_edges})

        Adds the Partial Overlapping Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Partial
        Overlapping Edges Layout algorithm parameters for any diagram based on
        that template.This layout algorithm detects sets of collinear edges or
        collinear
        portions of edges (edge segments) that can be considered as being
        inside a buffer zone of a given size.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zone in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          Specifies how segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments is optimized in each set
          of collinear segments. This is done by focusing on their connections
          instead of their positions. Segments that cross each other can be
          repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment is
          maintained in the collinear segment set and crossings are preserved.
          This is the default option."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddPartialOverlappingEdgesLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, buffer_width_absolute, offset_absolute, optimize_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRadialTreeLayout_un', None)
def AddRadialTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None):
    """AddRadialTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor})

        Adds the Radial Tree Layout algorithm to the list of the layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Radial Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a radial tree according to the specified radius
        parameters. It works from a root junction that it uses as the circle
        center to arrange the subtrees starting from this root in concentric
        circles, each circle corresponding to one hierarchical level.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter is required when using
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      radius_factor {Double}:
          Represents the multiplicative factor used to increase or decrease the
          radius of each concentric circle. It also represents the distance that
          separates each concentric circle related to a hierarchical level. When
          using a radius factor less than 1, the distance that separates the
          diagram junctions belonging to the (n) hierarchical level and the
          (n+1) hierarchical level progressively decreases. With a factor
          greater than 1, the distance between the hierarchical levels increases
          progressively. The default is 1."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRadialTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceEdgeByAttributeRule_un', None)
def AddReduceEdgeByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None, reconnected_edges_option=None):
    """AddReduceEdgeByAttributeRule_un(in_utility_network, template_name, is_active, network_source, {where_clause}, {description}, {reconnected_edges_option})

        Adds a diagram rule to automatically reduce diagram edges during the
        building of diagrams based on an existing template. This rule can be
        set up to reduce diagram edges by attributes.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      network_source (Feature Class):
          The network edge source class to process during the reduction rule.
          All diagram edges related to network lines that belong to this source
          class are candidates for the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network edges among
          the edges that are candidates for the reduction that will be reduced
          in the diagrams based on the input template. For more information on
          SQL syntax, see the SQL reference for query expressions used in ArcGIS
          help topic.
      description {String}:
          The description of the rule.
      reconnected_edges_option {Boolean}:
          Specifies whether the rule must aggregate the edges that are
          reconnected to the reduction junctions or not.

          * DONT_AGGREGATE_RECONNECTED_EDGES-Any edge connecting a point along
          the edge that is reduced is kept and simply reconnected to the
          reduction junction.

          * AGGREGATE_RECONNECTED_EDGES-Any edge connecting a point along the
          edge that is reduced is replaced by a reduction edge. This reduction
          edge is reconnected to the reduction junction. This is the default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceEdgeByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description, reconnected_edges_option), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionByAttributeRule_un', None)
def AddReduceJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionByAttributeRule_un(in_utility_network, template_name, is_active, junction_source, {where_clause}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. The junctions
        to reduce are queried from a given utility network junction source
        class by attributes according to the number of other junctions they
        are connected to.This tool is a configuration and administration tool
        that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      junction_source (Feature Class):
          The network junction source class to process during the reduction
          rule. All diagram junctions related to network junctions that belong
          to this source class are candidates for the reduction.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of network junctions
          among the junctions that are candidates for the reduction that will be
          reduced in the diagrams based on the input template. For more
          information on SQL syntax, see the SQL reference for query expressions
          used in ArcGIS help topic.
      connectivity_options {String}:
          This parameter allows specifying which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions that have
          two connections or fewer. In this case, the rule executes a specific
          process according to the number of junctions that the junction to
          reduce connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions that have
          three connections or more. In this case, the rule will execute
          upstream traces to determine whether or not the junctions that are
          candidates for the reduction can be reduced.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction that is a candidate
          for the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          that are candidates for the reduction that are unconnected. Each of
          those junctions will be removed.

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction that is a candidate for the
          reduction and connected to a single other junction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions that
          are candidates for the reduction and connected to a single junction.
          Each of those junctions and its incident edge will be reduced onto its
          single connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions that are
          candidates for the reduction and connected to a single junction. This
          is the default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions that is a candidate for the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions that
          are candidates for the reduction and connect two other junctions. Each
          of those junctions and its incident edges will be reduced onto a super
          span edge, the reduction edge. This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions that are
          candidates for the reduction and connect two other junctions.
      edges_attributes {String}:
          The alias of the attributes brought by the edges adjacent to the
          junction that is a candidate for the reduction.The junction will be
          reduced only when all its adjacent edges have
          brought the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReduceJunctionRule_un', None)
def AddReduceJunctionRule(in_utility_network=None, template_name=None, is_active=None, inverse_source_selection=None, junction_source=None, connectivity_options=None, unconnected_junctions=None, one_connected_junction=None, two_connected_junctions=None, edges_attributes=None, description=None):
    """AddReduceJunctionRule_un(in_utility_network, template_name, is_active, inverse_source_selection, {junction_source;junction_source...}, {connectivity_options}, {unconnected_junctions}, {one_connected_junction}, {two_connected_junctions}, {edges_attributes;edges_attributes...}, {description})

        Adds a diagram rule to automatically reduce diagram junctions during
        the building of diagrams based on an existing template. This rule
        reduces junctions based on several utility network junction source
        classes according to the number of other junctions they are connected
        to.This tool is a configuration and administration tool that must be
        run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      inverse_source_selection (String):
          How the rule processes the specified junction source classes.

          * EXCLUDE_SOURCE_CLASSES-The junctions based on the specified source
          classes will not be processed by the Reduce Junction rule, while all
          the other junctions will be.

          * INCLUDE_SOURCE_CLASSES-The junctions based on only the specified
          source classes will be processed by the Reduce Junction rule. This is
          the default.
      junction_source {Feature Class}:
          The junction source class (or classes) that must be excluded or
          included during the Reduce Junction rule execution depending on the
          chosen rule process. With the Include source classes rule process set
          by default, the
          Reduce Junction rule expects one or more network junction source
          classes to process during the rule execution. All diagram junctions
          related to network junctions that belong to those source classes are
          candidates for the reductions. The Reduce Junction rule will process
          the junction source classes in
          the order specified in this list, from the junction class with the
          highest priority-the first class in the list-to the junction class
          with the lowest priority-the last class in the list.With the Exclude
          source classes rule process, the rule can be
          configured without specifying any particular junction source class; in
          that case, it will reduce all junctions in the generated diagrams,
          whatever their source class.
      connectivity_options {String}:
          This parameter allows specifying which kind of reduction the rule
          will process.

          * MAX_2_CONNECTED_JUNCTIONS-The rule will process junctions that have
          two connections or fewer. In this case, the rule executes a specific
          process according to the number of junctions that the junction to
          reduce connects. This is the default.

          * MIN_3_CONNECTED_JUNCTIONS-The rule will process junctions that have
          three connections or more. In this case, the rule will execute
          upstream traces to determine whether or not the junctions that are
          candidates for the reduction can be reduced.
      unconnected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram unconnected junction that is a candidate
          for the reduction is reduced or kept.

          *  REDUCE_UNCONNECTED_JCT-The rule will reduce the diagram junctions
          that are candidates for the reduction that are unconnected. Each of
          those junctions will be removed.

          *  KEEP_UNCONNECTED_JCT-The rule will keep the unconnected diagram
          junctions. This is the default.
      one_connected_junction {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction that is a candidate for the
          reduction and connected to a single other junction is reduced or kept.

          *  REDUCE_JCT_TO_1JCT-The rule will reduce the diagram junctions that
          are candidates for the reduction and connected to a single junction.
          Each of those junctions and its incident edge will be reduced onto its
          single connected junction.

          *  KEEP_JCT_TO_1JCT-The rule will keep the diagram junctions that are
          candidates for the reduction and connected to a single junction. This
          is the default.
      two_connected_junctions {Boolean}:
          This option is available when the rule is configured to run with the
          Maximum two connected junctions connectivity option. It determines
          whether each network diagram junction connected to two different other
          junctions that is a candidate for the reduction is reduced or kept:

          *  REDUCE_JCT_TO_2JCTS-The rule will reduce the diagram junctions that
          are candidates for the reduction and connect two other junctions. Each
          of those junctions and its incident edges will be reduced onto a super
          span edge, the reduction edge. This is the default.

          *  KEEP_JCT_TO_2JCTS-The rule will keep the diagram junctions that are
          candidates for the reduction and connect two other junctions.
      edges_attributes {String}:
          The alias of the attributes brought by the edges adjacent to the
          junction that is a candidate for the reduction.The junction will be
          reduced only when all its adjacent edges have
          brought the same values for each of the specified attribute aliases.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReduceJunctionRule_un(*gp_fixargs((in_utility_network, template_name, is_active, inverse_source_selection, junction_source, connectivity_options, unconnected_junctions, one_connected_junction, two_connected_junctions, edges_attributes, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRelativeMainlineLayout_un', None)
def AddRelativeMainlineLayout(in_utility_network=None, template_name=None, is_active=None, line_attribute=None, mainline_direction=None, offset_between_branches=None, breakpoint_angle=None, type_attribute=None, mainline_values=None, branch_values=None, excluded_values=None, is_compressing=None, compression_ratio=None, minimal_distance=None, alignment_attribute=None, initial_distances=None, length_attribute=None):
    """AddRelativeMainlineLayout_un(in_utility_network, template_name, is_active, line_attribute, {mainline_direction}, {offset_between_branches}, {breakpoint_angle}, {type_attribute}, {mainline_values;mainline_values...}, {branch_values;branch_values...}, {excluded_values;excluded_values...}, {is_compressing}, {compression_ratio}, {minimal_distance}, {alignment_attribute}, {initial_distances}, {length_attribute})

        Adds the Relative Mainline Layout algorithm to the list of layouts to
        be automatically chained at the end of the building of diagrams based
        on a given template. This tool also presets the Relative Mainline
        Layout algorithm parameters for any diagram based on that
        template.This layout arranges the network diagram features in the
        active
        diagram along parallel straight lines, with all the connected edges
        having the same attribute value. It also places the branches from
        those lines, preserving their directions regarding the straight lines
        and the distances proportional to the initial distance and relative to
        each other.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      line_attribute (String):
          The name of the network attribute that will be used to identify the
          lines that comprise the straight lines. This network attribute must
          exist in the utility network line classes. Its values should be the
          same for all the edges that comprise a straight line, for example,
          Line 1, Line 2, and so on
      mainline_direction {String}:
          The direction of the main line

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      offset_between_branches {Linear Unit}:
          The spacing between two adjacent branches along the axis
          perpendicular to the direction of the lines.
      breakpoint_angle {Double}:
          The angle that will be used to position the break point on the
          branches. It is a value between 30 and 90 degrees that is combined
          with the offset_between_branches parameter value to compute this
          position. When the break point angle value is 90 degrees, each branch
          displays orthogonally.
      type_attribute {String}:
          The name of the network attribute that will be used to qualify the
          lines. This network attribute may exist in the utility network line
          classes.The type_attribute and line_attribute network attributes can
          be the
          same.
      mainline_values {Value Table}:
          The type_attribute values that identify the main lines. When such
          values exist, they must be the same for any edge that comprises the
          main lines, regardless of their related utility network feature
          classes.
      branch_values {Value Table}:
          The type_attribute values that identify the branches.
      excluded_values {Value Table}:
          The type_attribute values that identify the edges that must be
          excluded from the straight lines (crossovers or ladders).
      is_compressing {Boolean}:
          Specifies whether the graph will be compressed.

          * USE_COMPRESSION-An additional step is executed at the end of the
          process to reduce the distances between adjacent groups of neighbor
          junctions along the direction while trying to maintain relative
          positioning between these groups. Neighbor junctions are junctions
          that are geographically close to each other without being directly
          connected.

          * DO_NOT_USE_COMPRESSION-Compression will not be used. This is the
          default.
      compression_ratio {Double}:
          A value between 0 and 100 that is applied to the length of any edge
          after subtracting the minimal distance of its length. When
          compression_ratio is 100, the distance between each detected junction
          group is equal to the minimal distance.
      minimal_distance {Linear Unit}:
          The minimal distance between two adjacent groups of neighbor
          junctions. This minimal distance is also used to group neighbor
          junctions regarding their projection along the direction axis. Two
          junctions projected on this axis will belong to the same group when
          the distance between the two projected points is less than this
          distance.
      alignment_attribute {String}:
          The name of the network attribute that will be used to align lines
          that are split. The algorithm aligns the line with the same attribute
          value.
      initial_distances {String}:
          Specifies how the length of the diagram edges will be assessed. This
          length determines the positions of the junctions along the direction.
          The distances between the connected junctions along the direction are
          not equidistant; they are relative to each other and depend on the
          current edge length and the length of the shortest edge.

          * FROM_CURRENT_EDGE_GEOMETRY-The distances will be computed from the
          current edge geometry. This is the default.

          * FROM_ATTRIBUTE_EDGE-The distances will be computed from a given
          attribute that exists on an edge.
      length_attribute {String}:
          The network attribute from which the distances will be computed when
          initial_distances is FROM_ATTRIBUTE_EDGE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRelativeMainlineLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, line_attribute, mainline_direction, offset_between_branches, breakpoint_angle, type_attribute, mainline_values, branch_values, excluded_values, is_compressing, compression_ratio, minimal_distance, alignment_attribute, initial_distances, length_attribute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureByAttributeRule_un', None)
def AddRemoveFeatureByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, description=None):
    """AddRemoveFeatureByAttributeRule_un(in_utility_network, template_name, is_active, network_source, {where_clause}, {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. The features
        to remove are queried from a given utility network source class.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      network_source (Feature Class):
          The network source class to process during the Remove Feature rule.
          All diagram features related to network features that belong to this
          source class are candidates for removal.
      where_clause {SQL Expression}:
          An SQL expression used to select the subset of features among the
          features that are candidates for the removal that will be removed in
          the diagrams based on the input template. For more information on SQL
          syntax, see the SQL reference for query expressions used in ArcGIS
          help topic.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddRemoveFeatureRule_un', None)
def AddRemoveFeatureRule(in_utility_network=None, template_name=None, is_active=None, source_type=None, inverse_source_selection=None, network_source=None, description=None):
    """AddRemoveFeatureRule_un(in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source;network_source..., {description})

        Adds a diagram rule to automatically remove diagram features during
        the building of diagrams based on an existing template. This rule
        removes features based on different utility network source
        classes.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      source_type (String):
          The geometry type of the source class feature the rule must process.

          * JUNCTIONS-Only junction source classes will be processed; that is,
          the utility network polygon or point source classes.

          * EDGES-Only edge source classes will be processed; that is, the
          utility network linear source classes.

          * BOTH-Both junction and edge types will be processed. This is the
          default.
      inverse_source_selection (String):
          Specifies how the rule will process the specified network source
          classes.

          * EXCLUDE_SOURCE_CLASSES-Features based on the specified network
          source classes will not be processed by the Remove Feature rule. while
          other features will be processed.

          * INCLUDE_SOURCE_CLASSES-Features based on the specified network
          source classes will be processed by the Remove Feature rule. This is
          the default.
      network_source (Feature Class):
          The network source class or classes that must be excluded or included
          during the Remove Feature rule execution depending on the chosen rule
          process.By default, with the include source classes rule process, the
          Remove
          Feature rule expects one or more network source classes to process
          during the rule execution. All diagram features related to network
          features that belong to those classes are removed.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddRemoveFeatureRule_un(*gp_fixargs((in_utility_network, template_name, is_active, source_type, inverse_source_selection, network_source, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddReshapeDiagramEdgesLayout_un', None)
def AddReshapeDiagramEdgesLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None, circular_arc_radius=None, circular_arc_position=None):
    """AddReshapeDiagramEdgesLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold}, {circular_arc_radius}, {circular_arc_position})

        Adds the Reshape Diagram Edges Layout algorithm to the list of the
        layouts to be automatically chained at the end of the building of
        diagrams based on a given template. This tool also presets the Reshape
        Diagram Edges Layout algorithm parameters for any diagram based on
        that template.This layout is used to process simple operations on
        vertices along
        edges in network diagrams. It allows you to do the following:

        * Remove all vertices along diagram edges.

        * Reduce some vertices along diagram edges.

        * Square diagram edges with the addition of vertices on edges.

        * Separate diagram edges that overlap.

        * Detect diagram edges that cross each other at right angles and
        reshape their geometries to display a circular arc at the crossing
        locations.
        This tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      reshape_type {String}:
          Specifies how edges will be reshaped.

          * REMOVE_VERTICES-Removes all vertices along any edges in the diagram.

          * SQUARE_EDGES-Inserts vertices along diagram edges so these edges are
          displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Separates edges that connect the same
          origin and extremity junctions when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Removes some or all vertices displayed
          along diagram edges according to the angle that separates the segments
          incident to those vertices.

          * MARK_CROSSING_EDGES-Detects the horizontal and vertical diagram
          edges that cross each other at a right angle in the diagram and
          reshapes one of the crossing edges' geometry to display a circular arc
          at this location.
      is_path_preserved {Boolean}:
          Specifies whether or not the vertices along the edges that are going
          to be squared will be preserved. This parameter is required when
          reshape_type is set to SQUARE_EDGES.

          *  PRESERVE_PATH-The direction of any edge will be considered and
          vertices along that edge will be preserved, from the first vertex to
          the last. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered,
          and the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter is required when
          reshape_type is set to SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the first or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter is required when reshape_type is set to
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          The absolute spacing that will separate two edges. The default is 0.5
          in the units of the diagram's coordinate system. This parameter is
          required when setting reshape_type to SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          The angle formed by the incident segments over which the vertex
          related to these segments is reduced. The wider the angle, the fewer
          vertices are reduced. The default is 160 degrees. This parameter is
          required when setting reshape_type to REDUCE_VERTICES_BY_ANGLE.
      circular_arc_radius {Linear Unit}:
          The radius of the circular arc that will be added at the crossing
          edge locations. The default is 5.
      circular_arc_position {String}:
          Specifies the segment on which the circular arc will be inserted.

          * LEFT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the left
          of the vertical segment.

          * RIGHT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the right
          of the vertical segment.

          * ABOVE_HORIZONTAL_SEGMENT-A circular arc will be placed above the
          horizontal segment.

          * BELOW_HORIZONTAL_SEGMENT-A circular arc will be placed below the
          horizontal segment."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddReshapeDiagramEdgesLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold, circular_arc_radius, circular_arc_position), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSetRootJunctionByAttributeRule_un', None)
def AddSetRootJunctionByAttributeRule(in_utility_network=None, template_name=None, is_active=None, junction_source=None, where_clause=None, description=None):
    """AddSetRootJunctionByAttributeRule_un(in_utility_network, template_name, is_active, junction_source, {where_clause}, {description})

        Adds a diagram rule to automatically flag diagram junctions as root
        junctions during the building of diagrams based on an existing
        template. This rule specifies root junctions based on a particular
        source class and eventually filters using their attributes.This tool
        is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      junction_source (Feature Class):
          The network junction source class to process during the Set Root
          Junction By Attribute rule. All diagram junctions related to network
          features that belong to this source class are candidates for root
          junctions.
      where_clause {SQL Expression}:
          An optional SQL expression used to filter out the expected root
          junctions among all the junction candidates for root junctions for the
          diagrams based on the input template. For more information on SQL
          syntax, see SQL reference for query expressions used in ArcGIS.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSetRootJunctionByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, junction_source, where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSetStartingPointByAttributeRule_un', None)
def AddSetStartingPointByAttributeRule(in_utility_network=None, template_name=None, is_active=None, network_source=None, where_clause=None, junction_terminals=None, description=None):
    """AddSetStartingPointByAttributeRule_un(in_utility_network, template_name, is_active, network_source, {where_clause}, {junction_terminals;junction_terminals...}, {description})

        Adds a diagram rule to a diagram template to set diagram features
        currently represented in the diagrams as starting points for tracing
        rules. The diagram features are queried from a given utility network
        source class and can be filtered by their attributes.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      network_source (Feature Class):
          The network source class that references the features that will be
          set as starting points.
      where_clause {SQL Expression}:
          An SQL expression to select the subset of features in the source
          class that will be set as starting points. For more information on SQL
          syntax, see SQL reference for query expressions used in ArcGIS.
      junction_terminals {Long}:
          The terminal IDs that will be considered to start tracing if the
          network source class references junctions with terminals.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSetStartingPointByAttributeRule_un(*gp_fixargs((in_utility_network, template_name, is_active, network_source, where_clause, junction_terminals, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSmartTreeLayout_un', None)
def AddSmartTreeLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """AddSmartTreeLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Adds the Smart Tree Layout algorithm to the list of the layouts to be
        automatically chained at the end of the building of diagrams based on
        a given template. This tool also presets the Smart Tree Layout
        algorithm parameters for any diagram based on that template.This
        layout algorithm arranges the diagram features hierarchically and
        places them in a smart tree according to the direction and spacing
        distances specified.This tool is a configuration and administration
        tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from left to right. This
          is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from right to left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from bottom to top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from top to bottom.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      subtree_absolute {Linear Unit}:
          Determines the spacing between two neighboring subtrees; that is, the
          spacing between diagram junctions that are displayed perpendicular to
          the smart tree direction and belong to a different subtree. The
          default is in the units of the diagram's coordinate system. This
          parameter is required when using absolute units.
      subtree_proportional {Double}:
          Determines the spacing between two neighboring subtrees; that is, the
          spacing between diagram junctions that are displayed perpendicular to
          the smart tree direction and belong to a different subtree. The
          default is 2. This parameter is required when using proportional
          units.
      perpendicular_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2 in the units of the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2. This parameter is
          required when using proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches
          display.This parameter is deprecated at ArcGIS Pro 2.3. It is
          systematically
          ignored regardless of its value when the edge_display_type is
          specified. However, to maintain compatibility with ArcGIS Pro 2.1, it
          remains enabled when the edge_display_type parameter is not specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSmartTreeLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSpatialDispatchLayout_un', None)
def AddSpatialDispatchLayout(in_utility_network=None, template_name=None, is_active=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None):
    """AddSpatialDispatchLayout_un(in_utility_network, template_name, is_active, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor})

        Adds the Spatial Dispatch Layout algorithm to the list of the layouts
        to be automatically chained at the end of the building of diagrams
        based on a given template. This tool also presets the Spatial Dispatch
        Layout algorithm parameters for any diagram based on that
        template.This layout algorithm progressively separates diagram
        junctions that
        are visibly close to overlapping according to their current positions
        and to the shift factor specified.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the layout algorithm is automatically executed when
          generating diagrams based on the specified template.

          * ACTIVE-The added layout algorithm will automatically run during the
          generation of any diagram that is based on the template_name
          parameter. This is the default.The parameter values specified for the
          layout algorithm are used to run the layout during diagram generation.
          They are also loaded by default when the algorithm is to be run on any
          diagram based on the input template.

          * INACTIVE-All the parameter values currently specified for the added
          layout algorithm will be loaded by default when the algorithm is to be
          run on any diagram based on the input template.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          Increases the diagram junctions' displacement for junctions that are
          very close together. The larger the shift factor, the larger the
          separation between the diagram junctions that almost overlap. The
          default is 2."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSpatialDispatchLayout_un(*gp_fixargs((in_utility_network, template_name, is_active, are_containers_preserved, iterations_number, maximum_shift_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddSpatialQueryRule_un', None)
def AddSpatialQueryRule(in_utility_network=None, template_name=None, is_active=None, added_features=None, overlap_type=None, existing_features=None, search_distance=None, added_where_clause=None, existing_where_clause=None, description=None):
    """AddSpatialQueryRule_un(in_utility_network, template_name, is_active, added_features, overlap_type, existing_features, {search_distance}, {added_where_clause}, {existing_where_clause}, {description})

        Adds a diagram rule that automatically appends new utility network
        features to the diagrams based on their location relative to the
        utility network features currently represented in the diagram.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      added_features (Feature Class):
          The source feature class to which you want to add features
      overlap_type (String):
          The spatial relationship to be evaluated.

          *  INTERSECT-The features in the added_features source feature class
          will be appended to the diagram if they intersect one of the
          existing_features. This is the default.

          *  WITHIN_A_DISTANCE-The features in the added_features source
          feature class will be appended to the diagram if they are within the
          specified distance (using Euclidean distance) of one of the
          existing_features. Use the search_distance parameter to specify the
          distance.

          *  CONTAINS-The features in the added_features source feature class
          will be appended to the diagram if they contain one of the
          existing_features.

          *  WITHIN-The features in the added_features source feature class
          will be appended to the diagram if they are within existing_features.

          *  BOUNDARY_TOUCHES-The features in the added_features source feature
          class will be appended to the diagram if they have a boundary that
          touches one of the existing_features. When the existing_features are
          lines or polygons, the boundary of the added_features can only touch
          the boundary of one of the existing_features, and no part of the input
          feature can cross the boundary of one of the existing_features.

          *  SHARE_A_LINE_SEGMENT_WITH-The features in the added_features
          source feature class will be appended to the diagram if they share a
          line segment with one of the existing_features. The added and existing
          features must be line or polygon.

          *  CROSSED_BY_THE_OUTLINE_OF-The features in the added_features
          source feature class will be appended to the diagram if they are
          crossed by the outline of one of the existing_features. The added and
          existing features must be lines or polygons. If polygons are used for
          the existing_features, the polygon's boundary (line) will be used.
          Lines that cross at a point will be selected; lines that share a line
          segment will not.
      existing_features (Feature Class):
          The source feature class of the features existing in the diagram from
          which the spatial query will execute.
      search_distance {Linear Unit}:
          This parameter is only valid if the overlap_type parameter is set to
          INTERSECT, WITHIN_A_DISTANCE, CONTAINS, or WITHIN
      added_where_clause {SQL Expression}:
          The SQL query that will be used to filter the features to be added to
          the diagram. Without an SQL query, the features based on the specified
          source class that are spatially related to the specified existing
          features will be appended to the diagram.
      existing_where_clause {SQL Expression}:
          The SQL query that will be used to filter the features existing in
          the diagram. Without an SQL query, the features based on the specified
          source class that exist in the diagram will be considered.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddSpatialQueryRule_un(*gp_fixargs((in_utility_network, template_name, is_active, added_features, overlap_type, existing_features, search_distance, added_where_clause, existing_where_clause, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStartIterationRule_un', None)
def AddStartIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStartIterationRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the beginning of a rule sequence
        during the building of diagrams based on an existing template.This
        tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStartIterationRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStopIterationRule_un', None)
def AddStopIterationRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStopIterationRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to specify the end of a rule sequence during the
        building of diagrams based on an existing template.This tool is a
        configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStopIterationRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddStructuralAttachmentsRule_un', None)
def AddStructuralAttachmentsRule(in_utility_network=None, template_name=None, is_active=None, description=None):
    """AddStructuralAttachmentsRule_un(in_utility_network, template_name, is_active, {description})

        Adds a diagram rule to automatically represent structural attachments
        during the building of diagrams based on an existing template. This
        rule processes structural attachment associations for which both the
        attached feature and structure feature are currently represented in
        the diagrams.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddStructuralAttachmentsRule_un(*gp_fixargs((in_utility_network, template_name, is_active, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AddTraceRule_un', None)
def AddTraceRule(in_utility_network=None, template_name=None, is_active=None, trace_type=None, domain_network=None, tier=None, target_tier=None, include_structures=None, include_barriers=None, condition_barriers=None, function_barriers=None, traversability_scope=None, filter_barriers=None, filter_function_barriers=None, filter_scope=None, filter_bitset_network_attribute_name=None, filter_nearest=None, nearest_count=None, nearest_cost_network_attribute=None, nearest_categories=None, nearest_assets=None, propagators=None, description=None):
    """AddTraceRule_un(in_utility_network, template_name, is_active, trace_type, {domain_network}, {tier}, {target_tier}, {include_structures}, {include_barriers}, {condition_barriers;condition_barriers...}, {function_barriers;function_barriers...}, {traversability_scope}, {filter_barriers;filter_barriers...}, {filter_function_barriers;filter_function_barriers...}, {filter_scope}, {filter_bitset_network_attribute_name}, {filter_nearest}, {nearest_count}, {nearest_cost_network_attribute}, {nearest_categories;nearest_categories...}, {nearest_assets;nearest_assets...}, {propagators;propagators...}, {description})

        Adds a diagram rule to automatically execute a trace on the network
        during the building of diagrams based on an existing template. The
        resulting traced network features are used to build the diagram
        content.This tool is a configuration and administration tool that must
        be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template to modify.
      is_active (Boolean):
          Specifies whether the rule is enabled when generating and updating
          diagrams based on the specified template.

          * ACTIVE-The added rule becomes enabled during the generation and
          update of any diagrams based on the input template. This is the
          default.

          * INACTIVE-The added rule is not enabled during the generation or
          update of any diagrams based on the input template.
      trace_type (String):
          The type of trace the rule must perform to build the diagram content.

          * CONNECTED-A connected trace is executed from the network features
          currently represented in the diagram when the rule starts and spans
          outward along connected features. This is the default.

          * SUBNETWORK-A subnetwork trace is executed from the network features
          currently represented in the diagram when the rule starts and spans
          outward along connected features to find sources or sinks from which
          it spans outward along the related subnetwork.

          * UPSTREAM-An upstream trace is executed from the network features
          currently represented in the diagram when the rule starts to discover
          features upstream.

          * DOWNSTREAM-A downstream trace is executed from the network features
          currently represented in the diagram when the rule starts to discover
          features downstream.
      domain_network {String}:
          The name of the domain network where the trace is run. This parameter
          is needed when running the subnetwork, upstream, and downstream trace
          types.
      tier {String}:
          The name of the tier where the trace starts. This parameter is
          optional when running the connected trace type; it is required when
          running the subnetwork, upstream, and downstream trace types.
      target_tier {String}:
          The name of the target tier to which the input tier flows.  If this
          parameter is missing for upstream and downstream traces, those traces
          will stop when they reach the boundary of the starting subnetwork.
          This parameter can be used to allow these traces to continue either
          farther up or farther down the hierarchy.
      include_structures {Boolean}:
          Defines whether structure features are included in the trace results.

          * INCLUDE_STRUCTURES-Structure features are included in the trace
          results.

          * EXCLUDE_STRUCTURES-Structure features are not included in the trace
          results. This is the default.
      include_barriers {Boolean}:
          Defines whether the traversability barrier features are included in
          the trace results. Traversability barriers are optional even if they
          have been preset in the subnetwork definition. This parameter does not
          apply to device features with terminals.

          * INCLUDE_BARRIERS-Traversability barrier features are included in the
          trace results. This is the default.

          * EXCLUDE_BARRIERS-Traversability barrier features are not included in
          the trace results.
      condition_barriers {Value Table}:
          Condition barrier components are as follows:

          * Name-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value for the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The condition barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The condition barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The condition barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      function_barriers {Value Table}:
          Function barrier components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, and the trace
          continues.
          The function barrier function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The function barrier operator value options are:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The function barrier Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      traversability_scope {String}:
          The type of traversability to enforce. Traversability scope dictates
          whether traversability is enforced at junctions, edges, or both. For
          example, if a condition barrier is defined to stop the trace if Device
          Status is equal to Open and traversability scope is set to edges only,
          then even if the trace encounters an open device, the trace would not
          stop because Device Status is only applicable to junctions. In other
          words, this parameter indicates to the trace whether to ignore
          junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply traversability to both junctions and
          edges. This is the default.

          * JUNCTIONS_ONLY-Apply traversability to only junctions.

          * EDGES_ONLY-Apply traversability to only edges.
      filter_barriers {Value Table}:
          Specifies when a trace should stop for a specific category or network
          attribute. For example, stop a trace at features that have a life
          cycle status attribute that is equal to a certain value. This
          parameter is used to set a terminator based on a value of a network
          attribute that is defined in the system. If using more than one
          attribute, you can use the Combine Using option to define an And or an
          Or condition.Filter barrier components are as follows:

          * Name-Choose to filter by category or any network attribute defined
          in the system.

          * Operator-Choose from a number of different operators.

          * Type-Choose a specific value or network attribute from the value
          that is specified in the name parameter.

          * Value-Provide a specific value of the input attribute type that
          would cause termination based on the operator value.

          * Combine Using-Set this value if you have multiple attributes to add.
          You can choose to combine them using an And or an Or condition.
          The filter barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES NOT INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INLCUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter barriers Type value options are as follows:

          * SPECIFIC_VALUE-Filter by a specific value.

          * NETWORK_ATTRIBUTE-Filter by a network attribute.
          The filter barriers Combine Using value options are as follows:

          * AND-Combine the condition barriers.

          * OR-Use if either condition barrier is met.
      filter_function_barriers {Value Table}:
          Filters the results of the trace for a specific category.Filter
          function barriers components are as follows:

          * Function-Choose from a number of different calculation functions.

          * Attribute-Choose to filter by any network attribute defined in the
          system.

          * Operator-Choose from a number of different operators.

          * Value-Provide a specific value for the input attribute type that, if
          discovered, will cause the termination.

          * Use Local Values-Calculates values in each direction as opposed to
          an overall global value. For example, a function barrier that is
          calculating the sum of Shape length where the trace terminates if the
          value is greater than or equal to 4. In the global case, after you
          have traversed two edges with a value of 2, you will have already
          reached a shape length sum of 4, so the trace stops. If local values
          are used, the local values along each path change, or the trace
          continues.
          The filter function barriers function value options are as follows:

          * AVERAGE-The average of the input values.

          * COUNT-The number of features.

          * MAX-The maximum of the input values.

          * MIN-The minimum of the input values.

          * ADD-The sum of the values.

          * SUBTRACT-The difference between the values. Subnetwork controllers
          and loops trace types do not support the subtract function.
          The filter function barriers operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          The filter function barriers Use Local Values options are as follows:

          * TRUE-Use local values.

          * FALSE-Use global values. This is the default.
      filter_scope {String}:
          Determines whether the filter for a specific category is enforced at
          junctions, edges, or both. For example, if a filter barrier is defined
          to stop the trace if Device Status is equal to Open and traversability
          scope is set to edges only, then even if the trace encounters an open
          device, the trace will not stop because Device Status is only
          applicable to junctions. In other words, this parameter indicates to
          the trace whether to ignore junctions, edges, or both.

          * BOTH_JUNCTIONS_AND_EDGES-Apply filter to both junctions and edges.
          This is the default.

          * JUNCTIONS_ONLY-Apply filter to only junctions.

          * EDGES_ONLY-Apply filter to only edges.
      filter_bitset_network_attribute_name {String}:
          The name of the network attribute that can be used to filter by
          bitset. This parameter is only applicable to upstream, downstream, and
          loops trace types. This parameter can be used to add special logic
          during a trace so the trace is more reflective of real world
          scenarios. For example, for a loops trace, the Phases current network
          attribute can determine if the loop is a true electrical loop (the
          same phase is energized all around the loop, that is, A) and return
          only real electrical loops for the trace results. An example for an
          upstream trace is when tracing an electric distribution network,
          specify a Phases current network attribute, and the trace results will
          only include valid paths that are the specified in the network
          attribute, not all paths.
      filter_nearest {Boolean}:
          Returns a number of features of a certain type within a given
          distance by using the k-nearest neighbors algorithm. When this
          parameter is used, you can specify a count and a cost as well as a
          collection of categories, an asset type, or both.

          * FILTER_BY_NEAREST-Use k-nearest neighbors to return a number of
          features as specified in the nearest_count,
          nearest_cost_network_attribute, nearest_categories, or nearest_assets
          parameter.

          * DO_NOT_FILTER-Do not filter results using k-nearest neighbors. This
          is the default.
      nearest_count {Long}:
          When filter_nearest is True,you can use this parameter to specify the
          number of features to be returned, for example, 4.
      nearest_cost_network_attribute {String}:
          When filter_nearest is True, you can use this parameter to specify the
          numeric network attribute that will be used to calculate nearness,
          cost, or distance-for example,  Shape length.
      nearest_categories {String}:
          When filter_nearest is True, you can use this parameter to specify the
          categories that will be returned-for example, Protective.
      nearest_assets {String}:
          When filter_nearest is True, you can use this parameter to specify the
          asset groups and asset types that will be returned-for example,
          ElectricDistributionDevice/Transformer/Step Down.
      propagators {Value Table}:
          The propagators function value options are as follows:

          * PROPAGATED_BITWISE_AND-Compare the values from one feature to the
          next.

          * PROPAGATED_MIN-Get the minimum value.

          * PROPAGATED_MAX-Get the maximum value.
          The propagators operator value options are as follows:

          * IS_EQUAL_TO-The attribute is equal to the value.

          * DOES_NOT_EQUAL-The attribute is not equal to the value.

          * IS_GREATER_THAN-The attribute is greater than the value.

          * IS_GREATER_THAN_OR_EQUAL_TO-The attribute is greater than or equal
          to the value.

          * IS_LESS_THAN-The attribute is less than the value.

          * IS_LESS_THAN_OR_EQUAL_TO-The attribute is less than or equal to the
          value.

          * INCLUDES_THE_VALUES-A bitwise AND operation where all bits in the
          value are present in the attribute (bitwise AND == value).

          * DOES_NOT_INCLUDE_THE_VALUES-A bitwise AND operation where not all of
          the bits in the value are present in the attribute (bitwise AND !=
          value).

          * INCLUDES_ANY-A bitwise AND operation where at least one bit in the
          value is present in the attribute (bitwise AND == True).

          * DOES_NOT_INCLUDE_ANY-A bitwise AND operation where none of the bits
          in the value are present in the attribute (bitwise AND == False).
          This parameter is only available via Python.
      description {String}:
          The description of the rule."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AddTraceRule_un(*gp_fixargs((in_utility_network, template_name, is_active, trace_type, domain_network, tier, target_tier, include_structures, include_barriers, condition_barriers, function_barriers, traversability_scope, filter_barriers, filter_function_barriers, filter_scope, filter_bitset_network_attribute_name, filter_nearest, nearest_count, nearest_cost_network_attribute, nearest_categories, nearest_assets, propagators, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('AlterDiagramTemplate_un', None)
def AlterDiagramTemplate(in_utility_network=None, template_name=None, out_name=None, is_default_template=None, are_rules_and_layouts_removed=None, are_vertices_kept=None, container_margin=None, is_diagram_storage_enabled=None, is_diagram_extension_enabled=None, description=None):
    """AlterDiagramTemplate_un(in_utility_network, template_name, {out_name}, {is_default_template}, {are_rules_and_layouts_removed}, {are_vertices_kept}, {container_margin}, {is_diagram_storage_enabled}, {is_diagram_extension_enabled}, {description})

        Alters the properties of a diagram template, for example, its name,
        how it handles vertices along input utility network edges, whether the
        related diagrams can be stored or extended, the margin between
        containers and their contents in these diagrams, and the removal of
        its rules and layouts definition.This tool is a configuration and
        administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network of the diagram template to alter.
      template_name (String):
          The name of the diagram template to alter.
      out_name {String}:
          The new name of the template.
      is_default_template {Boolean}:
          Specifies the default status of the template.

          *  DEFAULT_TEMPLATE-The input diagram template will be the default
          template.

          *  NOT_DEFAULT_TEMPLATE-The input diagram template will not be the
          default template. This is the default.
          The default template is the one used when generating a diagram if a
          template is not specified.
      are_rules_and_layouts_removed {Boolean}:
          Specifies whether the template rules and layouts definition will be
          removed.

          *  REMOVE_RULES_AND_LAYOUTS-The rules and layouts definition related
          to the input diagram template will be removed.

          *  DO_NOT_REMOVE_RULES_AND_LAYOUTS-The rules and layouts definition
          related to the input diagram template will not be removed. This is the
          default.
      are_vertices_kept {Boolean}:
          Specifies how vertices along the GIS edges will be managed in the
          diagrams based on this template.

          *  KEEP_VERTICES-All vertices that display along GIS edges will be
          preserved on the associated edges in each network diagram based on
          this template.

          *  DO_NOT_KEEP_VERTICES-Diagram edges will be drawn as straight lines
          between their connected junctions. This is the default.
      container_margin {Linear Unit}:
          The minimum distance between the center of any junctions inside the
          container and the container border.
      is_diagram_storage_enabled {Boolean}:
          Specifies whether the diagrams based on this template can be stored.

          *  ENABLE_DIAGRAM_STORAGE-The diagrams based on this template can be
          stored. This is the default.

          *  DISABLE_DIAGRAM_STORAGE-The diagrams based on this template cannot
          be stored.
      is_diagram_extension_enabled {Boolean}:
          Specifies whether the diagrams based on this template can be extended.

          *  ENABLE_DIAGRAM_EXTENSION-The diagrams based on this template can be
          extended by connectivity, traversability, containment, or attachment.

          *  DISABLE_DIAGRAM_EXTENSION-The diagrams based on this template
          cannot be extended. This is the default.
      description {String}:
          The description of the template."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.AlterDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name, out_name, is_default_template, are_rules_and_layouts_removed, are_vertices_kept, container_margin, is_diagram_storage_enabled, is_diagram_extension_enabled, description), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('CreateDiagramLayerDefinition_un', None)
def CreateDiagramLayerDefinition(in_utility_network=None, template_name=None, system_junctions=None, connectivity_associations=None, structural_attachments=None, reduction_edges=None, point_subLayers=None, polygon_subLayers=None):
    """CreateDiagramLayerDefinition_un(in_utility_network, template_name, {system_junctions}, {connectivity_associations}, {structural_attachments}, {reduction_edges}, {point_subLayers;point_subLayers...}, {polygon_subLayers;polygon_subLayers...})

        Creates a diagram layer definition for the input diagram template
        considering the settings of the network feature layers present in the
        active map.This tool allows the following:

        * Import the appearance and labeling settings configured on each
        feature layer present in the active map when those layers are related
        to the utility network layer specified in input.

        * Control the set of extra layers that are created by default to
        represent pure schematic features-for example, reduction edges,
        connectivity associations, and structural attachments-when those
        layers have no meaning for your template.
        This tool is a configuration and administration tool that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network Layer):
          The utility network layer in the active map.
      template_name (String):
          The name of the diagram template to modify.
      system_junctions {Boolean}:
          Specifies whether or not system junctions are represented in the
          diagrams based on the specified template.

          *  SHOW-The diagram layer will include a System Junctions sublayer to
          represent the system junctions in the diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the system junctions in the diagrams.
      connectivity_associations {Boolean}:
          Specifies whether or not connectivity associations are represented in
          the diagrams based on the specified template.

          *  SHOW-The diagram layer will include a Connectivity Associations
          sublayer to represent the connectivity associations in the diagrams.
          This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the connectivity associations in the diagrams.
      structural_attachments {Boolean}:
          Specifies whether or not structural attachment associations are
          represented in the diagrams based on the specified template.

          *  SHOW-The diagram layer will include a Structural Attachments
          sublayer to represent the  structural attachment associations in the
          diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the structural attachment associations in the diagrams.
      reduction_edges {Boolean}:
          Specifies whether or not reduction edges are represented in the
          diagrams based on the specified template.

          *  SHOW-The diagram layer will include a Reduction Edges sublayer to
          represent the reduction edges in the diagrams. This is the default.

          *  HIDE-No sublayer will exist under the diagram layer to represent
          the reduction edges in the diagrams.
      point_subLayers {Value Table}:
          The sublayers that will be added to represent container polygon or
          line network features as point features in the diagrams.The Subtype
          Layer column is used as follows:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default.
      polygon_subLayers {Value Table}:
          The sublayers that will be added to represent container point network
          features as polygon features in the diagrams.The Subtype Layer column
          is used as follows:

          * True-The layer will be created with subtype group layers.

          * False-The layer will be created as a simple layer. This is the
          default."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.CreateDiagramLayerDefinition_un(*gp_fixargs((in_utility_network, template_name, system_junctions, connectivity_associations, structural_attachments, reduction_edges, point_subLayers, polygon_subLayers), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('DeleteDiagramTemplate_un', None)
def DeleteDiagramTemplate(in_utility_network=None, template_name=None):
    """DeleteDiagramTemplate_un(in_utility_network, template_name)

        Deletes a diagram template and all diagrams  based on that
        template.This tool is a configuration and administration tool that
        must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network related to the diagram template to delete.
      template_name (String):
          The name of the diagram template to delete."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.DeleteDiagramTemplate_un(*gp_fixargs((in_utility_network, template_name), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramLayerDefinition_un', None)
def ExportDiagramLayerDefinition(in_network_diagram_layer=None, out_ndld_file=None):
    """ExportDiagramLayerDefinition_un(in_network_diagram_layer, out_ndld_file)

        Exports the diagram layer definition currently set up for the input
        diagram layer into a diagram layer definition file (.ndld).

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram layer which layer definition will be exported.

     OUTPUTS:
      out_ndld_file (File):
          The network diagram layer definition file (.ndld) to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramLayerDefinition_un(*gp_fixargs((in_network_diagram_layer, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ExportDiagramTemplateDefinitions_un', None)
def ExportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, out_ndbd_file=None, out_ndld_file=None):
    """ExportDiagramTemplateDefinitions_un(in_utility_network, template_name, {out_ndbd_file}, {out_ndld_file})

        Exports the network diagram rules and layouts definition and the
        network diagram layer definition to .ndbd and .ndld files.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template definition to
          export.
      template_name (String):
          The name of the diagram template with definitions to be exported.

     OUTPUTS:
      out_ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to be
          created.
      out_ndld_file {File}:
          The network diagram layer definition file (.ndld) to be created."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ExportDiagramTemplateDefinitions_un(*gp_fixargs((in_utility_network, template_name, out_ndbd_file, out_ndld_file), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('GetDiagramTemplateNames_un', None)
def GetDiagramTemplateNames(in_utility_network=None):
    """GetDiagramTemplateNames_un(in_utility_network)

        Returns the names of all diagram templates related to a utility
        network.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network to which the diagram template names are related."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.GetDiagramTemplateNames_un(*gp_fixargs((in_utility_network,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ImportDiagramTemplateDefinitions_un', None)
def ImportDiagramTemplateDefinitions(in_utility_network=None, template_name=None, ndbd_file=None, ndld_file=None):
    """ImportDiagramTemplateDefinitions_un(in_utility_network, template_name, {ndbd_file}, {ndld_file})

        Imports a network diagram rules and layouts definition file (.ndbd),
        network diagram layer definition file (.ndld), or both into an
        existing template.This tool is a configuration and administration tool
        that must be run
        by the database owner of the utility network through a direct
        connection to the default version. In addition to that requirement,
        the connected portal account must be the owner of the utility network
        to perform this operation. This essentially forms two-factor
        authentication.

     INPUTS:
      in_utility_network (Utility Network):
          The utility network referencing the diagram template to modify.
      template_name (String):
          The name of the diagram template onto which the definition will be
          imported.
      ndbd_file {File}:
          The network diagram rules and layouts definition file (.ndbd) to
          import.Such a file results from the execution of the Export Diagram
          Template
          Definitions tool on an existing template.At least one of the two
          definition file input parameters needs to be
          completed; that is, either the network diagram rules and layouts
          definition file (.ndbd) or the network diagram layer definition file
          (.ndld) needs to be completed.
      ndld_file {File}:
          The network diagram layer definition file (.ndld) to import.Such a
          file results from the execution of the Export Diagram Template
          Definitions or Export Diagram Layer Definition geoprocessing tools on
          an existing template.At least one of the two definition file input
          parameters needs to be
          completed; that is, either the network diagram rules and layouts
          definition file (.ndbd) or the network diagram layer definition file
          (.ndld) needs to be completed."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ImportDiagramTemplateDefinitions_un(*gp_fixargs((in_utility_network, template_name, ndbd_file, ndld_file), True)))
        return retval
    except Exception as e:
        raise e


# Network Diagrams\Layout toolset
@gptooldoc('ApplyAngleDirectedLayout_un', None)
def ApplyAngleDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, number_of_directions=None):
    """ApplyAngleDirectedLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {number_of_directions})

        Moves a diagram's edges in specified alignment directions.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 1.
      number_of_directions {String}:
          The number of directions that must be used to align the diagram edges
          and their connected junctions.

          * TWELVE_DIRECTIONS-The edges will move so they progressively approach
          one of the 12 axes, starting with the edge's origin junction and
          inclined at 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330, or 360
          degrees.

          * EIGHT_DIRECTIONS-The edges will move so they progressively approach
          one of the 8 axes, starting with the edge's origin junction and
          inclined at 45, 90, 135, 180, 225, 270, 315, or 360 degrees. This is
          the default.

          * FOUR_DIRECTIONS-The edges will move so they progressively approach
          one of the 4 axes, starting with the edge's origin junction and
          inclined at 90, 180, 270, or 360 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyAngleDirectedLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, number_of_directions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyCompressionLayout_un', None)
def ApplyCompressionLayout(in_network_diagram_layer=None, are_containers_preserved=None, grouping_distance_absolute=None, vertices_removal_rule=None):
    """ApplyCompressionLayout_un(in_network_diagram_layer, {are_containers_preserved}, {grouping_distance_absolute}, {vertices_removal_rule})

        Compresses the diagram features toward the middle of the diagram.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the Compression layout
          algorithm.

          * PRESERVE_CONTAINERS-The Compression layout algorithm executes on
          the top graph of the diagram so containers are preserved. This is the
          default.

          * IGNORE_CONTAINERS-The Compression layout algorithm executes on both
          content and noncontent features in the diagram.
      grouping_distance_absolute {Linear Unit}:
          The grouping distance is used to determine whether two connected
          junctions are close enough to be considered part of the same junctions
          group. A junctions group represents many junctions that are moved as a
          group during execution. The group may contain both junctions and
          containers. To group two junctions together, they must also be
          connected in the diagram by an edge. The default is 20 units in the
          diagram's coordinate system.
      vertices_removal_rule {String}:
          How vertices along edges in the diagram will be processed.

          * ALL-All vertices on all edges will be removed from the diagram.

          * OUTER-Any edge vertices that are within the detected junctions'
          groups will be maintained, while edge vertices that are outside will
          be removed.When there are containers in the diagram that have edges
          that intersect the container polygons, a vertex is added at the
          intersection of the edge and container polygon. This is the default.

          * OUTER_EXCEPT_FIRST-Any edge vertices that are within the detected
          junctions' groups will be maintained, while edge vertices that are
          outside will be removed.When there are containers in the diagram that
          have edges that intersect the container polygons, the first (or last)
          outside vertex is preserved on edges that intersect a container
          polygon. A vertex is automatically inserted at the intersection of the
          edges and container polygons."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyCompressionLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, grouping_distance_absolute, vertices_removal_rule), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyForceDirectedLayout_un', None)
def ApplyForceDirectedLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, repel_factor=None, degree_freedom=None, breakpoint_position=None, edge_display_type=None):
    """ApplyForceDirectedLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {repel_factor}, {degree_freedom}, {breakpoint_position}, {edge_display_type})

        Emphasizes loops contained in a network diagram.If you have an open
        edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          Specifies the number of iterations to process. The default is 20.
      repel_factor {Double}:
          Adds distance between diagram junctions that are close together. The
          larger the repel factor, the greater the distance that will be added
          between nearly overlapping diagram junctions. The default is 1.
      degree_freedom {String}:
          Limits the area used to move the diagram junctions during each
          algorithm iteration.

          * LOW-The area used to move the diagram junctions will be very
          limited. This is the default.

          * HIGH-The area used to move the diagram junctions will be very large.

          * MEDIUM-The area used to move the diagram junctions will be moderate.
      breakpoint_position {Double}:
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when Edge Display Type is set to Curved edges
          (edges_display_type="CURVED_EDGES" in Python). It is a percentage
          between 15 and 40; 30 by default. With a Break Point Relative Position
          (%) value of N between 15 and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment

          The notion of the from and to junctions above is relative to the tree
          direction; it is unrelated to the topology of the network feature
          edge.This parameter is ignored when Edge Display Type is set to
          Regular
          edges (edges_display_type="REGULAR_EDGES" in Python)
      edge_display_type {String}:
          The type of display for the diagram edges.

          * REGULAR_EDGES-All diagram edges display as straight lines. This is
          the default.

          * CURVED_EDGES-All diagram edges are curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyForceDirectedLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, repel_factor, degree_freedom, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGeoPositionsLayout_un', None)
def ApplyGeoPositionsLayout(in_network_diagram_layer=None, restore_edges_geo_positions=None):
    """ApplyGeoPositionsLayout_un(in_network_diagram_layer, {restore_edges_geo_positions})

        Moves each diagram junction and edge feature so they match the
        geographical positions of the associated network features.If you have
        an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      restore_edges_geo_positions {Boolean}:
          Indicates whether or not diagram edges will be restored to the
          geographic position of their vertices:

          *  RESTORE_EDGES_GEO_POSITIONS-Vertices along diagram edges will be
          restored when possible, moving them to match the geographic positions
          of the network features. This is the default.

          *  DO_NOT_RESTORE_EDGES_GEO_POSITIONS-Vertices along diagram edges
          will not be restored. They will appear as straight lines between their
          connecting junctions."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGeoPositionsLayout_un(*gp_fixargs((in_network_diagram_layer, restore_edges_geo_positions), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyGridLayout_un', None)
def ApplyGridLayout(in_network_diagram_layer=None, are_containers_preserved=None, cell_width_absolute=None, cell_height_absolute=None):
    """ApplyGridLayout_un(in_network_diagram_layer, {are_containers_preserved}, {cell_width_absolute}, {cell_height_absolute})

        Positions diagram junctions relative to a predefined magnetic grid.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      cell_width_absolute {Linear Unit}:
          The width of each grid cell. The default is 2 in the units of the
          diagram's coordinate system.
      cell_height_absolute {Linear Unit}:
          The height of each grid cell. The default is 2 in the units of the
          diagram's coordinate system."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyGridLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, cell_width_absolute, cell_height_absolute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyLinearDispatchLayout_un', None)
def ApplyLinearDispatchLayout(in_network_diagram_layer=None, junction_placement_type=None, is_unit_absolute=None, maximum_shift_absolute=None, maximum_shift_proportional=None, minimum_shift_absolute=None, minimum_shift_proportional=None, iterations_number=None, is_path_preserved=None, are_leaves_moved=None, are_leaves_expanded=None, expand_shift_absolute=None, expand_shift_proportional=None):
    """ApplyLinearDispatchLayout_un(in_network_diagram_layer, {junction_placement_type}, {is_unit_absolute}, {maximum_shift_absolute}, {maximum_shift_proportional}, {minimum_shift_absolute}, {minimum_shift_proportional}, {iterations_number}, {is_path_preserved}, {are_leaves_moved}, {are_leaves_expanded}, {expand_shift_absolute}, {expand_shift_proportional})

        Spaces out diagram junctions that are visually too close,
        overlapping, or coincident.If you have an open edit session, you must
        save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      junction_placement_type {String}:
          Specifies how the junctions will move.

          * EQUAL_DISTANCE-All junctions with two connected edges will move so
          the distances between them and their two connected junctions are
          equal. This is the default.

          * USER_DEFINE_DISTANCE-All junctions with two connected edges will
          move so there is a minimum distance (Minimum Shift value) between them
          and the other end of the edges they connect to. This occurs at the end
          of the layout execution.

          * ITERATIVE_DISTANCE-All the junctions with two connected edges will
          move slightly  according to the Number of Iterations and Maximum Shift
          parameter values.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      maximum_shift_absolute {Linear Unit}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect. The default is 2 in the
          units of the diagram's coordinate system. At the time this distance is
          reached, junctions are no longer moved during following iterations.
          This parameter is required when using the ITERATIVE_DISTANCE  junction
          placement type and working with absolute units.
      maximum_shift_proportional {Double}:
          The maximum distance the junctions with two connections can be spaced
          from the junctions to which they connect. The default is 2. At the
          time this distance is reached, junctions are no longer moved during
          the following iterations. This parameter is required when using the
          ITERATIVE_DISTANCE  junction placement type and working with
          proportional units.
      minimum_shift_absolute {Linear Unit}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2 units in the units of the diagram's
          coordinate system. When this parameter value is too large, the
          junctions with two connections are moved so the distances between each
          moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is required when
          using the USER_DEFINE_DISTANCE  junction placement type and working
          with absolute units.
      minimum_shift_proportional {Double}:
          The minimum distance that will separate each junction with two
          connected edges from its two edge extremities after the layout
          execution. The default is 2. When this parameter value is too large,
          the junctions with two connections are moved so the distances between
          each moved junction and its edge extremities are equal along the path
          defined by its two connected edges. This parameter is expected when
          using the USER_DEFINE_DISTANCE junction placement type and working
          with proportional units.
      iterations_number {Long}:
          The number of iterations to process. The default is 5. This parameter
          is required when using the ITERATIVE_DISTANCE  junction placement type
      is_path_preserved {Boolean}:
          Specifies how vertices along edges will be processed:

          *  PRESERVE_PATH-All vertices along the connected edges will be kept,
          and new vertices will be added at the moved junctions' original
          location. This is the default.

          *  IGNORE_PATH-Vertices along edges will not be preserved.
      are_leaves_moved {Boolean}:
          Specifies whether the leaf junctions-the junctions with one
          connection-can be moved during the algorithm execution:

          *  MOVE_LEAVES-Leaf junctions will be moved.

          *  DO_NOT_MOVE_LEAVES-Leaf junctions will not be moved. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      are_leaves_expanded {Boolean}:
          Specifies whether the leaf junctions can be expanded:

          *  EXPAND_LEAVES-The leaves can be expanded. The expand_shift_absolute
          value specifies the maximum distance those leaf junctions can be
          expanded away from the junctions to which they connect.

          *  DO_NOT_EXPAND_LEAVES-The leaves cannot be expanded. This is the
          default unless the specified input network diagram is based on a
          template for which the Linear Dispatch Layout algorithm has been
          configured with another parameter value.
      expand_shift_absolute {Linear Unit}:
          The maximum distance the leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 in the units of the
          diagram's coordinate system unless the specified input network diagram
          is based on a template for which the Linear Dispatch Layout algorithm
          has been configured with another parameter value. At the time this
          distance is reached, leaf nodes are no longer moved during the
          following iterations. This parameter is required when enabling the
          Expand leaves parameter and working with absolute units.
      expand_shift_proportional {Double}:
          The maximum distance the leaf junctions must be expanded from the
          junctions to which they connect. The default is 2 unless the specified
          input network diagram is based on a template for which the Linear
          Dispatch Layout algorithm has been configured with another parameter
          value. At the time this distance is reached, leaf nodes are no longer
          moved during the following iterations. This parameter is required when
          enabling the Expand leaves parameter and working with proportional
          units."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyLinearDispatchLayout_un(*gp_fixargs((in_network_diagram_layer, junction_placement_type, is_unit_absolute, maximum_shift_absolute, maximum_shift_proportional, minimum_shift_absolute, minimum_shift_proportional, iterations_number, is_path_preserved, are_leaves_moved, are_leaves_expanded, expand_shift_absolute, expand_shift_proportional), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMainRingLayout_un', None)
def ApplyMainRingLayout(in_network_diagram_layer=None, are_containers_preserved=None, ring_type=None, is_unit_absolute=None, ring_width_absolute=None, ring_width_proportional=None, ring_height_absolute=None, ring_height_proportional=None, tree_type=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, breakpoint_position=None, edge_display_type=None):
    """ApplyMainRingLayout_un(in_network_diagram_layer, {are_containers_preserved}, {ring_type}, {is_unit_absolute}, {ring_width_absolute}, {ring_width_proportional}, {ring_height_absolute}, {ring_height_proportional}, {tree_type}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {breakpoint_position}, {edge_display_type})

        Arranges the diagram features in a network diagram around a main
        ring.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      ring_type {String}:
          The type of ring.

          * ELLIPSE-The diagram features of the detected main ring will display
          along an ellipse. This is the default.

          * RECTANGLE-The diagram features of the detected main ring will
          display along a rectangle.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      ring_width_absolute {Linear Unit}:
          Specifies the width of the ring. The default is in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      ring_width_proportional {Double}:
          Specifies the width of the ring. The default is 50. This parameter is
          required when using proportional units.
      ring_height_absolute {Linear Unit}:
          Specifies the height of the ring. The default is in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      ring_height_proportional {Double}:
          Specifies the height of the ring. The default is 20. This parameter
          is required when using proportional units.
      tree_type {String}:
          Specifies how the trees coming out of the main ring's junctions will
          be positioned.

          * BOTH_SIDES-Each tree will be displayed along a main line, and its
          related branches will be arranged on both the left and right sides of
          this main line.

          * LEFT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the left side of
          this main line.

          * RIGHT_SIDE-Each tree will be displayed hierarchically along a main
          line, and its related branches will be arranged on the right side of
          this main line.

          * SMART_TREE-Each tree will be displayed hierarchically as a smart
          tree. This is the default.
      perpendicular_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the tree direction and belong to the same subtree
          level. The default is 2 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      perpendicular_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the tree direction and belong to the same subtree
          level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          along the tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          along the tree direction. The default is 2. This parameter is required
          when using proportional units.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMainRingLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, ring_type, is_unit_absolute, ring_width_absolute, ring_width_proportional, ring_height_absolute, ring_height_proportional, tree_type, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyMainlineTreeLayout_un', None)
def ApplyMainlineTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, branches_placement=None, is_unit_absolute=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """ApplyMainlineTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {branches_placement}, {is_unit_absolute}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Arranges diagram junctions and edges hierarchically along a main
        line.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the main line.

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_RIGHT_TO_LEFT-The main line will be drawn as a horizontal line
          starting from the right and ending on the left.

          * FROM_BOTTOM_TO_TOP-The main line will be drawn as a vertical line
          starting from the bottom and ending at the top.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      branches_placement {String}:
          Specifies how branches from the main line are relatively placed with
          regard to its direction.

          * BOTH_SIDES-Branches will be placed on both the left and right sides
          of the main line. This is the default.

          * LEFT_SIDE-Branches will only be placed on the left side of the main
          line.

          * RIGHT_SIDE-Branches will only be placed on the right side of the
          main line.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      perpendicular_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2 in the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          axis perpendicular to the main line. The default is 2. This parameter
          is required when using proportional units.
      along_absolute {Linear Unit}:
          The spacing between diagram junctions that are displayed along the
          main line. It also dictates the spacing between diagram junctions that
          are displayed along the axis parallel to this main line. This
          parameter is required when using absolute units. The default is 2 in
          the units of the diagram's coordinate system.
      along_proportional {Double}:
          The spacing between diagram junctions that are displayed along the
          main line and diagram junctions that are displayed along the axis
          parallel to this main line. This parameter is expected when using
          proportional units. The default is 2.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches
          display.This parameter is deprecated at ArcGIS Pro 2.3. It is
          systematically
          ignored regardless of its value when the edge_display_type is
          specified. However, to maintain compatibility with ArcGIS Pro 2.1, it
          remains enabled when the edge_display_type parameter is not specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyMainlineTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, branches_placement, is_unit_absolute, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyPartialOverlappingEdgesLayout_un', None)
def ApplyPartialOverlappingEdgesLayout(in_network_diagram_layer=None, buffer_width_absolute=None, offset_absolute=None, optimize_edges=None):
    """ApplyPartialOverlappingEdgesLayout_un(in_network_diagram_layer, buffer_width_absolute, offset_absolute, {optimize_edges})

        Spaces out collinear edges or collinear portions of edges (edge
        segments) inside a given buffer zone.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      buffer_width_absolute (Linear Unit):
          The width of the buffer zone in which to search for collinear edge
          segments.
      offset_absolute (Linear Unit):
          The distance that will separate the detected edge segments.
      optimize_edges {Boolean}:
          Specifies how segments are placed along edges:

          *  OPTIMIZE_EDGES-The placement of segments is optimized in each set
          of collinear segments. This is done by focusing on their connections
          instead of their positions. Segments that cross each other can be
          repositioned so they do not cross.

          *  DO_NOT_OPTIMIZE_EDGES-The initial position of each segment is
          maintained in the collinear segment set and crossings are preserved.
          This is the default option."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyPartialOverlappingEdgesLayout_un(*gp_fixargs((in_network_diagram_layer, buffer_width_absolute, offset_absolute, optimize_edges), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRadialTreeLayout_un', None)
def ApplyRadialTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, is_unit_absolute=None, initial_radius_absolute=None, initial_radius_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, radius_factor=None):
    """ApplyRadialTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {is_unit_absolute}, {initial_radius_absolute}, {initial_radius_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {radius_factor})

        Arranges diagram features hierarchically and places them in a radial
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      initial_radius_absolute {Linear Unit}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5 in the units of the diagram's coordinate
          system. This parameter is required when using absolute units.
      initial_radius_proportional {Double}:
          The radius of the first concentric circle whose center is the radial
          tree root junction; that is, the radius of the circle around which the
          diagram junctions belonging to the first hierarchical level are
          placed. The default is 5. This parameter is required when using
          proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      radius_factor {Double}:
          Represents the multiplicative factor used to increase or decrease the
          radius of each concentric circle. It also represents the distance that
          separates each concentric circle related to a hierarchical level. When
          using a radius factor less than 1, the distance that separates the
          diagram junctions belonging to the (n) hierarchical level and the
          (n+1) hierarchical level progressively decreases. With a factor
          greater than 1, the distance between the hierarchical levels increases
          progressively. The default is 1."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRadialTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, is_unit_absolute, initial_radius_absolute, initial_radius_proportional, disjoined_graph_absolute, disjoined_graph_proportional, radius_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRelativeMainlineLayout_un', None)
def ApplyRelativeMainlineLayout(in_network_diagram_layer=None, line_attribute=None, mainline_direction=None, offset_between_branches=None, breakpoint_angle=None, type_attribute=None, mainline_values=None, branch_values=None, excluded_values=None, is_compressing=None, compression_ratio=None, minimal_distance=None, alignment_attribute=None, initial_distances=None, length_attribute=None):
    """ApplyRelativeMainlineLayout_un(in_network_diagram_layer, line_attribute, {mainline_direction}, {offset_between_branches}, {breakpoint_angle}, {type_attribute}, {mainline_values;mainline_values...}, {branch_values;branch_values...}, {excluded_values;excluded_values...}, {is_compressing}, {compression_ratio}, {minimal_distance}, {alignment_attribute}, {initial_distances}, {length_attribute})

        Arranges the network diagram features in the active diagram along
        parallel straight lines.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      line_attribute (String):
          The name of the network attribute that will be used to identify the
          lines that comprise the straight lines. This network attribute must
          exist in the utility network line classes. Its values should be the
          same for all the edges that comprise a straight line, for example,
          Line 1, Line 2, and so on
      mainline_direction {String}:
          The direction of the main line

          * FROM_LEFT_TO_RIGHT-The main line will be drawn as a horizontal line
          starting from the left and ending on the right. This is the default.

          * FROM_TOP_TO_BOTTOM-The main line will be drawn as a vertical line
          starting from the top and ending at the bottom.
      offset_between_branches {Linear Unit}:
          The spacing between two adjacent branches along the axis
          perpendicular to the direction of the lines.
      breakpoint_angle {Double}:
          The angle that will be used to position the break point on the
          branches. It is a value between 30 and 90 degrees that is combined
          with the offset_between_branches parameter value to compute this
          position. When the break point angle value is 90 degrees, each branch
          displays orthogonally.
      type_attribute {String}:
          The name of the network attribute that will be used to qualify the
          lines. This network attribute may exist in the utility network line
          classes.The type_attribute and line_attribute network attributes can
          be the
          same.
      mainline_values {Value Table}:
          The type_attribute values that identify the main lines. When such
          values exist, they must be the same for any edge that comprises the
          main lines, regardless of their related utility network feature
          classes.
      branch_values {Value Table}:
          The type_attribute values that identify the branches.
      excluded_values {Value Table}:
          The type_attribute values that identify the edges that must be
          excluded from the straight lines (crossovers or ladders).
      is_compressing {Boolean}:
          Specifies whether the graph will be compressed.

          * USE_COMPRESSION-An additional step is executed at the end of the
          process to reduce the distances between adjacent groups of neighbor
          junctions along the direction while trying to maintain relative
          positioning between these groups. Neighbor junctions are junctions
          that are geographically close to each other without being directly
          connected.

          * DO_NOT_USE_COMPRESSION-Compression will not be used. This is the
          default.
      compression_ratio {Double}:
          A value between 0 and 100 that is applied to the length of any edge
          after subtracting the minimal distance of its length. When
          compression_ratio is 100, the distance between each detected junction
          group is equal to the minimal distance.
      minimal_distance {Linear Unit}:
          The minimal distance between two adjacent groups of neighbor
          junctions. This minimal distance is also used to group neighbor
          junctions regarding their projection along the direction axis. Two
          junctions projected on this axis will belong to the same group when
          the distance between the two projected points is less than this
          distance.
      alignment_attribute {String}:
          The name of the network attribute that will be used to align lines
          that are split. The algorithm aligns the line with the same attribute
          value.
      initial_distances {String}:
          Specifies how the length of the diagram edges will be assessed. This
          length determines the positions of the junctions along the direction.
          The distances between the connected junctions along the direction are
          not equidistant; they are relative to each other and depend on the
          current edge length and the length of the shortest edge.

          * FROM_CURRENT_EDGE_GEOMETRY-The distances will be computed from the
          current edge geometry. This is the default.

          * FROM_ATTRIBUTE_EDGE-The distances will be computed from a given
          attribute that exists on an edge.
      length_attribute {String}:
          The network attribute from which the distances will be computed when
          initial_distances is FROM_ATTRIBUTE_EDGE."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRelativeMainlineLayout_un(*gp_fixargs((in_network_diagram_layer, line_attribute, mainline_direction, offset_between_branches, breakpoint_angle, type_attribute, mainline_values, branch_values, excluded_values, is_compressing, compression_ratio, minimal_distance, alignment_attribute, initial_distances, length_attribute), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyRotateTreeLayout_un', None)
def ApplyRotateTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, rotation_angle=None):
    """ApplyRotateTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {rotation_angle})

        Rotates the tree or trees related to pivot junctions currently set up
        in a diagram to the specified angle.If you have an open edit session,
        you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      rotation_angle {Double}:
          The angle in degrees that will be used to rotate the tree. The default
          is 45 degrees."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyRotateTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, rotation_angle), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySmartTreeLayout_un', None)
def ApplySmartTreeLayout(in_network_diagram_layer=None, are_containers_preserved=None, tree_direction=None, is_unit_absolute=None, subtree_absolute=None, subtree_proportional=None, perpendicular_absolute=None, perpendicular_proportional=None, along_absolute=None, along_proportional=None, disjoined_graph_absolute=None, disjoined_graph_proportional=None, are_edges_orthogonal=None, breakpoint_position=None, edge_display_type=None):
    """ApplySmartTreeLayout_un(in_network_diagram_layer, {are_containers_preserved}, {tree_direction}, {is_unit_absolute}, {subtree_absolute}, {subtree_proportional}, {perpendicular_absolute}, {perpendicular_proportional}, {along_absolute}, {along_proportional}, {disjoined_graph_absolute}, {disjoined_graph_proportional}, {are_edges_orthogonal}, {breakpoint_position}, {edge_display_type})

        Arranges diagram features hierarchically and places them in a smart
        tree.If you have an open edit session, you must save your edits prior
        to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      tree_direction {String}:
          The direction of the tree.

          * FROM_LEFT_TO_RIGHT-The tree will be drawn from left to right. This
          is the default.

          * FROM_RIGHT_TO_LEFT-The tree will be drawn from right to left.

          * FROM_BOTTOM_TO_TOP-The tree will be drawn from bottom to top.

          * FROM_TOP_TO_BOTTOM-The tree will be drawn from top to bottom.
      is_unit_absolute {Boolean}:
          Specifies how parameters representing distances will be interpreted.

          *  ABSOLUTE_UNIT-The layout algorithm will interpret any distance
          values as linear units.

          *  PROPORTIONAL_UNIT-The layout algorithm will interpret any distance
          values as relative units to an estimation of the average of the
          junction sizes in the diagram when it is generated. This is the
          default.
      subtree_absolute {Linear Unit}:
          Determines the spacing between two neighboring subtrees; that is, the
          spacing between diagram junctions that are displayed perpendicular to
          the smart tree direction and belong to a different subtree. The
          default is in the units of the diagram's coordinate system. This
          parameter is required when using absolute units.
      subtree_proportional {Double}:
          Determines the spacing between two neighboring subtrees; that is, the
          spacing between diagram junctions that are displayed perpendicular to
          the smart tree direction and belong to a different subtree. The
          default is 2. This parameter is required when using proportional
          units.
      perpendicular_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2 in the units of the diagram's
          coordinate system. This parameter is required when using absolute
          units.
      perpendicular_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          perpendicular to the smart tree direction and belong to the same
          subtree level. The default is 2. This parameter is required when using
          proportional units.
      along_absolute {Linear Unit}:
          Specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2 in the units of the
          diagram's coordinate system. This parameter is required when using
          absolute units.
      along_proportional {Double}:
          Specifies the spacing between diagram junctions that are displayed
          along the smart tree direction. The default is 2. This parameter is
          required when using proportional units.
      disjoined_graph_absolute {Linear Unit}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using absolute units. The default is 4 in the units
          of the diagram's coordinate system.
      disjoined_graph_proportional {Double}:
          The minimum spacing that must separate features belonging to
          disjoined graphs when the diagram contains such graphs. This parameter
          is required when using proportional units. The default is 4.
      are_edges_orthogonal {Boolean}:
          Specifies how diagram edges that are related to the tree branches
          display.This parameter is deprecated at ArcGIS Pro 2.3. It is
          systematically
          ignored regardless of its value when the edge_display_type is
          specified. However, to maintain compatibility with ArcGIS Pro 2.1, it
          remains enabled when the edge_display_type parameter is not specified.

          *  ORTHOGONAL_EDGES-All diagram edges related to the tree branches
          will display with right angles.

          *  SLANTED_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.
      breakpoint_position {Double}:
          The relative position of the break point that will be inserted along
          the diagram edges when edge_display_type = REGULAR_EDGES or
          edge_display_type = ORTHOGONAL_EDGES. It is a percentage between 0 and
          100.

          * With a Break Point Relative Position (%) value of 0, the break point
          is positioned at the x-coordinate of the edge's from junction and at
          the y-coordinate of the edge's to junction for a horizontal tree. It
          is positioned at the y-coordinate of the edge's from junction and at
          the x-coordinate of the edge's to junction for a vertical tree.

          * With a Break Point Relative Position (%) value of 100, there is no
          break point inserted on the diagram edges; each diagram edge directly
          connects its from and to junctions.

          * With a Break Point Relative Position (%) value of N between 0 and
          100, the break point is positioned at N% of the length of the [XY]
          segment, X being the x-coordinate of the edge's from junction and Y
          being the y-coordinate of the edge's to junction for a horizontal
          tree. It is positioned at N% of the length of the [YX] segment, Y
          being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree.
          The relative position of the two inflexion points that will be
          inserted along the diagram edges to compute the curved edges geometry
          when edge_display_type = CURVED_EDGES. It is a percentage between 15
          and 40. With a Break Point Relative Position (%) value of N between 15
          and 40:

          * X being the x-coordinate of the edge's from junction and Y being the
          y-coordinate of the edge's to junction for a horizontal tree:

          * The first inflexion point will be positioned at N% of the length of
          the [XY] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          * Y being the y-coordinate of the edge's from junction and X being the
          x-coordinate of the edge's to junction for a vertical tree:

          * The first inflexion point will be positioned at N% of the length of
          the [YX] segment.

          * The second inflexion point will be positioned at (100 - N)% of the
          length of the [XY] segment.

          The notion of the from and to junctions above is relative to the tree
          direction; it has nothing to do with the real topology of the network
          feature edge.
      edge_display_type {String}:
          The type of display for the diagram edges related to the tree
          branches.

          * REGULAR_EDGES-All diagram edges related to the tree branches do not
          display with right angles. This is the default.

          * ORTHOGONAL_EDGES-All diagram edges related to the tree branches will
          display with right angles.

          * CURVED_EDGES-All diagram edges related to the tree branches will be
          curved."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySmartTreeLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, tree_direction, is_unit_absolute, subtree_absolute, subtree_proportional, perpendicular_absolute, perpendicular_proportional, along_absolute, along_proportional, disjoined_graph_absolute, disjoined_graph_proportional, are_edges_orthogonal, breakpoint_position, edge_display_type), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplySpatialDispatchLayout_un', None)
def ApplySpatialDispatchLayout(in_network_diagram_layer=None, are_containers_preserved=None, iterations_number=None, maximum_shift_factor=None):
    """ApplySpatialDispatchLayout_un(in_network_diagram_layer, {are_containers_preserved}, {iterations_number}, {maximum_shift_factor})

        Separates diagram junctions that are visibly close to overlapping.If
        you have an open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      iterations_number {Long}:
          The number of iterations to process. The default is 5.
      maximum_shift_factor {Double}:
          Increases the diagram junctions' displacement for junctions that are
          very close together. The larger the shift factor, the larger the
          separation between the diagram junctions that almost overlap. The
          default is 2."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplySpatialDispatchLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, iterations_number, maximum_shift_factor), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ApplyTemplateLayouts_un', None)
def ApplyTemplateLayouts(in_network_diagram_layer=None):
    """ApplyTemplateLayouts_un(in_network_diagram_layer)

        Applies the list of layout algorithms currently configured for the
        diagram template to the input network diagram layer.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ApplyTemplateLayouts_un(*gp_fixargs((in_network_diagram_layer,), True)))
        return retval
    except Exception as e:
        raise e

@gptooldoc('ReshapeDiagramEdgesLayout_un', None)
def ReshapeDiagramEdgesLayout(in_network_diagram_layer=None, are_containers_preserved=None, reshape_type=None, is_path_preserved=None, offset_between_segment_absolute=None, breakpoint_absolute=None, shift_between_edge_absolute=None, angle_threshold=None, circular_arc_radius=None, circular_arc_position=None):
    """ReshapeDiagramEdgesLayout_un(in_network_diagram_layer, {are_containers_preserved}, {reshape_type}, {is_path_preserved}, {offset_between_segment_absolute}, {breakpoint_absolute}, {shift_between_edge_absolute}, {angle_threshold}, {circular_arc_radius}, {circular_arc_position})

        Processes simple operations on vertices along edges.If you have an
        open edit session, you must save your edits prior to
        running this tool. This ensures the diagram reflects the latest
        changes made to the network topology in the database. If you fail to
        save your edits, the edits will not be reflected in the diagram.Each
        layout algorithm includes default parameter values. The default
        parameter values will be used unless otherwise specified. If the input
        network diagram is based on a template for which this layout has been
        configured with a different parameter value, that value is used
        instead.

     INPUTS:
      in_network_diagram_layer (Diagram Layer):
          The network diagram where the layout will be applied.
      are_containers_preserved {Boolean}:
          Specifies how containers will be processed by the algorithm.

          * PRESERVE_CONTAINERS-The layout algorithm executes on the top graph
          of the diagram so containers are preserved.

          * IGNORE_CONTAINERS-The layout algorithm executes on both content and
          noncontent features in the diagram. This is the default.
      reshape_type {String}:
          Specifies how edges will be reshaped.

          * REMOVE_VERTICES-Removes all vertices along any edges in the diagram.

          * SQUARE_EDGES-Inserts vertices along diagram edges so these edges are
          displayed with right angles. This is the default.

          * SEPARATE_OVERLAPPING_EDGES-Separates edges that connect the same
          origin and extremity junctions when they are overlapping.

          * REDUCE_VERTICES_BY_ANGLE-Removes some or all vertices displayed
          along diagram edges according to the angle that separates the segments
          incident to those vertices.

          * MARK_CROSSING_EDGES-Detects the horizontal and vertical diagram
          edges that cross each other at a right angle in the diagram and
          reshapes one of the crossing edges' geometry to display a circular arc
          at this location.
      is_path_preserved {Boolean}:
          Specifies whether or not the vertices along the edges that are going
          to be squared will be preserved. This parameter is required when
          reshape_type is set to SQUARE_EDGES.

          *  PRESERVE_PATH-The direction of any edge will be considered and
          vertices along that edge will be preserved, from the first vertex to
          the last. This is the default.

          * IGNORE_PATH-Vertices along the diagram edges will not be considered,
          and the vertices will be removed during execution.
      offset_between_segment_absolute {Linear Unit}:
          The spacing that will separate parallel segments of squared edges
          incident to the same junction. The default is 5 in the units of the
          diagram's coordinate system. This parameter is required when
          reshape_type is set to SQUARE_EDGES.
      breakpoint_absolute {Linear Unit}:
          The maximum distance between each junction to the first or last break
          point along edges incident to that junction when those edges are
          squared. The default is 8.66 in the units of the diagram's coordinate
          system. This parameter is required when reshape_type is set to
          SQUARE_EDGES.
      shift_between_edge_absolute {Linear Unit}:
          The absolute spacing that will separate two edges. The default is 0.5
          in the units of the diagram's coordinate system. This parameter is
          required when setting reshape_type to SEPARATE_OVERLAPPING_EDGES.
      angle_threshold {Double}:
          The angle formed by the incident segments over which the vertex
          related to these segments is reduced. The wider the angle, the fewer
          vertices are reduced. The default is 160 degrees. This parameter is
          required when setting reshape_type to REDUCE_VERTICES_BY_ANGLE.
      circular_arc_radius {Linear Unit}:
          The radius of the circular arc that will be added at the crossing
          edge locations. The default is 5.
      circular_arc_position {String}:
          Specifies the segment on which the circular arc will be inserted.

          * LEFT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the left
          of the vertical segment.

          * RIGHT_OF_VERTICAL_SEGMENT-A circular arc will be placed to the right
          of the vertical segment.

          * ABOVE_HORIZONTAL_SEGMENT-A circular arc will be placed above the
          horizontal segment.

          * BELOW_HORIZONTAL_SEGMENT-A circular arc will be placed below the
          horizontal segment."""
    from arcpy.geoprocessing._base import gp, gp_fixargs
    from arcpy.arcobjects.arcobjectconversion import convertArcObjectToPythonObject
    try:
        retval = convertArcObjectToPythonObject(gp.ReshapeDiagramEdgesLayout_un(*gp_fixargs((in_network_diagram_layer, are_containers_preserved, reshape_type, is_path_preserved, offset_between_segment_absolute, breakpoint_absolute, shift_between_edge_absolute, angle_threshold, circular_arc_radius, circular_arc_position), True)))
        return retval
    except Exception as e:
        raise e


# End of generated toolbox code
del gptooldoc, gp, gp_fixargs, convertArcObjectToPythonObject